Method: Google::Api::ClientLibrarySettings#version

Defined in:
proto_docs/google/api/client.rb

#version::String

Returns Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud.speech.v1" and "google.spanner.admin.database.v1".

Returns:

  • (::String)

    Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud.speech.v1" and "google.spanner.admin.database.v1".



76
77
78
79
# File 'proto_docs/google/api/client.rb', line 76

class ClientLibrarySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end