Class: Google::Cloud::Compute::V1::AcceleratorTopologiesInfoAcceleratorTopologyInfoInfoPerTopologyState

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Info for each topology state.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#count::Integer

Returns The number of accelerator topologies in this state.

Returns:

  • (::Integer)

    The number of accelerator topologies in this state.



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 167

class AcceleratorTopologiesInfoAcceleratorTopologyInfoInfoPerTopologyState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is available.
    AVAILABLE = 442_079_913

    # The accelerator topology is degraded. The underlying capacity is not in a
    # healthy state and is not available.
    DEGRADED = 396_890_926

    # The accelerator topology is running. If there are both running and
    # degraded hosts within a topology, DEGRADED state will be returned.
    RUNNING = 121_282_975

    # The state of the topology is unspecified.
    TOPOLOGY_STATE_UNSPECIFIED = 188_327_545

    # This value has been deprecated and is no longer used.
    UNHEALTHY = 462_118_084
  end
end

#state::String

Returns The state of the accelerator topology. Check the State enum for the list of possible values.

Returns:

  • (::String)

    The state of the accelerator topology. Check the State enum for the list of possible values.



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 167

class AcceleratorTopologiesInfoAcceleratorTopologyInfoInfoPerTopologyState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is available.
    AVAILABLE = 442_079_913

    # The accelerator topology is degraded. The underlying capacity is not in a
    # healthy state and is not available.
    DEGRADED = 396_890_926

    # The accelerator topology is running. If there are both running and
    # degraded hosts within a topology, DEGRADED state will be returned.
    RUNNING = 121_282_975

    # The state of the topology is unspecified.
    TOPOLOGY_STATE_UNSPECIFIED = 188_327_545

    # This value has been deprecated and is no longer used.
    UNHEALTHY = 462_118_084
  end
end