Class: Google::Cloud::Compute::V1::Accelerators

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#guest_accelerator_count ⇒ ::Integer

Returns Number of accelerator cards exposed to the guest.

Returns:

  • (::Integer) —

    Number of accelerator cards exposed to the guest.



329
330
331
332
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 329

class Accelerators
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#guest_accelerator_type ⇒ ::String

Returns The accelerator type resource name, not a full URL, e.g.nvidia-tesla-t4.

Returns:

  • (::String) —

    The accelerator type resource name, not a full URL, e.g.nvidia-tesla-t4.



329
330
331
332
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 329

class Accelerators
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end