Class: Google::Cloud::Compute::V1::AccessConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

An access configuration attached to an instance's network interface. Only one access config per instance is supported.

Defined Under Namespace

Modules: NetworkTier, Type

Instance Attribute Summary collapse

Instance Attribute Details

#external_ipv6::String

Returns Applies to ipv6AccessConfigs only. The first IPv6 address of the external IPv6 range associated with this instance, prefix length is stored inexternalIpv6PrefixLength in ipv6AccessConfig. To use a static external IP address, it must be unused and in the same region as the instance's zone. If not specified, Google Cloud will automatically assign an external IPv6 address from the instance's subnetwork.

Returns:

  • (::String)

    Applies to ipv6AccessConfigs only. The first IPv6 address of the external IPv6 range associated with this instance, prefix length is stored inexternalIpv6PrefixLength in ipv6AccessConfig. To use a static external IP address, it must be unused and in the same region as the instance's zone. If not specified, Google Cloud will automatically assign an external IPv6 address from the instance's subnetwork.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end

#external_ipv6_prefix_length::Integer

Returns Applies to ipv6AccessConfigs only. The prefix length of the external IPv6 range.

Returns:

  • (::Integer)

    Applies to ipv6AccessConfigs only. The prefix length of the external IPv6 range.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#accessConfig for access configs.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Alwayscompute#accessConfig for access configs.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end

#name::String

Returns The name of this access configuration. In accessConfigs (IPv4), the default and recommended name is External NAT, but you can use any arbitrary string, such as My external IP orNetwork Access. In ipv6AccessConfigs, the recommend name is External IPv6.

Returns:

  • (::String)

    The name of this access configuration. In accessConfigs (IPv4), the default and recommended name is External NAT, but you can use any arbitrary string, such as My external IP orNetwork Access. In ipv6AccessConfigs, the recommend name is External IPv6.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end

#nat_i_p::String

Returns Applies to accessConfigs (IPv4) only. Anexternal IP address associated with this instance. Specify an unused static external IP address available to the project or leave this field undefined to use an IP from a shared ephemeral IP address pool. If you specify a static external IP address, it must live in the same region as the zone of the instance.

Returns:

  • (::String)

    Applies to accessConfigs (IPv4) only. Anexternal IP address associated with this instance. Specify an unused static external IP address available to the project or leave this field undefined to use an IP from a shared ephemeral IP address pool. If you specify a static external IP address, it must live in the same region as the zone of the instance.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end

#network_tier::String

Returns This signifies the networking tier used for configuring this access configuration and can only take the following values: PREMIUM,STANDARD.

If an AccessConfig is specified without a valid external IP address, an ephemeral IP will be created with this networkTier.

If an AccessConfig with a valid external IP address is specified, it must match that of the networkTier associated with the Address resource owning that IP. Check the NetworkTier enum for the list of possible values.

Returns:

  • (::String)

    This signifies the networking tier used for configuring this access configuration and can only take the following values: PREMIUM,STANDARD.

    If an AccessConfig is specified without a valid external IP address, an ephemeral IP will be created with this networkTier.

    If an AccessConfig with a valid external IP address is specified, it must match that of the networkTier associated with the Address resource owning that IP. Check the NetworkTier enum for the list of possible values.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end

#public_ptr_domain_name::String

Returns The DNS domain name for the public PTR record.

You can set this field only if the setPublicPtr field is enabled inaccessConfig. If this field is unspecified inipv6AccessConfig, a default PTR record will be created for first IP in associated external IPv6 range.

Returns:

  • (::String)

    The DNS domain name for the public PTR record.

    You can set this field only if the setPublicPtr field is enabled inaccessConfig. If this field is unspecified inipv6AccessConfig, a default PTR record will be created for first IP in associated external IPv6 range.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end

#security_policy::String

Returns The resource URL for the security policy associated with this access config.

Returns:

  • (::String)

    The resource URL for the security policy associated with this access config.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end

#set_public_ptr::Boolean

Returns Specifies whether a public DNS 'PTR' record should be created to map the external IP address of the instance to a DNS domain name.

This field is not used in ipv6AccessConfig. A default PTR record will be created if the VM has external IPv6 range associated.

Returns:

  • (::Boolean)

    Specifies whether a public DNS 'PTR' record should be created to map the external IP address of the instance to a DNS domain name.

    This field is not used in ipv6AccessConfig. A default PTR record will be created if the VM has external IPv6 range associated.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end

#type::String

Returns The type of configuration. In accessConfigs (IPv4), the default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    The type of configuration. In accessConfigs (IPv4), the default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6. Check the Type enum for the list of possible values.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 392

class AccessConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This signifies the networking tier used for configuring this access
  # configuration and can only take the following values: PREMIUM,STANDARD.
  #
  # If an AccessConfig is specified without a valid external IP address, an
  # ephemeral IP will be created with this networkTier.
  #
  # If an AccessConfig with a valid external IP address is specified, it must
  # match that of the networkTier associated with the Address resource owning
  # that IP.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The type of configuration. In accessConfigs (IPv4), the
  # default and only option is ONE_TO_ONE_NAT. Inipv6AccessConfigs, the default and only option isDIRECT_IPV6.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    DIRECT_IPV6 = 4_397_213

    ONE_TO_ONE_NAT = 84_090_205
  end
end