Module: Google::Cloud::Compute::V1::Address::AddressType

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The type of address to reserve, either INTERNAL or EXTERNAL. If unspecified, defaults to EXTERNAL.

Constant Summary collapse

UNDEFINED_ADDRESS_TYPE =

A value indicating that the enum field is not set.

0
EXTERNAL =

A publicly visible external IP address.

35_607_499
INTERNAL =

A private network IP address, for use with an Instance or Internal Load Balancer forwarding rule.

279_295_677
UNSPECIFIED_TYPE =
53_933_922