Module: Google::Cloud::Compute::V1::Address::Purpose

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The purpose of this resource, which can be one of the following values:

 - GCE_ENDPOINT for addresses that are used by VM
 instances, alias IP ranges, load balancers, and similar resources.
 - DNS_RESOLVER for a DNS resolver address in a subnetwork
   for a Cloud DNS  inbound
   forwarder IP addresses (regional internal IP address in a subnet of
   a VPC network)
 - VPC_PEERING for global internal IP addresses used for

      private services access allocated ranges.
 - NAT_AUTO for the regional external IP addresses used by
      Cloud NAT when allocating addresses using

      automatic NAT IP address allocation.
 - IPSEC_INTERCONNECT for addresses created from a private
 IP range that are reserved for a VLAN attachment in an
 *HA VPN over Cloud Interconnect* configuration. These addresses
 are regional resources.
 - `SHARED_LOADBALANCER_VIP` for an internal IP address that is assigned
 to multiple internal forwarding rules.
 - `PRIVATE_SERVICE_CONNECT` for a private network address that is
 used to configure Private Service Connect. Only global internal addresses
 can use this purpose.

Constant Summary collapse

UNDEFINED_PURPOSE =

A value indicating that the enum field is not set.

0
DNS_RESOLVER =

DNS resolver address in the subnetwork.

476_114_556
GCE_ENDPOINT =

VM internal/alias IP, Internal LB service IP, etc.

230_515_243
IPSEC_INTERCONNECT =

A regional internal IP address range reserved for the VLAN attachment that is used in HA VPN over Cloud Interconnect. This regional internal IP address range must not overlap with any IP address range of subnet/route in the VPC network and its peering networks. After the VLAN attachment is created with the reserved IP address range, when creating a new VPN gateway, its interface IP address is allocated from the associated VLAN attachment’s IP address range.

340_437_251
NAT_AUTO =

External IP automatically reserved for Cloud NAT.

163_666_477
PRIVATE_SERVICE_CONNECT =

A private network IP address that can be used to configure Private Service Connect. This purpose can be specified only forGLOBAL addresses of Type INTERNAL

48_134_724
SERVERLESS =

A regional internal IP address range reserved for Serverless.

270_492_508
SHARED_LOADBALANCER_VIP =

A private network IP address that can be shared by multiple Internal Load Balancer forwarding rules.

294_447_572
VPC_PEERING =

IP range for peer networks.

400_800_170