Method: Google::Cloud::Compute::V1::Address#subnetwork

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

#subnetwork::String

Returns The URL of the subnetwork in which to reserve the address. If an IP address is specified, it must be within the subnetwork's IP range. This field can only be used with INTERNAL type with a GCE_ENDPOINT or DNS_RESOLVER purpose.

Returns:

  • (::String)

    The URL of the subnetwork in which to reserve the address. If an IP address is specified, it must be within the subnetwork's IP range. This field can only be used with INTERNAL type with a GCE_ENDPOINT or DNS_RESOLVER purpose.



783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 783

class Address
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of address to reserve, either INTERNAL or EXTERNAL. If unspecified, defaults to EXTERNAL.
  module AddressType
    # A value indicating that the enum field is not set.
    UNDEFINED_ADDRESS_TYPE = 0

    # A publicly visible external IP address.
    EXTERNAL = 35_607_499

    # A private network IP address, for use with an Instance or Internal Load Balancer forwarding rule.
    INTERNAL = 279_295_677

    UNSPECIFIED_TYPE = 53_933_922
  end

  # The IP version that will be used by this address. Valid options are IPV4 or IPV6.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    UNSPECIFIED_VERSION = 21_850_000
  end

  # The endpoint type of this address, which should be VM or NETLB. This is used for deciding which type of endpoint this address can be used after the external IPv6 address reservation.
  module Ipv6EndpointType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ENDPOINT_TYPE = 0

    # Reserved IPv6 address can be used on network load balancer.
    NETLB = 74_173_363

    # Reserved IPv6 address can be used on VM.
    VM = 2743
  end

  # This signifies the networking tier used for configuring this address and can only take the following values: PREMIUM or STANDARD. Internal IP addresses are always Premium Tier; global external IP addresses are always Premium Tier; regional external IP addresses can be either Standard or Premium Tier. If this field is not specified, it is assumed to be PREMIUM.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # The purpose of this resource, which can be one of the following values: - GCE_ENDPOINT for addresses that are used by VM instances, alias IP ranges, load balancers, and similar resources. - DNS_RESOLVER for a DNS resolver address in a subnetwork for a Cloud DNS inbound forwarder IP addresses (regional internal IP address in a subnet of a VPC network) - VPC_PEERING for global internal IP addresses used for private services access allocated ranges. - NAT_AUTO for the regional external IP addresses used by Cloud NAT when allocating addresses using automatic NAT IP address allocation. - IPSEC_INTERCONNECT for addresses created from a private IP range that are reserved for a VLAN attachment in an *HA VPN over Cloud Interconnect* configuration. These addresses are regional resources. - `SHARED_LOADBALANCER_VIP` for an internal IP address that is assigned to multiple internal forwarding rules. - `PRIVATE_SERVICE_CONNECT` for a private network address that is used to configure Private Service Connect. Only global internal addresses can use this purpose.
  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # DNS resolver address in the subnetwork.
    DNS_RESOLVER = 476_114_556

    # VM internal/alias IP, Internal LB service IP, etc.
    GCE_ENDPOINT = 230_515_243

    # A regional internal IP address range reserved for the VLAN attachment that is used in HA VPN over Cloud Interconnect. This regional internal IP address range must not overlap with any IP address range of subnet/route in the VPC network and its peering networks. After the VLAN attachment is created with the reserved IP address range, when creating a new VPN gateway, its interface IP address is allocated from the associated VLAN attachment’s IP address range.
    IPSEC_INTERCONNECT = 340_437_251

    # External IP automatically reserved for Cloud NAT.
    NAT_AUTO = 163_666_477

    # A private network IP address that can be used to configure Private Service Connect. This purpose can be specified only for GLOBAL addresses of Type INTERNAL
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # A regional internal IP address range reserved for Serverless.
    SERVERLESS = 270_492_508

    # A private network IP address that can be shared by multiple Internal Load Balancer forwarding rules.
    SHARED_LOADBALANCER_VIP = 294_447_572

    # IP range for peer networks.
    VPC_PEERING = 400_800_170
  end

  # [Output Only] The status of the address, which can be one of RESERVING, RESERVED, or IN_USE. An address that is RESERVING is currently in the process of being reserved. A RESERVED address is currently reserved and available to use. An IN_USE address is currently being used by another resource and is not available.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Address is being used by another resource and is not available.
    IN_USE = 17_393_485

    # Address is reserved and available to use.
    RESERVED = 432_241_448

    # Address is being reserved.
    RESERVING = 514_587_225
  end
end