Module: Google::Cloud::Compute::V1::AggregatedListSubnetworksRequest::Views
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Defines the extra views returned back in the subnetwork resource. Supported values:
- WITH_UTILIZATION: Utilization data is included in the response.
Constant Summary collapse
- UNDEFINED_VIEWS =
A value indicating that the enum field is not set.
0- DEFAULT =
115_302_945- WITH_UTILIZATION =
Utilization data is included in the response.
504_090_633