Class: Google::Cloud::Compute::V1::AllocationAggregateReservation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation.

Defined Under Namespace

Modules: VmFamily, WorkloadType

Instance Attribute Summary collapse

Instance Attribute Details

#in_use_resources ⇒ ::Array<::Google::Cloud::Compute::V1::AllocationAggregateReservationReservedResourceInfo>

Returns Output only. [Output only] List of resources currently in use.

Returns:



7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
7884
7885
7886
7887
7888
7889
7890
7891
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7849

class AllocationAggregateReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The VM family that all instances scheduled against this reservation must
  # belong to.
  module VmFamily
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_FAMILY = 0

    VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948

    VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067

    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267

    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438

    VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888
  end

  # The workload type of the instances that will target this reservation.
  module WorkloadType
    # A value indicating that the enum field is not set.
    UNDEFINED_WORKLOAD_TYPE = 0

    # Reserved resources will be optimized for BATCH workloads, such as ML
    # training.
    BATCH = 62_971_674

    # Reserved resources will be optimized for SERVING workloads, such as ML
    # inference.
    SERVING = 17_781_740

    UNSPECIFIED = 526_786_327
  end
end

#reserved_resources ⇒ ::Array<::Google::Cloud::Compute::V1::AllocationAggregateReservationReservedResourceInfo>

Returns List of reserved resources (CPUs, memory, accelerators).

Returns:



7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
7884
7885
7886
7887
7888
7889
7890
7891
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7849

class AllocationAggregateReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The VM family that all instances scheduled against this reservation must
  # belong to.
  module VmFamily
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_FAMILY = 0

    VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948

    VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067

    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267

    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438

    VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888
  end

  # The workload type of the instances that will target this reservation.
  module WorkloadType
    # A value indicating that the enum field is not set.
    UNDEFINED_WORKLOAD_TYPE = 0

    # Reserved resources will be optimized for BATCH workloads, such as ML
    # training.
    BATCH = 62_971_674

    # Reserved resources will be optimized for SERVING workloads, such as ML
    # inference.
    SERVING = 17_781_740

    UNSPECIFIED = 526_786_327
  end
end

#vm_family ⇒ ::String

Returns The VM family that all instances scheduled against this reservation must belong to. Check the VmFamily enum for the list of possible values.

Returns:

  • (::String) —

    The VM family that all instances scheduled against this reservation must belong to. Check the VmFamily enum for the list of possible values.



7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
7884
7885
7886
7887
7888
7889
7890
7891
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7849

class AllocationAggregateReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The VM family that all instances scheduled against this reservation must
  # belong to.
  module VmFamily
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_FAMILY = 0

    VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948

    VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067

    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267

    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438

    VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888
  end

  # The workload type of the instances that will target this reservation.
  module WorkloadType
    # A value indicating that the enum field is not set.
    UNDEFINED_WORKLOAD_TYPE = 0

    # Reserved resources will be optimized for BATCH workloads, such as ML
    # training.
    BATCH = 62_971_674

    # Reserved resources will be optimized for SERVING workloads, such as ML
    # inference.
    SERVING = 17_781_740

    UNSPECIFIED = 526_786_327
  end
end

#workload_type ⇒ ::String

Returns The workload type of the instances that will target this reservation. Check the WorkloadType enum for the list of possible values.

Returns:

  • (::String) —

    The workload type of the instances that will target this reservation. Check the WorkloadType enum for the list of possible values.



7849
7850
7851
7852
7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
7871
7872
7873
7874
7875
7876
7877
7878
7879
7880
7881
7882
7883
7884
7885
7886
7887
7888
7889
7890
7891
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7849

class AllocationAggregateReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The VM family that all instances scheduled against this reservation must
  # belong to.
  module VmFamily
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_FAMILY = 0

    VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948

    VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067

    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267

    VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407

    VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438

    VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888
  end

  # The workload type of the instances that will target this reservation.
  module WorkloadType
    # A value indicating that the enum field is not set.
    UNDEFINED_WORKLOAD_TYPE = 0

    # Reserved resources will be optimized for BATCH workloads, such as ML
    # training.
    BATCH = 62_971_674

    # Reserved resources will be optimized for SERVING workloads, such as ML
    # inference.
    SERVING = 17_781_740

    UNSPECIFIED = 526_786_327
  end
end