Class: Google::Cloud::Compute::V1::AllocationReservationSharingPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: ServiceShareType

Instance Attribute Summary collapse

Instance Attribute Details

#service_share_type ⇒ ::String

Returns Sharing config for all Google Cloud services. Check the ServiceShareType enum for the list of possible values.

Returns:

  • (::String) —

    Sharing config for all Google Cloud services. Check the ServiceShareType enum for the list of possible values.



7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7917

class AllocationReservationSharingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Sharing config for all Google Cloud services.
  module ServiceShareType
    # A value indicating that the enum field is not set.
    UNDEFINED_SERVICE_SHARE_TYPE = 0

    # Allow all Google Cloud managed services to share reservations.
    ALLOW_ALL = 475_536_235

    # [Default] Disallow sharing with all Google Cloud services.
    DISALLOW_ALL = 277_786_301

    SERVICE_SHARE_TYPE_UNSPECIFIED = 279_057_148
  end
end