Class: Google::Cloud::Compute::V1::AllocationResourceStatusSpecificSKUAllocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains Properties set for the reservation.

Defined Under Namespace

Classes: UtilizationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#source_instance_template_id ⇒ ::String

Returns ID of the instance template used to populate reservation properties.

Returns:

  • (::String) —

    ID of the instance template used to populate reservation properties.



7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7993

class AllocationResourceStatusSpecificSKUAllocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Integer]
  class UtilizationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#utilizations ⇒ ::Google::Protobuf::Map{::String => ::Integer}

Returns Per service utilization breakdown. The Key is the Google Cloud managed service name.

Returns:

  • (::Google::Protobuf::Map{::String => ::Integer}) —

    Per service utilization breakdown. The Key is the Google Cloud managed service name.



7993
7994
7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7993

class AllocationResourceStatusSpecificSKUAllocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Integer]
  class UtilizationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end