Module: Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk::Interface
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
Constant Summary collapse
- UNDEFINED_INTERFACE =
A value indicating that the enum field is not set.
0- NVME =
2_408_800- SCSI =
2_539_686