Class: Google::Cloud::Compute::V1::AllocationSpecificSKUReservation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

This reservation type allows to pre allocate specific instance configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#assured_count ⇒ ::Integer

Returns Output only. [Output Only] Indicates how many instances are actually usable currently.

Returns:

  • (::Integer) —

    Output only. [Output Only] Indicates how many instances are actually usable currently.



8086
8087
8088
8089
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8086

class AllocationSpecificSKUReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#count ⇒ ::Integer

Returns Specifies the number of resources that are allocated.

Returns:

  • (::Integer) —

    Specifies the number of resources that are allocated.



8086
8087
8088
8089
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8086

class AllocationSpecificSKUReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#in_use_count ⇒ ::Integer

Returns Output only. [Output Only] Indicates how many instances are in use.

Returns:

  • (::Integer) —

    Output only. [Output Only] Indicates how many instances are in use.



8086
8087
8088
8089
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8086

class AllocationSpecificSKUReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_properties ⇒ ::Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationReservedInstanceProperties

Returns The instance properties for the reservation.

Returns:



8086
8087
8088
8089
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8086

class AllocationSpecificSKUReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_instance_template ⇒ ::String

Returns Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field.

This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template:

  - https://www.googleapis.com/compute/v1/projects/project/global/instanceTemplates/instanceTemplate
  - projects/project/global/instanceTemplates/instanceTemplate
  - global/instanceTemplates/instanceTemplate.

Returns:

  • (::String) —

    Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field.

    This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template:

      - https://www.googleapis.com/compute/v1/projects/project/global/instanceTemplates/instanceTemplate
      - projects/project/global/instanceTemplates/instanceTemplate
      - global/instanceTemplates/instanceTemplate


8086
8087
8088
8089
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8086

class AllocationSpecificSKUReservation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end