Class: Google::Cloud::Compute::V1::AnnouncePublicDelegatedPrefixeRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AnnouncePublicDelegatedPrefixeRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for PublicDelegatedPrefixes.Announce. See the method description for details.
Instance Attribute Summary collapse
-
#project ⇒ ::String
Project ID for this request.
-
#public_delegated_prefix ⇒ ::String
The name of the public delegated prefix.
-
#region ⇒ ::String
The name of theregion where the public delegated prefix is located.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
Instance Attribute Details
#project ⇒ ::String
Returns Project ID for this request.
7984 7985 7986 7987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7984 class AnnouncePublicDelegatedPrefixeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#public_delegated_prefix ⇒ ::String
Returns The name of the public delegated prefix. It should comply with RFC1035.
7984 7985 7986 7987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7984 class AnnouncePublicDelegatedPrefixeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns The name of theregion where the public delegated prefix is located. It should comply with RFC1035.
7984 7985 7986 7987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7984 class AnnouncePublicDelegatedPrefixeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
7984 7985 7986 7987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7984 class AnnouncePublicDelegatedPrefixeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |