Class: Google::Cloud::Compute::V1::ApplyUpdatesToInstancesInstanceGroupManagerRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for InstanceGroupManagers.ApplyUpdatesToInstances. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#instance_group_manager ⇒ ::String

Returns The name of the managed instance group, should conform to RFC1035.

Returns:

  • (::String) —

    The name of the managed instance group, should conform to RFC1035.



8182
8183
8184
8185
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8182

class ApplyUpdatesToInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_group_managers_apply_updates_request_resource ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagersApplyUpdatesRequest

Returns The body resource for this request.

Returns:



8182
8183
8184
8185
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8182

class ApplyUpdatesToInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns Project ID for this request.

Returns:

  • (::String) —

    Project ID for this request.



8182
8183
8184
8185
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8182

class ApplyUpdatesToInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone ⇒ ::String

Returns The name of thezone where the managed instance group is located. Should conform to RFC1035.

Returns:

  • (::String) —

    The name of thezone where the managed instance group is located. Should conform to RFC1035.



8182
8183
8184
8185
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8182

class ApplyUpdatesToInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end