Class: Google::Cloud::Compute::V1::AttachedDisk
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AttachedDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
An instance-attached disk resource.
Defined Under Namespace
Modules: Architecture, Interface, Mode, SavedState, Type
Instance Attribute Summary collapse
-
#architecture ⇒ ::String
Output only.
-
#auto_delete ⇒ ::Boolean
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
-
#boot ⇒ ::Boolean
Indicates that this is a boot disk.
-
#device_name ⇒ ::String
Specifies a unique device name of your choice that is reflected into the/dev/disk/by-id/google-* tree of a Linux operating system running within the instance.
-
#disk_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Encrypts or decrypts a disk using acustomer-supplied encryption key.
-
#disk_size_gb ⇒ ::Integer
The size of the disk in GB.
-
#force_attach ⇒ ::Boolean
[Input Only] Whether to force attach the regional disk even if it's currently attached to another instance.
-
#guest_os_features ⇒ ::Array<::Google::Cloud::Compute::V1::GuestOsFeature>
A list of features to enable on the guest operating system.
-
#index ⇒ ::Integer
Output only.
-
#initialize_params ⇒ ::Google::Cloud::Compute::V1::AttachedDiskInitializeParams
[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance.
-
#interface ⇒ ::String
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
-
#kind ⇒ ::String
Output only.
-
#licenses ⇒ ::Array<::String>
Output only.
-
#mode ⇒ ::String
The mode in which to attach this disk, either READ_WRITE orREAD_ONLY.
-
#saved_state ⇒ ::String
Output only.
-
#shielded_instance_initial_state ⇒ ::Google::Cloud::Compute::V1::InitialStateConfig
Output only.
-
#source ⇒ ::String
Specifies a valid partial or full URL to an existing Persistent Disk resource.
-
#type ⇒ ::String
Specifies the type of the disk, either SCRATCH orPERSISTENT.
Instance Attribute Details
#architecture ⇒ ::String
Returns Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 or X86_64. Check the Architecture enum for the list of possible values.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#auto_delete ⇒ ::Boolean
Returns Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#boot ⇒ ::Boolean
Returns Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#device_name ⇒ ::String
Returns Specifies a unique device name of your choice that is reflected into the/dev/disk/by-id/google-* tree of a Linux operating system running within the instance. This name can be used to reference the device for mounting, resizing, and so on, from within the instance.
If not specified, the server chooses a default device name to apply to this disk, in the form persistent-disk-x, where x is a number assigned by Google Compute Engine. This field is only applicable for persistent disks.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#disk_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Returns Encrypts or decrypts a disk using acustomer-supplied encryption key.
If you are creating a new disk, this field encrypts the new disk using an encryption key that you provide. If you are attaching an existing disk that is already encrypted, this field decrypts the disk using the customer-supplied encryption key.
If you encrypt a disk using a customer-supplied key, you must provide the same key again when you attempt to use this resource at a later time. For example, you must provide the key when you create a snapshot or an image from the disk or when you attach the disk to a virtual machine instance.
If you do not provide an encryption key, then the disk will be encrypted using an automatically generated key and you do not need to provide a key to use the disk later.
Note:
Instance templates do not storecustomer-supplied encryption keys, so you cannot use your own keys to encrypt disks in amanaged instance group.
You cannot create VMs that have disks with customer-supplied keys using the bulk insert method.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#disk_size_gb ⇒ ::Integer
Returns The size of the disk in GB.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#force_attach ⇒ ::Boolean
Returns [Input Only] Whether to force attach the regional disk even if it's currently attached to another instance. If you try to force attach a zonal disk to an instance, you will receive an error.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#guest_os_features ⇒ ::Array<::Google::Cloud::Compute::V1::GuestOsFeature>
Returns A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#index ⇒ ::Integer
Returns Output only. [Output Only] A zero-based index to this disk, where 0 is reserved for the boot disk. If you have many disks attached to an instance, each disk would have a unique index number.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#initialize_params ⇒ ::Google::Cloud::Compute::V1::AttachedDiskInitializeParams
Returns [Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance.
This property is mutually exclusive with the source property; you can only define one or the other, but not both.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#interface ⇒ ::String
Returns Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. For most machine types, the default is SCSI. Local SSDs can use either NVME or SCSI. In certain configurations, persistent disks can use NVMe. For more information, seeAbout persistent disks. Check the Interface enum for the list of possible values.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#licenses ⇒ ::Array<::String>
Returns Output only. [Output Only] Any valid publicly visible licenses.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#mode ⇒ ::String
Returns The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode. Check the Mode enum for the list of possible values.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#saved_state ⇒ ::String
Returns Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this field is set to PRESERVED if the LocalSSD data has been saved to a persistent location by customer request. (see the discard_local_ssd option on Stop/Suspend). Read-only in the api. Check the SavedState enum for the list of possible values.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#shielded_instance_initial_state ⇒ ::Google::Cloud::Compute::V1::InitialStateConfig
Returns Output only. [Output Only] shielded vm initial state stored on disk.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#source ⇒ ::String
Returns Specifies a valid partial or full URL to an existing Persistent Disk resource. When creating a new instance boot disk, one ofinitializeParams.sourceImage orinitializeParams.sourceSnapshot or disks.source is required.
If desired, you can also attach existing non-root persistent disks using this property. This field is only applicable for persistent disks.
Note that for InstanceTemplate, specify the disk name for zonal disk, and the URL for regional disk.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#type ⇒ ::String
Returns Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. Check the Type enum for the list of possible values.
8290 8291 8292 8293 8294 8295 8296 8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 8310 8311 8312 8313 8314 8315 8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 8330 8331 8332 8333 8334 8335 8336 8337 8338 8339 8340 8341 8342 8343 8344 8345 8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8290 class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. Valid values are ARM64 # or X86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. For most machine types, the # default is SCSI. Local SSDs can use either NVME or SCSI. # In certain configurations, persistent disks can use NVMe. For more # information, seeAbout # persistent disks. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk # in READ_WRITE mode. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this # field is set to PRESERVED if the LocalSSD data has been saved # to a persistent location by customer request. (see the # discard_local_ssd option on Stop/Suspend). # Read-only in the api. module SavedState # A value indicating that the enum field is not set. UNDEFINED_SAVED_STATE = 0 # *[Default]* Disk state has not been preserved. DISK_SAVED_STATE_UNSPECIFIED = 391_290_831 # Disk state has been preserved. PRESERVED = 254_159_736 end # Specifies the type of the disk, either SCRATCH orPERSISTENT. If not specified, the default isPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |