Class: Google::Cloud::Compute::V1::AutoscalerStatusDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ ::String

Returns The status message.

Returns:

  • (::String) —

    The status message.



9189
9190
9191
9192
9193
9194
9195
9196
9197
9198
9199
9200
9201
9202
9203
9204
9205
9206
9207
9208
9209
9210
9211
9212
9213
9214
9215
9216
9217
9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
9231
9232
9233
9234
9235
9236
9237
9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
9266
9267
9268
9269
9270
9271
9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
9287
9288
9289
9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
9325
9326
9327
9328
9329
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9189

class AutoscalerStatusDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of error, warning, or notice returned. Current set of possible
  # values:
  #
  #    - ALL_INSTANCES_UNHEALTHY (WARNING):
  #      All instances in the instance group are unhealthy (not in RUNNING
  #      state).
  #    - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR):
  #      There is no backend service attached to the instance group.
  #    - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
  #      Autoscaler recommends a size greater than maxNumReplicas.
  #    - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING):
  #      The custom metric samples are not exported often enough to be
  #      a credible base for autoscaling.
  #    - CUSTOM_METRIC_INVALID (ERROR):
  #      The custom metric that was specified does not exist or does not have
  #      the necessary labels.
  #    - MIN_EQUALS_MAX (WARNING):
  #      The minNumReplicas is equal to maxNumReplicas. This means the
  #      autoscaler cannot add or remove instances from the instance group.
  #    - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING):
  #      The autoscaler did not receive any data from the custom metric
  #      configured for autoscaling.
  #    - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING):
  #      The autoscaler is configured to scale based on a load balancing signal
  #      but the instance group has not received any requests from the load
  #      balancer.
  #    - MODE_OFF (WARNING):
  #      Autoscaling is turned off. The number of instances in the group won't
  #      change automatically. The autoscaling configuration is preserved.
  #    - MODE_ONLY_UP (WARNING):
  #      Autoscaling is in the "Autoscale only out" mode. The autoscaler can add
  #      instances but not remove any.
  #    - MORE_THAN_ONE_BACKEND_SERVICE (ERROR):
  #      The instance group cannot be autoscaled because it has more than one
  #      backend service attached to it.
  #    - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR):
  #      There is insufficient quota for the necessary resources, such as CPU or
  #      number of instances.
  #    - REGION_RESOURCE_STOCKOUT (ERROR):
  #      Shown only for regional autoscalers: there is a resource stockout in
  #      the chosen region.
  #    - SCALING_TARGET_DOES_NOT_EXIST (ERROR):
  #      The target to be scaled does not exist.
  #    - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION
  #      (ERROR): Autoscaling does not work with an HTTP/S load balancer that
  #      has been configured for maxRate.
  #    - ZONE_RESOURCE_STOCKOUT (ERROR):
  #      For zonal autoscalers: there is a resource stockout in the chosen zone.
  #      For regional autoscalers: in at least one of the zones you're using
  #      there is a resource stockout.
  #
  #
  # New values might be added in the future. Some of the values might not be
  # available in all API versions.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # All instances in the instance group are unhealthy (not in RUNNING state).
    ALL_INSTANCES_UNHEALTHY = 404_965_477

    # There is no backend service attached to the instance group.
    BACKEND_SERVICE_DOES_NOT_EXIST = 191_417_626

    # Autoscaler recommends a size greater than maxNumReplicas.
    CAPPED_AT_MAX_NUM_REPLICAS = 518_617

    # The custom metric samples are not exported often enough to be a credible
    # base for autoscaling.
    CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE = 328_964_659

    # The custom metric that was specified does not exist or does not have the
    # necessary labels.
    CUSTOM_METRIC_INVALID = 204_430_550

    # The minNumReplicas is equal to maxNumReplicas. This means the autoscaler
    # cannot add or remove instances from the instance group.
    MIN_EQUALS_MAX = 2_821_361

    # The autoscaler did not receive any data from the custom metric configured
    # for autoscaling.
    MISSING_CUSTOM_METRIC_DATA_POINTS = 94_885_086

    # The autoscaler is configured to scale based on a load balancing signal
    # but the instance group has not received any requests from the load
    # balancer.
    MISSING_LOAD_BALANCING_DATA_POINTS = 509_858_898

    # Autoscaling is turned off. The number of instances in the group won't
    # change automatically. The autoscaling configuration is preserved.
    MODE_OFF = 164_169_907

    # Autoscaling is in the "Autoscale only scale out" mode.
    # Instances in the group will be only added.
    MODE_ONLY_SCALE_OUT = 3_840_994

    # Autoscaling is in the "Autoscale only out" mode. Instances in the group
    # will be only added.
    MODE_ONLY_UP = 100_969_842

    # The instance group cannot be autoscaled because it has more than one
    # backend service attached to it.
    MORE_THAN_ONE_BACKEND_SERVICE = 151_922_141

    # There is insufficient quota for the necessary resources, such as CPU or
    # number of instances.
    NOT_ENOUGH_QUOTA_AVAILABLE = 403_101_631

    # Showed only for regional autoscalers: there is a resource stockout in
    # the chosen region.
    REGION_RESOURCE_STOCKOUT = 528_622_846

    # The target to be scaled does not exist.
    SCALING_TARGET_DOES_NOT_EXIST = 122_636_699

    # For some scaling schedules minRequiredReplicas is greater than
    # maxNumReplicas. Autoscaler always recommends at most maxNumReplicas
    # instances.
    SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX = 29_275_586

    # For some scaling schedules minRequiredReplicas is less than
    # minNumReplicas. Autoscaler always recommends at least minNumReplicas
    # instances.
    SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN = 398_287_669

    UNKNOWN = 433_141_802

    # Autoscaling does not work with an HTTP/S load balancer that has been
    # configured for maxRate.
    UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION = 330_845_009

    # For zonal autoscalers: there is a resource stockout in the chosen zone.
    # For regional autoscalers: in at least one of the zones you're using there
    # is a resource stockout.
    ZONE_RESOURCE_STOCKOUT = 210_200_502
  end
end

#type ⇒ ::String

Returns The type of error, warning, or notice returned. Current set of possible values:

- ALL_INSTANCES_UNHEALTHY (WARNING):
 All instances in the instance group are unhealthy (not in RUNNING
 state).
- BACKEND_SERVICE_DOES_NOT_EXIST (ERROR):
 There is no backend service attached to the instance group.
- CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
 Autoscaler recommends a size greater than maxNumReplicas.
- CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING):
 The custom metric samples are not exported often enough to be
 a credible base for autoscaling.
- CUSTOM_METRIC_INVALID (ERROR):
 The custom metric that was specified does not exist or does not have
 the necessary labels.
- MIN_EQUALS_MAX (WARNING):
 The minNumReplicas is equal to maxNumReplicas. This means the
 autoscaler cannot add or remove instances from the instance group.
- MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING):
 The autoscaler did not receive any data from the custom metric
 configured for autoscaling.
- MISSING_LOAD_BALANCING_DATA_POINTS (WARNING):
 The autoscaler is configured to scale based on a load balancing signal
 but the instance group has not received any requests from the load
 balancer.
- MODE_OFF (WARNING):
 Autoscaling is turned off. The number of instances in the group won't
 change automatically. The autoscaling configuration is preserved.
- MODE_ONLY_UP (WARNING):
 Autoscaling is in the "Autoscale only out" mode. The autoscaler can add
 instances but not remove any.
- MORE_THAN_ONE_BACKEND_SERVICE (ERROR):
 The instance group cannot be autoscaled because it has more than one
 backend service attached to it.
- NOT_ENOUGH_QUOTA_AVAILABLE (ERROR):
 There is insufficient quota for the necessary resources, such as CPU or
 number of instances.
- REGION_RESOURCE_STOCKOUT (ERROR):
 Shown only for regional autoscalers: there is a resource stockout in
 the chosen region.
- SCALING_TARGET_DOES_NOT_EXIST (ERROR):
 The target to be scaled does not exist.
- UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION
 (ERROR): Autoscaling does not work with an HTTP/S load balancer that
 has been configured for maxRate.
- ZONE_RESOURCE_STOCKOUT (ERROR):
 For zonal autoscalers: there is a resource stockout in the chosen zone.
 For regional autoscalers: in at least one of the zones you're using
 there is a resource stockout.

New values might be added in the future. Some of the values might not be available in all API versions. Check the Type enum for the list of possible values.

Returns:

  • (::String) —

    The type of error, warning, or notice returned. Current set of possible values:

    - ALL_INSTANCES_UNHEALTHY (WARNING):
     All instances in the instance group are unhealthy (not in RUNNING
     state).
    - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR):
     There is no backend service attached to the instance group.
    - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
     Autoscaler recommends a size greater than maxNumReplicas.
    - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING):
     The custom metric samples are not exported often enough to be
     a credible base for autoscaling.
    - CUSTOM_METRIC_INVALID (ERROR):
     The custom metric that was specified does not exist or does not have
     the necessary labels.
    - MIN_EQUALS_MAX (WARNING):
     The minNumReplicas is equal to maxNumReplicas. This means the
     autoscaler cannot add or remove instances from the instance group.
    - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING):
     The autoscaler did not receive any data from the custom metric
     configured for autoscaling.
    - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING):
     The autoscaler is configured to scale based on a load balancing signal
     but the instance group has not received any requests from the load
     balancer.
    - MODE_OFF (WARNING):
     Autoscaling is turned off. The number of instances in the group won't
     change automatically. The autoscaling configuration is preserved.
    - MODE_ONLY_UP (WARNING):
     Autoscaling is in the "Autoscale only out" mode. The autoscaler can add
     instances but not remove any.
    - MORE_THAN_ONE_BACKEND_SERVICE (ERROR):
     The instance group cannot be autoscaled because it has more than one
     backend service attached to it.
    - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR):
     There is insufficient quota for the necessary resources, such as CPU or
     number of instances.
    - REGION_RESOURCE_STOCKOUT (ERROR):
     Shown only for regional autoscalers: there is a resource stockout in
     the chosen region.
    - SCALING_TARGET_DOES_NOT_EXIST (ERROR):
     The target to be scaled does not exist.
    - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION
     (ERROR): Autoscaling does not work with an HTTP/S load balancer that
     has been configured for maxRate.
    - ZONE_RESOURCE_STOCKOUT (ERROR):
     For zonal autoscalers: there is a resource stockout in the chosen zone.
     For regional autoscalers: in at least one of the zones you're using
     there is a resource stockout.
    

    New values might be added in the future. Some of the values might not be available in all API versions. Check the Type enum for the list of possible values.



9189
9190
9191
9192
9193
9194
9195
9196
9197
9198
9199
9200
9201
9202
9203
9204
9205
9206
9207
9208
9209
9210
9211
9212
9213
9214
9215
9216
9217
9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
9231
9232
9233
9234
9235
9236
9237
9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
9266
9267
9268
9269
9270
9271
9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
9287
9288
9289
9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
9325
9326
9327
9328
9329
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9189

class AutoscalerStatusDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of error, warning, or notice returned. Current set of possible
  # values:
  #
  #    - ALL_INSTANCES_UNHEALTHY (WARNING):
  #      All instances in the instance group are unhealthy (not in RUNNING
  #      state).
  #    - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR):
  #      There is no backend service attached to the instance group.
  #    - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
  #      Autoscaler recommends a size greater than maxNumReplicas.
  #    - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING):
  #      The custom metric samples are not exported often enough to be
  #      a credible base for autoscaling.
  #    - CUSTOM_METRIC_INVALID (ERROR):
  #      The custom metric that was specified does not exist or does not have
  #      the necessary labels.
  #    - MIN_EQUALS_MAX (WARNING):
  #      The minNumReplicas is equal to maxNumReplicas. This means the
  #      autoscaler cannot add or remove instances from the instance group.
  #    - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING):
  #      The autoscaler did not receive any data from the custom metric
  #      configured for autoscaling.
  #    - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING):
  #      The autoscaler is configured to scale based on a load balancing signal
  #      but the instance group has not received any requests from the load
  #      balancer.
  #    - MODE_OFF (WARNING):
  #      Autoscaling is turned off. The number of instances in the group won't
  #      change automatically. The autoscaling configuration is preserved.
  #    - MODE_ONLY_UP (WARNING):
  #      Autoscaling is in the "Autoscale only out" mode. The autoscaler can add
  #      instances but not remove any.
  #    - MORE_THAN_ONE_BACKEND_SERVICE (ERROR):
  #      The instance group cannot be autoscaled because it has more than one
  #      backend service attached to it.
  #    - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR):
  #      There is insufficient quota for the necessary resources, such as CPU or
  #      number of instances.
  #    - REGION_RESOURCE_STOCKOUT (ERROR):
  #      Shown only for regional autoscalers: there is a resource stockout in
  #      the chosen region.
  #    - SCALING_TARGET_DOES_NOT_EXIST (ERROR):
  #      The target to be scaled does not exist.
  #    - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION
  #      (ERROR): Autoscaling does not work with an HTTP/S load balancer that
  #      has been configured for maxRate.
  #    - ZONE_RESOURCE_STOCKOUT (ERROR):
  #      For zonal autoscalers: there is a resource stockout in the chosen zone.
  #      For regional autoscalers: in at least one of the zones you're using
  #      there is a resource stockout.
  #
  #
  # New values might be added in the future. Some of the values might not be
  # available in all API versions.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # All instances in the instance group are unhealthy (not in RUNNING state).
    ALL_INSTANCES_UNHEALTHY = 404_965_477

    # There is no backend service attached to the instance group.
    BACKEND_SERVICE_DOES_NOT_EXIST = 191_417_626

    # Autoscaler recommends a size greater than maxNumReplicas.
    CAPPED_AT_MAX_NUM_REPLICAS = 518_617

    # The custom metric samples are not exported often enough to be a credible
    # base for autoscaling.
    CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE = 328_964_659

    # The custom metric that was specified does not exist or does not have the
    # necessary labels.
    CUSTOM_METRIC_INVALID = 204_430_550

    # The minNumReplicas is equal to maxNumReplicas. This means the autoscaler
    # cannot add or remove instances from the instance group.
    MIN_EQUALS_MAX = 2_821_361

    # The autoscaler did not receive any data from the custom metric configured
    # for autoscaling.
    MISSING_CUSTOM_METRIC_DATA_POINTS = 94_885_086

    # The autoscaler is configured to scale based on a load balancing signal
    # but the instance group has not received any requests from the load
    # balancer.
    MISSING_LOAD_BALANCING_DATA_POINTS = 509_858_898

    # Autoscaling is turned off. The number of instances in the group won't
    # change automatically. The autoscaling configuration is preserved.
    MODE_OFF = 164_169_907

    # Autoscaling is in the "Autoscale only scale out" mode.
    # Instances in the group will be only added.
    MODE_ONLY_SCALE_OUT = 3_840_994

    # Autoscaling is in the "Autoscale only out" mode. Instances in the group
    # will be only added.
    MODE_ONLY_UP = 100_969_842

    # The instance group cannot be autoscaled because it has more than one
    # backend service attached to it.
    MORE_THAN_ONE_BACKEND_SERVICE = 151_922_141

    # There is insufficient quota for the necessary resources, such as CPU or
    # number of instances.
    NOT_ENOUGH_QUOTA_AVAILABLE = 403_101_631

    # Showed only for regional autoscalers: there is a resource stockout in
    # the chosen region.
    REGION_RESOURCE_STOCKOUT = 528_622_846

    # The target to be scaled does not exist.
    SCALING_TARGET_DOES_NOT_EXIST = 122_636_699

    # For some scaling schedules minRequiredReplicas is greater than
    # maxNumReplicas. Autoscaler always recommends at most maxNumReplicas
    # instances.
    SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX = 29_275_586

    # For some scaling schedules minRequiredReplicas is less than
    # minNumReplicas. Autoscaler always recommends at least minNumReplicas
    # instances.
    SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN = 398_287_669

    UNKNOWN = 433_141_802

    # Autoscaling does not work with an HTTP/S load balancer that has been
    # configured for maxRate.
    UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION = 330_845_009

    # For zonal autoscalers: there is a resource stockout in the chosen zone.
    # For regional autoscalers: in at least one of the zones you're using there
    # is a resource stockout.
    ZONE_RESOURCE_STOCKOUT = 210_200_502
  end
end