Module: Google::Cloud::Compute::V1::AutoscalingPolicy::Mode
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Defines the operating mode for this policy. The following modes are available:
- OFF: Disables the autoscaler but maintains its configuration.
- ONLY_SCALE_OUT: Restricts the autoscaler to add VM instances only.
- ON: Enables all autoscaler activities according to its policy.
For more information, see "Turning off or restricting an autoscaler"
Constant Summary collapse
- UNDEFINED_MODE =
A value indicating that the enum field is not set.
0- OFF =
Do not automatically scale the MIG in or out. The recommended_size field contains the size of MIG that would be set if the actuation mode was enabled.
78_159- ON =
Automatically scale the MIG in and out according to the policy.
2527- ONLY_SCALE_OUT =
Automatically create VMs according to the policy, but do not scale the MIG in.
152_713_670- ONLY_UP =
Automatically create VMs according to the policy, but do not scale the MIG in.
478_095_374