Method: Google::Cloud::Compute::V1::AutoscalingPolicy#cpu_utilization

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

#cpu_utilization::Google::Cloud::Compute::V1::AutoscalingPolicyCpuUtilization

Returns Defines the CPU utilization policy that allows the autoscaler to scale based on the average CPU utilization of a managed instance group.

Returns:



3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3301

class AutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule]
  class ScalingSchedulesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines the operating mode for this policy. The following modes are available: - OFF: Disables the autoscaler but maintains its configuration. - ONLY_SCALE_OUT: Restricts the autoscaler to add VM instances only. - ON: Enables all autoscaler activities according to its policy. For more information, see "Turning off or restricting an autoscaler"
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Do not automatically scale the MIG in or out. The recommended_size field contains the size of MIG that would be set if the actuation mode was enabled.
    OFF = 78_159

    # Automatically scale the MIG in and out according to the policy.
    ON = 2527

    # Automatically create VMs according to the policy, but do not scale the MIG in.
    ONLY_SCALE_OUT = 152_713_670

    # Automatically create VMs according to the policy, but do not scale the MIG in.
    ONLY_UP = 478_095_374
  end
end