Class: Google::Cloud::Compute::V1::AutoscalingPolicyCpuUtilization

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

CPU utilization policy.

Defined Under Namespace

Modules: PredictiveMethod

Instance Attribute Summary collapse

Instance Attribute Details

#predictive_method ⇒ ::String

Returns Indicates whether predictive autoscaling based on CPU metric is enabled. Valid values are:

  • NONE (default). No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics.
  • OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by monitoring daily and weekly load patterns and scaling out ahead of anticipated demand. Check the PredictiveMethod enum for the list of possible values.

Returns:

  • (::String) —

    Indicates whether predictive autoscaling based on CPU metric is enabled. Valid values are:

    • NONE (default). No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics.
    • OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by monitoring daily and weekly load patterns and scaling out ahead of anticipated demand. Check the PredictiveMethod enum for the list of possible values.


9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
9510
9511
9512
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9488

class AutoscalingPolicyCpuUtilization
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates whether predictive autoscaling based on CPU metric is enabled.
  # Valid values are:
  #
  # * NONE (default). No predictive method is used. The autoscaler scales the
  # group to meet current demand based on real-time metrics.
  # * OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by
  # monitoring daily and weekly load patterns and scaling out ahead of
  # anticipated demand.
  module PredictiveMethod
    # A value indicating that the enum field is not set.
    UNDEFINED_PREDICTIVE_METHOD = 0

    # No predictive method is used. The autoscaler scales the group to meet
    # current demand based on real-time metrics
    NONE = 2_402_104

    # Predictive autoscaling improves availability by monitoring daily and
    # weekly load patterns and scaling out ahead of anticipated demand.
    OPTIMIZE_AVAILABILITY = 11_629_437
  end
end

#utilization_target ⇒ ::Float

Returns The target CPU utilization that the autoscaler maintains. Must be a float value in the range (0, 1]. If not specified, the default is0.6.

If the CPU level is below the target utilization, the autoscaler scales in the number of instances until it reaches the minimum number of instances you specified or until the average CPU of your instances reaches the target utilization.

If the average CPU is above the target utilization, the autoscaler scales out until it reaches the maximum number of instances you specified or until the average utilization reaches the target utilization.

Returns:

  • (::Float) —

    The target CPU utilization that the autoscaler maintains. Must be a float value in the range (0, 1]. If not specified, the default is0.6.

    If the CPU level is below the target utilization, the autoscaler scales in the number of instances until it reaches the minimum number of instances you specified or until the average CPU of your instances reaches the target utilization.

    If the average CPU is above the target utilization, the autoscaler scales out until it reaches the maximum number of instances you specified or until the average utilization reaches the target utilization.



9488
9489
9490
9491
9492
9493
9494
9495
9496
9497
9498
9499
9500
9501
9502
9503
9504
9505
9506
9507
9508
9509
9510
9511
9512
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9488

class AutoscalingPolicyCpuUtilization
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates whether predictive autoscaling based on CPU metric is enabled.
  # Valid values are:
  #
  # * NONE (default). No predictive method is used. The autoscaler scales the
  # group to meet current demand based on real-time metrics.
  # * OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by
  # monitoring daily and weekly load patterns and scaling out ahead of
  # anticipated demand.
  module PredictiveMethod
    # A value indicating that the enum field is not set.
    UNDEFINED_PREDICTIVE_METHOD = 0

    # No predictive method is used. The autoscaler scales the group to meet
    # current demand based on real-time metrics
    NONE = 2_402_104

    # Predictive autoscaling improves availability by monitoring daily and
    # weekly load patterns and scaling out ahead of anticipated demand.
    OPTIMIZE_AVAILABILITY = 11_629_437
  end
end