Module: Google::Cloud::Compute::V1::AutoscalingPolicyCustomMetricUtilization::UtilizationTargetType

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Defines how target utilization value is expressed for a Stackdriver Monitoring metric. Either GAUGE, DELTA_PER_SECOND, or DELTA_PER_MINUTE.

Constant Summary collapse

UNDEFINED_UTILIZATION_TARGET_TYPE =

A value indicating that the enum field is not set.

0
DELTA_PER_MINUTE =

Sets the utilization target value for a cumulative or delta metric, expressed as the rate of growth per minute.

87_432_861
DELTA_PER_SECOND =

Sets the utilization target value for a cumulative or delta metric, expressed as the rate of growth per second.

255_180_029
GAUGE =

Sets the utilization target value for a gauge metric. The autoscaler will collect the average utilization of the virtual machines from the last couple of minutes, and compare the value to the utilization target value to perform autoscaling.

67_590_361