Module: Google::Cloud::Compute::V1::Backend::Preference

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are:

- PREFERRED: Backends with this preference level will be
filled up to their capacity limits first, based on RTT.
- DEFAULT:  If preferred backends don't have enough
capacity, backends in this layer would be used and traffic would be
assigned based on the load balancing algorithm you use. This is the
default

For global external Passthrough Network Load Balancers, the following restrictions apply:

- At most one backend can be marked as PREFERRED.
- PREFERRED and DEFAULT backends cannot reside
in the same Cloud region.

Constant Summary collapse

UNDEFINED_PREFERENCE =

A value indicating that the enum field is not set.

0
DEFAULT =

No preference.

115_302_945
PREFERENCE_UNSPECIFIED =

If preference is unspecified, we set it to the DEFAULT value

496_219_571
PREFERRED =

Traffic will be sent to this backend first.

418_847_841