Class: Google::Cloud::Compute::V1::BackendBackendOrchestrationInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A message containing information about the resource or system that manages the backend.

Instance Attribute Summary collapse

Instance Attribute Details

#resource_uri::String

Returns The URI of the resource or system that manages the backend.

Returns:

  • (::String)

    The URI of the resource or system that manages the backend.



9825
9826
9827
9828
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9825

class BackendBackendOrchestrationInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end