Class: Google::Cloud::Compute::V1::BackendBucketCdnPolicyNegativeCachingPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendBucketCdnPolicyNegativeCachingPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specify CDN TTLs for response error codes.
Instance Attribute Summary collapse
-
#code ⇒ ::Integer
The HTTP status code to define a TTL against.
-
#ttl ⇒ ::Integer
The TTL (in seconds) for which to cache responses with the corresponding status code.
Instance Attribute Details
#code ⇒ ::Integer
Returns The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 can be specified as values, and you cannot specify a status code more than once.
10063 10064 10065 10066 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 10063 class BackendBucketCdnPolicyNegativeCachingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ttl ⇒ ::Integer
Returns The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes), noting that infrequently accessed objects may be evicted from the cache before the defined TTL.
10063 10064 10065 10066 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 10063 class BackendBucketCdnPolicyNegativeCachingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |