Module: Google::Cloud::Compute::V1::BackendServiceConnectionTrackingPolicy::TrackingMode
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies the key used for connection tracking. There are two options:
- PER_CONNECTION: This is the default mode. The Connection
Tracking is performed as per the Connection Key (default Hash Method) for
the specific protocol.
- PER_SESSION: The Connection Tracking is performed as per
the configured Session Affinity. It matches the configured Session
Affinity.
For more details, see Tracking Mode for Network Load Balancing and Tracking Mode for Internal TCP/UDP Load Balancing.
Constant Summary collapse
- UNDEFINED_TRACKING_MODE =
A value indicating that the enum field is not set.
0- INVALID_TRACKING_MODE =
49_234_371- PER_CONNECTION =
85_162_848- PER_SESSION =
182_099_252