Class: Google::Cloud::Compute::V1::BackendServiceCustomMetric
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceCustomMetric
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Custom Metrics are used for WEIGHTED_ROUND_ROBIN locality_lb_policy.
Instance Attribute Summary collapse
-
#dry_run ⇒ ::Boolean
If true, the metric data is not used for load balancing.
-
#name ⇒ ::String
Name of a custom utilization signal.
Instance Attribute Details
#dry_run ⇒ ::Boolean
Returns If true, the metric data is not used for load balancing.
11456 11457 11458 11459 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11456 class BackendServiceCustomMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Name of a custom utilization signal. The name must be 1-64 characters
long and match the regular expression
[a-z]([-_.a-z0-9]*[a-z0-9])? which means that the
first character must be a lowercase letter, and all following
characters must be a dash, period, underscore, lowercase letter, or
digit, except the last character, which cannot be a dash, period, or
underscore. For usage guidelines, see Custom Metrics balancing mode. This
field can only be used for a global or regional backend service with the
loadBalancingScheme set to EXTERNAL_MANAGED,INTERNAL_MANAGED INTERNAL_SELF_MANAGED.
11456 11457 11458 11459 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11456 class BackendServiceCustomMetric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |