Class: Google::Cloud::Compute::V1::BackendServiceGroupHealth

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: AnnotationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Metadata defined as annotations on the network endpoint group.

Returns:

  • Metadata defined as annotations on the network endpoint group.



4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 4287

class BackendServiceGroupHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#health_status::Array<::Google::Cloud::Compute::V1::HealthStatus>

Returns Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.

Returns:

  • Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.



4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 4287

class BackendServiceGroupHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns [Output Only] Type of resource. Always compute#backendServiceGroupHealth for the health of backend services.

Returns:

  • [Output Only] Type of resource. Always compute#backendServiceGroupHealth for the health of backend services.



4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 4287

class BackendServiceGroupHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end