Class: Google::Cloud::Compute::V1::BackendServiceHAPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: FastIPMove

Instance Attribute Summary collapse

Instance Attribute Details

#fast_i_p_move ⇒ ::String

Returns Specifies whether fast IP move is enabled, and if so, the mechanism to achieve it.

Supported values are:

- DISABLED: Fast IP Move is disabled. You can only use the
haPolicy.leader API to update the leader.
- >GARP_RA: Provides a method to very quickly define a new network
endpoint as the leader. This method is faster than updating the leader
using the haPolicy.leader API. Fast IP move works as follows: The VM
hosting the network endpoint that should become the new leader sends
either a Gratuitous ARP (GARP) packet (IPv4) or an ICMPv6 Router
Advertisement(RA) packet (IPv6).  Google Cloud immediately but
temporarily associates the forwarding rule IP address with that VM, and
both new and in-flight packets are quickly delivered to that VM.

Note the important properties of the Fast IP Move functionality:

- The GARP/RA-initiated re-routing stays active for approximately 20
minutes. After triggering fast failover, you must also
appropriately set the haPolicy.leader.
-  The new leader instance should continue to send GARP/RA packets
periodically every 10 seconds until at least 10 minutes after updating
the haPolicy.leader (but stop immediately if it is no longer the leader).
- After triggering a fast failover, we recommend that you wait at least
3 seconds before sending another GARP/RA packet from a different VM
instance to avoid race conditions.
- Don't send GARP/RA packets from different VM
instances at the same time. If multiple instances continue to send
GARP/RA packets, traffic might be routed to different destinations in an
alternating order. This condition ceases when a single instance
issues a GARP/RA packet.
- The GARP/RA request always takes priority over the leader API.
Using the haPolicy.leader API to change the leader to a different
instance will have no effect until the GARP/RA request becomes
inactive.
- The GARP/RA packets should follow the GARP/RA
Packet Specifications..
-  When multiple forwarding rules refer to a regional backend service,
you need only send a GARP or RA packet for a single forwarding rule
virtual IP. The virtual IPs for all forwarding rules targeting the same
backend service will also be moved to the sender of the GARP or RA
packet.

The following are the Fast IP Move limitations (that is, when fastIPMove is not DISABLED):

- Multiple forwarding rules cannot use the same IP address if one of
them refers to a regional backend service with fastIPMove.
- The regional backend service must set the network field, and all
NEGs must belong to that network. However, individual
NEGs can belong to different subnetworks of that network.
- The maximum number of network endpoints across all backends of a
backend service with fastIPMove is 32.
- The maximum number of backend services with fastIPMove that can have
the same network endpoint attached to one of its backends is 64.
- The maximum number of backend services with fastIPMove in a VPC in a
region is 64.
- The network endpoints that are attached to a backend of a backend
service with fastIPMove cannot resolve to Gen3+ machines for IPv6.
- Traffic directed to the leader by a static route next hop will not be
redirected to a new leader by fast failover. Such traffic will only be
redirected once an haPolicy.leader update has taken effect. Only traffic
to the forwarding rule's virtual IP will be redirected to a new leader by
fast failover.

haPolicy.fastIPMove can be set only at backend service creation time. Once set, it cannot be updated.

By default, fastIpMove is set to DISABLED. Check the FastIPMove enum for the list of possible values.

Returns:

  • (::String) —

    Specifies whether fast IP move is enabled, and if so, the mechanism to achieve it.

    Supported values are:

    - DISABLED: Fast IP Move is disabled. You can only use the
    haPolicy.leader API to update the leader.
    - >GARP_RA: Provides a method to very quickly define a new network
    endpoint as the leader. This method is faster than updating the leader
    using the haPolicy.leader API. Fast IP move works as follows: The VM
    hosting the network endpoint that should become the new leader sends
    either a Gratuitous ARP (GARP) packet (IPv4) or an ICMPv6 Router
    Advertisement(RA) packet (IPv6).  Google Cloud immediately but
    temporarily associates the forwarding rule IP address with that VM, and
    both new and in-flight packets are quickly delivered to that VM.
    

    Note the important properties of the Fast IP Move functionality:

    - The GARP/RA-initiated re-routing stays active for approximately 20
    minutes. After triggering fast failover, you must also
    appropriately set the haPolicy.leader.
    -  The new leader instance should continue to send GARP/RA packets
    periodically every 10 seconds until at least 10 minutes after updating
    the haPolicy.leader (but stop immediately if it is no longer the leader).
    - After triggering a fast failover, we recommend that you wait at least
    3 seconds before sending another GARP/RA packet from a different VM
    instance to avoid race conditions.
    - Don't send GARP/RA packets from different VM
    instances at the same time. If multiple instances continue to send
    GARP/RA packets, traffic might be routed to different destinations in an
    alternating order. This condition ceases when a single instance
    issues a GARP/RA packet.
    - The GARP/RA request always takes priority over the leader API.
    Using the haPolicy.leader API to change the leader to a different
    instance will have no effect until the GARP/RA request becomes
    inactive.
    - The GARP/RA packets should follow the GARP/RA
    Packet Specifications..
    -  When multiple forwarding rules refer to a regional backend service,
    you need only send a GARP or RA packet for a single forwarding rule
    virtual IP. The virtual IPs for all forwarding rules targeting the same
    backend service will also be moved to the sender of the GARP or RA
    packet.
    

    The following are the Fast IP Move limitations (that is, when fastIPMove is not DISABLED):

    - Multiple forwarding rules cannot use the same IP address if one of
    them refers to a regional backend service with fastIPMove.
    - The regional backend service must set the network field, and all
    NEGs must belong to that network. However, individual
    NEGs can belong to different subnetworks of that network.
    - The maximum number of network endpoints across all backends of a
    backend service with fastIPMove is 32.
    - The maximum number of backend services with fastIPMove that can have
    the same network endpoint attached to one of its backends is 64.
    - The maximum number of backend services with fastIPMove in a VPC in a
    region is 64.
    - The network endpoints that are attached to a backend of a backend
    service with fastIPMove cannot resolve to Gen3+ machines for IPv6.
    - Traffic directed to the leader by a static route next hop will not be
    redirected to a new leader by fast failover. Such traffic will only be
    redirected once an haPolicy.leader update has taken effect. Only traffic
    to the forwarding rule's virtual IP will be redirected to a new leader by
    fast failover.
    

    haPolicy.fastIPMove can be set only at backend service creation time. Once set, it cannot be updated.

    By default, fastIpMove is set to DISABLED. Check the FastIPMove enum for the list of possible values.



11905
11906
11907
11908
11909
11910
11911
11912
11913
11914
11915
11916
11917
11918
11919
11920
11921
11922
11923
11924
11925
11926
11927
11928
11929
11930
11931
11932
11933
11934
11935
11936
11937
11938
11939
11940
11941
11942
11943
11944
11945
11946
11947
11948
11949
11950
11951
11952
11953
11954
11955
11956
11957
11958
11959
11960
11961
11962
11963
11964
11965
11966
11967
11968
11969
11970
11971
11972
11973
11974
11975
11976
11977
11978
11979
11980
11981
11982
11983
11984
11985
11986
11987
11988
11989
11990
11991
11992
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11905

class BackendServiceHAPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether fast IP move is enabled, and if so, the mechanism to
  # achieve it.
  #
  # Supported values are:
  #
  #    - DISABLED: Fast IP Move is disabled. You can only use the
  #    haPolicy.leader API to update the leader.
  #    - >GARP_RA: Provides a method to very quickly define a new network
  #    endpoint as the leader. This method is faster than updating the leader
  #    using the haPolicy.leader API. Fast IP move works as follows: The VM
  #    hosting the network endpoint that should become the new leader sends
  #    either a Gratuitous ARP (GARP) packet (IPv4) or an ICMPv6 Router
  #    Advertisement(RA) packet (IPv6).  Google Cloud immediately but
  #    temporarily associates the forwarding rule IP address with that VM, and
  #    both new and in-flight packets are quickly delivered to that VM.
  #
  #
  #
  # Note the important properties of the Fast IP Move functionality:
  #
  #    - The GARP/RA-initiated re-routing stays active for approximately 20
  #    minutes. After triggering fast failover, you must also
  #    appropriately set the haPolicy.leader.
  #    -  The new leader instance should continue to send GARP/RA packets
  #    periodically every 10 seconds until at least 10 minutes after updating
  #    the haPolicy.leader (but stop immediately if it is no longer the leader).
  #    - After triggering a fast failover, we recommend that you wait at least
  #    3 seconds before sending another GARP/RA packet from a different VM
  #    instance to avoid race conditions.
  #    - Don't send GARP/RA packets from different VM
  #    instances at the same time. If multiple instances continue to send
  #    GARP/RA packets, traffic might be routed to different destinations in an
  #    alternating order. This condition ceases when a single instance
  #    issues a GARP/RA packet.
  #    - The GARP/RA request always takes priority over the leader API.
  #    Using the haPolicy.leader API to change the leader to a different
  #    instance will have no effect until the GARP/RA request becomes
  #    inactive.
  #    - The GARP/RA packets should follow the GARP/RA
  #    Packet Specifications..
  #    -  When multiple forwarding rules refer to a regional backend service,
  #    you need only send a GARP or RA packet for a single forwarding rule
  #    virtual IP. The virtual IPs for all forwarding rules targeting the same
  #    backend service will also be moved to the sender of the GARP or RA
  #    packet.
  #
  #
  #
  # The following are the Fast IP Move limitations (that is, when fastIPMove
  # is not DISABLED):
  #
  #    - Multiple forwarding rules cannot use the same IP address if one of
  #    them refers to a regional backend service with fastIPMove.
  #    - The regional backend service must set the network field, and all
  #    NEGs must belong to that network. However, individual
  #    NEGs can belong to different subnetworks of that network.
  #    - The maximum number of network endpoints across all backends of a
  #    backend service with fastIPMove is 32.
  #    - The maximum number of backend services with fastIPMove that can have
  #    the same network endpoint attached to one of its backends is 64.
  #    - The maximum number of backend services with fastIPMove in a VPC in a
  #    region is 64.
  #    - The network endpoints that are attached to a backend of a backend
  #    service with fastIPMove cannot resolve to Gen3+ machines for IPv6.
  #    - Traffic directed to the leader by a static route next hop will not be
  #    redirected to a new leader by fast failover. Such traffic will only be
  #    redirected once an haPolicy.leader update has taken effect. Only traffic
  #    to the forwarding rule's virtual IP will be redirected to a new leader by
  #    fast failover.
  #
  #
  # haPolicy.fastIPMove can be set only at backend service creation time.
  # Once set, it cannot be updated.
  #
  # By default, fastIpMove is set to DISABLED.
  module FastIPMove
    # A value indicating that the enum field is not set.
    UNDEFINED_FAST_I_P_MOVE = 0

    DISABLED = 516_696_700

    GARP_RA = 527_352_630
  end
end

#leader ⇒ ::Google::Cloud::Compute::V1::BackendServiceHAPolicyLeader

Returns Selects one of the network endpoints attached to the backend NEGs of this service as the active endpoint (the leader) that receives all traffic.

When the leader changes, there is no connection draining to persist existing connections on the old leader.

You are responsible for selecting a suitable endpoint as the leader. For example, preferring a healthy endpoint over unhealthy ones. Note that this service does not track backend endpoint health, and selects the configured leader unconditionally.

Returns:

  • (::Google::Cloud::Compute::V1::BackendServiceHAPolicyLeader) —

    Selects one of the network endpoints attached to the backend NEGs of this service as the active endpoint (the leader) that receives all traffic.

    When the leader changes, there is no connection draining to persist existing connections on the old leader.

    You are responsible for selecting a suitable endpoint as the leader. For example, preferring a healthy endpoint over unhealthy ones. Note that this service does not track backend endpoint health, and selects the configured leader unconditionally.



11905
11906
11907
11908
11909
11910
11911
11912
11913
11914
11915
11916
11917
11918
11919
11920
11921
11922
11923
11924
11925
11926
11927
11928
11929
11930
11931
11932
11933
11934
11935
11936
11937
11938
11939
11940
11941
11942
11943
11944
11945
11946
11947
11948
11949
11950
11951
11952
11953
11954
11955
11956
11957
11958
11959
11960
11961
11962
11963
11964
11965
11966
11967
11968
11969
11970
11971
11972
11973
11974
11975
11976
11977
11978
11979
11980
11981
11982
11983
11984
11985
11986
11987
11988
11989
11990
11991
11992
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11905

class BackendServiceHAPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether fast IP move is enabled, and if so, the mechanism to
  # achieve it.
  #
  # Supported values are:
  #
  #    - DISABLED: Fast IP Move is disabled. You can only use the
  #    haPolicy.leader API to update the leader.
  #    - >GARP_RA: Provides a method to very quickly define a new network
  #    endpoint as the leader. This method is faster than updating the leader
  #    using the haPolicy.leader API. Fast IP move works as follows: The VM
  #    hosting the network endpoint that should become the new leader sends
  #    either a Gratuitous ARP (GARP) packet (IPv4) or an ICMPv6 Router
  #    Advertisement(RA) packet (IPv6).  Google Cloud immediately but
  #    temporarily associates the forwarding rule IP address with that VM, and
  #    both new and in-flight packets are quickly delivered to that VM.
  #
  #
  #
  # Note the important properties of the Fast IP Move functionality:
  #
  #    - The GARP/RA-initiated re-routing stays active for approximately 20
  #    minutes. After triggering fast failover, you must also
  #    appropriately set the haPolicy.leader.
  #    -  The new leader instance should continue to send GARP/RA packets
  #    periodically every 10 seconds until at least 10 minutes after updating
  #    the haPolicy.leader (but stop immediately if it is no longer the leader).
  #    - After triggering a fast failover, we recommend that you wait at least
  #    3 seconds before sending another GARP/RA packet from a different VM
  #    instance to avoid race conditions.
  #    - Don't send GARP/RA packets from different VM
  #    instances at the same time. If multiple instances continue to send
  #    GARP/RA packets, traffic might be routed to different destinations in an
  #    alternating order. This condition ceases when a single instance
  #    issues a GARP/RA packet.
  #    - The GARP/RA request always takes priority over the leader API.
  #    Using the haPolicy.leader API to change the leader to a different
  #    instance will have no effect until the GARP/RA request becomes
  #    inactive.
  #    - The GARP/RA packets should follow the GARP/RA
  #    Packet Specifications..
  #    -  When multiple forwarding rules refer to a regional backend service,
  #    you need only send a GARP or RA packet for a single forwarding rule
  #    virtual IP. The virtual IPs for all forwarding rules targeting the same
  #    backend service will also be moved to the sender of the GARP or RA
  #    packet.
  #
  #
  #
  # The following are the Fast IP Move limitations (that is, when fastIPMove
  # is not DISABLED):
  #
  #    - Multiple forwarding rules cannot use the same IP address if one of
  #    them refers to a regional backend service with fastIPMove.
  #    - The regional backend service must set the network field, and all
  #    NEGs must belong to that network. However, individual
  #    NEGs can belong to different subnetworks of that network.
  #    - The maximum number of network endpoints across all backends of a
  #    backend service with fastIPMove is 32.
  #    - The maximum number of backend services with fastIPMove that can have
  #    the same network endpoint attached to one of its backends is 64.
  #    - The maximum number of backend services with fastIPMove in a VPC in a
  #    region is 64.
  #    - The network endpoints that are attached to a backend of a backend
  #    service with fastIPMove cannot resolve to Gen3+ machines for IPv6.
  #    - Traffic directed to the leader by a static route next hop will not be
  #    redirected to a new leader by fast failover. Such traffic will only be
  #    redirected once an haPolicy.leader update has taken effect. Only traffic
  #    to the forwarding rule's virtual IP will be redirected to a new leader by
  #    fast failover.
  #
  #
  # haPolicy.fastIPMove can be set only at backend service creation time.
  # Once set, it cannot be updated.
  #
  # By default, fastIpMove is set to DISABLED.
  module FastIPMove
    # A value indicating that the enum field is not set.
    UNDEFINED_FAST_I_P_MOVE = 0

    DISABLED = 516_696_700

    GARP_RA = 527_352_630
  end
end