Class: Google::Cloud::Compute::V1::BackendServiceHAPolicyLeader
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceHAPolicyLeader
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#backend_group ⇒ ::String
A fully-qualified URL (starting with https://www.googleapis.com/) of the zonal Network Endpoint Group (NEG) with
GCE_VM_IPendpoints that the leader is attached to. -
#network_endpoint ⇒ ::Google::Cloud::Compute::V1::BackendServiceHAPolicyLeaderNetworkEndpoint
The network endpoint within the leader.backendGroup that is designated as the leader.
Instance Attribute Details
#backend_group ⇒ ::String
Returns A fully-qualified URL (starting with https://www.googleapis.com/)
of the zonal Network Endpoint Group (NEG) with GCE_VM_IP endpoints
that the leader is attached to.
The leader's backendGroup must already be specified as a backend of this backend service. Removing a backend that is designated as the leader's backendGroup is not permitted.
11735 11736 11737 11738 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11735 class BackendServiceHAPolicyLeader include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network_endpoint ⇒ ::Google::Cloud::Compute::V1::BackendServiceHAPolicyLeaderNetworkEndpoint
Returns The network endpoint within the leader.backendGroup that is designated as the leader.
This network endpoint cannot be detached from the NEG specified in the haPolicy.leader.backendGroup until the leader is updated with another network endpoint, or the leader is removed from the haPolicy.
11735 11736 11737 11738 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11735 class BackendServiceHAPolicyLeader include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |