Class: Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The configuration for a custom policy implemented by the user and deployed with the client.
Instance Attribute Summary collapse
-
#data ⇒ ::String
An optional, arbitrary JSON object with configuration data, understood by a locally installed custom policy implementation.
-
#name ⇒ ::String
Identifies the custom policy.
Instance Attribute Details
#data ⇒ ::String
4268 4269 4270 4271 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 4268 class BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
4268 4269 4270 4271 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 4268 class BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |