Class: Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#zonal_affinity ⇒ ::Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
When configured, new connections are load balanced across healthy backend endpoints in the local zone.
Instance Attribute Details
#zonal_affinity ⇒ ::Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
Returns When configured, new connections are load balanced across healthy backend endpoints in the local zone.
12022 12023 12024 12025 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12022 class BackendServiceNetworkPassThroughLbTrafficPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |