Module: Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity::Spillover

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

This field indicates whether zonal affinity is enabled or not. The possible values are:

  • ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity is disabled. The load balancer distributes new connections to all healthy backend endpoints across all zones.
  • ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there are no healthy backend endpoints in the local zone, the load balancer distributes new connections to all backend endpoints in the local zone.
  • ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there aren't enough healthy backend endpoints in the local zone, the load balancer distributes new connections to all healthy backend endpoints across all zones.

Constant Summary collapse

UNDEFINED_SPILLOVER =

A value indicating that the enum field is not set.

0
ZONAL_AFFINITY_DISABLED =
230_207_960
ZONAL_AFFINITY_SPILL_CROSS_ZONE =
251_048_410
ZONAL_AFFINITY_STAY_WITHIN_ZONE =
12_177_782