Class: Google::Cloud::Compute::V1::BackendServiceOrchestrationInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A message containing information about the resource or system that manages the backend service.

Instance Attribute Summary collapse

Instance Attribute Details

#resource_uri::String

Returns The resource URI of the resource or system that manages the backend service.

Returns:

  • (::String)

    The resource URI of the resource or system that manages the backend service.



12221
12222
12223
12224
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12221

class BackendServiceOrchestrationInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end