Class: Google::Cloud::Compute::V1::BgpRouteAsPath
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BgpRouteAsPath
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#asns ⇒ ::Array<::Integer>
Output only.
-
#asns32 ⇒ ::Array<::Integer>
Output only.
-
#type ⇒ ::String
Output only.
Instance Attribute Details
#asns ⇒ ::Array<::Integer>
Returns Output only. [Output only] ASNs in the path segment. When type is SEQUENCE, these are ordered.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12827 class BgpRouteAsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output only] Type of AS-PATH segment (SEQUENCE or SET) module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 AS_PATH_TYPE_SEQUENCE = 362_887_609 AS_PATH_TYPE_SET = 302_584_650 end end |
#asns32 ⇒ ::Array<::Integer>
Returns Output only. [Output only] ASNs in the path segment. This field is for better support of 32 bit ASNs as the other asns field suffers from overflow when the ASN is larger. When type is SEQUENCE, these are ordered.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12827 class BgpRouteAsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output only] Type of AS-PATH segment (SEQUENCE or SET) module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 AS_PATH_TYPE_SEQUENCE = 362_887_609 AS_PATH_TYPE_SET = 302_584_650 end end |
#type ⇒ ::String
Returns Output only. [Output only] Type of AS-PATH segment (SEQUENCE or SET) Check the Type enum for the list of possible values.
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12827 class BgpRouteAsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output only] Type of AS-PATH segment (SEQUENCE or SET) module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 AS_PATH_TYPE_SEQUENCE = 362_887_609 AS_PATH_TYPE_SET = 302_584_650 end end |