Class: Google::Cloud::Compute::V1::Binding
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Binding
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Associates members, or principals, with a role.
Instance Attribute Summary collapse
- #binding_id ⇒ ::String
-
#condition ⇒ ::Google::Cloud::Compute::V1::Expr
The condition that is associated with this binding.
-
#members ⇒ ::Array<::String>
Specifies the principals requesting access for a Google Cloud resource.
-
#role ⇒ ::String
Role that is assigned to the list of
members, or principals.
Instance Attribute Details
#binding_id ⇒ ::String
12633 12634 12635 12636 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12633 class Binding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#condition ⇒ ::Google::Cloud::Compute::V1::Expr
Returns The condition that is associated with this binding.
If the condition evaluates to true, then this binding applies to the
current request.
If the condition evaluates to false, then this binding does not apply to
the current request. However, a different role binding might grant the same
role to one or more of the principals in this binding.
To learn which resources support conditions in their IAM policies, see the IAM documentation.
12633 12634 12635 12636 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12633 class Binding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#members ⇒ ::Array<::String>
Returns Specifies the principals requesting access for a Google Cloud resource.
members can have the following values:
allUsers: A special identifier that represents anyone who is on the internet; with or without a Google account.allAuthenticatedUsers: A special identifier that represents anyone who is authenticated with a Google account or a service account. Does not include identities that come from external identity providers (IdPs) through identity federation.user:{emailid}: An email address that represents a specific Google account. For example,alice@example.com.serviceAccount:{emailid}: An email address that represents a Google service account. For example,my-other-app@appspot.gserviceaccount.com.serviceAccount:{projectid}.svc.id.goog[{namespace}/{kubernetes-sa}]: An identifier for a Kubernetes service account. For example,my-project.svc.id.goog[my-namespace/my-kubernetes-sa].group:{emailid}: An email address that represents a Google group. For example,admins@example.com.domain:{domain}: The G Suite domain (primary) that represents all the users of that domain. For example,google.comorexample.com.principal://iam.googleapis.com/locations/global/workforcePools/{pool_id}/subject/{subject_attribute_value}: A single identity in a workforce identity pool.principalSet://iam.googleapis.com/locations/global/workforcePools/{pool_id}/group/{group_id}: All workforce identities in a group.principalSet://iam.googleapis.com/locations/global/workforcePools/{pool_id}/attribute.{attribute_name}/{attribute_value}: All workforce identities with a specific attribute value.principalSet://iam.googleapis.com/locations/global/workforcePools/{pool_id}/*: All identities in a workforce identity pool.principal://iam.googleapis.com/projects/{project_number}/locations/global/workloadIdentityPools/{pool_id}/subject/{subject_attribute_value}: A single identity in a workload identity pool.principalSet://iam.googleapis.com/projects/{project_number}/locations/global/workloadIdentityPools/{pool_id}/group/{group_id}: A workload identity pool group.principalSet://iam.googleapis.com/projects/{project_number}/locations/global/workloadIdentityPools/{pool_id}/attribute.{attribute_name}/{attribute_value}: All identities in a workload identity pool with a certain attribute.principalSet://iam.googleapis.com/projects/{project_number}/locations/global/workloadIdentityPools/{pool_id}/*: All identities in a workload identity pool.deleted:user:{emailid}?uid={uniqueid}: An email address (plus unique identifier) representing a user that has been recently deleted. For example,alice@example.com?uid=123456789012345678901. If the user is recovered, this value reverts touser:{emailid}and the recovered user retains the role in the binding.deleted:serviceAccount:{emailid}?uid={uniqueid}: An email address (plus unique identifier) representing a service account that has been recently deleted. For example,my-other-app@appspot.gserviceaccount.com?uid=123456789012345678901. If the service account is undeleted, this value reverts toserviceAccount:{emailid}and the undeleted service account retains the role in the binding.deleted:group:{emailid}?uid={uniqueid}: An email address (plus unique identifier) representing a Google group that has been recently deleted. For example,admins@example.com?uid=123456789012345678901. If the group is recovered, this value reverts togroup:{emailid}and the recovered group retains the role in the binding.deleted:principal://iam.googleapis.com/locations/global/workforcePools/{pool_id}/subject/{subject_attribute_value}: Deleted single identity in a workforce identity pool. For example,deleted:principal://iam.googleapis.com/locations/global/workforcePools/my-pool-id/subject/my-subject-attribute-value.
12633 12634 12635 12636 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12633 class Binding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#role ⇒ ::String
Returns Role that is assigned to the list of members, or principals.
For example, roles/viewer, roles/editor, or roles/owner.
For an overview of the IAM roles and permissions, see the IAM documentation. For a list of the available pre-defined roles, see here.
12633 12634 12635 12636 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12633 class Binding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |