Class: Google::Cloud::Compute::V1::BulkInsertInstanceResource
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BulkInsertInstanceResource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A transient resource used in compute.instances.bulkInsert and compute.regionInstances.bulkInsert . This resource is not persisted anywhere, it is used only for processing the requests.
Defined Under Namespace
Classes: PerInstancePropertiesEntry
Instance Attribute Summary collapse
-
#count ⇒ ::Integer
The maximum number of instances to create.
-
#instance_flexibility_policy ⇒ ::Google::Cloud::Compute::V1::InstanceFlexibilityPolicy
A flexible specification of machine type of instances to create.
-
#instance_properties ⇒ ::Google::Cloud::Compute::V1::InstanceProperties
The instance properties defining the VM instances to be created.
-
#location_policy ⇒ ::Google::Cloud::Compute::V1::LocationPolicy
Policy for choosing target zone.
-
#min_count ⇒ ::Integer
The minimum number of instances to create.
-
#name_pattern ⇒ ::String
The string pattern used for the names of the VMs.
-
#per_instance_properties ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties}
Per-instance properties to be set on individual instances.
-
#source_instance_template ⇒ ::String
Specifies the instance template from which to create instances.
Instance Attribute Details
#count ⇒ ::Integer
Returns The maximum number of instances to create.
12785 12786 12787 12788 12789 12790 12791 12792 12793 12794 12795 12796 12797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12785 class BulkInsertInstanceResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties] class PerInstancePropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#instance_flexibility_policy ⇒ ::Google::Cloud::Compute::V1::InstanceFlexibilityPolicy
Returns A flexible specification of machine type of instances to create.
12785 12786 12787 12788 12789 12790 12791 12792 12793 12794 12795 12796 12797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12785 class BulkInsertInstanceResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties] class PerInstancePropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#instance_properties ⇒ ::Google::Cloud::Compute::V1::InstanceProperties
Returns The instance properties defining the VM instances to be created. Required if sourceInstanceTemplate is not provided.
12785 12786 12787 12788 12789 12790 12791 12792 12793 12794 12795 12796 12797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12785 class BulkInsertInstanceResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties] class PerInstancePropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#location_policy ⇒ ::Google::Cloud::Compute::V1::LocationPolicy
Returns Policy for choosing target zone. For more information, seeCreate VMs in bulk.
12785 12786 12787 12788 12789 12790 12791 12792 12793 12794 12795 12796 12797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12785 class BulkInsertInstanceResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties] class PerInstancePropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#min_count ⇒ ::Integer
Returns The minimum number of instances to create. If no min_count is specified then count is used as the default value. Ifmin_count instances cannot be created, then no instances will be created and instances already created will be deleted.
12785 12786 12787 12788 12789 12790 12791 12792 12793 12794 12795 12796 12797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12785 class BulkInsertInstanceResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties] class PerInstancePropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name_pattern ⇒ ::String
Returns The string pattern used for the names of the VMs. Either name_pattern or per_instance_properties must be set. The pattern must contain one continuous sequence of placeholder hash characters (#) with each character corresponding to one digit of the generated instance name. Example: a name_pattern of inst-#### generates instance names such asinst-0001 and inst-0002. If existing instances in the same project and zone have names that match the name pattern then the generated instance numbers start after the biggest existing number. For example, if there exists an instance with nameinst-0050, then instance names generated using the patterninst-#### begin with inst-0051. The name pattern placeholder #...# can contain up to 18 characters.
12785 12786 12787 12788 12789 12790 12791 12792 12793 12794 12795 12796 12797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12785 class BulkInsertInstanceResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties] class PerInstancePropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#per_instance_properties ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties}
Returns Per-instance properties to be set on individual instances. Keys of this map specify requested instance names. Can be empty if name_pattern is used.
12785 12786 12787 12788 12789 12790 12791 12792 12793 12794 12795 12796 12797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12785 class BulkInsertInstanceResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties] class PerInstancePropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source_instance_template ⇒ ::String
Returns Specifies the instance template from which to create instances. You may combine sourceInstanceTemplate withinstanceProperties to override specific values from an existing instance template. Bulk API follows the semantics of JSON Merge Patch described by RFC 7396.
It can be a full or partial URL. For example, the following are all valid URLs to an instance template:
- https://www.googleapis.com/compute/v1/projects/project/global/instanceTemplates/instanceTemplate
- projects/project/global/instanceTemplates/instanceTemplate
- global/instanceTemplates/instanceTemplate
This field is optional.
12785 12786 12787 12788 12789 12790 12791 12792 12793 12794 12795 12796 12797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12785 class BulkInsertInstanceResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::BulkInsertInstanceResourcePerInstanceProperties] class PerInstancePropertiesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |