Class: Google::Cloud::Compute::V1::BundledLocalSsds

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#default_interface::String

Returns The default disk interface if the interface is not specified.

Returns:

  • (::String)

    The default disk interface if the interface is not specified.



12985
12986
12987
12988
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12985

class BundledLocalSsds
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#partition_count::Integer

Returns The number of partitions.

Returns:

  • (::Integer)

    The number of partitions.



12985
12986
12987
12988
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12985

class BundledLocalSsds
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end