Module: Google::Cloud::Compute::V1::CachePolicy::CacheMode
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies the cache setting for all responses from this route. If not
specified, Cloud CDN uses CACHE_ALL_STATIC mode.
Constant Summary collapse
- UNDEFINED_CACHE_MODE =
A value indicating that the enum field is not set.
0- CACHE_ALL_STATIC =
Automatically cache static content, including common image formats, media (video and audio), and web assets (JavaScript and CSS). Requests and responses that are marked as uncacheable, as well as dynamic content (including HTML), will not be cached.
355_027_945- FORCE_CACHE_ALL =
Cache all content, ignoring any "private", "no-store" or "no-cache" directives in Cache-Control response headers. Warning: this may result in Cloud CDN caching private, per-user (user identifiable) content.
486_026_928- USE_ORIGIN_HEADERS =
Requires the origin to set valid caching headers to cache content. Responses without these headers will not be cached at the edge, and will require a full trip to the origin on every request, potentially impacting performance and increasing load on the origin server.
55_380_261