Class: Google::Cloud::Compute::V1::CachePolicyNegativeCachingPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specify CDN TTLs for response error codes.

Instance Attribute Summary collapse

Instance Attribute Details

#code::Integer

Returns The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 can be specified as values, and you cannot specify a status code more than once.

Returns:

  • (::Integer)

    The HTTP status code to define a TTL against. Only HTTP status codes 300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 can be specified as values, and you cannot specify a status code more than once.



13392
13393
13394
13395
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13392

class CachePolicyNegativeCachingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ttl::Google::Cloud::Compute::V1::Duration

Returns The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes). Infrequently accessed objects may be evicted from the cache before the defined TTL.

Returns:

  • (::Google::Cloud::Compute::V1::Duration)

    The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes). Infrequently accessed objects may be evicted from the cache before the defined TTL.



13392
13393
13394
13395
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13392

class CachePolicyNegativeCachingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end