Class: Google::Cloud::Compute::V1::CalendarModeAdviceResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CalendarModeAdviceResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A response containing the recommended way of creating the specified resources in the future. It contains (will contain) multiple recommendations that can be analyzed by the customer and the best one can be picked.
Instance Attribute Summary collapse
-
#recommendations ⇒ ::Array<::Google::Cloud::Compute::V1::CalendarModeRecommendation>
Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost.
Instance Attribute Details
#recommendations ⇒ ::Array<::Google::Cloud::Compute::V1::CalendarModeRecommendation>
Returns Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost.
13633 13634 13635 13636 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13633 class CalendarModeAdviceResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |