Class: Google::Cloud::Compute::V1::CancelRolloutRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for Rollouts.Cancel. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



13628
13629
13630
13631
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13628

class CancelRolloutRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



13628
13629
13630
13631
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13628

class CancelRolloutRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rollback::Boolean

Returns Optional. If true, then the ongoing rollout must be rolled back. Else, just cancel the rollout without taking any further actions. Note that products must support at least one of these options, however, it does not need to support both.

Returns:

  • (::Boolean)

    Optional. If true, then the ongoing rollout must be rolled back. Else, just cancel the rollout without taking any further actions. Note that products must support at least one of these options, however, it does not need to support both.



13628
13629
13630
13631
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13628

class CancelRolloutRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rollout::String

Returns Name of the Rollout resource to cancel.

Returns:

  • (::String)

    Name of the Rollout resource to cancel.



13628
13629
13630
13631
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13628

class CancelRolloutRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end