Class: Google::Cloud::Compute::V1::CapacityAdviceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CapacityAdviceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request to provide Assistant Scores. These scores determine VM obtainability and preemption likelihood.
Instance Attribute Summary collapse
-
#distribution_policy ⇒ ::Google::Cloud::Compute::V1::CapacityAdviceRequestDistributionPolicy
Policy specifying the distribution of instances across zones within the requested region.
-
#instance_flexibility_policy ⇒ ::Google::Cloud::Compute::V1::CapacityAdviceRequestInstanceFlexibilityPolicy
Policy for instance selectors.
-
#instance_properties ⇒ ::Google::Cloud::Compute::V1::CapacityAdviceRequestInstanceProperties
Instance properties for this request.
-
#size ⇒ ::Integer
The number of VM instances to request.
Instance Attribute Details
#distribution_policy ⇒ ::Google::Cloud::Compute::V1::CapacityAdviceRequestDistributionPolicy
Returns Policy specifying the distribution of instances across zones within the requested region.
13855 13856 13857 13858 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13855 class CapacityAdviceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_flexibility_policy ⇒ ::Google::Cloud::Compute::V1::CapacityAdviceRequestInstanceFlexibilityPolicy
Returns Policy for instance selectors.
13855 13856 13857 13858 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13855 class CapacityAdviceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_properties ⇒ ::Google::Cloud::Compute::V1::CapacityAdviceRequestInstanceProperties
Returns Instance properties for this request.
13855 13856 13857 13858 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13855 class CapacityAdviceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#size ⇒ ::Integer
Returns The number of VM instances to request.
13855 13856 13857 13858 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13855 class CapacityAdviceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |