Class: Google::Cloud::Compute::V1::CapacityAdviceRequestDistributionPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Distribution policy.

Defined Under Namespace

Modules: TargetShape

Instance Attribute Summary collapse

Instance Attribute Details

#target_shape ⇒ ::String

Returns Target distribution shape. You can specify the following values:ANY, ANY_SINGLE_ZONE, or BALANCED. Check the TargetShape enum for the list of possible values.

Returns:

  • (::String) —

    Target distribution shape. You can specify the following values:ANY, ANY_SINGLE_ZONE, or BALANCED. Check the TargetShape enum for the list of possible values.



13868
13869
13870
13871
13872
13873
13874
13875
13876
13877
13878
13879
13880
13881
13882
13883
13884
13885
13886
13887
13888
13889
13890
13891
13892
13893
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13868

class CapacityAdviceRequestDistributionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Target distribution shape. You can specify the following values:ANY, ANY_SINGLE_ZONE, or BALANCED.
  module TargetShape
    # A value indicating that the enum field is not set.
    UNDEFINED_TARGET_SHAPE = 0

    # Picks zones for creating VM instances to fulfill the requested number
    # of VMs within present resource constraints.
    ANY = 64_972

    # Creates all VM instances within a single zone. The zone is selected
    # based on the present resource constraints.
    ANY_SINGLE_ZONE = 61_100_880

    # Prioritizes acquisition of resources, scheduling VMs in zones where
    # resources are available while distributing VMs as evenly as possible
    # across selected zones to minimize the impact of zonal failure.
    BALANCED = 468_409_608

    # Default value, unused.
    TARGET_SHAPE_UNSPECIFIED = 449_316_907
  end
end

#zones ⇒ ::Array<::Google::Cloud::Compute::V1::CapacityAdviceRequestDistributionPolicyZoneConfiguration>

Returns Zones where Capacity Advisor looks for capacity.

Returns:



13868
13869
13870
13871
13872
13873
13874
13875
13876
13877
13878
13879
13880
13881
13882
13883
13884
13885
13886
13887
13888
13889
13890
13891
13892
13893
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13868

class CapacityAdviceRequestDistributionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Target distribution shape. You can specify the following values:ANY, ANY_SINGLE_ZONE, or BALANCED.
  module TargetShape
    # A value indicating that the enum field is not set.
    UNDEFINED_TARGET_SHAPE = 0

    # Picks zones for creating VM instances to fulfill the requested number
    # of VMs within present resource constraints.
    ANY = 64_972

    # Creates all VM instances within a single zone. The zone is selected
    # based on the present resource constraints.
    ANY_SINGLE_ZONE = 61_100_880

    # Prioritizes acquisition of resources, scheduling VMs in zones where
    # resources are available while distributing VMs as evenly as possible
    # across selected zones to minimize the impact of zonal failure.
    BALANCED = 468_409_608

    # Default value, unused.
    TARGET_SHAPE_UNSPECIFIED = 449_316_907
  end
end