Class: Google::Cloud::Compute::V1::CapacityAdviceRequestInstanceFlexibilityPolicyInstanceSelectionAttachedDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Attached disk configuration.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#type ⇒ ::String

Returns Specifies the type of the disk. Check the Type enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the type of the disk. Check the Type enum for the list of possible values.



13950
13951
13952
13953
13954
13955
13956
13957
13958
13959
13960
13961
13962
13963
13964
13965
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13950

class CapacityAdviceRequestInstanceFlexibilityPolicyInstanceSelectionAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the disk.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Default value, unspecified disk type.
    DISK_TYPE_UNSPECIFIED = 333_621_236

    # Scratch disk (Local SSD).
    SCRATCH = 496_778_970
  end
end