Class: Google::Cloud::Compute::V1::CapacityAdviceRequestInstancePropertiesScheduling

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Defines the instance scheduling options.

Defined Under Namespace

Modules: ProvisioningModel

Instance Attribute Summary collapse

Instance Attribute Details

#provisioning_model ⇒ ::String

Returns Specifies the provisioning model. Check the ProvisioningModel enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the provisioning model. Check the ProvisioningModel enum for the list of possible values.



13981
13982
13983
13984
13985
13986
13987
13988
13989
13990
13991
13992
13993
13994
13995
13996
13997
13998
13999
14000
14001
14002
14003
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13981

class CapacityAdviceRequestInstancePropertiesScheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the provisioning model.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end