Class: Google::Cloud::Compute::V1::CapacityAdviceResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CapacityAdviceResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A response contains scoring recommendations.
Instance Attribute Summary collapse
-
#recommendations ⇒ ::Array<::Google::Cloud::Compute::V1::CapacityAdviceResponseRecommendation>
Initially the API will provide one recommendation which balances the individual scores according to the service provider's preference.
Instance Attribute Details
#recommendations ⇒ ::Array<::Google::Cloud::Compute::V1::CapacityAdviceResponseRecommendation>
Returns Initially the API will provide one recommendation which balances the individual scores according to the service provider's preference.
14010 14011 14012 14013 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14010 class CapacityAdviceResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |