Class: Google::Cloud::Compute::V1::CapacityHistoryRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request to get the capacity history.

Defined Under Namespace

Modules: Types

Instance Attribute Summary collapse

Instance Attribute Details

#instance_properties ⇒ ::Google::Cloud::Compute::V1::CapacityHistoryRequestInstanceProperties

Returns Instance properties for this request.

Returns:



14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14124

class CapacityHistoryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Types
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPES = 0

    # Default value, unused.
    HISTORY_TYPE_UNSPECIFIED = 58_549_757

    # Preemption history.
    PREEMPTION = 512_869_337

    # Price history.
    PRICE = 76_396_841
  end
end

#location_policy ⇒ ::Google::Cloud::Compute::V1::CapacityHistoryRequestLocationPolicy

Returns Location policy for this request.

Returns:



14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14124

class CapacityHistoryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Types
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPES = 0

    # Default value, unused.
    HISTORY_TYPE_UNSPECIFIED = 58_549_757

    # Preemption history.
    PREEMPTION = 512_869_337

    # Price history.
    PRICE = 76_396_841
  end
end

#types ⇒ ::Array<::String>

Returns List of history types to get capacity history for. Check the Types enum for the list of possible values.

Returns:

  • (::Array<::String>) —

    List of history types to get capacity history for. Check the Types enum for the list of possible values.



14124
14125
14126
14127
14128
14129
14130
14131
14132
14133
14134
14135
14136
14137
14138
14139
14140
14141
14142
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14124

class CapacityHistoryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Types
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPES = 0

    # Default value, unused.
    HISTORY_TYPE_UNSPECIFIED = 58_549_757

    # Preemption history.
    PREEMPTION = 512_869_337

    # Price history.
    PRICE = 76_396_841
  end
end