Module: Google::Cloud::Compute::V1::CapacityHistoryRequestInstancePropertiesScheduling::ProvisioningModel
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The provisioning model to get capacity history for. This field must be set to SPOT.
For more information, see Compute Engine instances provisioning models.
Constant Summary collapse
- UNDEFINED_PROVISIONING_MODEL =
A value indicating that the enum field is not set.
0- FLEX_START =
Instance is provisioned using the Flex Start provisioning model and has a limited runtime.
101_746_812- RESERVATION_BOUND =
Bound to the lifecycle of the reservation in which it is provisioned.
293_538_571- SPOT =
Heavily discounted, no guaranteed runtime.
2_552_066- STANDARD =
Standard provisioning with user controlled runtime, no discounts.
484_642_493