Class: Google::Cloud::Compute::V1::CommitmentResourceStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] Contains output only fields.

Instance Attribute Summary collapse

Instance Attribute Details

#custom_term_eligibility_end_timestamp::String

Returns [Output Only] Indicates the end time of customer's eligibility to send custom term requests in RFC3339 text format. Term extension requests that (not the end time in the request) after this time will be rejected.

Returns:

  • (::String)

    [Output Only] Indicates the end time of customer's eligibility to send custom term requests in RFC3339 text format. Term extension requests that (not the end time in the request) after this time will be rejected.



5261
5262
5263
5264
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 5261

class CommitmentResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end