Class: Google::Cloud::Compute::V1::CompositeHealthChecksGetHealthResponseHealthSourceHealth

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: HealthState

Instance Attribute Summary collapse

Instance Attribute Details

#health_state ⇒ ::String

Returns Health state of the associated HealthSource resource. Check the HealthState enum for the list of possible values.

Returns:

  • (::String) —

    Health state of the associated HealthSource resource. Check the HealthState enum for the list of possible values.



15004
15005
15006
15007
15008
15009
15010
15011
15012
15013
15014
15015
15016
15017
15018
15019
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15004

class CompositeHealthChecksGetHealthResponseHealthSourceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the associated HealthSource resource.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end

#source ⇒ ::String

Returns Fully qualified URL of the associated HealthSource resource.

Returns:

  • (::String) —

    Fully qualified URL of the associated HealthSource resource.



15004
15005
15006
15007
15008
15009
15010
15011
15012
15013
15014
15015
15016
15017
15018
15019
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15004

class CompositeHealthChecksGetHealthResponseHealthSourceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the associated HealthSource resource.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end