Class: Google::Cloud::Compute::V1::CompositeHealthChecksScopedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CompositeHealthChecksScopedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#composite_health_checks ⇒ ::Array<::Google::Cloud::Compute::V1::CompositeHealthCheck>
A list of CompositeHealthChecks contained in this scope.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Informational warning which replaces the list of composite health checks when the list is empty.
Instance Attribute Details
#composite_health_checks ⇒ ::Array<::Google::Cloud::Compute::V1::CompositeHealthCheck>
Returns A list of CompositeHealthChecks contained in this scope.
14190 14191 14192 14193 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14190 class CompositeHealthChecksScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Informational warning which replaces the list of composite health checks when the list is empty.
14190 14191 14192 14193 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14190 class CompositeHealthChecksScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |