Class: Google::Cloud::Compute::V1::ConfidentialInstanceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A set of Confidential Instance options.

Defined Under Namespace

Modules: ConfidentialInstanceType

Instance Attribute Summary collapse

Instance Attribute Details

#confidential_instance_type ⇒ ::String

Returns Defines the type of technology used by the confidential instance. Check the ConfidentialInstanceType enum for the list of possible values.

Returns:

  • (::String) —

    Defines the type of technology used by the confidential instance. Check the ConfidentialInstanceType enum for the list of possible values.



15041
15042
15043
15044
15045
15046
15047
15048
15049
15050
15051
15052
15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15041

class ConfidentialInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the type of technology used by the confidential instance.
  module ConfidentialInstanceType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE = 0

    # Bare Metal Secure AI.
    BMSAI = 63_328_144

    # Arm Confidential Compute Architecture.
    CCA = 66_529

    # No type specified. Do not use this value.
    CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 115_021_829

    # AMD Secure Encrypted Virtualization.
    SEV = 81_988

    # AMD Secure Encrypted Virtualization - Secure Nested Paging.
    SEV_SNP = 21_753_562

    # Intel Trust Domain eXtension.
    TDX = 82_920
  end
end

#enable_confidential_compute ⇒ ::Boolean

Returns Defines whether the instance should have confidential compute enabled.

Returns:

  • (::Boolean) —

    Defines whether the instance should have confidential compute enabled.



15041
15042
15043
15044
15045
15046
15047
15048
15049
15050
15051
15052
15053
15054
15055
15056
15057
15058
15059
15060
15061
15062
15063
15064
15065
15066
15067
15068
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15041

class ConfidentialInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the type of technology used by the confidential instance.
  module ConfidentialInstanceType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE = 0

    # Bare Metal Secure AI.
    BMSAI = 63_328_144

    # Arm Confidential Compute Architecture.
    CCA = 66_529

    # No type specified. Do not use this value.
    CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 115_021_829

    # AMD Secure Encrypted Virtualization.
    SEV = 81_988

    # AMD Secure Encrypted Virtualization - Secure Nested Paging.
    SEV_SNP = 21_753_562

    # Intel Trust Domain eXtension.
    TDX = 82_920
  end
end