Class: Google::Cloud::Compute::V1::CrossSiteNetwork

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A resource that represents a cross-site network.

You can use cross-site networks to connect your on-premises networks to each other through Interconnect connections.

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp ⇒ ::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String) —

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



15387
15388
15389
15390
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15387

class CrossSiteNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description ⇒ ::String

Returns An optional description of the cross-site network.

Returns:

  • (::String) —

    An optional description of the cross-site network.



15387
15388
15389
15390
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15387

class CrossSiteNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id ⇒ ::Integer

Returns Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.

Returns:

  • (::Integer) —

    Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.



15387
15388
15389
15390
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15387

class CrossSiteNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#crossSiteNetwork for cross-site networks.

Returns:

  • (::String) —

    Output only. [Output Only] Type of the resource. Alwayscompute#crossSiteNetwork for cross-site networks.



15387
15388
15389
15390
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15387

class CrossSiteNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String) —

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



15387
15388
15389
15390
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15387

class CrossSiteNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for the resource.



15387
15388
15389
15390
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15387

class CrossSiteNetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end