Class: Google::Cloud::Compute::V1::CustomErrorResponsePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.

Instance Attribute Summary collapse

Instance Attribute Details

#error_response_rules::Array<::Google::Cloud::Compute::V1::CustomErrorResponsePolicyCustomErrorResponseRule>



5710
5711
5712
5713
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 5710

class CustomErrorResponsePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#error_service::String



5710
5711
5712
5713
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 5710

class CustomErrorResponsePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end