Class: Google::Cloud::Compute::V1::CustomErrorResponsePolicyCustomErrorResponseRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specifies the mapping between the response code that will be returned along with the custom error content and the response code returned by the backend service.

Instance Attribute Summary collapse

Instance Attribute Details

#match_response_codes::Array<::String>

Returns Valid values include:

 - A number between 400 and 599: For example
 401 or 503, in which case the load balancer
 applies the policy if the error code exactly matches this value.
 - 5xx: Load Balancer will apply the policy if the
 backend service responds with any response code in the range of
 500 to 599.
  • 4xx: Load Balancer will apply the policy if the backend service responds with any response code in the range of 400 to 499.

Values must be unique within matchResponseCodes and across allerrorResponseRules ofCustomErrorResponsePolicy.

Returns:

  • (::Array<::String>)

    Valid values include:

     - A number between 400 and 599: For example
     401 or 503, in which case the load balancer
     applies the policy if the error code exactly matches this value.
     - 5xx: Load Balancer will apply the policy if the
     backend service responds with any response code in the range of
     500 to 599.
    
    • 4xx: Load Balancer will apply the policy if the backend service responds with any response code in the range of 400 to 499.

    Values must be unique within matchResponseCodes and across allerrorResponseRules ofCustomErrorResponsePolicy.



14655
14656
14657
14658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14655

class CustomErrorResponsePolicyCustomErrorResponseRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#override_response_code::Integer

Returns The HTTP status code returned with the response containing the custom error content. If overrideResponseCode is not supplied, the same response code returned by the original backend bucket or backend service is returned to the client.

Returns:

  • (::Integer)

    The HTTP status code returned with the response containing the custom error content. If overrideResponseCode is not supplied, the same response code returned by the original backend bucket or backend service is returned to the client.



14655
14656
14657
14658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14655

class CustomErrorResponsePolicyCustomErrorResponseRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path::String

Returns The full path to a file within backendBucket . For example:/errors/defaultError.html

path must start with a leading slash. path cannot have trailing slashes.

If the file is not available in backendBucket or the load balancer cannot reach the BackendBucket, a simpleNot Found Error is returned to the client.

The value must be from 1 to 1024 characters.

Returns:

  • (::String)

    The full path to a file within backendBucket . For example:/errors/defaultError.html

    path must start with a leading slash. path cannot have trailing slashes.

    If the file is not available in backendBucket or the load balancer cannot reach the BackendBucket, a simpleNot Found Error is returned to the client.

    The value must be from 1 to 1024 characters



14655
14656
14657
14658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14655

class CustomErrorResponsePolicyCustomErrorResponseRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end