Class: Google::Cloud::Compute::V1::Date
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Date
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:
- A full date, with non-zero year, month, and day values.
- A month and day, with a zero year (for example, an anniversary).
- A year on its own, with a zero month and a zero day.
- A year and month, with a zero day (for example, a credit card expiration date).
Related types:
- google.type.TimeOfDay
- google.type.DateTime
- google.protobuf.Timestamp
Instance Attribute Summary collapse
-
#day ⇒ ::Integer
Day of a month.
-
#month ⇒ ::Integer
Month of a year.
-
#year ⇒ ::Integer
Year of the date.
Instance Attribute Details
#day ⇒ ::Integer
Returns Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.
14788 14789 14790 14791 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14788 class Date include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#month ⇒ ::Integer
Returns Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
14788 14789 14790 14791 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14788 class Date include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#year ⇒ ::Integer
Returns Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year.
14788 14789 14790 14791 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14788 class Date include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |