Class: Google::Cloud::Compute::V1::DeleteInstancesInstanceGroupManagerRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for InstanceGroupManagers.DeleteInstances. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#instance_group_manager ⇒ ::String

Returns The name of the managed instance group.

Returns:

  • (::String) —

    The name of the managed instance group.



16477
16478
16479
16480
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16477

class DeleteInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_group_managers_delete_instances_request_resource ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagersDeleteInstancesRequest

Returns The body resource for this request.

Returns:



16477
16478
16479
16480
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16477

class DeleteInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#no_graceful_shutdown ⇒ ::Boolean

Returns When set, graceful shutdown is skipped for instance deletion even if it's configured for the instances.

Returns:

  • (::Boolean) —

    When set, graceful shutdown is skipped for instance deletion even if it's configured for the instances.



16477
16478
16479
16480
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16477

class DeleteInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns Project ID for this request.

Returns:

  • (::String) —

    Project ID for this request.



16477
16478
16479
16480
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16477

class DeleteInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id ⇒ ::String

Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String) —

    An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



16477
16478
16479
16480
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16477

class DeleteInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone ⇒ ::String

Returns The name of thezone where the managed instance group is located.

Returns:

  • (::String) —

    The name of thezone where the managed instance group is located.



16477
16478
16479
16480
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16477

class DeleteInstancesInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end