Class: Google::Cloud::Compute::V1::DeletePerInstanceConfigsInstanceGroupManagerRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for InstanceGroupManagers.DeletePerInstanceConfigs. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#instance_group_manager ⇒ ::String

Returns The name of the managed instance group. It should conform to RFC1035.

Returns:

  • (::String) —

    The name of the managed instance group. It should conform to RFC1035.



17124
17125
17126
17127
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17124

class DeletePerInstanceConfigsInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_group_managers_delete_per_instance_configs_req_resource ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagersDeletePerInstanceConfigsReq

Returns The body resource for this request.

Returns:



17124
17125
17126
17127
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17124

class DeletePerInstanceConfigsInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns Project ID for this request.

Returns:

  • (::String) —

    Project ID for this request.



17124
17125
17126
17127
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17124

class DeletePerInstanceConfigsInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone ⇒ ::String

Returns The name of thezone where the managed instance group is located. It should conform to RFC1035.

Returns:

  • (::String) —

    The name of thezone where the managed instance group is located. It should conform to RFC1035.



17124
17125
17126
17127
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17124

class DeletePerInstanceConfigsInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end