Class: Google::Cloud::Compute::V1::DeleteRegionInstanceGroupManagerResizeRequestRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::DeleteRegionInstanceGroupManagerResizeRequestRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for RegionInstanceGroupManagerResizeRequests.Delete. See the method description for details.
Instance Attribute Summary collapse
-
#instance_group_manager ⇒ ::String
The name of the managed instance group.
-
#project ⇒ ::String
Project ID for this request.
-
#region ⇒ ::String
The name of the region scoping this request.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#resize_request ⇒ ::String
The name of the resize request to delete.
Instance Attribute Details
#instance_group_manager ⇒ ::String
Returns The name of the managed instance group. Name should conform to RFC1035 or be a resource ID.
16547 16548 16549 16550 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16547 class DeleteRegionInstanceGroupManagerResizeRequestRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID for this request.
16547 16548 16549 16550 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16547 class DeleteRegionInstanceGroupManagerResizeRequestRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns The name of the region scoping this request. Name should conform to RFC1035.
16547 16548 16549 16550 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16547 class DeleteRegionInstanceGroupManagerResizeRequestRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
16547 16548 16549 16550 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16547 class DeleteRegionInstanceGroupManagerResizeRequestRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resize_request ⇒ ::String
Returns The name of the resize request to delete. Name should conform to RFC1035 or be a resource ID.
16547 16548 16549 16550 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16547 class DeleteRegionInstanceGroupManagerResizeRequestRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |