Module: Google::Cloud::Compute::V1::Disk::AccessMode

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The access mode of the disk.

 - READ_WRITE_SINGLE: The default AccessMode, means the
 disk can be attached to single instance in RW mode.
 - READ_WRITE_MANY: The AccessMode means the disk can be
 attached to multiple instances in RW mode.
 - READ_ONLY_MANY: The AccessMode means the disk can be
 attached to multiple instances in RO mode.

The AccessMode is only valid for Hyperdisk disk types.

Constant Summary collapse

UNDEFINED_ACCESS_MODE =

A value indicating that the enum field is not set.

0
READ_ONLY_MANY =

The AccessMode means the disk can be attached to multiple instances in RO mode.

63_460_265
READ_WRITE_MANY =

The AccessMode means the disk can be attached to multiple instances in RW mode.

488_743_208
READ_WRITE_SINGLE =

The default AccessMode, means the disk can be attached to single instance in RW mode.

99_323_089