Module: Google::Cloud::Compute::V1::Disk::Status

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. [Output Only] The status of disk creation.

 - CREATING: Disk is provisioning.
 - RESTORING: Source data is being copied into the
 disk.
 - FAILED: Disk creation failed.
 - READY: Disk is ready for use.
 - DELETING: Disk is deleting.

Constant Summary collapse

UNDEFINED_STATUS =

A value indicating that the enum field is not set.

0
CREATING =

Disk is provisioning

455_564_985
DELETING =

Disk is deleting.

528_602_024
FAILED =

Disk creation failed.

455_706_685
READY =

Disk is ready for use.

77_848_963
RESTORING =

Source data is being copied into the disk.

404_263_851
UNAVAILABLE =

Disk is currently unavailable and cannot be accessed, attached or detached.

413_756_464