Class: Google::Cloud::Compute::V1::DiskAsyncReplication
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::DiskAsyncReplication
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#consistency_group_policy ⇒ ::String
Output only.
-
#consistency_group_policy_id ⇒ ::String
Output only.
-
#disk ⇒ ::String
The other disk asynchronously replicated to or from the current disk.
-
#disk_id ⇒ ::String
Output only.
Instance Attribute Details
#consistency_group_policy ⇒ ::String
Returns Output only. [Output Only] URL of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group.
18608 18609 18610 18611 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18608 class DiskAsyncReplication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#consistency_group_policy_id ⇒ ::String
Returns Output only. [Output Only] ID of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group.
18608 18609 18610 18611 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18608 class DiskAsyncReplication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disk ⇒ ::String
Returns The other disk asynchronously replicated to or from the current disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk.
18608 18609 18610 18611 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18608 class DiskAsyncReplication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disk_id ⇒ ::String
Returns Output only. [Output Only] The unique ID of the other disk asynchronously replicated to or from the current disk. This value identifies the exact disk that was used to create this replication. For example, if you started replicating the persistent disk from a disk that was later deleted and recreated under the same name, the disk ID would identify the exact version of the disk that was used.
18608 18609 18610 18611 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18608 class DiskAsyncReplication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |