Class: Google::Cloud::Compute::V1::DiskMoveRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#destination_zone ⇒ ::String

Returns The URL of the destination zone to move the disk. This can be a full or partial URL. For example, the following are all valid URLs to a zone:

- https://www.googleapis.com/compute/v1/projects/project/zones/zone
- projects/project/zones/zone
- zones/zone.

Returns:

  • (::String) —

    The URL of the destination zone to move the disk. This can be a full or partial URL. For example, the following are all valid URLs to a zone:

    - https://www.googleapis.com/compute/v1/projects/project/zones/zone
    - projects/project/zones/zone
    - zones/zone
    


19810
19811
19812
19813
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19810

class DiskMoveRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_disk ⇒ ::String

Returns The URL of the target disk to move. This can be a full or partial URL. For example, the following are all valid URLs to a disk:

- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk.

Returns:

  • (::String) —

    The URL of the target disk to move. This can be a full or partial URL. For example, the following are all valid URLs to a disk:

    - https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
    - projects/project/zones/zone/disks/disk
    - zones/zone/disks/disk
    


19810
19811
19812
19813
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19810

class DiskMoveRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end