Class: Google::Cloud::Compute::V1::DiskType
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::DiskType
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Disk Type resource.
Google Compute Engine has two Disk Type resources:
You can choose from a variety of disk types based on your needs. For more information, readStorage options.
The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks.
The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_disk_size_gb ⇒ ::Integer
[Output Only] Server-defined default disk size in GB.
-
#deprecated ⇒ ::Google::Cloud::Compute::V1::DeprecationStatus
[Output Only] The deprecation status associated with this disk type.
-
#description ⇒ ::String
[Output Only] An optional description of this resource.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
[Output Only] Name of the resource.
-
#region ⇒ ::String
[Output Only] URL of the region where the disk type resides.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#valid_disk_size ⇒ ::String
[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB".
-
#zone ⇒ ::String
[Output Only] URL of the zone where the disk type resides.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns [Output Only] Creation timestamp inRFC3339 text format.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#default_disk_size_gb ⇒ ::Integer
Returns [Output Only] Server-defined default disk size in GB.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deprecated ⇒ ::Google::Cloud::Compute::V1::DeprecationStatus
Returns [Output Only] The deprecation status associated with this disk type.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns [Output Only] An optional description of this resource.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#diskType for disk types.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns [Output Only] Name of the resource.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns [Output Only] URL of the region where the disk type resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#valid_disk_size ⇒ ::String
Returns [Output Only] An optional textual description of the valid disk size, such as "10GB-10TB".
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
Returns [Output Only] URL of the zone where the disk type resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
19173 19174 19175 19176 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19173 class DiskType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |