Class: Google::Cloud::Compute::V1::DistributionPolicyZoneConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#zone ⇒ ::String

Returns The URL of thezone. The zone must exist in the region where the managed instance group is located.

Returns:

  • (::String) —

    The URL of thezone. The zone must exist in the region where the managed instance group is located.



20204
20205
20206
20207
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20204

class DistributionPolicyZoneConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end