Class: Google::Cloud::Compute::V1::ErrorDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Container for structured error details providing additional context specific to the encountered error code.

Instance Attribute Summary collapse

Instance Attribute Details

#error_info ⇒ ::Google::Cloud::Compute::V1::ErrorInfo

Returns Error information containing structured domain, reason, and metadata.

Returns:



20304
20305
20306
20307
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20304

class ErrorDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#help ⇒ ::Google::Cloud::Compute::V1::Help

Returns Links and information to help the user resolve the error.

Returns:



20304
20305
20306
20307
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20304

class ErrorDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#localized_message ⇒ ::Google::Cloud::Compute::V1::LocalizedMessage

Returns A localized human-readable error message intended for end users.

Returns:



20304
20305
20306
20307
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20304

class ErrorDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#quota_info ⇒ ::Google::Cloud::Compute::V1::QuotaExceededInfo

Returns Details about quota limits and metrics when a quota is exceeded.

Returns:



20304
20305
20306
20307
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20304

class ErrorDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end