Class: Google::Cloud::Compute::V1::Firewall

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Firewall Rule resource. Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, read Firewall rules.

Defined Under Namespace

Modules: Direction

Instance Attribute Summary collapse

Instance Attribute Details

#allowed::Array<::Google::Cloud::Compute::V1::Allowed>



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#creation_timestamp::String



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#denied::Array<::Google::Cloud::Compute::V1::Denied>



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#description::String



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#destination_ranges::Array<::String>



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#direction::String



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#disabled::Boolean



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#id::Integer



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#kind::String



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#log_config::Google::Cloud::Compute::V1::FirewallLogConfig



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#name::String



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#network::String



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#params::Google::Cloud::Compute::V1::FirewallParams



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#priority::Integer



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end


8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#source_ranges::Array<::String>



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#source_service_accounts::Array<::String>



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#source_tags::Array<::String>



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#target_service_accounts::Array<::String>



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end

#target_tags::Array<::String>



8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552

class Firewall
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields.
  module Direction
    # A value indicating that the enum field is not set.
    UNDEFINED_DIRECTION = 0

    # Indicates that firewall should apply to outgoing traffic.
    EGRESS = 432_880_501

    # Indicates that firewall should apply to incoming traffic.
    INGRESS = 516_931_221
  end
end