Class: Google::Cloud::Compute::V1::FirewallPoliciesScopedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#firewall_policies ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicy>

Returns A list of firewall policies contained in this scope.

Returns:

  • A list of firewall policies contained in this scope.



21047
21048
21049
21050
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21047

class FirewallPoliciesScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns Informational warning which replaces the list of firewall policies when the list is empty.

Returns:

  • Informational warning which replaces the list of firewall policies when the list is empty.



21047
21048
21049
21050
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21047

class FirewallPoliciesScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end