Class: Google::Cloud::Compute::V1::FirewallPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Firewall Policy resource.

Defined Under Namespace

Modules: PolicyType

Instance Attribute Summary collapse

Instance Attribute Details

#associations::Array<::Google::Cloud::Compute::V1::FirewallPolicyAssociation>

Returns A list of associations that belong to this firewall policy.

Returns:



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#display_name::String

Returns Deprecated, please use short name instead. User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Deprecated, please use short name instead. User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#fingerprint::String

Returns Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet.

To see the latest fingerprint, make get() request to the firewall policy.

Returns:

  • (::String)

    Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet.

    To see the latest fingerprint, make get() request to the firewall policy.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#id::Integer

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    [Output Only] The unique identifier for the resource. This identifier is defined by the server.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#kind::String

Returns Output only. [Output only] Type of the resource. Alwayscompute#firewallPolicyfor firewall policies.

Returns:

  • (::String)

    Output only. [Output only] Type of the resource. Alwayscompute#firewallPolicyfor firewall policies



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#name::String

Returns Name of the resource. For Organization Firewall Policies it's a [Output Only] numeric ID allocated by Google Cloud which uniquely identifies the Organization Firewall Policy.

Returns:

  • (::String)

    Name of the resource. For Organization Firewall Policies it's a [Output Only] numeric ID allocated by Google Cloud which uniquely identifies the Organization Firewall Policy.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#packet_mirroring_rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns A list of packet mirroring rules that belong to this policy.

Returns:



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#parent::String

Returns Output only. [Output Only] The parent of the firewall policy. This field is not applicable to network firewall policies.

Returns:

  • (::String)

    Output only. [Output Only] The parent of the firewall policy. This field is not applicable to network firewall policies.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#policy_type::String

Returns The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.

Note: if not specified then VPC_POLICY will be used. Check the PolicyType enum for the list of possible values.

Returns:

  • (::String)

    The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.

    Note: if not specified then VPC_POLICY will be used. Check the PolicyType enum for the list of possible values.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#region::String

Returns Output only. [Output Only] URL of the region where the regional firewall policy resides. This field is not applicable to global firewall policies. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Returns:

  • (::String)

    Output only. [Output Only] URL of the region where the regional firewall policy resides. This field is not applicable to global firewall policies. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#rule_tuple_count::Integer

Returns Output only. [Output Only] Total count of all firewall policy rule tuples. A firewall policy can not exceed a set number of tuples.

Returns:

  • (::Integer)

    Output only. [Output Only] Total count of all firewall policy rule tuples. A firewall policy can not exceed a set number of tuples.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns A list of rules that belong to this policy. There must always be a default rule (rule with priority 2147483647 and match "*"). If no rules are provided when creating a firewall policy, a default rule with action "allow" will be added.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>)

    A list of rules that belong to this policy. There must always be a default rule (rule with priority 2147483647 and match "*"). If no rules are provided when creating a firewall policy, a default rule with action "allow" will be added.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for the resource.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource with the resource id.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource with the resource id.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end

#short_name::String

Returns User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



20091
20092
20093
20094
20095
20096
20097
20098
20099
20100
20101
20102
20103
20104
20105
20106
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20091

class FirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the firewall policy. This field can be eitherVPC_POLICY or RDMA_ROCE_POLICY.
  #
  # Note: if not specified then VPC_POLICY will be used.
  module PolicyType
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY_TYPE = 0

    RDMA_ROCE_POLICY = 148_757_145

    VPC_POLICY = 74_319_208
  end
end