Class: Google::Cloud::Compute::V1::FirewallPolicyAssociation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_target ⇒ ::String

Returns The target that the firewall policy is attached to.

Returns:

  • (::String) —

    The target that the firewall policy is attached to.



21184
21185
21186
21187
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21184

class FirewallPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name ⇒ ::String

Returns [Output Only] Deprecated, please use short name instead. The display name of the firewall policy of the association.

Returns:

  • (::String) —

    [Output Only] Deprecated, please use short name instead. The display name of the firewall policy of the association.



21184
21185
21186
21187
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21184

class FirewallPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#firewall_policy_id ⇒ ::String

Returns Output only. [Output Only] The firewall policy ID of the association.

Returns:

  • (::String) —

    Output only. [Output Only] The firewall policy ID of the association.



21184
21185
21186
21187
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21184

class FirewallPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String

Returns The name for an association.

Returns:

  • (::String) —

    The name for an association.



21184
21185
21186
21187
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21184

class FirewallPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#short_name ⇒ ::String

Returns Output only. [Output Only] The short name of the firewall policy of the association.

Returns:

  • (::String) —

    Output only. [Output Only] The short name of the firewall policy of the association.



21184
21185
21186
21187
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21184

class FirewallPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end