Class: Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ ::String

Returns Name of the secure tag, created with TagManager's TagValue API.

Returns:

  • (::String) —

    Name of the secure tag, created with TagManager's TagValue API.



21546
21547
21548
21549
21550
21551
21552
21553
21554
21555
21556
21557
21558
21559
21560
21561
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21546

class FirewallPolicyRuleSecureTag
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] State of the secure tag, either `EFFECTIVE` or
  # `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted
  # or its network is deleted.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    EFFECTIVE = 244_201_863

    INEFFECTIVE = 304_458_242
  end
end

#state ⇒ ::String

Returns Output only. [Output Only] State of the secure tag, either EFFECTIVE or INEFFECTIVE. A secure tag is INEFFECTIVE when it is deleted or its network is deleted. Check the State enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] State of the secure tag, either EFFECTIVE or INEFFECTIVE. A secure tag is INEFFECTIVE when it is deleted or its network is deleted. Check the State enum for the list of possible values.



21546
21547
21548
21549
21550
21551
21552
21553
21554
21555
21556
21557
21558
21559
21560
21561
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21546

class FirewallPolicyRuleSecureTag
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] State of the secure tag, either `EFFECTIVE` or
  # `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted
  # or its network is deleted.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    EFFECTIVE = 244_201_863

    INEFFECTIVE = 304_458_242
  end
end