Module: Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag::State

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] State of the secure tag, either EFFECTIVE or INEFFECTIVE. A secure tag is INEFFECTIVE when it is deleted or its network is deleted.

Constant Summary collapse

UNDEFINED_STATE =

A value indicating that the enum field is not set.

0
EFFECTIVE =
244_201_863
INEFFECTIVE =
304_458_242