Class: Google::Cloud::Compute::V1::ForwardingRulesScopedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#forwarding_rules ⇒ ::Array<::Google::Cloud::Compute::V1::ForwardingRule>

Returns A list of forwarding rules contained in this scope.

Returns:



22315
22316
22317
22318
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22315

class ForwardingRulesScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns Informational warning which replaces the list of forwarding rules when the list is empty.

Returns:



22315
22316
22317
22318
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22315

class ForwardingRulesScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end