Module: Google::Cloud::Compute::V1::FutureReservation::PlanningStatus

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Planning state before being submitted for evaluation

Constant Summary collapse

UNDEFINED_PLANNING_STATUS =

A value indicating that the enum field is not set.

0
DRAFT =

Future Reservation is being drafted.

65_307_009
PLANNING_STATUS_UNSPECIFIED =
252_728_940
SUBMITTED =

Future Reservation has been submitted for evaluation by GCP.

450_918_619