Module: Google::Cloud::Compute::V1::FutureReservation::ReservationMode

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The reservation mode which determines reservation-termination behavior and expected pricing.

Constant Summary collapse

UNDEFINED_RESERVATION_MODE =

A value indicating that the enum field is not set.

0
CALENDAR =

The delivered reservations will delivered at specified start time and terminated at specified end time along with terminating the VMs running on it.

67_431_230
DEFAULT =

The delivered reservations do not terminate VMs at the end of reservations. This is default mode.

115_302_945
RESERVATION_MODE_UNSPECIFIED =
233_810_606