Class: Google::Cloud::Compute::V1::FutureReservationCommitmentInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: CommitmentPlan, PreviousCommitmentTerms

Instance Attribute Summary collapse

Instance Attribute Details

#commitment_name ⇒ ::String

Returns name of the commitment where capacity is being delivered to.

Returns:

  • (::String) —

    name of the commitment where capacity is being delivered to.



22549
22550
22551
22552
22553
22554
22555
22556
22557
22558
22559
22560
22561
22562
22563
22564
22565
22566
22567
22568
22569
22570
22571
22572
22573
22574
22575
22576
22577
22578
22579
22580
22581
22582
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22549

class FutureReservationCommitmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates if a Commitment needs to be created as part of FR delivery. If
  # this field is not present, then no
  # commitment needs to be created.
  module CommitmentPlan
    # A value indicating that the enum field is not set.
    UNDEFINED_COMMITMENT_PLAN = 0

    INVALID = 530_283_991

    THIRTY_SIX_MONTH = 266_295_942

    TWELVE_MONTH = 173_083_962
  end

  # Only applicable if FR is delivering to the same reservation. If set, all
  # parent commitments will be extended to match the end date of the plan for
  # this commitment.
  module PreviousCommitmentTerms
    # A value indicating that the enum field is not set.
    UNDEFINED_PREVIOUS_COMMITMENT_TERMS = 0

    # All associated parent Committed Used Discount(s) end-date/term will be
    # extended to the end-time of this future reservation. Default is to
    # extend previous commitment(s) time to the end_time of the reservation.
    EXTEND = 448_639_770

    # No changes to associated parents Committed Used Discount(s) terms.
    PREVIOUSCOMMITMENTTERM_UNSPECIFIED = 98_482_448
  end
end

#commitment_plan ⇒ ::String

Returns Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created. Check the CommitmentPlan enum for the list of possible values.

Returns:

  • (::String) —

    Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created. Check the CommitmentPlan enum for the list of possible values.



22549
22550
22551
22552
22553
22554
22555
22556
22557
22558
22559
22560
22561
22562
22563
22564
22565
22566
22567
22568
22569
22570
22571
22572
22573
22574
22575
22576
22577
22578
22579
22580
22581
22582
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22549

class FutureReservationCommitmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates if a Commitment needs to be created as part of FR delivery. If
  # this field is not present, then no
  # commitment needs to be created.
  module CommitmentPlan
    # A value indicating that the enum field is not set.
    UNDEFINED_COMMITMENT_PLAN = 0

    INVALID = 530_283_991

    THIRTY_SIX_MONTH = 266_295_942

    TWELVE_MONTH = 173_083_962
  end

  # Only applicable if FR is delivering to the same reservation. If set, all
  # parent commitments will be extended to match the end date of the plan for
  # this commitment.
  module PreviousCommitmentTerms
    # A value indicating that the enum field is not set.
    UNDEFINED_PREVIOUS_COMMITMENT_TERMS = 0

    # All associated parent Committed Used Discount(s) end-date/term will be
    # extended to the end-time of this future reservation. Default is to
    # extend previous commitment(s) time to the end_time of the reservation.
    EXTEND = 448_639_770

    # No changes to associated parents Committed Used Discount(s) terms.
    PREVIOUSCOMMITMENTTERM_UNSPECIFIED = 98_482_448
  end
end

#previous_commitment_terms ⇒ ::String

Returns Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment. Check the PreviousCommitmentTerms enum for the list of possible values.

Returns:

  • (::String) —

    Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment. Check the PreviousCommitmentTerms enum for the list of possible values.



22549
22550
22551
22552
22553
22554
22555
22556
22557
22558
22559
22560
22561
22562
22563
22564
22565
22566
22567
22568
22569
22570
22571
22572
22573
22574
22575
22576
22577
22578
22579
22580
22581
22582
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22549

class FutureReservationCommitmentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates if a Commitment needs to be created as part of FR delivery. If
  # this field is not present, then no
  # commitment needs to be created.
  module CommitmentPlan
    # A value indicating that the enum field is not set.
    UNDEFINED_COMMITMENT_PLAN = 0

    INVALID = 530_283_991

    THIRTY_SIX_MONTH = 266_295_942

    TWELVE_MONTH = 173_083_962
  end

  # Only applicable if FR is delivering to the same reservation. If set, all
  # parent commitments will be extended to match the end date of the plan for
  # this commitment.
  module PreviousCommitmentTerms
    # A value indicating that the enum field is not set.
    UNDEFINED_PREVIOUS_COMMITMENT_TERMS = 0

    # All associated parent Committed Used Discount(s) end-date/term will be
    # extended to the end-time of this future reservation. Default is to
    # extend previous commitment(s) time to the end_time of the reservation.
    EXTEND = 448_639_770

    # No changes to associated parents Committed Used Discount(s) terms.
    PREVIOUSCOMMITMENTTERM_UNSPECIFIED = 98_482_448
  end
end