Module: Google::Cloud::Compute::V1::FutureReservationCommitmentInfo::CommitmentPlan

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created.

Constant Summary collapse

UNDEFINED_COMMITMENT_PLAN =

A value indicating that the enum field is not set.

0
INVALID =
530_283_991
THIRTY_SIX_MONTH =
266_295_942
TWELVE_MONTH =
173_083_962