Class: Google::Cloud::Compute::V1::FutureReservationSpecificSKUProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#instance_properties ⇒ ::Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationReservedInstanceProperties

Returns Properties of the SKU instances being reserved.

Returns:



22619
22620
22621
22622
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22619

class FutureReservationSpecificSKUProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_instance_template ⇒ ::String

Returns The instance template that will be used to populate the ReservedInstanceProperties of the future reservation.

Returns:

  • (::String) —

    The instance template that will be used to populate the ReservedInstanceProperties of the future reservation



22619
22620
22621
22622
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22619

class FutureReservationSpecificSKUProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_count ⇒ ::Integer

Returns Total number of instances for which capacity assurance is requested at a future time period.

Returns:

  • (::Integer) —

    Total number of instances for which capacity assurance is requested at a future time period.



22619
22620
22621
22622
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22619

class FutureReservationSpecificSKUProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end