Module: Google::Cloud::Compute::V1::FutureReservationStatus::AmendmentStatus

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. [Output Only] The current status of the requested amendment.

Constant Summary collapse

UNDEFINED_AMENDMENT_STATUS =

A value indicating that the enum field is not set.

0
AMENDMENT_APPROVED =

The requested amendment to the Future Resevation has been approved and applied by GCP.

150_573_001
AMENDMENT_DECLINED =

The requested amendment to the Future Reservation has been declined by GCP and the original state was restored.

70_395_200
AMENDMENT_IN_REVIEW =

The requested amendment to the Future Reservation is currently being reviewd by GCP.

25_830_624
AMENDMENT_STATUS_UNSPECIFIED =
412_250_332