Module: Google::Cloud::Compute::V1::FutureReservationStatus::ProcurementStatus

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. Current state of this Future Reservation

Constant Summary collapse

UNDEFINED_PROCUREMENT_STATUS =

A value indicating that the enum field is not set.

0
APPROVED =

Future reservation is approved by GCP.

357_258_935
CANCELLED =

Future reservation is cancelled by the customer.

41_957_681
COMMITTED =

Future reservation is committed by the customer.

221_710_172
DECLINED =

Future reservation is rejected by GCP.

277_081_134
DRAFTING =

Related status for PlanningStatus.Draft. Transitions to PENDING_APPROVAL upon user submitting FR.

477_863_585
FAILED =

Future reservation failed. No additional reservations were provided.

455_706_685
FAILED_PARTIALLY_FULFILLED =

Future reservation is partially fulfilled. Additional reservations were provided but did not reach total_count reserved instance slots.

14_455_212
FULFILLED =

Future reservation is fulfilled completely.

409_958_655
PENDING_AMENDMENT_APPROVAL =

An Amendment to the Future Reservation has been requested. If the Amendment is declined, the Future Reservation will be restored to the last known good state.

510_150_429
PENDING_APPROVAL =

Future reservation is pending approval by GCP.

209_692_683
PROCUREMENT_STATUS_UNSPECIFIED =
45_807_705
PROCURING =

Future reservation is being procured by GCP. Beyond this point, Future reservation is locked and no further modifications are allowed.

95_959_663
PROVISIONING =

Future reservation capacity is being provisioned. This state will be entered after start_time, while reservations are being created to provide total_count reserved instance slots. This state will not persist past start_time + 24h.

290_896_621