Class: Google::Cloud::Compute::V1::FutureReservationStatusSpecificSKUProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Properties to be set for the Future Reservation.

Instance Attribute Summary collapse

Instance Attribute Details

#source_instance_template_id::String

Returns ID of the instance template used to populate the Future Reservation properties.

Returns:

  • (::String)

    ID of the instance template used to populate the Future Reservation properties.



21703
21704
21705
21706
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21703

class FutureReservationStatusSpecificSKUProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end