Class: Google::Cloud::Compute::V1::FutureReservationsScopedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureReservationsScopedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#future_reservations ⇒ ::Array<::Google::Cloud::Compute::V1::FutureReservation>
A list of future reservations contained in this scope.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Informational warning which replaces the list of future reservations when the list is empty.
Instance Attribute Details
#future_reservations ⇒ ::Array<::Google::Cloud::Compute::V1::FutureReservation>
Returns A list of future reservations contained in this scope.
21805 21806 21807 21808 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21805 class FutureReservationsScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Informational warning which replaces the list of future reservations when the list is empty.
21805 21806 21807 21808 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21805 class FutureReservationsScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |