Class: Google::Cloud::Compute::V1::FutureResourcesRecommendation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Recommendation for single resources specification, to be created in the future.

Defined Under Namespace

Modules: RecommendationType Classes: OtherLocationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#end_time ⇒ ::String

Returns:

  • (::String)


23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
23043
23044
23045
23046
23047
23048
23049
23050
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23026

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#location ⇒ ::String

Returns The advised location for resource usage. When a zone, in format 'zones/'. If not set, it means that no location is recommended - see other_locations for details.

Returns:

  • (::String) —

    The advised location for resource usage. When a zone, in format 'zones/'. If not set, it means that no location is recommended - see other_locations for details.



23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
23043
23044
23045
23046
23047
23048
23049
23050
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23026

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#other_locations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation}

Returns List of locations in the request scope that were not recommended. Keys of the map are zones, in format 'zones/'. The values are status information indicating the recommendation status.

Returns:



23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
23043
23044
23045
23046
23047
23048
23049
23050
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23026

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#recommendation_id ⇒ ::String

Returns Unique id of the recommendation, a UUID string generated by the API.

Returns:

  • (::String) —

    Unique id of the recommendation, a UUID string generated by the API.



23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
23043
23044
23045
23046
23047
23048
23049
23050
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23026

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#recommendation_type ⇒ ::String

Returns Type of recommendation. Currently only FUTURE_RESERVATION is supported. Check the RecommendationType enum for the list of possible values.

Returns:

  • (::String) —

    Type of recommendation. Currently only FUTURE_RESERVATION is supported. Check the RecommendationType enum for the list of possible values.



23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
23043
23044
23045
23046
23047
23048
23049
23050
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23026

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#start_time ⇒ ::String

Returns:

  • (::String)


23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
23038
23039
23040
23041
23042
23043
23044
23045
23046
23047
23048
23049
23050
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23026

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end