Class: Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Information about recommendation status for locations that were allowed but not used by the response.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#details ⇒ ::String

Returns Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions.

Returns:

  • (::String) —

    Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions.



23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
23087
23088
23089
23090
23091
23092
23093
23094
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23064

class FutureResourcesRecommendationOtherLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status of recommendation in this location.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The requested resources are offered in this location
    # but the requested time window is does not meet the required conditions.
    CONDITIONS_NOT_MET = 363_628_457

    # The requested resources are not offered in this location.
    # Retrying the request will not change this status.
    NOT_SUPPORTED = 317_950_466

    # The requested resources are offered in this location
    # and the requested time window is accepted
    # but there is no capacity within the requested time window.
    NO_CAPACITY = 274_240_888

    # Default value, unused.
    OTHER_LOCATION_STATUS_UNDEFINED = 222_662_622

    # The requested resources are offered in this location
    # and it is possible to request them. However, another location
    # was better and was recommended.
    RECOMMENDED = 369_652_283
  end
end

#status ⇒ ::String

Returns Status of recommendation in this location. Check the Status enum for the list of possible values.

Returns:

  • (::String) —

    Status of recommendation in this location. Check the Status enum for the list of possible values.



23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
23087
23088
23089
23090
23091
23092
23093
23094
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23064

class FutureResourcesRecommendationOtherLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status of recommendation in this location.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The requested resources are offered in this location
    # but the requested time window is does not meet the required conditions.
    CONDITIONS_NOT_MET = 363_628_457

    # The requested resources are not offered in this location.
    # Retrying the request will not change this status.
    NOT_SUPPORTED = 317_950_466

    # The requested resources are offered in this location
    # and the requested time window is accepted
    # but there is no capacity within the requested time window.
    NO_CAPACITY = 274_240_888

    # Default value, unused.
    OTHER_LOCATION_STATUS_UNDEFINED = 222_662_622

    # The requested resources are offered in this location
    # and it is possible to request them. However, another location
    # was better and was recommended.
    RECOMMENDED = 369_652_283
  end
end