Module: Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation::Status

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Status of recommendation in this location.

Constant Summary collapse

UNDEFINED_STATUS =

A value indicating that the enum field is not set.

0
CONDITIONS_NOT_MET =

The requested resources are offered in this location but the requested time window is does not meet the required conditions.

363_628_457
NOT_SUPPORTED =

The requested resources are not offered in this location. Retrying the request will not change this status.

317_950_466
NO_CAPACITY =

The requested resources are offered in this location and the requested time window is accepted but there is no capacity within the requested time window.

274_240_888
OTHER_LOCATION_STATUS_UNDEFINED =

Default value, unused.

222_662_622
369_652_283