Class: Google::Cloud::Compute::V1::GetAssociationFirewallPolicyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for FirewallPolicies.GetAssociation. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#firewall_policy ⇒ ::String

Returns Name of the firewall policy to which the queried rule belongs.

Returns:

  • (::String) —

    Name of the firewall policy to which the queried rule belongs.



23497
23498
23499
23500
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23497

class GetAssociationFirewallPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String

Returns The name of the association to get from the firewall policy.

Returns:

  • (::String) —

    The name of the association to get from the firewall policy.



23497
23498
23499
23500
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23497

class GetAssociationFirewallPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end