Class: Google::Cloud::Compute::V1::GetGlobalOperationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for GlobalOperations.Get. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#operation ⇒ ::String

Returns Name of the Operations resource to return, or its unique numeric identifier.

Returns:

  • (::String) —

    Name of the Operations resource to return, or its unique numeric identifier.



23853
23854
23855
23856
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23853

class GetGlobalOperationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns Project ID for this request.

Returns:

  • (::String) —

    Project ID for this request.



23853
23854
23855
23856
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23853

class GetGlobalOperationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end