Class: Google::Cloud::Compute::V1::GetHostRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for Hosts.Get. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#association ⇒ ::String

Returns The parent resource association for the Host. This field specifies the hierarchical context (e.g., reservation, block, sub-block) when accessing the host. For example, reservations/reservation_name, reservations/reservation_name/reservationBlocks/reservation_block_name or reservations/reservation_name/reservationBlocks/reservation_block_name/reservationSubBlocks/reservation_sub_block_name.

Returns:

  • (::String) —

    The parent resource association for the Host. This field specifies the hierarchical context (e.g., reservation, block, sub-block) when accessing the host. For example, reservations/reservation_name, reservations/reservation_name/reservationBlocks/reservation_block_name or reservations/reservation_name/reservationBlocks/reservation_block_name/reservationSubBlocks/reservation_sub_block_name.



24158
24159
24160
24161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24158

class GetHostRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#host ⇒ ::String

Returns The name of the host, formatted as RFC1035 or a resource ID number.

Returns:

  • (::String) —

    The name of the host, formatted as RFC1035 or a resource ID number.



24158
24159
24160
24161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24158

class GetHostRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns The project ID for this request.

Returns:

  • (::String) —

    The project ID for this request.



24158
24159
24160
24161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24158

class GetHostRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone ⇒ ::String

Returns The name of the zone for this request, formatted as RFC1035.

Returns:

  • (::String) —

    The name of the zone for this request, formatted as RFC1035.



24158
24159
24160
24161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24158

class GetHostRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end