Class: Google::Cloud::Compute::V1::GetIamPolicyBackendServiceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for BackendServices.GetIamPolicy. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#options_requested_policy_version ⇒ ::Integer

Returns Requested IAM Policy version.

Returns:

  • (::Integer) —

    Requested IAM Policy version.



24188
24189
24190
24191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24188

class GetIamPolicyBackendServiceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns Project ID for this request.

Returns:

  • (::String) —

    Project ID for this request.



24188
24189
24190
24191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24188

class GetIamPolicyBackendServiceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource ⇒ ::String

Returns Name or id of the resource for this request.

Returns:

  • (::String) —

    Name or id of the resource for this request.



24188
24189
24190
24191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24188

class GetIamPolicyBackendServiceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end