Class: Google::Cloud::Compute::V1::GetIamPolicyReservationBlockRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for ReservationBlocks.GetIamPolicy. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#options_requested_policy_version ⇒ ::Integer

Returns Requested IAM Policy version.

Returns:

  • Requested IAM Policy version.



24593
24594
24595
24596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24593

class GetIamPolicyReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent_resource ⇒ ::String

Returns Name or id of parent resource of the resource for this request.

Returns:

  • Name or id of parent resource of the resource for this request.



24593
24594
24595
24596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24593

class GetIamPolicyReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns Project ID for this request.

Returns:

  • Project ID for this request.



24593
24594
24595
24596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24593

class GetIamPolicyReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource ⇒ ::String

Returns Name or id of the resource for this request.

Returns:

  • Name or id of the resource for this request.



24593
24594
24595
24596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24593

class GetIamPolicyReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone ⇒ ::String

Returns The name of the zone for this request.

Returns:

  • The name of the zone for this request.



24593
24594
24595
24596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24593

class GetIamPolicyReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end