Class: Google::Cloud::Compute::V1::GetInstanceGroupManagerRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for InstanceGroupManagers.Get. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#instance_group_manager ⇒ ::String

Returns The name of the managed instance group.

Returns:

  • (::String) —

    The name of the managed instance group.



24762
24763
24764
24765
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24762

class GetInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns Project ID for this request.

Returns:

  • (::String) —

    Project ID for this request.



24762
24763
24764
24765
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24762

class GetInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone ⇒ ::String

Returns The name of thezone where the managed instance group is located.

Returns:

  • (::String) —

    The name of thezone where the managed instance group is located.



24762
24763
24764
24765
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24762

class GetInstanceGroupManagerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end