Class: Google::Cloud::Compute::V1::GetRoutePolicyRouterRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for Routers.GetRoutePolicy. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#policy ⇒ ::String

Returns The Policy name for this request. Name must conform to RFC1035.

Returns:

  • (::String) —

    The Policy name for this request. Name must conform to RFC1035



26062
26063
26064
26065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26062

class GetRoutePolicyRouterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns Project ID for this request.

Returns:

  • (::String) —

    Project ID for this request.



26062
26063
26064
26065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26062

class GetRoutePolicyRouterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region ⇒ ::String

Returns Name of the region for this request.

Returns:

  • (::String) —

    Name of the region for this request.



26062
26063
26064
26065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26062

class GetRoutePolicyRouterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#router ⇒ ::String

Returns Name of the Router resource to query for the route policy. The name should conform to RFC1035.

Returns:

  • (::String) —

    Name of the Router resource to query for the route policy. The name should conform to RFC1035.



26062
26063
26064
26065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26062

class GetRoutePolicyRouterRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end