Class: Google::Cloud::Compute::V1::GetVersionHostRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GetVersionHostRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for Hosts.GetVersion. See the method description for details.
Instance Attribute Summary collapse
-
#association ⇒ ::String
The parent resource association for the Host.
-
#host ⇒ ::String
The name of the host, formatted as RFC1035 or a resource ID number.
-
#hosts_get_version_request_resource ⇒ ::Google::Cloud::Compute::V1::HostsGetVersionRequest
The body resource for this request.
-
#project ⇒ ::String
Project ID for this request.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#zone ⇒ ::String
Name of the zone for this request.
Instance Attribute Details
#association ⇒ ::String
Returns The parent resource association for the Host. This field specifies the hierarchical context (e.g., reservation, block, sub-block) when accessing the host.
26566 26567 26568 26569 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26566 class GetVersionHostRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#host ⇒ ::String
Returns The name of the host, formatted as RFC1035 or a resource ID number.
26566 26567 26568 26569 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26566 class GetVersionHostRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#hosts_get_version_request_resource ⇒ ::Google::Cloud::Compute::V1::HostsGetVersionRequest
Returns The body resource for this request.
26566 26567 26568 26569 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26566 class GetVersionHostRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID for this request.
26566 26567 26568 26569 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26566 class GetVersionHostRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
26566 26567 26568 26569 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26566 class GetVersionHostRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
Returns Name of the zone for this request. Zone name should conform to RFC1035.
26566 26567 26568 26569 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26566 class GetVersionHostRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |