Class: Google::Cloud::Compute::V1::GetVersionOperationMetadataSbomInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: CurrentComponentVersionsEntry, TargetComponentVersionsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#current_component_versions ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns A mapping of components to their currently-applied versions or other appropriate identifiers.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    A mapping of components to their currently-applied versions or other appropriate identifiers.



26586
26587
26588
26589
26590
26591
26592
26593
26594
26595
26596
26597
26598
26599
26600
26601
26602
26603
26604
26605
26606
26607
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26586

class GetVersionOperationMetadataSbomInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class CurrentComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#target_component_versions ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns A mapping of components to their target versions or other appropriate identifiers.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    A mapping of components to their target versions or other appropriate identifiers.



26586
26587
26588
26589
26590
26591
26592
26593
26594
26595
26596
26597
26598
26599
26600
26601
26602
26603
26604
26605
26606
26607
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26586

class GetVersionOperationMetadataSbomInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class CurrentComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end