Class: Google::Cloud::Compute::V1::GetVersionReservationSlotRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for ReservationSlots.GetVersion. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#parent_name::String

Returns The name of the parent reservation and parent block. In the format of reservations/{reservation_name}/reservationBlocks/{reservation_block_name}/reservationSubBlocks/{reservation_sub_block_name}.

Returns:

  • (::String)

    The name of the parent reservation and parent block. In the format of reservations/{reservation_name}/reservationBlocks/{reservation_block_name}/reservationSubBlocks/{reservation_sub_block_name}



25141
25142
25143
25144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25141

class GetVersionReservationSlotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



25141
25142
25143
25144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25141

class GetVersionReservationSlotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



25141
25142
25143
25144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25141

class GetVersionReservationSlotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reservation_slot::String

Returns The name of the reservation slot. Name should conform to RFC1035 or be a resource ID.

Returns:

  • (::String)

    The name of the reservation slot. Name should conform to RFC1035 or be a resource ID.



25141
25142
25143
25144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25141

class GetVersionReservationSlotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reservation_slots_get_version_request_resource::Google::Cloud::Compute::V1::ReservationSlotsGetVersionRequest

Returns The body resource for this request.

Returns:



25141
25142
25143
25144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25141

class GetVersionReservationSlotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns Name of the zone for this request. Zone name should conform to RFC1035.

Returns:

  • (::String)

    Name of the zone for this request. Zone name should conform to RFC1035.



25141
25142
25143
25144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25141

class GetVersionReservationSlotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end