Method: Google::Cloud::Compute::V1::GlobalAddressesMoveRequest#description

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

#description::String

Returns An optional destination address description if intended to be different from the source.

Returns:

  • (::String)

    An optional destination address description if intended to be different from the source.



11643
11644
11645
11646
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11643

class GlobalAddressesMoveRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end