Class: Google::Cloud::Compute::V1::GlobalForwardingRules::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GlobalForwardingRules::Rest::Client
- Defined in:
- lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb
Overview
REST client for the GlobalForwardingRules service.
The GlobalForwardingRules API.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#global_operations ⇒ ::Google::Cloud::Compute::V1::GlobalOperations::Rest::Client
readonly
Get the associated client for long-running operations via GlobalOperations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the GlobalForwardingRules Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the GlobalForwardingRules Client instance.
-
#delete(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::GenericLRO::Operation
Deletes the specified GlobalForwardingRule resource.
-
#get(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Compute::V1::ForwardingRule
Returns the specified GlobalForwardingRule resource.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new GlobalForwardingRules REST client object.
-
#insert(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::GenericLRO::Operation
Creates a GlobalForwardingRule resource in the specified project using the data included in the request.
-
#list(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Compute::V1::ForwardingRule>
Retrieves a list of GlobalForwardingRule resources available to the specified project.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#patch(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::GenericLRO::Operation
Updates the specified forwarding rule with the data included in the request.
-
#set_labels(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::GenericLRO::Operation
Sets the labels on the specified resource.
-
#set_target(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::GenericLRO::Operation
Changes target URL for the GlobalForwardingRule resource.
-
#universe_domain ⇒ String
The effective universe domain.
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new GlobalForwardingRules REST client object.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 145 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @global_operations = ::Google::Cloud::Compute::V1::GlobalOperations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @global_forwarding_rules_stub = ::Google::Cloud::Compute::V1::GlobalForwardingRules::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @global_forwarding_rules_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#global_operations ⇒ ::Google::Cloud::Compute::V1::GlobalOperations::Rest::Client (readonly)
Get the associated client for long-running operations via GlobalOperations.
199 200 201 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 199 def global_operations @global_operations end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the GlobalForwardingRules Client class.
See Configuration for a description of the configuration fields.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 63 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Compute", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.delete.timeout = 600.0 default_config.rpcs.get.timeout = 600.0 default_config.rpcs.get.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.insert.timeout = 600.0 default_config.rpcs.list.timeout = 600.0 default_config.rpcs.list.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.patch.timeout = 600.0 default_config.rpcs.set_labels.timeout = 600.0 default_config.rpcs.set_target.timeout = 600.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the GlobalForwardingRules Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
115 116 117 118 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 115 def configure yield @config if block_given? @config end |
#delete(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation #delete(forwarding_rule: nil, project: nil, request_id: nil) ⇒ ::Gapic::GenericLRO::Operation
Deletes the specified GlobalForwardingRule resource.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 271 def delete request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::DeleteGlobalForwardingRuleRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Compute::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete.timeout, metadata: , retry_policy: @config.rpcs.delete.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @global_forwarding_rules_stub.delete request, do |result, response| result = ::Google::Cloud::Compute::V1::GlobalOperations::Rest::NonstandardLro.create_operation( operation: result, client: global_operations, request_values: { "project" => request.project }, options: ) yield result, response if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get(request, options = nil) ⇒ ::Google::Cloud::Compute::V1::ForwardingRule #get(forwarding_rule: nil, project: nil) ⇒ ::Google::Cloud::Compute::V1::ForwardingRule
Returns the specified GlobalForwardingRule resource. Gets a list of available forwarding rules by making a list() request.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 361 def get request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::GetGlobalForwardingRuleRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Compute::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get.timeout, metadata: , retry_policy: @config.rpcs.get.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @global_forwarding_rules_stub.get request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#insert(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation #insert(forwarding_rule_resource: nil, project: nil, request_id: nil) ⇒ ::Gapic::GenericLRO::Operation
Creates a GlobalForwardingRule resource in the specified project using the data included in the request.
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 456 def insert request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::InsertGlobalForwardingRuleRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.insert..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Compute::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.insert.timeout, metadata: , retry_policy: @config.rpcs.insert.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @global_forwarding_rules_stub.insert request, do |result, response| result = ::Google::Cloud::Compute::V1::GlobalOperations::Rest::NonstandardLro.create_operation( operation: result, client: global_operations, request_values: { "project" => request.project }, options: ) yield result, response if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Compute::V1::ForwardingRule> #list(filter: nil, max_results: nil, order_by: nil, page_token: nil, project: nil, return_partial_success: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Compute::V1::ForwardingRule>
Retrieves a list of GlobalForwardingRule resources available to the specified project.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 632 def list request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::ListGlobalForwardingRulesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Compute::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list.timeout, metadata: , retry_policy: @config.rpcs.list.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @global_forwarding_rules_stub.list request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @global_forwarding_rules_stub, :list, "items", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
206 207 208 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 206 def logger @global_forwarding_rules_stub.logger end |
#patch(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation #patch(forwarding_rule: nil, forwarding_rule_resource: nil, project: nil, request_id: nil) ⇒ ::Gapic::GenericLRO::Operation
Updates the specified forwarding rule with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules. Currently, you can only patch the network_tier field.
734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 734 def patch request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::PatchGlobalForwardingRuleRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.patch..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Compute::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.patch.timeout, metadata: , retry_policy: @config.rpcs.patch.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @global_forwarding_rules_stub.patch request, do |result, response| result = ::Google::Cloud::Compute::V1::GlobalOperations::Rest::NonstandardLro.create_operation( operation: result, client: global_operations, request_values: { "project" => request.project }, options: ) yield result, response if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#set_labels(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation #set_labels(global_set_labels_request_resource: nil, project: nil, resource: nil) ⇒ ::Gapic::GenericLRO::Operation
Sets the labels on the specified resource. To learn more about labels, read the Labeling resources documentation.
827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 827 def set_labels request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::SetLabelsGlobalForwardingRuleRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.set_labels..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Compute::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.set_labels.timeout, metadata: , retry_policy: @config.rpcs.set_labels.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @global_forwarding_rules_stub.set_labels request, do |result, response| result = ::Google::Cloud::Compute::V1::GlobalOperations::Rest::NonstandardLro.create_operation( operation: result, client: global_operations, request_values: { "project" => request.project }, options: ) yield result, response if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#set_target(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation #set_target(forwarding_rule: nil, project: nil, request_id: nil, target_reference_resource: nil) ⇒ ::Gapic::GenericLRO::Operation
Changes target URL for the GlobalForwardingRule resource. The new target should be of the same type as the old target.
933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 933 def set_target request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::SetTargetGlobalForwardingRuleRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.set_target..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Compute::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.set_target.timeout, metadata: , retry_policy: @config.rpcs.set_target.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @global_forwarding_rules_stub.set_target request, do |result, response| result = ::Google::Cloud::Compute::V1::GlobalOperations::Rest::NonstandardLro.create_operation( operation: result, client: global_operations, request_values: { "project" => request.project }, options: ) yield result, response if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
125 126 127 |
# File 'lib/google/cloud/compute/v1/global_forwarding_rules/rest/client.rb', line 125 def universe_domain @global_forwarding_rules_stub.universe_domain end |