Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Message describing GlobalVmExtensionPolicy object.

Defined Under Namespace

Modules: ScopedResourceStatus Classes: ExtensionPoliciesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp ⇒ ::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String) —

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#description ⇒ ::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String) —

    An optional description of this resource. Provide this property when you create the resource.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#extension_policies ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy}

Returns Required. Map from extension (eg: "cloudops") to its policy configuration. The key is the name of the extension.

Returns:



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#id ⇒ ::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer) —

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#instance_selectors ⇒ ::Array<::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyInstanceSelector>

Returns Optional. Selector to target VMs for a policy. There is a logical "AND" between instance_selectors.

Returns:



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#globalVmExtensionPolicy for globalVmExtensionPolicies.

Returns:

  • (::String) —

    Output only. [Output Only] Type of the resource. Alwayscompute#globalVmExtensionPolicy for globalVmExtensionPolicies.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#name ⇒ ::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String) —

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#priority ⇒ ::Integer

Returns Optional. Used to resolve conflicts when multiple policies are active for the same extension. Defaults to 0.

Larger the number, higher the priority. When the priority is the same, the policy with the newer create time has higher priority.

Returns:

  • (::Integer) —

    Optional. Used to resolve conflicts when multiple policies are active for the same extension. Defaults to 0.

    Larger the number, higher the priority. When the priority is the same, the policy with the newer create time has higher priority.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#rollout_operation ⇒ ::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperation

Returns Required. The rollout strategy and status.

Returns:



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#scoped_resource_status ⇒ ::String

Returns Output only. [Output Only] The scoped resource status. It's only for tracking the purging status of the policy. Check the ScopedResourceStatus enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] The scoped resource status. It's only for tracking the purging status of the policy. Check the ScopedResourceStatus enum for the list of possible values.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined fully-qualified URL for this resource.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource's resource id.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for this resource's resource id.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end

#update_timestamp ⇒ ::String

Returns Output only. [Output Only] Update timestamp inRFC3339 text format.

Returns:

  • (::String) —

    Output only. [Output Only] Update timestamp inRFC3339 text format.



27040
27041
27042
27043
27044
27045
27046
27047
27048
27049
27050
27051
27052
27053
27054
27055
27056
27057
27058
27059
27060
27061
27062
27063
27064
27065
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27040

class GlobalVmExtensionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy]
  class ExtensionPoliciesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The scoped resource status. It's only for tracking the
  # purging status of the policy.
  module ScopedResourceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPED_RESOURCE_STATUS = 0

    # The zonal policies are being deleted.
    SCOPED_RESOURCE_STATUS_DELETING = 404_198_387

    # Default value. This value is unused.
    SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996
  end
end