Module: Google::Cloud::Compute::V1::GlobalVmExtensionPolicy::ScopedResourceStatus

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. [Output Only] The scoped resource status. It's only for tracking the purging status of the policy.

Constant Summary collapse

UNDEFINED_SCOPED_RESOURCE_STATUS =

A value indicating that the enum field is not set.

0
SCOPED_RESOURCE_STATUS_DELETING =

The zonal policies are being deleted.

404_198_387
SCOPED_RESOURCE_STATUS_UNSPECIFIED =

Default value. This value is unused.

437_941_996