Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyLabelSelector

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A LabelSelector is applicable for a VM only if it matches all labels in the LabelSelector.

Defined Under Namespace

Classes: InclusionLabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#inclusion_labels ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels as key value pairs. A VM should contain all the pairs specified in this map to be selected; Labels within the LabelSelector are OR'ed.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    Optional. Labels as key value pairs. A VM should contain all the pairs specified in this map to be selected; Labels within the LabelSelector are OR'ed.



27098
27099
27100
27101
27102
27103
27104
27105
27106
27107
27108
27109
27110
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27098

class GlobalVmExtensionPolicyLabelSelector
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InclusionLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end