Module: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutInput::PredefinedRolloutPlan

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Optional. Specifies the predefined rollout plan for the policy. Valid values are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is SLOW_ROLLOUT for progressive rollout. For more information, see Rollout plans for global policies.

Constant Summary collapse

UNDEFINED_PREDEFINED_ROLLOUT_PLAN =

A value indicating that the enum field is not set.

0
FAST_ROLLOUT =
207_153_326
ROLLOUT_PLAN_UNSPECIFIED =
144_511_983
SLOW_ROLLOUT =
31_032_659