Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#current_rollouts::Array<::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata>

Returns Output only. [Output Only] The current rollouts for the latest version of the resource. There should be only one current rollout, but for scalability, we make it repeated.

Returns:



26056
26057
26058
26059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26056

class GlobalVmExtensionPolicyRolloutOperationRolloutStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#previous_rollout::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Returns Output only. [Output Only] The last completed rollout resource. This field will not be populated until the first rollout is completed.

Returns:



26056
26057
26058
26059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26056

class GlobalVmExtensionPolicyRolloutOperationRolloutStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end