Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State Classes: LocationRolloutStatusEntry

Instance Attribute Summary collapse

Instance Attribute Details

#location_rollout_status ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus}

Returns Output only. [Output Only] The rollout status for each location. The list of the locations is the same as the list of locations in the rollout plan.

Returns:



27251
27252
27253
27254
27255
27256
27257
27258
27259
27260
27261
27262
27263
27264
27265
27266
27267
27268
27269
27270
27271
27272
27273
27274
27275
27276
27277
27278
27279
27280
27281
27282
27283
27284
27285
27286
27287
27288
27289
27290
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27251

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end

#rollout ⇒ ::String

Returns Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/.

Returns:

  • (::String) —

    Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/.



27251
27252
27253
27254
27255
27256
27257
27258
27259
27260
27261
27262
27263
27264
27265
27266
27267
27268
27269
27270
27271
27272
27273
27274
27275
27276
27277
27278
27279
27280
27281
27282
27283
27284
27285
27286
27287
27288
27289
27290
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27251

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end

#rollout_plan ⇒ ::String

Returns Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.

Returns:

  • (::String) —

    Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.



27251
27252
27253
27254
27255
27256
27257
27258
27259
27260
27261
27262
27263
27264
27265
27266
27267
27268
27269
27270
27271
27272
27273
27274
27275
27276
27277
27278
27279
27280
27281
27282
27283
27284
27285
27286
27287
27288
27289
27290
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27251

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end

#state ⇒ ::String

Returns Output only. [Output Only] The overall state of the rollout. Check the State enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] The overall state of the rollout. Check the State enum for the list of possible values.



27251
27252
27253
27254
27255
27256
27257
27258
27259
27260
27261
27262
27263
27264
27265
27266
27267
27268
27269
27270
27271
27272
27273
27274
27275
27276
27277
27278
27279
27280
27281
27282
27283
27284
27285
27286
27287
27288
27289
27290
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27251

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end