Module: Google::Cloud::Compute::V1::GuestOsFeature::Type

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values: - VIRTIO_SCSI_MULTIQUEUE - WINDOWS - MULTI_IP_SUBNET - UEFI_COMPATIBLE - GVNIC - SEV_CAPABLE - SUSPEND_RESUME_COMPATIBLE - SEV_LIVE_MIGRATABLE_V2 - SEV_SNP_CAPABLE - TDX_CAPABLE - IDPF - SNP_SVSM_CAPABLE For more information, see Enabling guest operating system features.

Constant Summary collapse

UNDEFINED_TYPE =

A value indicating that the enum field is not set.

0
BARE_METAL_LINUX_COMPATIBLE =
354_232_740
FEATURE_TYPE_UNSPECIFIED =
531_767_259
GVNIC =
68_209_305
IDPF =
2_242_641
MULTI_IP_SUBNET =
151_776_719
SECURE_BOOT =
376_811_194
SEV_CAPABLE =
87_083_793
SEV_LIVE_MIGRATABLE =
392_039_820
SEV_LIVE_MIGRATABLE_V2 =
168_551_983
SEV_SNP_CAPABLE =
426_919
SNP_SVSM_CAPABLE =
52_921_460
TDX_CAPABLE =
240_446_133
UEFI_COMPATIBLE =
195_865_408
VIRTIO_SCSI_MULTIQUEUE =
201_597_069
WINDOWS =
456_863_331