Class: Google::Cloud::Compute::V1::HealthCheck

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a health check resource.

Google Compute Engine has two health check resources:

These health check resources can be used for load balancing and for autohealing VMs in a managed instance group (MIG).

Load balancing

Health check requirements vary depending on the type of load balancer. For details about the type of health check supported for each load balancer and corresponding backend type, see Health checks overview: Load balancer guide.

Autohealing in MIGs

The health checks that you use for autohealing VMs in a MIG can be either regional or global. For more information, see Set up an application health check and autohealing.

For more information, seeHealth checks overview.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#check_interval_sec::Integer

Returns How often (in seconds) to send a health check. The default value is 5 seconds.

Returns:

  • (::Integer)

    How often (in seconds) to send a health check. The default value is 5 seconds.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp in3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp in3339 text format.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#grpc_health_check::Google::Cloud::Compute::V1::GRPCHealthCheck



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#grpc_tls_health_check::Google::Cloud::Compute::V1::GRPCTLSHealthCheck



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#healthy_threshold::Integer

Returns A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.

Returns:

  • (::Integer)

    A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#http2_health_check::Google::Cloud::Compute::V1::HTTP2HealthCheck



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#http_health_check::Google::Cloud::Compute::V1::HTTPHealthCheck



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#https_health_check::Google::Cloud::Compute::V1::HTTPSHealthCheck



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#id::Integer

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    [Output Only] The unique identifier for the resource. This identifier is defined by the server.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#kind::String

Returns Output only. Type of the resource.

Returns:

  • (::String)

    Output only. Type of the resource.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#log_config::Google::Cloud::Compute::V1::HealthCheckLogConfig

Returns Configure logging on this health check.

Returns:



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#name::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. For example, a name that is 1-63 characters long, matches the regular expression [a-z]([-a-z0-9]*[a-z0-9])?, and otherwise complies with RFC1035. This regular expression describes a name where the first character is a lowercase letter, and all following characters are a dash, lowercase letter, or digit, except the last character, which isn't a dash.

Returns:

  • (::String)

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. For example, a name that is 1-63 characters long, matches the regular expression [a-z]([-a-z0-9]*[a-z0-9])?, and otherwise complies with RFC1035. This regular expression describes a name where the first character is a lowercase letter, and all following characters are a dash, lowercase letter, or digit, except the last character, which isn't a dash.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#region::String

Returns Output only. [Output Only] Region where the health check resides. Not applicable to global health checks.

Returns:

  • (::String)

    Output only. [Output Only] Region where the health check resides. Not applicable to global health checks.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for the resource.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#source_regions::Array<::String>

Returns The list of cloud regions from which health checks are performed. If any regions are specified, then exactly 3 regions should be specified. The region names must be valid names of Google Cloud regions. This can only be set for global health check. If this list is non-empty, then there are restrictions on what other health check fields are supported and what other resources can use this health check:

  • SSL, HTTP2, and GRPC protocols are not supported.
  • The TCP request field is not supported.
  • The proxyHeader field for HTTP, HTTPS, and TCP is not supported.
  • The checkIntervalSec field must be at least 30.
  • The health check cannot be used with BackendService nor with managed instance group auto-healing.

Returns:

  • (::Array<::String>)

    The list of cloud regions from which health checks are performed. If any regions are specified, then exactly 3 regions should be specified. The region names must be valid names of Google Cloud regions. This can only be set for global health check. If this list is non-empty, then there are restrictions on what other health check fields are supported and what other resources can use this health check:

    • SSL, HTTP2, and GRPC protocols are not supported.
    • The TCP request field is not supported.
    • The proxyHeader field for HTTP, HTTPS, and TCP is not supported.
    • The checkIntervalSec field must be at least 30.
    • The health check cannot be used with BackendService nor with managed instance group auto-healing.


26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#ssl_health_check::Google::Cloud::Compute::V1::SSLHealthCheck



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#tcp_health_check::Google::Cloud::Compute::V1::TCPHealthCheck



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#timeout_sec::Integer

Returns How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec.

Returns:

  • (::Integer)

    How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#type::String

Returns Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the protocol-specific health check fields must be specified, which must matchtype field. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the protocol-specific health check fields must be specified, which must matchtype field. Check the Type enum for the list of possible values.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end

#unhealthy_threshold::Integer

Returns A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.

Returns:

  • (::Integer)

    A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.



26297
26298
26299
26300
26301
26302
26303
26304
26305
26306
26307
26308
26309
26310
26311
26312
26313
26314
26315
26316
26317
26318
26319
26320
26321
26322
26323
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26297

class HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the
  # protocol-specific health check fields must be specified, which must matchtype field.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    GRPC = 2_196_510

    GRPC_WITH_TLS = 268_089_571

    HTTP = 2_228_360

    HTTP2 = 69_079_210

    HTTPS = 69_079_243

    INVALID = 530_283_991

    SSL = 82_412

    TCP = 82_881
  end
end