Module: Google::Cloud::Compute::V1::HealthCheck::Type

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specifies the type of the healthCheck, either TCP, SSL, HTTP, HTTPS, HTTP2 or GRPC. Exactly one of the protocol-specific health check fields must be specified, which must match type field.

Constant Summary collapse

UNDEFINED_TYPE =

A value indicating that the enum field is not set.

0
GRPC =
2_196_510
HTTP =
2_228_360
HTTP2 =
69_079_210
HTTPS =
69_079_243
INVALID =
530_283_991
SSL =
82_412
TCP =
82_881