Class: Google::Cloud::Compute::V1::HealthCheckService

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Health-Check as a Service resource.

Defined Under Namespace

Modules: HealthStatusAggregationPolicy

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#fingerprint::String

Returns Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthCheckService. An up-to-date fingerprint must be provided in order to patch/update the HealthCheckService; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthCheckService.

Returns:

  • (::String)

    Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthCheckService. An up-to-date fingerprint must be provided in order to patch/update the HealthCheckService; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthCheckService.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#health_checks::Array<::String>

Returns A list of URLs to the HealthCheck resources. Must have at least one HealthCheck, and not more than 10 for regionalHealthCheckService, and not more than 1 for globalHealthCheckService.HealthCheck resources must haveportSpecification=USE_SERVING_PORT orportSpecification=USE_FIXED_PORT. For regional HealthCheckService, theHealthCheck must be regional and in the same region. For global HealthCheckService,HealthCheck must be global. Mix of regional and globalHealthChecks is not supported. Multiple regionalHealthChecks must belong to the same region. RegionalHealthChecks must belong to the same region as zones ofNetworkEndpointGroups. For globalHealthCheckService using globalINTERNET_IP_PORT NetworkEndpointGroups, the global HealthChecks must specify sourceRegions, and HealthChecks that specify sourceRegions can only be used with global INTERNET_IP_PORTNetworkEndpointGroups.

Returns:

  • (::Array<::String>)

    A list of URLs to the HealthCheck resources. Must have at least one HealthCheck, and not more than 10 for regionalHealthCheckService, and not more than 1 for globalHealthCheckService.HealthCheck resources must haveportSpecification=USE_SERVING_PORT orportSpecification=USE_FIXED_PORT. For regional HealthCheckService, theHealthCheck must be regional and in the same region. For global HealthCheckService,HealthCheck must be global. Mix of regional and globalHealthChecks is not supported. Multiple regionalHealthChecks must belong to the same region. RegionalHealthChecks must belong to the same region as zones ofNetworkEndpointGroups. For globalHealthCheckService using globalINTERNET_IP_PORT NetworkEndpointGroups, the global HealthChecks must specify sourceRegions, and HealthChecks that specify sourceRegions can only be used with global INTERNET_IP_PORTNetworkEndpointGroups.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#health_status_aggregation_policy::String

Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified.

  • NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service.
  • AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.

. This is only allowed with regional HealthCheckService. Check the HealthStatusAggregationPolicy enum for the list of possible values.

Returns:

  • (::String)

    Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified.

    • NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service.
    • AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.

    . This is only allowed with regional HealthCheckService. Check the HealthStatusAggregationPolicy enum for the list of possible values.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#kind::String

Returns Output only. [Output only] Type of the resource. Alwayscompute#healthCheckServicefor health check services.

Returns:

  • (::String)

    Output only. [Output only] Type of the resource. Alwayscompute#healthCheckServicefor health check services.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#name::String

Returns Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#network_endpoint_groups::Array<::String>

Returns A list of URLs to the NetworkEndpointGroup resources. Must not have more than 100. For regionalHealthCheckService, NEGs must be in zones in the region of the HealthCheckService. For globalHealthCheckServices, the NetworkEndpointGroups must be global INTERNET_IP_PORT.

Returns:

  • (::Array<::String>)

    A list of URLs to the NetworkEndpointGroup resources. Must not have more than 100. For regionalHealthCheckService, NEGs must be in zones in the region of the HealthCheckService. For globalHealthCheckServices, the NetworkEndpointGroups must be global INTERNET_IP_PORT.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#notification_endpoints::Array<::String>

Returns A list of URLs to the NotificationEndpoint resources. Must not have more than 10. A list of endpoints for receiving notifications of change in health status. For regionalHealthCheckService,NotificationEndpoint must be regional and in the same region. For global HealthCheckService,NotificationEndpoint must be global.

Returns:

  • (::Array<::String>)

    A list of URLs to the NotificationEndpoint resources. Must not have more than 10. A list of endpoints for receiving notifications of change in health status. For regionalHealthCheckService,NotificationEndpoint must be regional and in the same region. For global HealthCheckService,NotificationEndpoint must be global.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#region::String

Returns Output only. [Output Only] URL of the region where the health check service resides. This field is not applicable to global health check services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Returns:

  • (::String)

    Output only. [Output Only] URL of the region where the health check service resides. This field is not applicable to global health check services. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for the resource.



26455
26456
26457
26458
26459
26460
26461
26462
26463
26464
26465
26466
26467
26468
26469
26470
26471
26472
26473
26474
26475
26476
26477
26478
26479
26480
26481
26482
26483
26484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26455

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks
  # for the same endpoint are aggregated. Defaults to NO_AGGREGATION
  # if unspecified.
  #
  #    - NO_AGGREGATION. An EndpointHealth message is
  #    returned for each  pair in the health check
  #    service.
  #    - AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
  #
  # .
  # This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY,
    # then UNHEALTHY is the HealthState of
    # the entire health check service. If all backend's are healthy,
    # the HealthState of the health check service isHEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each
    # backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end