Module: Google::Cloud::Compute::V1::HealthCheckService::HealthStatusAggregationPolicy
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified.
- NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service.
- AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY is theHealthState of the endpoint. If all health checks reportHEALTHY, the HealthState of the endpoint isHEALTHY.
. This is only allowed with regional HealthCheckService.
Constant Summary collapse
- UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY =
A value indicating that the enum field is not set.
0- AND =
If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service isHEALTHY.
64_951- NO_AGGREGATION =
An EndpointHealth message is returned for each backend in the health check service.
426_445_124