Class: Google::Cloud::Compute::V1::HealthCheckServicesScopedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HealthCheckServicesScopedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#resources ⇒ ::Array<::Google::Cloud::Compute::V1::HealthCheckService>
A list of HealthCheckServices contained in this scope.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Informational warning which replaces the list of backend services when the list is empty.
Instance Attribute Details
#resources ⇒ ::Array<::Google::Cloud::Compute::V1::HealthCheckService>
Returns A list of HealthCheckServices contained in this scope.
26574 26575 26576 26577 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26574 class HealthCheckServicesScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Informational warning which replaces the list of backend services when the list is empty.
26574 26575 26576 26577 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26574 class HealthCheckServicesScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |