Class: Google::Cloud::Compute::V1::HealthSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a health source.

A health source resource specifies the source resources and the health aggregation policy applied to the source resources to determine the aggregated health status.

Defined Under Namespace

Modules: SourceType

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

#fingerprint::String

Returns Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthSource. An up-to-date fingerprint must be provided in order to patch the HealthSource; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthSource.

Returns:

  • (::String)

    Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthSource. An up-to-date fingerprint must be provided in order to patch the HealthSource; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthSource.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

#health_aggregation_policy::String

Returns URL to the HealthAggregationPolicy resource. Must be set. Must be regional and in the same region as the HealthSource. Can be mutated.

Returns:

  • (::String)

    URL to the HealthAggregationPolicy resource. Must be set. Must be regional and in the same region as the HealthSource. Can be mutated.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

#id::Integer

Returns Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier.

Returns:

  • (::Integer)

    Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#healthSource for health sources.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Alwayscompute#healthSource for health sources.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

#name::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

#region::String

Returns Output only. [Output Only] URL of the region where the health source resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Returns:

  • (::String)

    Output only. [Output Only] URL of the region where the health source resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for the resource.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

Returns Output only. [Output Only] Server-defined URL with id for the resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL with id for the resource.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

#source_type::String

Returns Specifies the type of the HealthSource. The only allowed value is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated. Check the SourceType enum for the list of possible values.

Returns:

  • (::String)

    Specifies the type of the HealthSource. The only allowed value is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated. Check the SourceType enum for the list of possible values.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end

#sources::Array<::String>

Returns URLs to the source resources. Must be size 1. Must be aBackendService if the sourceType is BACKEND_SERVICE. TheBackendService must have load balancing schemeINTERNAL or INTERNAL_MANAGED and must be regional and in the same region as the HealthSource (cross-region deployment for INTERNAL_MANAGED is not supported). TheBackendService may use only IGs, MIGs, or NEGs of typeGCE_VM_IP or GCE_VM_IP_PORT. TheBackendService may not use haPolicy. Can be mutated.

Returns:

  • (::Array<::String>)

    URLs to the source resources. Must be size 1. Must be aBackendService if the sourceType is BACKEND_SERVICE. TheBackendService must have load balancing schemeINTERNAL or INTERNAL_MANAGED and must be regional and in the same region as the HealthSource (cross-region deployment for INTERNAL_MANAGED is not supported). TheBackendService may use only IGs, MIGs, or NEGs of typeGCE_VM_IP or GCE_VM_IP_PORT. TheBackendService may not use haPolicy. Can be mutated.



26697
26698
26699
26700
26701
26702
26703
26704
26705
26706
26707
26708
26709
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26697

class HealthSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of the HealthSource. The only allowed value
  # is BACKEND_SERVICE. Must be specified when theHealthSource is created, and cannot be mutated.
  module SourceType
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE_TYPE = 0

    BACKEND_SERVICE = 285_792_202
  end
end