Class: Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfoBackendInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#endpoint_count ⇒ ::Integer

Returns Total number of endpoints when determining the health of the regionHealthSource.

Returns:

  • (::Integer) —

    Total number of endpoints when determining the health of the regionHealthSource.



28691
28692
28693
28694
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28691

class HealthSourcesGetHealthResponseSourceInfoBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#group ⇒ ::String

Returns Fully qualified URL of an instance group or network endpoint group behind the source backend service.

Returns:

  • (::String) —

    Fully qualified URL of an instance group or network endpoint group behind the source backend service.



28691
28692
28693
28694
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28691

class HealthSourcesGetHealthResponseSourceInfoBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#healthy_endpoint_count ⇒ ::Integer

Returns Number of endpoints considered healthy when determining health of the regionHealthSource.

Returns:

  • (::Integer) —

    Number of endpoints considered healthy when determining health of the regionHealthSource.



28691
28692
28693
28694
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28691

class HealthSourcesGetHealthResponseSourceInfoBackendInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end