Class: Google::Cloud::Compute::V1::HealthSourcesScopedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HealthSourcesScopedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#health_sources ⇒ ::Array<::Google::Cloud::Compute::V1::HealthSource>
A list of HealthSources contained in this scope.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Informational warning which replaces the list of health sources when the list is empty.
Instance Attribute Details
#health_sources ⇒ ::Array<::Google::Cloud::Compute::V1::HealthSource>
Returns A list of HealthSources contained in this scope.
26848 26849 26850 26851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26848 class HealthSourcesScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Informational warning which replaces the list of health sources when the list is empty.
26848 26849 26850 26851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26848 class HealthSourcesScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |