Class: Google::Cloud::Compute::V1::HealthStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: HealthState, Ipv6HealthState, WeightError Classes: AnnotationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns Metadata defined as annotations for network endpoint.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    Metadata defined as annotations for network endpoint.



28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#forwarding_rule ⇒ ::String

Returns URL of the forwarding rule associated with the health status of the instance.

Returns:

  • (::String) —

    URL of the forwarding rule associated with the health status of the instance.



28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#forwarding_rule_ip ⇒ ::String

Returns A forwarding rule IP address assigned to this instance.

Returns:

  • (::String) —

    A forwarding rule IP address assigned to this instance.



28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#health_state ⇒ ::String

Returns Health state of the IPv4 address of the instance. Check the HealthState enum for the list of possible values.

Returns:

  • (::String) —

    Health state of the IPv4 address of the instance. Check the HealthState enum for the list of possible values.



28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#instance ⇒ ::String

Returns URL of the instance resource.

Returns:

  • (::String) —

    URL of the instance resource.



28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#ip_address ⇒ ::String

Returns For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip.

Returns:

  • (::String) —

    For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip.



28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#ipv6_address ⇒ ::String

Returns:

  • (::String)


28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#ipv6_health_state ⇒ ::String

Returns Health state of the IPv6 address of the instance. Check the Ipv6HealthState enum for the list of possible values.

Returns:

  • (::String) —

    Health state of the IPv6 address of the instance. Check the Ipv6HealthState enum for the list of possible values.



28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#port ⇒ ::Integer

Returns The named port of the instance group, not necessarily the port that is health-checked.

Returns:

  • (::Integer) —

    The named port of the instance group, not necessarily the port that is health-checked.



28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#weight ⇒ ::String

Returns:

  • (::String)


28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#weight_error ⇒ ::String

Returns Check the WeightError enum for the list of possible values.

Returns:

  • (::String) —

    Check the WeightError enum for the list of possible values.



28745
28746
28747
28748
28749
28750
28751
28752
28753
28754
28755
28756
28757
28758
28759
28760
28761
28762
28763
28764
28765
28766
28767
28768
28769
28770
28771
28772
28773
28774
28775
28776
28777
28778
28779
28780
28781
28782
28783
28784
28785
28786
28787
28788
28789
28790
28791
28792
28793
28794
28795
28796
28797
28798
28799
28800
28801
28802
28803
28804
28805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28745

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end