Class: Google::Cloud::Compute::V1::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: HealthState, Ipv6HealthState

Instance Attribute Summary collapse

Instance Attribute Details

#backend_service ⇒ ::Google::Cloud::Compute::V1::BackendServiceReference

Returns URL of the backend service associated with the health state of the network endpoint.

Returns:



28833
28834
28835
28836
28837
28838
28839
28840
28841
28842
28843
28844
28845
28846
28847
28848
28849
28850
28851
28852
28853
28854
28855
28856
28857
28858
28859
28860
28861
28862
28863
28864
28865
28866
28867
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28833

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    # Endpoint is being drained.
    DRAINING = 480_455_402

    # Endpoint is healthy.
    HEALTHY = 439_801_213

    # Endpoint is unhealthy.
    UNHEALTHY = 462_118_084

    # Health status of the endpoint is unknown.
    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#forwarding_rule ⇒ ::Google::Cloud::Compute::V1::ForwardingRuleReference

Returns URL of the forwarding rule associated with the health state of the network endpoint.

Returns:



28833
28834
28835
28836
28837
28838
28839
28840
28841
28842
28843
28844
28845
28846
28847
28848
28849
28850
28851
28852
28853
28854
28855
28856
28857
28858
28859
28860
28861
28862
28863
28864
28865
28866
28867
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28833

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    # Endpoint is being drained.
    DRAINING = 480_455_402

    # Endpoint is healthy.
    HEALTHY = 439_801_213

    # Endpoint is unhealthy.
    UNHEALTHY = 462_118_084

    # Health status of the endpoint is unknown.
    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#health_check ⇒ ::Google::Cloud::Compute::V1::HealthCheckReference

Returns URL of the health check associated with the health state of the network endpoint.

Returns:



28833
28834
28835
28836
28837
28838
28839
28840
28841
28842
28843
28844
28845
28846
28847
28848
28849
28850
28851
28852
28853
28854
28855
28856
28857
28858
28859
28860
28861
28862
28863
28864
28865
28866
28867
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28833

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    # Endpoint is being drained.
    DRAINING = 480_455_402

    # Endpoint is healthy.
    HEALTHY = 439_801_213

    # Endpoint is unhealthy.
    UNHEALTHY = 462_118_084

    # Health status of the endpoint is unknown.
    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#health_check_service ⇒ ::Google::Cloud::Compute::V1::HealthCheckServiceReference

Returns URL of the health check service associated with the health state of the network endpoint.

Returns:



28833
28834
28835
28836
28837
28838
28839
28840
28841
28842
28843
28844
28845
28846
28847
28848
28849
28850
28851
28852
28853
28854
28855
28856
28857
28858
28859
28860
28861
28862
28863
28864
28865
28866
28867
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28833

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    # Endpoint is being drained.
    DRAINING = 480_455_402

    # Endpoint is healthy.
    HEALTHY = 439_801_213

    # Endpoint is unhealthy.
    UNHEALTHY = 462_118_084

    # Health status of the endpoint is unknown.
    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#health_state ⇒ ::String

Returns Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.

Returns:

  • (::String) —

    Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.



28833
28834
28835
28836
28837
28838
28839
28840
28841
28842
28843
28844
28845
28846
28847
28848
28849
28850
28851
28852
28853
28854
28855
28856
28857
28858
28859
28860
28861
28862
28863
28864
28865
28866
28867
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28833

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    # Endpoint is being drained.
    DRAINING = 480_455_402

    # Endpoint is healthy.
    HEALTHY = 439_801_213

    # Endpoint is unhealthy.
    UNHEALTHY = 462_118_084

    # Health status of the endpoint is unknown.
    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#ipv6_health_state ⇒ ::String

Returns Health state of the ipv6 network endpoint determined based on the health checks configured. Check the Ipv6HealthState enum for the list of possible values.

Returns:

  • (::String) —

    Health state of the ipv6 network endpoint determined based on the health checks configured. Check the Ipv6HealthState enum for the list of possible values.



28833
28834
28835
28836
28837
28838
28839
28840
28841
28842
28843
28844
28845
28846
28847
28848
28849
28850
28851
28852
28853
28854
28855
28856
28857
28858
28859
28860
28861
28862
28863
28864
28865
28866
28867
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28833

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    # Endpoint is being drained.
    DRAINING = 480_455_402

    # Endpoint is healthy.
    HEALTHY = 439_801_213

    # Endpoint is unhealthy.
    UNHEALTHY = 462_118_084

    # Health status of the endpoint is unknown.
    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end