Class: Google::Cloud::Compute::V1::Host

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a host resource.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

Returns Output only. All aliases for this resource. e.g. projects/123/zones/us-centra1-a/reservation/r1/reservationBlock/b1/hosts/h1.

Returns:

  • (::Array<::String>) —

    Output only. All aliases for this resource. e.g. projects/123/zones/us-centra1-a/reservation/r1/reservationBlock/b1/hosts/h1



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#creation_timestamp ⇒ ::String

Returns Output only. The creation timestamp, formatted asRFC3339 text.

Returns:

  • (::String) —

    Output only. The creation timestamp, formatted asRFC3339 text.



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#description ⇒ ::String

Returns An optional description of this resource.

Returns:

  • (::String) —

    An optional description of this resource.



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#id ⇒ ::Integer

Returns Output only. The unique identifier for this resource. This identifier is defined by the server.

Returns:

  • (::Integer) —

    Output only. The unique identifier for this resource. This identifier is defined by the server.



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#kind ⇒ ::String

Returns Output only. The type of resource. Alwayscompute#host for hosts.

Returns:

  • (::String) —

    Output only. The type of resource. Alwayscompute#host for hosts.



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#name ⇒ ::String

Returns Output only. The name of the host.

Returns:

  • (::String) —

    Output only. The name of the host.



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

Returns Output only. The self link of the host.

Returns:

  • (::String) —

    Output only. The self link of the host.



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

Returns Output only. The self link with id of the host.

Returns:

  • (::String) —

    Output only. The self link with id of the host.



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#state ⇒ ::String

Returns Output only. The state of the host. Check the State enum for the list of possible values.

Returns:

  • (::String) —

    Output only. The state of the host. Check the State enum for the list of possible values.



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#status ⇒ ::Google::Cloud::Compute::V1::HostStatus

Returns Output only. The status of the host.

Returns:



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#zone ⇒ ::String

Returns Output only. The zone in which the host resides.

Returns:

  • (::String) —

    Output only. The zone in which the host resides.



28932
28933
28934
28935
28936
28937
28938
28939
28940
28941
28942
28943
28944
28945
28946
28947
28948
28949
28950
28951
28952
28953
28954
28955
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28932

class Host
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the host.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The host has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the host.
    CREATING = 455_564_985

    # The host is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The host is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end