Class: Google::Cloud::Compute::V1::HostPhysicalTopology

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#block ⇒ ::String

Returns The unique identifier of the capacity block within the cluster.

Returns:

  • (::String) —

    The unique identifier of the capacity block within the cluster.



28970
28971
28972
28973
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28970

class HostPhysicalTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cluster ⇒ ::String

Returns The cluster name of the reservation sub-block.

Returns:

  • (::String) —

    The cluster name of the reservation sub-block.



28970
28971
28972
28973
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28970

class HostPhysicalTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#host ⇒ ::String

Returns The unique identifier of the capacity host within the capacity sub-block.

Returns:

  • (::String) —

    The unique identifier of the capacity host within the capacity sub-block.



28970
28971
28972
28973
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28970

class HostPhysicalTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sub_block ⇒ ::String

Returns The unique identifier of the capacity sub-block within the capacity block.

Returns:

  • (::String) —

    The unique identifier of the capacity sub-block within the capacity block.



28970
28971
28972
28973
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28970

class HostPhysicalTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end