Class: Google::Cloud::Compute::V1::HostStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#physical_topology ⇒ ::Google::Cloud::Compute::V1::HostPhysicalTopology

Returns Output only. The physical topology of the reservation sub-block, if present.

Returns:



29008
29009
29010
29011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29008

class HostStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#running_instances ⇒ ::Array<::String>

Returns Output only. The URIs of the instances currently running on this host.

Returns:

  • (::Array<::String>) —

    Output only. The URIs of the instances currently running on this host.



29008
29009
29010
29011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29008

class HostStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end