Class: Google::Cloud::Compute::V1::HttpRedirectAction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specifies settings for an HTTP redirect.

Defined Under Namespace

Modules: RedirectResponseCode

Instance Attribute Summary collapse

Instance Attribute Details

#host_redirect ⇒ ::String

Returns The host that is used in the redirect response instead of the one that was supplied in the request.

The value must be from 1 to 255 characters.

Returns:

  • (::String) —

    The host that is used in the redirect response instead of the one that was supplied in the request.

    The value must be from 1 to 255 characters.



29350
29351
29352
29353
29354
29355
29356
29357
29358
29359
29360
29361
29362
29363
29364
29365
29366
29367
29368
29369
29370
29371
29372
29373
29374
29375
29376
29377
29378
29379
29380
29381
29382
29383
29384
29385
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29350

class HttpRedirectAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The HTTP Status code to use for this RedirectAction.
  #
  # Supported values are:
  #
  #    - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds
  #    to 301.
  #    - FOUND, which corresponds to 302.
  #    - SEE_OTHER which corresponds to 303.
  #    - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request
  #    method is retained.
  #    - PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
  #    method is retained.
  module RedirectResponseCode
    # A value indicating that the enum field is not set.
    UNDEFINED_REDIRECT_RESPONSE_CODE = 0

    # Http Status Code 302 - Found.
    FOUND = 67_084_130

    # Http Status Code 301 - Moved Permanently.
    MOVED_PERMANENTLY_DEFAULT = 386_698_449

    # Http Status Code 308 - Permanent Redirect maintaining HTTP method.
    PERMANENT_REDIRECT = 382_006_381

    # Http Status Code 303 - See Other.
    SEE_OTHER = 445_380_580

    # Http Status Code 307 - Temporary Redirect maintaining HTTP method.
    TEMPORARY_REDIRECT = 489_550_378
  end
end

#https_redirect ⇒ ::Boolean

Returns If set to true, the URL scheme in the redirected request is set to HTTPS. If set to false, the URL scheme of the redirected request remains the same as that of the request.

This must only be set for URL maps used inTargetHttpProxys. Setting this true forTargetHttpsProxy is not permitted.

The default is set to false.

Returns:

  • (::Boolean) —

    If set to true, the URL scheme in the redirected request is set to HTTPS. If set to false, the URL scheme of the redirected request remains the same as that of the request.

    This must only be set for URL maps used inTargetHttpProxys. Setting this true forTargetHttpsProxy is not permitted.

    The default is set to false.



29350
29351
29352
29353
29354
29355
29356
29357
29358
29359
29360
29361
29362
29363
29364
29365
29366
29367
29368
29369
29370
29371
29372
29373
29374
29375
29376
29377
29378
29379
29380
29381
29382
29383
29384
29385
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29350

class HttpRedirectAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The HTTP Status code to use for this RedirectAction.
  #
  # Supported values are:
  #
  #    - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds
  #    to 301.
  #    - FOUND, which corresponds to 302.
  #    - SEE_OTHER which corresponds to 303.
  #    - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request
  #    method is retained.
  #    - PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
  #    method is retained.
  module RedirectResponseCode
    # A value indicating that the enum field is not set.
    UNDEFINED_REDIRECT_RESPONSE_CODE = 0

    # Http Status Code 302 - Found.
    FOUND = 67_084_130

    # Http Status Code 301 - Moved Permanently.
    MOVED_PERMANENTLY_DEFAULT = 386_698_449

    # Http Status Code 308 - Permanent Redirect maintaining HTTP method.
    PERMANENT_REDIRECT = 382_006_381

    # Http Status Code 303 - See Other.
    SEE_OTHER = 445_380_580

    # Http Status Code 307 - Temporary Redirect maintaining HTTP method.
    TEMPORARY_REDIRECT = 489_550_378
  end
end

#path_redirect ⇒ ::String

Returns The path that is used in the redirect response instead of the one that was supplied in the request.

pathRedirect cannot be supplied together withprefixRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect.

The value must be from 1 to 1024 characters.

Returns:

  • (::String) —

    The path that is used in the redirect response instead of the one that was supplied in the request.

    pathRedirect cannot be supplied together withprefixRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect.

    The value must be from 1 to 1024 characters.



29350
29351
29352
29353
29354
29355
29356
29357
29358
29359
29360
29361
29362
29363
29364
29365
29366
29367
29368
29369
29370
29371
29372
29373
29374
29375
29376
29377
29378
29379
29380
29381
29382
29383
29384
29385
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29350

class HttpRedirectAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The HTTP Status code to use for this RedirectAction.
  #
  # Supported values are:
  #
  #    - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds
  #    to 301.
  #    - FOUND, which corresponds to 302.
  #    - SEE_OTHER which corresponds to 303.
  #    - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request
  #    method is retained.
  #    - PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
  #    method is retained.
  module RedirectResponseCode
    # A value indicating that the enum field is not set.
    UNDEFINED_REDIRECT_RESPONSE_CODE = 0

    # Http Status Code 302 - Found.
    FOUND = 67_084_130

    # Http Status Code 301 - Moved Permanently.
    MOVED_PERMANENTLY_DEFAULT = 386_698_449

    # Http Status Code 308 - Permanent Redirect maintaining HTTP method.
    PERMANENT_REDIRECT = 382_006_381

    # Http Status Code 303 - See Other.
    SEE_OTHER = 445_380_580

    # Http Status Code 307 - Temporary Redirect maintaining HTTP method.
    TEMPORARY_REDIRECT = 489_550_378
  end
end

#prefix_redirect ⇒ ::String

Returns The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request.

prefixRedirect cannot be supplied together withpathRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect.

The value must be from 1 to 1024 characters.

Returns:

  • (::String) —

    The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request.

    prefixRedirect cannot be supplied together withpathRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect.

    The value must be from 1 to 1024 characters.



29350
29351
29352
29353
29354
29355
29356
29357
29358
29359
29360
29361
29362
29363
29364
29365
29366
29367
29368
29369
29370
29371
29372
29373
29374
29375
29376
29377
29378
29379
29380
29381
29382
29383
29384
29385
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29350

class HttpRedirectAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The HTTP Status code to use for this RedirectAction.
  #
  # Supported values are:
  #
  #    - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds
  #    to 301.
  #    - FOUND, which corresponds to 302.
  #    - SEE_OTHER which corresponds to 303.
  #    - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request
  #    method is retained.
  #    - PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
  #    method is retained.
  module RedirectResponseCode
    # A value indicating that the enum field is not set.
    UNDEFINED_REDIRECT_RESPONSE_CODE = 0

    # Http Status Code 302 - Found.
    FOUND = 67_084_130

    # Http Status Code 301 - Moved Permanently.
    MOVED_PERMANENTLY_DEFAULT = 386_698_449

    # Http Status Code 308 - Permanent Redirect maintaining HTTP method.
    PERMANENT_REDIRECT = 382_006_381

    # Http Status Code 303 - See Other.
    SEE_OTHER = 445_380_580

    # Http Status Code 307 - Temporary Redirect maintaining HTTP method.
    TEMPORARY_REDIRECT = 489_550_378
  end
end

#redirect_response_code ⇒ ::String

Returns The HTTP Status code to use for this RedirectAction.

Supported values are:

- MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds
to 301.
- FOUND, which corresponds to 302.
- SEE_OTHER which corresponds to 303.
- TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request
method is retained.
- PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
method is retained.

Check the RedirectResponseCode enum for the list of possible values.

Returns:

  • (::String) —

    The HTTP Status code to use for this RedirectAction.

    Supported values are:

    - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds
    to 301.
    - FOUND, which corresponds to 302.
    - SEE_OTHER which corresponds to 303.
    - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request
    method is retained.
    - PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
    method is retained.
    

    Check the RedirectResponseCode enum for the list of possible values.



29350
29351
29352
29353
29354
29355
29356
29357
29358
29359
29360
29361
29362
29363
29364
29365
29366
29367
29368
29369
29370
29371
29372
29373
29374
29375
29376
29377
29378
29379
29380
29381
29382
29383
29384
29385
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29350

class HttpRedirectAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The HTTP Status code to use for this RedirectAction.
  #
  # Supported values are:
  #
  #    - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds
  #    to 301.
  #    - FOUND, which corresponds to 302.
  #    - SEE_OTHER which corresponds to 303.
  #    - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request
  #    method is retained.
  #    - PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
  #    method is retained.
  module RedirectResponseCode
    # A value indicating that the enum field is not set.
    UNDEFINED_REDIRECT_RESPONSE_CODE = 0

    # Http Status Code 302 - Found.
    FOUND = 67_084_130

    # Http Status Code 301 - Moved Permanently.
    MOVED_PERMANENTLY_DEFAULT = 386_698_449

    # Http Status Code 308 - Permanent Redirect maintaining HTTP method.
    PERMANENT_REDIRECT = 382_006_381

    # Http Status Code 303 - See Other.
    SEE_OTHER = 445_380_580

    # Http Status Code 307 - Temporary Redirect maintaining HTTP method.
    TEMPORARY_REDIRECT = 489_550_378
  end
end

#strip_query ⇒ ::Boolean

Returns If set to true, any accompanying query portion of the original URL is removed before redirecting the request. If set to false, the query portion of the original URL is retained.

The default is set to false.

Returns:

  • (::Boolean) —

    If set to true, any accompanying query portion of the original URL is removed before redirecting the request. If set to false, the query portion of the original URL is retained.

    The default is set to false.



29350
29351
29352
29353
29354
29355
29356
29357
29358
29359
29360
29361
29362
29363
29364
29365
29366
29367
29368
29369
29370
29371
29372
29373
29374
29375
29376
29377
29378
29379
29380
29381
29382
29383
29384
29385
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29350

class HttpRedirectAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The HTTP Status code to use for this RedirectAction.
  #
  # Supported values are:
  #
  #    - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds
  #    to 301.
  #    - FOUND, which corresponds to 302.
  #    - SEE_OTHER which corresponds to 303.
  #    - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request
  #    method is retained.
  #    - PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
  #    method is retained.
  module RedirectResponseCode
    # A value indicating that the enum field is not set.
    UNDEFINED_REDIRECT_RESPONSE_CODE = 0

    # Http Status Code 302 - Found.
    FOUND = 67_084_130

    # Http Status Code 301 - Moved Permanently.
    MOVED_PERMANENTLY_DEFAULT = 386_698_449

    # Http Status Code 308 - Permanent Redirect maintaining HTTP method.
    PERMANENT_REDIRECT = 382_006_381

    # Http Status Code 303 - See Other.
    SEE_OTHER = 445_380_580

    # Http Status Code 307 - Temporary Redirect maintaining HTTP method.
    TEMPORARY_REDIRECT = 489_550_378
  end
end