Class: Google::Cloud::Compute::V1::HttpRetryPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The retry policy associates with HttpRouteRule

Instance Attribute Summary collapse

Instance Attribute Details

#num_retries ⇒ ::Integer

Returns Specifies the allowed number retries. This number must be > 0. If not specified, defaults to 1.

Returns:

  • (::Integer) —

    Specifies the allowed number retries. This number must be > 0. If not specified, defaults to 1.



29442
29443
29444
29445
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29442

class HttpRetryPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#per_try_timeout ⇒ ::Google::Cloud::Compute::V1::Duration

Returns Specifies a non-zero timeout per retry attempt.

If not specified, will use the timeout set in theHttpRouteAction field. If timeout in the HttpRouteAction field is not set, this field uses the largest timeout among all backend services associated with the route.

Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.

Returns:

  • (::Google::Cloud::Compute::V1::Duration) —

    Specifies a non-zero timeout per retry attempt.

    If not specified, will use the timeout set in theHttpRouteAction field. If timeout in the HttpRouteAction field is not set, this field uses the largest timeout among all backend services associated with the route.

    Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.



29442
29443
29444
29445
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29442

class HttpRetryPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#retry_conditions ⇒ ::Array<::String>

Returns Specifies one or more conditions when this retry policy applies. Valid values are:

- 5xx: retry is attempted if the instance or endpoint
responds with any 5xx response code, or if the instance or
endpoint does not respond at all. For example, disconnects, reset, read
timeout, connection failure, and refused streams.
- gateway-error: Similar to 5xx, but only
applies to response codes 502, 503 or504.
- connect-failure: a retry is attempted on failures
connecting to the instance or endpoint. For example, connection
timeouts.
- retriable-4xx: a retry is attempted if the instance
or endpoint responds with a 4xx response code.
The only error that you can retry is error code 409.
- refused-stream: a retry is attempted if the instance
or endpoint resets the stream with a REFUSED_STREAM error
code. This reset type indicates that it is safe to retry.
- cancelled: a retry is attempted if the gRPC status
code in the response header is set to cancelled.
- deadline-exceeded: a retry is attempted if the gRPC
status code in the response header is set todeadline-exceeded.
- internal: a retry is attempted if the gRPC
status code in the response header is set tointernal.
- resource-exhausted: a retry is attempted if the gRPC
status code in the response header is set toresource-exhausted.
- unavailable: a retry is attempted if the gRPC
status code in the response header is set tounavailable.

Only the following codes are supported when the URL map is bound to target gRPC proxy that has validateForProxyless field set to true.

- cancelled
- deadline-exceeded
- internal
- resource-exhausted
- unavailable.

Returns:

  • (::Array<::String>) —

    Specifies one or more conditions when this retry policy applies. Valid values are:

    - 5xx: retry is attempted if the instance or endpoint
    responds with any 5xx response code, or if the instance or
    endpoint does not respond at all. For example, disconnects, reset, read
    timeout, connection failure, and refused streams.
    - gateway-error: Similar to 5xx, but only
    applies to response codes 502, 503 or504.
    - connect-failure: a retry is attempted on failures
    connecting to the instance or endpoint. For example, connection
    timeouts.
    - retriable-4xx: a retry is attempted if the instance
    or endpoint responds with a 4xx response code.
    The only error that you can retry is error code 409.
    - refused-stream: a retry is attempted if the instance
    or endpoint resets the stream with a REFUSED_STREAM error
    code. This reset type indicates that it is safe to retry.
    - cancelled: a retry is attempted if the gRPC status
    code in the response header is set to cancelled.
    - deadline-exceeded: a retry is attempted if the gRPC
    status code in the response header is set todeadline-exceeded.
    - internal: a retry is attempted if the gRPC
    status code in the response header is set tointernal.
    - resource-exhausted: a retry is attempted if the gRPC
    status code in the response header is set toresource-exhausted.
    - unavailable: a retry is attempted if the gRPC
    status code in the response header is set tounavailable.
    

    Only the following codes are supported when the URL map is bound to target gRPC proxy that has validateForProxyless field set to true.

    - cancelled
    - deadline-exceeded
    - internal
    - resource-exhausted
    - unavailable


29442
29443
29444
29445
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29442

class HttpRetryPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end