Method: Google::Cloud::Compute::V1::HttpRouteAction#request_mirror_policy

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

#request_mirror_policy::Google::Cloud::Compute::V1::RequestMirrorPolicy

Returns Specifies the policy on how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer does not wait for responses from the shadow service. Before sending traffic to the shadow service, the host / authority header is suffixed with -shadow. Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.

Returns:

  • (::Google::Cloud::Compute::V1::RequestMirrorPolicy)

    Specifies the policy on how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer does not wait for responses from the shadow service. Before sending traffic to the shadow service, the host / authority header is suffixed with -shadow. Not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true.



12643
12644
12645
12646
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12643

class HttpRouteAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end