Class: Google::Cloud::Compute::V1::HttpRouteRuleMatch
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HttpRouteRuleMatch
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
HttpRouteRuleMatch specifies a set of criteria for matching requests to an HttpRouteRule. All specified criteria must be satisfied for a match to occur.
Instance Attribute Summary collapse
-
#full_path_match ⇒ ::String
For satisfying the matchRule condition, the path of the request must exactly match the value specified infullPathMatch after removing any query parameters and anchor that may be part of the original URL.
-
#header_matches ⇒ ::Array<::Google::Cloud::Compute::V1::HttpHeaderMatch>
Specifies a list of header match criteria, all of which must match corresponding headers in the request.
-
#ignore_case ⇒ ::Boolean
Specifies that prefixMatch and fullPathMatch matches are case sensitive.
-
#metadata_filters ⇒ ::Array<::Google::Cloud::Compute::V1::MetadataFilter>
Opaque filter criteria used by the load balancer to restrict routing configuration to a limited set of xDS compliant clients.
-
#path_template_match ⇒ ::String
If specified, this field defines a path template pattern that must match the :path header after the query string is removed.
-
#prefix_match ⇒ ::String
For satisfying the matchRule condition, the request's path must begin with the specified prefixMatch.prefixMatch must begin with a /.
-
#query_parameter_matches ⇒ ::Array<::Google::Cloud::Compute::V1::HttpQueryParameterMatch>
Specifies a list of query parameter match criteria, all of which must match corresponding query parameters in the request.
-
#regex_match ⇒ ::String
For satisfying the matchRule condition, the path of the request must satisfy the regular expression specified inregexMatch after removing any query parameters and anchor supplied with the original URL.
Instance Attribute Details
#full_path_match ⇒ ::String
Returns For satisfying the matchRule condition, the path of the request must exactly match the value specified infullPathMatch after removing any query parameters and anchor that may be part of the original URL.
fullPathMatch must be from 1 to 1024 characters.
Only one of prefixMatch, fullPathMatch,regexMatch or path_template_match must be specified.
27761 27762 27763 27764 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27761 class HttpRouteRuleMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#header_matches ⇒ ::Array<::Google::Cloud::Compute::V1::HttpHeaderMatch>
Returns Specifies a list of header match criteria, all of which must match corresponding headers in the request.
27761 27762 27763 27764 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27761 class HttpRouteRuleMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ignore_case ⇒ ::Boolean
Returns Specifies that prefixMatch and fullPathMatch matches are case sensitive.
The default value is false.
ignoreCase must not be used with regexMatch.
Not supported when the URL map is bound to a target gRPC proxy.
27761 27762 27763 27764 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27761 class HttpRouteRuleMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metadata_filters ⇒ ::Array<::Google::Cloud::Compute::V1::MetadataFilter>
Returns Opaque filter criteria used by the load balancer to restrict routing configuration to a limited set of xDS compliant clients. In their xDS requests to the load balancer, xDS clients present node metadata. When there is a match, the relevant routing configuration is made available to those proxies.
For each metadataFilter in this list, if itsfilterMatchCriteria is set to MATCH_ANY, at least one of thefilterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata. If multiple metadata filters are specified, all of them need to be satisfied in order to be considered a match.
metadataFilters specified here is applied after those specified in ForwardingRule that refers to theUrlMap this HttpRouteRuleMatch belongs to.
metadataFilters only applies to load balancers that haveloadBalancingScheme set toINTERNAL_SELF_MANAGED.
Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
27761 27762 27763 27764 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27761 class HttpRouteRuleMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#path_template_match ⇒ ::String
Returns If specified, this field defines a path template pattern that must match the :path header after the query string is removed.
A path template pattern can include variables and wildcards. Variables are enclosed in curly braces, for example{variable_name}. Wildcards include * that matches a single path segment, and ** that matches zero or more path segments. The pattern must follow these rules:
- The value must be between 1 and 1024 characters.
- The pattern must start with a leading slash ("/").
- No more than 5 operators (variables or wildcards) may appear in
the pattern.
Precisely one ofprefixMatch, fullPathMatch,regexMatch, or pathTemplateMatch must be set.
27761 27762 27763 27764 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27761 class HttpRouteRuleMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#prefix_match ⇒ ::String
Returns For satisfying the matchRule condition, the request's path must begin with the specified prefixMatch.prefixMatch must begin with a /.
The value must be from 1 to 1024 characters.
The * character inside a prefix match is treated as a literal character, not as a wildcard.
Only one of prefixMatch, fullPathMatch,regexMatch or path_template_match can be used within a matchRule.
27761 27762 27763 27764 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27761 class HttpRouteRuleMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query_parameter_matches ⇒ ::Array<::Google::Cloud::Compute::V1::HttpQueryParameterMatch>
Returns Specifies a list of query parameter match criteria, all of which must match corresponding query parameters in the request.
Not supported when the URL map is bound to a target gRPC proxy.
27761 27762 27763 27764 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27761 class HttpRouteRuleMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#regex_match ⇒ ::String
Returns For satisfying the matchRule condition, the path of the request must satisfy the regular expression specified inregexMatch after removing any query parameters and anchor supplied with the original URL. For more information about regular expression syntax, see Syntax.
Only one of prefixMatch, fullPathMatch,regexMatch or path_template_match must be specified.
Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED, EXTERNAL_MANAGED (regional scope) or INTERNAL_MANAGED.
27761 27762 27763 27764 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27761 class HttpRouteRuleMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |