Module: Google::Cloud::Compute::V1::Image::SourceType

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The type of the image used to create this disk. The default and only valid value is RAW.

Constant Summary collapse

UNDEFINED_SOURCE_TYPE =

A value indicating that the enum field is not set.

0
RAW =
80_904