Class: Google::Cloud::Compute::V1::InsertInterconnectGroupRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InsertInterconnectGroupRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for InterconnectGroups.Insert. See the method description for details.
Instance Attribute Summary collapse
-
#interconnect_group_resource ⇒ ::Google::Cloud::Compute::V1::InterconnectGroup
The body resource for this request.
-
#project ⇒ ::String
Project ID for this request.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
Instance Attribute Details
#interconnect_group_resource ⇒ ::Google::Cloud::Compute::V1::InterconnectGroup
Returns The body resource for this request.
29631 29632 29633 29634 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29631 class InsertInterconnectGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID for this request.
29631 29632 29633 29634 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29631 class InsertInterconnectGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). end_interface: MixerMutationRequestBuilder.
29631 29632 29633 29634 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29631 class InsertInterconnectGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |