Class: Google::Cloud::Compute::V1::InsertOrganizationSecurityPolicyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InsertOrganizationSecurityPolicyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for OrganizationSecurityPolicies.Insert. See the method description for details.
Instance Attribute Summary collapse
-
#parent_id ⇒ ::String
Parent ID for this request.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#security_policy_resource ⇒ ::Google::Cloud::Compute::V1::SecurityPolicy
The body resource for this request.
Instance Attribute Details
#parent_id ⇒ ::String
Returns Parent ID for this request. The ID can be either be "folders/[FOLDER_ID]" if the parent is a folder or "organizations/[ORGANIZATION_ID]" if the parent is an organization.
29262 29263 29264 29265 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29262 class InsertOrganizationSecurityPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
29262 29263 29264 29265 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29262 class InsertOrganizationSecurityPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#security_policy_resource ⇒ ::Google::Cloud::Compute::V1::SecurityPolicy
Returns The body resource for this request.
29262 29263 29264 29265 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29262 class InsertOrganizationSecurityPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |