Class: Google::Cloud::Compute::V1::InsertRegionInstanceGroupManagerResizeRequestRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for RegionInstanceGroupManagerResizeRequests.Insert. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#instance_group_manager::String

Returns Name of the managed instance group to which the resize request is scoped. Name should conform to RFC1035 or be a resource ID.

Returns:

  • (::String)

    Name of the managed instance group to which the resize request is scoped. Name should conform to RFC1035 or be a resource ID.



29717
29718
29719
29720
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29717

class InsertRegionInstanceGroupManagerResizeRequestRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_group_manager_resize_request_resource::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequest

Returns The body resource for this request.

Returns:



29717
29718
29719
29720
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29717

class InsertRegionInstanceGroupManagerResizeRequestRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



29717
29718
29719
29720
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29717

class InsertRegionInstanceGroupManagerResizeRequestRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region::String

Returns Name of the region scoping this request. Name should conform to RFC1035.

Returns:

  • (::String)

    Name of the region scoping this request. Name should conform to RFC1035.



29717
29718
29719
29720
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29717

class InsertRegionInstanceGroupManagerResizeRequestRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



29717
29718
29719
29720
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29717

class InsertRegionInstanceGroupManagerResizeRequestRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end