Class: Google::Cloud::Compute::V1::InsertRegionInstantSnapshotGroupRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for RegionInstantSnapshotGroups.Insert. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#instant_snapshot_group_resource::Google::Cloud::Compute::V1::InstantSnapshotGroup

Returns The body resource for this request.

Returns:



29780
29781
29782
29783
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29780

class InsertRegionInstantSnapshotGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



29780
29781
29782
29783
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29780

class InsertRegionInstantSnapshotGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region::String

Returns Name of the region for this request.

Returns:

  • (::String)

    Name of the region for this request.



29780
29781
29782
29783
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29780

class InsertRegionInstantSnapshotGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



29780
29781
29782
29783
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29780

class InsertRegionInstantSnapshotGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_consistency_group::String

Returns begin_interface: MixerMutationRequestBuilder.

Returns:

  • (::String)

    begin_interface: MixerMutationRequestBuilder



29780
29781
29782
29783
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29780

class InsertRegionInstantSnapshotGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end