Class: Google::Cloud::Compute::V1::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstancesScopedList}
An object that contains a list of instances scoped by zone.
-
#kind ⇒ ::String
[Output Only] Type of resource.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ ::Array<::String>
[Output Only] Unreachable resources.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14508 class InstanceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstancesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstancesScopedList}
Returns An object that contains a list of instances scoped by zone.
14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14508 class InstanceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstancesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns [Output Only] Type of resource. Always compute#instanceAggregatedList for aggregated lists of Instance resources.
14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14508 class InstanceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstancesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14508 class InstanceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstancesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for this resource.
14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14508 class InstanceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstancesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns [Output Only] Unreachable resources.
14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14508 class InstanceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstancesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
14508 14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14508 class InstanceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstancesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |