Class: Google::Cloud::Compute::V1::InstanceConsumptionInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#guest_cpus ⇒ ::Integer

Returns Output only. The number of virtual CPUs that are available to the instance.

Returns:

  • (::Integer) —

    Output only. The number of virtual CPUs that are available to the instance.



33314
33315
33316
33317
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33314

class InstanceConsumptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#local_ssd_gb ⇒ ::Integer

Returns Output only. The amount of local SSD storage available to the instance, defined in GiB.

Returns:

  • (::Integer) —

    Output only. The amount of local SSD storage available to the instance, defined in GiB.



33314
33315
33316
33317
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33314

class InstanceConsumptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#memory_mb ⇒ ::Integer

Returns Output only. The amount of physical memory available to the instance, defined in MiB.

Returns:

  • (::Integer) —

    Output only. The amount of physical memory available to the instance, defined in MiB.



33314
33315
33316
33317
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33314

class InstanceConsumptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#min_node_cpus ⇒ ::Integer

Returns Output only. The minimal guaranteed number of virtual CPUs that are reserved.

Returns:

  • (::Integer) —

    Output only. The minimal guaranteed number of virtual CPUs that are reserved.



33314
33315
33316
33317
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33314

class InstanceConsumptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end