Class: Google::Cloud::Compute::V1::InstanceGroup
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents an Instance Group resource.
Instance Groups can be used to configure a target forload balancing.
Instance groups can either be managed or unmanaged.
To create managed instance groups, use the instanceGroupManager orregionInstanceGroupManager resource instead.
Use zonal unmanaged instance groups if you need to applyload balancing to groups of heterogeneous instances or if you need to manage the instances yourself. You cannot create regional unmanaged instance groups.
For more information, readInstance groups.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#fingerprint ⇒ ::String
Output only.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
The name of the instance group.
-
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
Optional.
-
#network ⇒ ::String
[Output Only] The URL of the network to which all instances in the instance group belong.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#size ⇒ ::Integer
Output only.
-
#subnetwork ⇒ ::String
Output only.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] The creation timestamp for this instance group inRFC3339 text format.
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fingerprint ⇒ ::String
Returns Output only. [Output Only] The fingerprint of the named ports. The system uses this fingerprint to detect conflicts when multiple users change the named ports concurrently.
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
Returns Output only. [Output Only] A unique identifier for this instance group, generated by the server.
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] The resource type, which is alwayscompute#instanceGroup for instance groups.
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns The name of the instance group. The name must be 1-63 characters long, and comply withRFC1035.
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
Returns Optional. Assigns a name to a port number. For example:{name: "http", port: 80}
This allows the system to reference ports by the assigned name instead of a port number. Named ports can also contain multiple ports. For example:[{name: "app1", port: 8080}, {name: "app1", port: 8081}, {name: "app2", port: 8082}]
Named ports apply to all instances in this instance group.
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network ⇒ ::String
Returns [Output Only] The URL of the network to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0).
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns Output only. [Output Only] The URL of theregion where the instance group is located (for regional resources).
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns Output only. [Output Only] The URL for this instance group. The server generates this URL.
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#size ⇒ ::Integer
Returns Output only. [Output Only] The total number of instances in the instance group.
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subnetwork ⇒ ::String
Returns Output only. [Output Only] The URL of the subnetwork to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0).
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
Returns Output only. [Output Only] The URL of thezone where the instance group is located (for zonal resources).
31366 31367 31368 31369 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31366 class InstanceGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |