Class: Google::Cloud::Compute::V1::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ ::String

Returns Output only. [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String) —

    Output only. [Output Only] Unique identifier for the resource; defined by the server.



33485
33486
33487
33488
33489
33490
33491
33492
33493
33494
33495
33496
33497
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33485

class InstanceGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceGroupsScopedList}

Returns A list of InstanceGroupsScopedList resources.

Returns:



33485
33486
33487
33488
33489
33490
33491
33492
33493
33494
33495
33496
33497
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33485

class InstanceGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] The resource type, which is alwayscompute#instanceGroupAggregatedList for aggregated lists of instance groups.

Returns:

  • (::String) —

    Output only. [Output Only] The resource type, which is alwayscompute#instanceGroupAggregatedList for aggregated lists of instance groups.



33485
33486
33487
33488
33489
33490
33491
33492
33493
33494
33495
33496
33497
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33485

class InstanceGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token ⇒ ::String

Returns Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String) —

    Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



33485
33486
33487
33488
33489
33490
33491
33492
33493
33494
33495
33496
33497
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33485

class InstanceGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for this resource.



33485
33486
33487
33488
33489
33490
33491
33492
33493
33494
33495
33496
33497
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33485

class InstanceGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables ⇒ ::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>) —

    Output only. [Output Only] Unreachable resources.



33485
33486
33487
33488
33489
33490
33491
33492
33493
33494
33495
33496
33497
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33485

class InstanceGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns Output only. [Output Only] Informational warning message.

Returns:



33485
33486
33487
33488
33489
33490
33491
33492
33493
33494
33495
33496
33497
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33485

class InstanceGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end