Class: Google::Cloud::Compute::V1::InstanceGroupManager
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManager
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Managed Instance Group resource.
An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups.
For zonal Managed Instance Group, use the instanceGroupManagers resource.
For regional Managed Instance Group, use theregionInstanceGroupManagers resource.
Defined Under Namespace
Modules: ListManagedInstancesResults
Instance Attribute Summary collapse
-
#all_instances_config ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerAllInstancesConfig
Specifies configuration that overrides the instance template configuration for the group.
-
#auto_healing_policies ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerAutoHealingPolicy>
The autohealing policy for this managed instance group.
-
#base_instance_name ⇒ ::String
The base instance name is a prefix that you want to attach to the names of all VMs in a MIG.
-
#creation_timestamp ⇒ ::String
Output only.
-
#current_actions ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerActionsSummary
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#distribution_policy ⇒ ::Google::Cloud::Compute::V1::DistributionPolicy
Policy specifying the intended distribution of managed instances across zones in a regional managed instance group.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#id ⇒ ::Integer
Output only.
-
#instance_flexibility_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceFlexibilityPolicy
Instance flexibility allowing MIG to create VMs from multiple types of machines.
-
#instance_group ⇒ ::String
Output only.
-
#instance_lifecycle_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy
The repair policy for this managed instance group.
-
#instance_template ⇒ ::String
The URL of the instance template that is specified for this managed instance group.
-
#kind ⇒ ::String
Output only.
-
#list_managed_instances_results ⇒ ::String
Pagination behavior of the listManagedInstances API method for this managed instance group.
-
#name ⇒ ::String
The name of the managed instance group.
-
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager.
-
#region ⇒ ::String
Output only.
-
#resource_policies ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResourcePolicies
Resource policies for this managed instance group.
-
#satisfies_pzi ⇒ ::Boolean
Output only.
-
#satisfies_pzs ⇒ ::Boolean
Output only.
-
#self_link ⇒ ::String
Output only.
-
#standby_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStandbyPolicy
Standby policy for stopped and suspended instances.
-
#stateful_policy ⇒ ::Google::Cloud::Compute::V1::StatefulPolicy
Stateful configuration for this Instanced Group Manager.
-
#status ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStatus
Output only.
-
#target_pools ⇒ ::Array<::String>
The URLs for all TargetPool resources to which instances in theinstanceGroup field are added.
-
#target_size ⇒ ::Integer
The target number of running instances for this managed instance group.
-
#target_size_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerTargetSizePolicy
The policy that specifies how the MIG creates its VMs to achieve the target size.
-
#target_stopped_size ⇒ ::Integer
The target number of stopped instances for this managed instance group.
-
#target_suspended_size ⇒ ::Integer
The target number of suspended instances for this managed instance group.
-
#update_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy
The update policy for this managed instance group.
-
#versions ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerVersion>
Specifies the instance templates used by this managed instance group to create instances.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#all_instances_config ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerAllInstancesConfig
Returns Specifies configuration that overrides the instance template configuration for the group.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#auto_healing_policies ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerAutoHealingPolicy>
Returns The autohealing policy for this managed instance group. You can specify only one value.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#base_instance_name ⇒ ::String
Returns The base instance name is a prefix that you want to attach to the names of all VMs in a MIG. The maximum character length is 58 and the name must comply with RFC1035 format.
When a VM is created in the group, the MIG appends a hyphen and a random
four-character string to the base instance name. If you want the MIG to
assign sequential numbers instead of a random string, then end the base
instance name with a hyphen followed by one or more hash symbols. The hash
symbols indicate the number of digits. For example, a base instance name of
"vm-###" results in "vm-001" as a VM name.
@pattern
a-z.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#creation_timestamp ⇒ ::String
Returns Output only. The creation timestamp for this managed instance group inRFC3339 text format.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#current_actions ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerActionsSummary
Returns Output only. The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#description ⇒ ::String
Returns An optional description of this resource.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#distribution_policy ⇒ ::Google::Cloud::Compute::V1::DistributionPolicy
Returns Policy specifying the intended distribution of managed instances across zones in a regional managed instance group.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#fingerprint ⇒ ::String
Returns Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#id ⇒ ::Integer
Returns Output only. A unique identifier for this resource type. The server generates this identifier.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#instance_flexibility_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceFlexibilityPolicy
Returns Instance flexibility allowing MIG to create VMs from multiple types of machines. Instance flexibility configuration on MIG overrides instance template configuration.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#instance_group ⇒ ::String
Returns Output only. The URL of the Instance Group resource.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#instance_lifecycle_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy
Returns The repair policy for this managed instance group.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#instance_template ⇒ ::String
Returns The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#kind ⇒ ::String
Returns Output only. The resource type, which is alwayscompute#instanceGroupManager for managed instance groups.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#list_managed_instances_results ⇒ ::String
Returns Pagination behavior of the listManagedInstances API method for this managed instance group. Check the ListManagedInstancesResults enum for the list of possible values.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#name ⇒ ::String
Returns The name of the managed instance group. The name must be 1-63 characters long, and comply withRFC1035.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
Returns [Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#region ⇒ ::String
Returns Output only. [Output Only] The URL of theregion where the managed instance group resides (for regional resources).
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#resource_policies ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResourcePolicies
Returns Resource policies for this managed instance group.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#satisfies_pzi ⇒ ::Boolean
Returns Output only. Reserved for future use.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#satisfies_pzs ⇒ ::Boolean
Returns Output only. Reserved for future use.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#self_link ⇒ ::String
Returns Output only. The URL for this managed instance group. The server defines this URL.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#standby_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStandbyPolicy
Returns Standby policy for stopped and suspended instances.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#stateful_policy ⇒ ::Google::Cloud::Compute::V1::StatefulPolicy
Returns Stateful configuration for this Instanced Group Manager.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#status ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStatus
Returns Output only. The status of this managed instance group.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#target_pools ⇒ ::Array<::String>
Returns The URLs for all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#target_size ⇒ ::Integer
Returns The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#target_size_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerTargetSizePolicy
Returns The policy that specifies how the MIG creates its VMs to achieve the target size.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#target_stopped_size ⇒ ::Integer
Returns The target number of stopped instances for this managed instance group. This number changes when you:
- Stop instance using the stopInstances method or start instances using the startInstances method.
- Manually change the targetStoppedSize using the update method.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#target_suspended_size ⇒ ::Integer
Returns The target number of suspended instances for this managed instance group. This number changes when you:
- Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
- Manually change the targetSuspendedSize using the update method.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#update_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy
Returns The update policy for this managed instance group.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#versions ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerVersion>
Returns Specifies the instance templates used by this managed instance group to create instances.
Each version is defined by an instanceTemplate and aname. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about therelationships between these fields. Exactly one version must leave thetargetSize field unset. That version will be applied to all remaining instances. For more information, read aboutcanary updates.
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |
#zone ⇒ ::String
Returns Output only. The URL of azone where the managed instance group is located (for zonal resources).
31611 31612 31613 31614 31615 31616 31617 31618 31619 31620 31621 31622 31623 31624 31625 31626 31627 31628 31629 31630 31631 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31611 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for # this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group'slistManagedInstances API method. maxResults # and pageToken query parameters are ignored and all # instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances # API method. maxResults and pageToken query # parameters are respected. PAGINATED = 40_190_637 end end |