Module: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy::DefaultActionOnFailure

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The action that a MIG performs on a failed VM. If the value of the onFailedHealthCheck field is DEFAULT_ACTION, then the same action also applies to the VMs on which your application fails a health check. Valid values are

- REPAIR (default): MIG automatically repairs a failed VM
by recreating it. For more information, see About
repairing VMs in a MIG.
- DO_NOTHING: MIG does not repair a failed VM.

Constant Summary collapse

UNDEFINED_DEFAULT_ACTION_ON_FAILURE =

A value indicating that the enum field is not set.

0
DO_NOTHING =

MIG does not repair a failed VM.

451_307_513
REPAIR =

(default): MIG automatically repairs a failed VM by recreating it. For more information, see About repairing VMs in a MIG.

266_277_773