Module: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy::ForceUpdateOnRepair

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:

 -  NO (default): If configuration updates are available, they are not
 forcefully applied during repair. Instead, configuration updates are
 applied according to the group's update policy.

 -  YES: If configuration updates are available, they are applied
 during repair.

Constant Summary collapse

UNDEFINED_FORCE_UPDATE_ON_REPAIR =

A value indicating that the enum field is not set.

0
NO =
2497
YES =
87_751