Module: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy::OnFailedHealthCheck

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:

- DEFAULT_ACTION (default): MIG uses the same action
configured for instanceLifecyclePolicy.defaultActionOnFailure field.
- REPAIR: MIG automatically repairs an unhealthy VM by
recreating it.
- DO_NOTHING: MIG doesn't repair an unhealthy VM.
For more information, see
About repairing VMs in a MIG.

Additional supported values which may be not listed in the enum directly due to technical reasons: DO_NOTHING REPAIR

Constant Summary collapse

UNDEFINED_ON_FAILED_HEALTH_CHECK =

A value indicating that the enum field is not set.

0
DEFAULT_ACTION =

(Default) MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.

463_967_764