Class: Google::Cloud::Compute::V1::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] A list of managed instance groups.

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ ::String

Returns Output only. Unique identifier for the resource; defined by the server.

Returns:

  • (::String) —

    Output only. Unique identifier for the resource; defined by the server.



34067
34068
34069
34070
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34067

class InstanceGroupManagerList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#items ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroupManager>

Returns A list of InstanceGroupManager resources.

Returns:



34067
34068
34069
34070
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34067

class InstanceGroupManagerList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind ⇒ ::String

Returns Output only. The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups.

Returns:

  • (::String) —

    Output only. The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups.



34067
34068
34069
34070
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34067

class InstanceGroupManagerList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token ⇒ ::String

Returns Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String) —

    Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



34067
34068
34069
34070
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34067

class InstanceGroupManagerList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Output only. Server-defined URL for this resource.

Returns:

  • (::String) —

    Output only. Server-defined URL for this resource.



34067
34068
34069
34070
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34067

class InstanceGroupManagerList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns Output only. Informational warning message.

Returns:



34067
34068
34069
34070
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34067

class InstanceGroupManagerList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end