Class: Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#error ⇒ ::Google::Cloud::Compute::V1::Error
Output only.
-
#last_attempt ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatusLastAttempt
Output only.
Instance Attribute Details
#error ⇒ ::Google::Cloud::Compute::V1::Error
Returns Output only. Fatal errors encountered during the queueing or provisioning phases of the ResizeRequest that caused the transition to the FAILED state. Contrary to the last_attempt errors, this field is final and errors are never removed from here, as the ResizeRequest is not going to retry.
32051 32052 32053 32054 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32051 class InstanceGroupManagerResizeRequestStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_attempt ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatusLastAttempt
Returns Output only. Information about the last attempt to fulfill the request. The value is temporary since the ResizeRequest can retry, as long as it's still active and the last attempt value can either be cleared or replaced with a different error. Since ResizeRequest retries infrequently, the value may be stale and no longer show an active problem. The value is cleared when ResizeRequest transitions to the final state (becomes inactive). If the final state is FAILED the error describing it will be stored in the "error" field only.
32051 32052 32053 32054 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32051 class InstanceGroupManagerResizeRequestStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |