Class: Google::Cloud::Compute::V1::InstanceGroupManagerResourcePolicies
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerResourcePolicies
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#workload_policy ⇒ ::String
The URL of the workload policy that is specified for this managed instance group.
Instance Attribute Details
#workload_policy ⇒ ::String
Returns The URL of the workload policy that is specified for this managed instance group. It can be a full or partial URL. For example, the following are all valid URLs to a workload policy:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/resourcePolicies/resourcePolicy
- projects/project/regions/region/resourcePolicies/resourcePolicy
- regions/region/resourcePolicies/resourcePolicy.
32104 32105 32106 32107 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32104 class InstanceGroupManagerResourcePolicies include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |