Class: Google::Cloud::Compute::V1::InstanceGroupManagerStandbyPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Attribute Details

#initial_delay_sec::Integer

Returns Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created. The initial delay gives the initialization script the time to prepare your VM for a quick scale out. The value of initial delay must be between 0 and 3600 seconds. The default value is 0.

Returns:

  • (::Integer)

    Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created. The initial delay gives the initialization script the time to prepare your VM for a quick scale out. The value of initial delay must be between 0 and 3600 seconds. The default value is 0.



15079
15080
15081
15082
15083
15084
15085
15086
15087
15088
15089
15090
15091
15092
15093
15094
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15079

class InstanceGroupManagerStandbyPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines how a MIG resumes or starts VMs from a standby pool when the group scales out. The default mode is `MANUAL`.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # MIG does not automatically resume or start VMs in the standby pool when the group scales out.
    MANUAL = 119_397_318

    # MIG automatically resumes or starts VMs in the standby pool when the group scales out, and replenishes the standby pool afterwards.
    SCALE_OUT_POOL = 635_394
  end
end

#mode::String

Returns Defines how a MIG resumes or starts VMs from a standby pool when the group scales out. The default mode is MANUAL. Check the Mode enum for the list of possible values.

Returns:

  • (::String)

    Defines how a MIG resumes or starts VMs from a standby pool when the group scales out. The default mode is MANUAL. Check the Mode enum for the list of possible values.



15079
15080
15081
15082
15083
15084
15085
15086
15087
15088
15089
15090
15091
15092
15093
15094
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15079

class InstanceGroupManagerStandbyPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines how a MIG resumes or starts VMs from a standby pool when the group scales out. The default mode is `MANUAL`.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # MIG does not automatically resume or start VMs in the standby pool when the group scales out.
    MANUAL = 119_397_318

    # MIG automatically resumes or starts VMs in the standby pool when the group scales out, and replenishes the standby pool afterwards.
    SCALE_OUT_POOL = 635_394
  end
end