Class: Google::Cloud::Compute::V1::InstanceGroupManagerStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#all_instances_config::Google::Cloud::Compute::V1::InstanceGroupManagerStatusAllInstancesConfig

Returns Output only. Status of all-instances configuration on the group.

Returns:



32176
32177
32178
32179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32176

class InstanceGroupManagerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#applied_accelerator_topologies::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopology>

Returns Output only. The accelerator topology applied to this MIG. Currently only one accelerator topology is supported.

Returns:



32176
32177
32178
32179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32176

class InstanceGroupManagerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#autoscaler::String

Returns Output only. The URL of theAutoscaler that targets this instance group manager.

Returns:

  • (::String)

    Output only. The URL of theAutoscaler that targets this instance group manager.



32176
32177
32178
32179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32176

class InstanceGroupManagerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#bulk_instance_operation::Google::Cloud::Compute::V1::InstanceGroupManagerStatusBulkInstanceOperation

Returns Output only. The status of bulk instance operation.

Returns:



32176
32177
32178
32179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32176

class InstanceGroupManagerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#current_instance_statuses::Google::Cloud::Compute::V1::InstanceGroupManagerStatusInstanceStatusSummary

Returns Output only. The list of instance statuses and the number of instances in this managed instance group that have the status. Currently only shown for TPU MIGs.

Returns:



32176
32177
32178
32179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32176

class InstanceGroupManagerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_stable::Boolean

Returns Output only. A bit indicating whether the managed instance group is in a stable state. A stable state means that: none of the instances in the managed instance group is currently undergoing any type of change (for example, creation, restart, or deletion); no future changes are scheduled for instances in the managed instance group; and the managed instance group itself is not being modified.

Returns:

  • (::Boolean)

    Output only. A bit indicating whether the managed instance group is in a stable state. A stable state means that: none of the instances in the managed instance group is currently undergoing any type of change (for example, creation, restart, or deletion); no future changes are scheduled for instances in the managed instance group; and the managed instance group itself is not being modified.



32176
32177
32178
32179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32176

class InstanceGroupManagerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stateful::Google::Cloud::Compute::V1::InstanceGroupManagerStatusStateful

Returns Output only. Stateful status of the given Instance Group Manager.

Returns:



32176
32177
32178
32179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32176

class InstanceGroupManagerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#version_target::Google::Cloud::Compute::V1::InstanceGroupManagerStatusVersionTarget

Returns Output only. A status of consistency of Instances' versions with their target version specified by version field on Instance Group Manager.

Returns:



32176
32177
32178
32179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32176

class InstanceGroupManagerStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end