Class: Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#accelerator_topology ⇒ ::String

Returns Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.

Returns:

  • (::String) —

    Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.



34322
34323
34324
34325
34326
34327
34328
34329
34330
34331
34332
34333
34334
34335
34336
34337
34338
34339
34340
34341
34342
34343
34344
34345
34346
34347
34348
34349
34350
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34322

class InstanceGroupManagerStatusAcceleratorTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is being activated.
    ACTIVATING = 378_825_968

    # The accelerator topology is active.
    ACTIVE = 314_733_318

    # The accelerator topology is being deactivated.
    DEACTIVATING = 57_182_257

    # The accelerator topology failed.
    FAILED = 455_706_685

    # The configuration is incomplete and the accelerator topology cannot
    # be activated due to insufficient number of running VMs.
    INCOMPLETE = 11_941_214

    # The accelerator topology is being reactivated.
    REACTIVATING = 253_727_587
  end
end

#state ⇒ ::String

Returns Output only. The state of the accelerator topology. Check the State enum for the list of possible values.

Returns:

  • (::String) —

    Output only. The state of the accelerator topology. Check the State enum for the list of possible values.



34322
34323
34324
34325
34326
34327
34328
34329
34330
34331
34332
34333
34334
34335
34336
34337
34338
34339
34340
34341
34342
34343
34344
34345
34346
34347
34348
34349
34350
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34322

class InstanceGroupManagerStatusAcceleratorTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is being activated.
    ACTIVATING = 378_825_968

    # The accelerator topology is active.
    ACTIVE = 314_733_318

    # The accelerator topology is being deactivated.
    DEACTIVATING = 57_182_257

    # The accelerator topology failed.
    FAILED = 455_706_685

    # The configuration is incomplete and the accelerator topology cannot
    # be activated due to insufficient number of running VMs.
    INCOMPLETE = 11_941_214

    # The accelerator topology is being reactivated.
    REACTIVATING = 253_727_587
  end
end

#state_details ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails

Returns Output only. The result of the latest accelerator topology state check.

Returns:



34322
34323
34324
34325
34326
34327
34328
34329
34330
34331
34332
34333
34334
34335
34336
34337
34338
34339
34340
34341
34342
34343
34344
34345
34346
34347
34348
34349
34350
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34322

class InstanceGroupManagerStatusAcceleratorTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is being activated.
    ACTIVATING = 378_825_968

    # The accelerator topology is active.
    ACTIVE = 314_733_318

    # The accelerator topology is being deactivated.
    DEACTIVATING = 57_182_257

    # The accelerator topology failed.
    FAILED = 455_706_685

    # The configuration is incomplete and the accelerator topology cannot
    # be activated due to insufficient number of running VMs.
    INCOMPLETE = 11_941_214

    # The accelerator topology is being reactivated.
    REACTIVATING = 253_727_587
  end
end