Class: Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#error::Google::Cloud::Compute::V1::Error

Returns Output only. Encountered errors.

Returns:



32231
32232
32233
32234
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32231

class InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#timestamp::String

Returns Output only. Timestamp is shown only if there is an error. The field has // RFC3339 // text format.

Returns:

  • (::String)

    Output only. Timestamp is shown only if there is an error. The field has // RFC3339 // text format.



32231
32232
32233
32234
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32231

class InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end