Class: Google::Cloud::Compute::V1::InstanceGroupManagerStatusAllInstancesConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#current_revision::String

Returns Output only. Current all-instances configuration revision. This value is in RFC3339 text format.

Returns:

  • (::String)

    Output only. Current all-instances configuration revision. This value is in RFC3339 text format.



32244
32245
32246
32247
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32244

class InstanceGroupManagerStatusAllInstancesConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#effective::Boolean

Returns Output only. A bit indicating whether this configuration has been applied to all managed instances in the group.

Returns:

  • (::Boolean)

    Output only. A bit indicating whether this configuration has been applied to all managed instances in the group.



32244
32245
32246
32247
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32244

class InstanceGroupManagerStatusAllInstancesConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end