Class: Google::Cloud::Compute::V1::InstanceGroupManagerStatusInstanceStatusSummary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.

Instance Attribute Summary collapse

Instance Attribute Details

#deprovisioning::Integer

Returns Output only. The number of instances in the managed instance group that have DEPROVISIONING status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have DEPROVISIONING status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#non_existent::Integer

Returns Output only. The number of instances that have not been created yet or have been deleted. Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as 'pending'.

Returns:

  • (::Integer)

    Output only. The number of instances that have not been created yet or have been deleted. Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as 'pending'.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pending::Integer

Returns Output only. The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources. Instances that do not exist because of the other reasons are counted as 'non_existent'.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources. Instances that do not exist because of the other reasons are counted as 'non_existent'.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pending_stop::Integer

Returns Output only. The number of instances in the managed instance group that have PENDING_STOP status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have PENDING_STOP status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#provisioning::Integer

Returns Output only. The number of instances in the managed instance group that have PROVISIONING status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have PROVISIONING status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#repairing::Integer

Returns Output only. The number of instances in the managed instance group that have REPAIRING status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have REPAIRING status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#running::Integer

Returns Output only. The number of instances in the managed instance group that have RUNNING status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have RUNNING status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#staging::Integer

Returns Output only. The number of instances in the managed instance group that have STAGING status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have STAGING status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stopped::Integer

Returns Output only. The number of instances in the managed instance group that have STOPPED status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have STOPPED status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stopping::Integer

Returns Output only. The number of instances in the managed instance group that have STOPPING status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have STOPPING status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#suspended::Integer

Returns Output only. The number of instances in the managed instance group that have SUSPENDED status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have SUSPENDED status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#suspending::Integer

Returns Output only. The number of instances in the managed instance group that have SUSPENDING status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have SUSPENDING status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#terminated::Integer

Returns Output only. The number of instances in the managed instance group that have TERMINATED status.

Returns:

  • (::Integer)

    Output only. The number of instances in the managed instance group that have TERMINATED status.



33377
33378
33379
33380
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33377

class InstanceGroupManagerStatusInstanceStatusSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end