Class: Google::Cloud::Compute::V1::InstanceGroupManagerTargetSizePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Attribute Details

#mode ⇒ ::String

Returns The mode of target size policy based on which the MIG creates its VMs individually or all at once. Check the Mode enum for the list of possible values.

Returns:

  • (::String) —

    The mode of target size policy based on which the MIG creates its VMs individually or all at once. Check the Mode enum for the list of possible values.



34512
34513
34514
34515
34516
34517
34518
34519
34520
34521
34522
34523
34524
34525
34526
34527
34528
34529
34530
34531
34532
34533
34534
34535
34536
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34512

class InstanceGroupManagerTargetSizePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The mode of target size policy based on which the MIG creates its VMs
  # individually or all at once.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The mode in which the MIG creates VMs all at once. In this mode, if the
    # MIG is unable to create even one VM, the MIG waits until all VMs can be
    # created at the same time.
    BULK = 2_050_322

    # The mode in which the MIG creates VMs individually. In this mode, if
    # the MIG is unable to create a VM, the MIG will continue to create the
    # other VMs in the group. This is the default mode.
    INDIVIDUAL = 438_800_025

    # If mode is unspecified, MIG will behave as in the default `INDIVIDUAL`
    # mode.
    UNSPECIFIED_MODE = 53_715_403
  end
end