Module: Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy::MinimalAction

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary.

- To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action,
Compute Engine performs the necessary action to execute the update.
- To apply a more disruptive action than is strictly necessary, set the
minimal action to RESTART or REPLACE. For
example, Compute Engine does not need to restart a VM to change its
. But if your application reads instance  only when a VM
is restarted, you can set the minimal action to RESTART in
order to pick up  changes.

Additional supported values which may be not listed in the enum directly due to technical reasons: NONE REFRESH REPLACE RESTART

Constant Summary collapse

UNDEFINED_MINIMAL_ACTION =

A value indicating that the enum field is not set.

0