Class: Google::Cloud::Compute::V1::InstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: InstanceState

Instance Attribute Summary collapse

Instance Attribute Details

#instance_state ⇒ ::String

Returns A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Check the InstanceState enum for the list of possible values.

Returns:

  • (::String) —

    A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Check the InstanceState enum for the list of possible values.



35103
35104
35105
35106
35107
35108
35109
35110
35111
35112
35113
35114
35115
35116
35117
35118
35119
35120
35121
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35103

class InstanceGroupsListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A filter for the state of the instances in the instance group. Valid
  # options are ALL or RUNNING. If you do not specify
  # this parameter the list includes all instances regardless of their state.
  module InstanceState
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_STATE = 0

    # Includes all instances in the generated list regardless of their state.
    ALL = 64_897

    # Includes instances in the generated list only if they have a RUNNING
    # state.
    RUNNING = 121_282_975
  end
end