Class: Google::Cloud::Compute::V1::InstanceGroupsScopedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupsScopedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#instance_groups ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroup>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Output only.
Instance Attribute Details
#instance_groups ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroup>
Returns Output only. [Output Only] The list ofinstance groups that are contained in this scope.
33009 33010 33011 33012 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33009 class InstanceGroupsScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Output only. [Output Only] An informational warning that replaces the list of instance groups when the list is empty.
33009 33010 33011 33012 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33009 class InstanceGroupsScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |