Class: Google::Cloud::Compute::V1::InstanceGroupsSetNamedPortsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupsSetNamedPortsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ ::String
The fingerprint of the named ports information for this instance group.
-
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
The list of named ports to set for this instance group.
Instance Attribute Details
#fingerprint ⇒ ::String
Returns The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with theinstanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. A request with an incorrect fingerprint will fail with error412 conditionNotMet.
35155 35156 35157 35158 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35155 class InstanceGroupsSetNamedPortsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
Returns The list of named ports to set for this instance group.
35155 35156 35157 35158 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35155 class InstanceGroupsSetNamedPortsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |