Class: Google::Cloud::Compute::V1::InstanceMoveRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#destination_zone ⇒ ::String

Returns The URL of the destination zone to move the instance. This can be a full or partial URL. For example, the following are all valid URLs to a zone:

- https://www.googleapis.com/compute/v1/projects/project/zones/zone
- projects/project/zones/zone
- zones/zone.

Returns:

  • (::String) —

    The URL of the destination zone to move the instance. This can be a full or partial URL. For example, the following are all valid URLs to a zone:

    - https://www.googleapis.com/compute/v1/projects/project/zones/zone
    - projects/project/zones/zone
    - zones/zone


35343
35344
35345
35346
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35343

class InstanceMoveRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target_instance ⇒ ::String

Returns The URL of the target instance to move. This can be a full or partial URL. For example, the following are all valid URLs to an instance:

- https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
- projects/project/zones/zone/instances/instance
- zones/zone/instances/instance.

Returns:

  • (::String) —

    The URL of the target instance to move. This can be a full or partial URL. For example, the following are all valid URLs to an instance:

    - https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
    - projects/project/zones/zone/instances/instance
    - zones/zone/instances/instance


35343
35344
35345
35346
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35343

class InstanceMoveRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end