Module: Google::Cloud::Compute::V1::InstanceProperties::LocalSsdEncryptionMode
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies which method should be used for encrypting the Local SSDs attached to the VM.
Constant Summary collapse
- UNDEFINED_LOCAL_SSD_ENCRYPTION_MODE =
A value indicating that the enum field is not set.
0- EPHEMERAL_KEY_ENCRYPTION =
The given VM will opt-in for using ephemeral key for encryption of Local SSDs. The Local SSDs will not be able to recover data in case of VM crash.
413_047_941- LOCAL_SSD_ENCRYPTION_MODE_UNSPECIFIED =
The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
454_655_720- STANDARD_ENCRYPTION =
The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
269_392_453