Class: Google::Cloud::Compute::V1::InstancePropertiesPatch

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents the change that you want to make to the instance properties.

Defined Under Namespace

Classes: LabelsEntry, MetadataEntry

Instance Attribute Summary collapse

Instance Attribute Details

#expose_host_topology ⇒ ::Boolean

Returns This optional flag exposes the hashed physical host ID.

Returns:

  • (::Boolean) —

    This optional flag exposes the hashed physical host ID.



35587
35588
35589
35590
35591
35592
35593
35594
35595
35596
35597
35598
35599
35600
35601
35602
35603
35604
35605
35606
35607
35608
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35587

class InstancePropertiesPatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns The label key-value pairs that you want to patch onto the instance.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    The label key-value pairs that you want to patch onto the instance.



35587
35588
35589
35590
35591
35592
35593
35594
35595
35596
35597
35598
35599
35600
35601
35602
35603
35604
35605
35606
35607
35608
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35587

class InstancePropertiesPatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns The metadata key-value pairs that you want to patch onto the instance. For more information, see Project and instance metadata.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    The metadata key-value pairs that you want to patch onto the instance. For more information, see Project and instance metadata.



35587
35588
35589
35590
35591
35592
35593
35594
35595
35596
35597
35598
35599
35600
35601
35602
35603
35604
35605
35606
35607
35608
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35587

class InstancePropertiesPatch
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class MetadataEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end