Class: Google::Cloud::Compute::V1::InstanceSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Instance Settings resource. You can use instance settings to configure default settings for Compute Engine VM instances. For example, you can use it to configure default machine type of Compute Engine VM instances.
Instance Attribute Summary collapse
-
#fingerprint ⇒ ::String
Specifies a fingerprint for instance settings, which is essentially a hash of the instance settings resource's contents and used for optimistic locking.
-
#kind ⇒ ::String
[Output Only] Type of the resource.
-
#metadata ⇒ ::Google::Cloud::Compute::V1::InstanceSettingsMetadata
The metadata key/value pairs assigned to all the instances in the corresponding scope.
-
#zone ⇒ ::String
[Output Only] URL of the zone where the resource resides You must specify this field as part of the HTTP request URL.
Instance Attribute Details
#fingerprint ⇒ ::String
15878 15879 15880 15881 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15878 class InstanceSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
15878 15879 15880 15881 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15878 class InstanceSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metadata ⇒ ::Google::Cloud::Compute::V1::InstanceSettingsMetadata
15878 15879 15880 15881 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15878 class InstanceSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
15878 15879 15880 15881 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15878 class InstanceSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |