Class: Google::Cloud::Compute::V1::InstancesSetMachineResourcesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#guest_accelerators::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>

Returns A list of the type and count of accelerator cards attached to the instance.

Returns:

  • A list of the type and count of accelerator cards attached to the instance.



15693
15694
15695
15696
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15693

class InstancesSetMachineResourcesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end