Class: Google::Cloud::Compute::V1::InstancesSetNameRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#current_name ⇒ ::String

Returns The current name of this resource, used to prevent conflicts. Provide the latest name when making a request to change name.

Returns:

  • (::String) —

    The current name of this resource, used to prevent conflicts. Provide the latest name when making a request to change name.



36097
36098
36099
36100
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36097

class InstancesSetNameRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String

Returns The name to be applied to the instance. Needs to be RFC 1035 compliant.

Returns:

  • (::String) —

    The name to be applied to the instance. Needs to be RFC 1035 compliant.



36097
36098
36099
36100
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36097

class InstancesSetNameRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end