Class: Google::Cloud::Compute::V1::InstantSnapshotGroupParameters

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#source_instant_snapshot_group::String

Returns The source instant snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

 - https://www.googleapis.com/compute/v1/projects/project/zones/zone/instantSnapshotGroups/instantSnapshotGroup
 - projects/project/zones/zone/instantSnapshotGroups/instantSnapshotGroup
 - zones/zone/instantSnapshotGroups/instantSnapshotGroup.

Returns:

  • (::String)

    The source instant snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

     - https://www.googleapis.com/compute/v1/projects/project/zones/zone/instantSnapshotGroups/instantSnapshotGroup
     - projects/project/zones/zone/instantSnapshotGroups/instantSnapshotGroup
     - zones/zone/instantSnapshotGroups/instantSnapshotGroup
    


34281
34282
34283
34284
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34281

class InstantSnapshotGroupParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end