Class: Google::Cloud::Compute::V1::InstantSnapshotParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Additional instant snapshot params.

Defined Under Namespace

Classes: ResourceManagerTagsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns Input only. Resource manager tags to be bound to the instant snapshot. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    Input only. Resource manager tags to be bound to the instant snapshot. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.



36509
36510
36511
36512
36513
36514
36515
36516
36517
36518
36519
36520
36521
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36509

class InstantSnapshotParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end