Module: Google::Cloud::Compute::V1::Interconnect::OperationalStatus

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. [Output Only] The current status of this Interconnect's functionality, which can take one of the following values:

  • OS_ACTIVE: A valid Interconnect, which is turned up and is ready to use. Attachments may be provisioned on this Interconnect.

    • OS_UNPROVISIONED: An Interconnect that has not completed turnup. No attachments may be provisioned on this Interconnect.
    • OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal maintenance. No attachments may be provisioned or updated on this Interconnect.

Constant Summary collapse

UNDEFINED_OPERATIONAL_STATUS =

A value indicating that the enum field is not set.

0
OS_ACTIVE =

The interconnect is valid, turned up, and ready to use. Attachments may be provisioned on this interconnect.

55_721_409
OS_UNPROVISIONED =

The interconnect has not completed turnup. No attachments may be provisioned on this interconnect.

239_771_840