Class: Google::Cloud::Compute::V1::InterconnectApplicationAwareInterconnect

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Configuration information for application awareness on this Cloud Interconnect.

Instance Attribute Summary collapse

Instance Attribute Details

#bandwidth_percentage_policy ⇒ ::Google::Cloud::Compute::V1::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy



36936
36937
36938
36939
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36936

class InterconnectApplicationAwareInterconnect
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#profile_description ⇒ ::String

Returns Description for the application awareness profile on this Cloud Interconnect.

Returns:

  • (::String) —

    Description for the application awareness profile on this Cloud Interconnect.



36936
36937
36938
36939
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36936

class InterconnectApplicationAwareInterconnect
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#shape_average_percentages ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectApplicationAwareInterconnectBandwidthPercentage>

Returns Optional field to specify a list of shape average percentages to be applied in conjunction with StrictPriorityPolicy or BandwidthPercentagePolicy.

Returns:



36936
36937
36938
36939
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36936

class InterconnectApplicationAwareInterconnect
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#strict_priority_policy ⇒ ::Google::Cloud::Compute::V1::InterconnectApplicationAwareInterconnectStrictPriorityPolicy



36936
36937
36938
36939
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36936

class InterconnectApplicationAwareInterconnect
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end