Class: Google::Cloud::Compute::V1::InterconnectApplicationAwareInterconnectBandwidthPercentage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specify bandwidth percentages [1-100] for various traffic classes in BandwidthPercentagePolicy. The sum of all percentages must equal 100. All traffic classes must have a percentage value specified.

Defined Under Namespace

Modules: TrafficClass

Instance Attribute Summary collapse

Instance Attribute Details

#percentage::Integer



16708
16709
16710
16711
16712
16713
16714
16715
16716
16717
16718
16719
16720
16721
16722
16723
16724
16725
16726
16727
16728
16729
16730
16731
16732
16733
16734
16735
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16708

class InterconnectApplicationAwareInterconnectBandwidthPercentage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # TrafficClass whose bandwidth percentage is being specified.
  module TrafficClass
    # A value indicating that the enum field is not set.
    UNDEFINED_TRAFFIC_CLASS = 0

    # Traffic Class 1, corresponding to DSCP ranges (0-7) 000xxx.
    TC1 = 82_850

    # Traffic Class 2, corresponding to DSCP ranges (8-15) 001xxx.
    TC2 = 82_851

    # Traffic Class 3, corresponding to DSCP ranges (16-23) 010xxx.
    TC3 = 82_852

    # Traffic Class 4, corresponding to DSCP ranges (24-31) 011xxx.
    TC4 = 82_853

    # Traffic Class 5, corresponding to DSCP ranges (32-47) 10xxxx.
    TC5 = 82_854

    # Traffic Class 6, corresponding to DSCP ranges (48-63) 11xxxx.
    TC6 = 82_855
  end
end

#traffic_class::String



16708
16709
16710
16711
16712
16713
16714
16715
16716
16717
16718
16719
16720
16721
16722
16723
16724
16725
16726
16727
16728
16729
16730
16731
16732
16733
16734
16735
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 16708

class InterconnectApplicationAwareInterconnectBandwidthPercentage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # TrafficClass whose bandwidth percentage is being specified.
  module TrafficClass
    # A value indicating that the enum field is not set.
    UNDEFINED_TRAFFIC_CLASS = 0

    # Traffic Class 1, corresponding to DSCP ranges (0-7) 000xxx.
    TC1 = 82_850

    # Traffic Class 2, corresponding to DSCP ranges (8-15) 001xxx.
    TC2 = 82_851

    # Traffic Class 3, corresponding to DSCP ranges (16-23) 010xxx.
    TC3 = 82_852

    # Traffic Class 4, corresponding to DSCP ranges (24-31) 011xxx.
    TC4 = 82_853

    # Traffic Class 5, corresponding to DSCP ranges (32-47) 10xxxx.
    TC5 = 82_854

    # Traffic Class 6, corresponding to DSCP ranges (48-63) 11xxxx.
    TC6 = 82_855
  end
end