Class: Google::Cloud::Compute::V1::InterconnectAttachmentConfigurationConstraints

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: BgpMd5

Instance Attribute Summary collapse

Instance Attribute Details

#bgp_md5 ⇒ ::String

Output only. [Output Only] Whether the attachment's BGP session requires/allows/disallows BGP MD5 authentication. This can take one of the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED.

For example, a Cross-Cloud Interconnect connection to a remote cloud provider that requires BGP MD5 authentication has the interconnectRemoteLocation attachment_configuration_constraints.bgp_md5 field set to MD5_REQUIRED, and that property is propagated to the attachment. Similarly, if BGP MD5 is MD5_UNSUPPORTED, an error is returned if MD5 is requested. Check the BgpMd5 enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] Whether the attachment's BGP session requires/allows/disallows BGP MD5 authentication. This can take one of the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED.

    For example, a Cross-Cloud Interconnect connection to a remote cloud provider that requires BGP MD5 authentication has the interconnectRemoteLocation attachment_configuration_constraints.bgp_md5 field set to MD5_REQUIRED, and that property is propagated to the attachment. Similarly, if BGP MD5 is MD5_UNSUPPORTED, an error is returned if MD5 is requested. Check the BgpMd5 enum for the list of possible values.



37665
37666
37667
37668
37669
37670
37671
37672
37673
37674
37675
37676
37677
37678
37679
37680
37681
37682
37683
37684
37685
37686
37687
37688
37689
37690
37691
37692
37693
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37665

class InterconnectAttachmentConfigurationConstraints
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Whether the attachment's BGP session
  # requires/allows/disallows BGP MD5 authentication. This can take one of
  # the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED.
  #
  # For example, a Cross-Cloud Interconnect connection to a remote cloud
  # provider that requires BGP MD5 authentication has the
  # interconnectRemoteLocation attachment_configuration_constraints.bgp_md5
  # field set to MD5_REQUIRED, and that property is propagated to the
  # attachment. Similarly, if BGP MD5 is MD5_UNSUPPORTED, an error is
  # returned if MD5 is requested.
  module BgpMd5
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_MD5 = 0

    # MD5_OPTIONAL: BGP MD5 authentication is supported and can optionally be
    # configured.
    MD5_OPTIONAL = 532_156_673

    # MD5_REQUIRED: BGP MD5 authentication must be configured.
    MD5_REQUIRED = 218_034_496

    # MD5_UNSUPPORTED: BGP MD5 authentication must not be configured
    MD5_UNSUPPORTED = 86_962_388
  end
end

#bgp_peer_asn_ranges ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange>

Returns Output only. [Output Only] List of ASN ranges that the remote location is known to support. Formatted as an array of inclusive ranges {min: min-value, max: max-value}. For example, [{min: 123, max: 123}, {min: 64512, max: 65534}] allows the peer ASN to be 123 or anything in the range 64512-65534.

This field is only advisory. Although the API accepts other ranges, these are the ranges that we recommend.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange>) —

    Output only. [Output Only] List of ASN ranges that the remote location is known to support. Formatted as an array of inclusive ranges {min: min-value, max: max-value}. For example, [{min: 123, max: 123}, {min: 64512, max: 65534}] allows the peer ASN to be 123 or anything in the range 64512-65534.

    This field is only advisory. Although the API accepts other ranges, these are the ranges that we recommend.



37665
37666
37667
37668
37669
37670
37671
37672
37673
37674
37675
37676
37677
37678
37679
37680
37681
37682
37683
37684
37685
37686
37687
37688
37689
37690
37691
37692
37693
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37665

class InterconnectAttachmentConfigurationConstraints
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Whether the attachment's BGP session
  # requires/allows/disallows BGP MD5 authentication. This can take one of
  # the following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED.
  #
  # For example, a Cross-Cloud Interconnect connection to a remote cloud
  # provider that requires BGP MD5 authentication has the
  # interconnectRemoteLocation attachment_configuration_constraints.bgp_md5
  # field set to MD5_REQUIRED, and that property is propagated to the
  # attachment. Similarly, if BGP MD5 is MD5_UNSUPPORTED, an error is
  # returned if MD5 is requested.
  module BgpMd5
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_MD5 = 0

    # MD5_OPTIONAL: BGP MD5 authentication is supported and can optionally be
    # configured.
    MD5_OPTIONAL = 532_156_673

    # MD5_REQUIRED: BGP MD5 authentication must be configured.
    MD5_REQUIRED = 218_034_496

    # MD5_UNSUPPORTED: BGP MD5 authentication must not be configured
    MD5_UNSUPPORTED = 86_962_388
  end
end