Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroup
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentGroup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
An interconnect attachment group resource allows customers to create, analyze, and expand highly available deployments.
Defined Under Namespace
Classes: AttachmentsEntry
Instance Attribute Summary collapse
-
#attachments ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment}
Attachments in the AttachmentGroup.
- #configured ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#etag ⇒ ::String
Opaque system-generated token that uniquely identifies the configuration.
-
#id ⇒ ::Integer
Output only.
- #intent ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupIntent
-
#interconnect_group ⇒ ::String
The URL of an InterconnectGroup that groups these Attachments' Interconnects.
-
#kind ⇒ ::String
Output only.
- #logical_structure ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupLogicalStructure
-
#name ⇒ ::String
Name of the resource.
-
#self_link ⇒ ::String
Output only.
Instance Attribute Details
#attachments ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment}
Returns Attachments in the AttachmentGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an "Attachments per group" quota.
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#configured ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#etag ⇒ ::String
Returns Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described byAIP 154.
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#intent ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupIntent
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#interconnect_group ⇒ ::String
Returns The URL of an InterconnectGroup that groups these Attachments' Interconnects. Customers do not need to set this unless directed by Google Support.
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#interconnectAttachmentGroup.
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#logical_structure ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupLogicalStructure
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
35586 35587 35588 35589 35590 35591 35592 35593 35594 35595 35596 35597 35598 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35586 class InterconnectAttachmentGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentGroupAttachment] class AttachmentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |