Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Attribute Details

#regions ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentGroupLogicalStructureRegion>



37905
37906
37907
37908
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37905

class InterconnectAttachmentGroupLogicalStructure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end