Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.
Instance Attribute Summary collapse
-
#attachments ⇒ ::Array<::String>
Output only.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#attachments ⇒ ::Array<::String>
Returns Output only. [Output Only] URLs of Attachments in the given zone, to the given region, on Interconnects in the given facility and metro. Every Attachment in the AG has such an entry.
37957 37958 37959 37960 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37957 class InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
Returns Output only. [Output Only] The name of a zone, either "zone1" or "zone2".
37957 37958 37959 37960 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37957 class InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |