Class: Google::Cloud::Compute::V1::InterconnectAttachmentPrivateInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED.

Instance Attribute Summary collapse

Instance Attribute Details

#tag8021q ⇒ ::Integer

Returns [Output Only] 802.1q encapsulation tag to be used for traffic between Google and the customer, going to and from this network and region.

Returns:

  • (::Integer) —

    [Output Only] 802.1q encapsulation tag to be used for traffic between Google and the customer, going to and from this network and region.



38305
38306
38307
38308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38305

class InterconnectAttachmentPrivateInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end