Class: Google::Cloud::Compute::V1::InterconnectAttachmentsScopedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#interconnect_attachments ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachment>

Returns A list of interconnect attachments contained in this scope.

Returns:

  • A list of interconnect attachments contained in this scope.



38317
38318
38319
38320
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38317

class InterconnectAttachmentsScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns Informational warning which replaces the list of addresses when the list is empty.

Returns:

  • Informational warning which replaces the list of addresses when the list is empty.



38317
38318
38319
38320
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38317

class InterconnectAttachmentsScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end