Class: Google::Cloud::Compute::V1::InterconnectGroup
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
An interconnect group resource allows customers to create, analyze, and expand their redundant connections.
Defined Under Namespace
Classes: InterconnectsEntry
Instance Attribute Summary collapse
- #configured ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#etag ⇒ ::String
Opaque system-generated token that uniquely identifies the configuration.
-
#id ⇒ ::Integer
Output only.
- #intent ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupIntent
-
#interconnects ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InterconnectGroupInterconnect}
Interconnects in the InterconnectGroup.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
- #physical_structure ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupPhysicalStructure
-
#self_link ⇒ ::String
Output only.
Instance Attribute Details
#configured ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#etag ⇒ ::String
Returns Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described by AIP 154.
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#intent ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupIntent
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#interconnects ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InterconnectGroupInterconnect}
Returns Interconnects in the InterconnectGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an "Interconnects per group" quota.
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#InterconnectGroup.
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#physical_structure ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupPhysicalStructure
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
36446 36447 36448 36449 36450 36451 36452 36453 36454 36455 36456 36457 36458 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36446 class InterconnectGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectGroupInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |