Class: Google::Cloud::Compute::V1::InterconnectGroupConfigured

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource.

Instance Attribute Summary collapse

Instance Attribute Details

#topology_capability ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapability



38639
38640
38641
38642
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38639

class InterconnectGroupConfigured
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end