Class: Google::Cloud::Compute::V1::InterconnectGroupIntent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The user's intent for this group. This is the only required field besides the name that must be specified on group creation.

Defined Under Namespace

Modules: TopologyCapability

Instance Attribute Summary collapse

Instance Attribute Details

#topology_capability ⇒ ::String

Returns Check the TopologyCapability enum for the list of possible values.

Returns:

  • (::String) —

    Check the TopologyCapability enum for the list of possible values.



38732
38733
38734
38735
38736
38737
38738
38739
38740
38741
38742
38743
38744
38745
38746
38747
38748
38749
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38732

class InterconnectGroupIntent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module TopologyCapability
    # A value indicating that the enum field is not set.
    UNDEFINED_TOPOLOGY_CAPABILITY = 0

    NO_SLA = 161_460_618

    PRODUCTION_CRITICAL = 470_416_485

    PRODUCTION_NON_CRITICAL = 117_399_223

    UNSPECIFIED = 526_786_327
  end
end