Class: Google::Cloud::Compute::V1::InterconnectGroupPhysicalStructureMetrosFacilities

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] The facilities Interconnects in this metro are present in.

Instance Attribute Summary collapse

Instance Attribute Details

#facility::String

Returns Output only. [Output Only] The ID of this facility, as a numeric string like "5467". This is the third component of the location of Interconnects in this facility.

Returns:

  • (::String)

    Output only. [Output Only] The ID of this facility, as a numeric string like "5467". This is the third component of the location of Interconnects in this facility.



36619
36620
36621
36622
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36619

class InterconnectGroupPhysicalStructureMetrosFacilities
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zones::Array<::Google::Cloud::Compute::V1::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>



36619
36620
36621
36622
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36619

class InterconnectGroupPhysicalStructureMetrosFacilities
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end