Class: Google::Cloud::Compute::V1::InterconnectGroupPhysicalStructureMetrosFacilitiesZones

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] The zones that Interconnects in this facility are present in.

Instance Attribute Summary collapse

Instance Attribute Details

#interconnects::Array<::String>

Returns Output only. [Output Only] URLs of Interconnects in this redundancy group in the given metro, facility, and zone.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] URLs of Interconnects in this redundancy group in the given metro, facility, and zone.



36635
36636
36637
36638
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36635

class InterconnectGroupPhysicalStructureMetrosFacilitiesZones
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns Output only. [Output Only] The name of the zone, either "zone1" or "zone2". This is the second component of the location of Interconnects in this facility.

Returns:

  • (::String)

    Output only. [Output Only] The name of the zone, either "zone1" or "zone2". This is the second component of the location of Interconnects in this facility.



36635
36636
36637
36638
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36635

class InterconnectGroupPhysicalStructureMetrosFacilitiesZones
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end