Module: Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput::InterconnectType

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Type of interconnect, which can take one of the following values: - PARTNER: A partner-managed interconnection shared between customers though a partner. - DEDICATED: A dedicated physical interconnection with the customer. Note that a value IT_PRIVATE has been deprecated in favor of DEDICATED.

Constant Summary collapse

UNDEFINED_INTERCONNECT_TYPE =

A value indicating that the enum field is not set.

0
DEDICATED =

A dedicated physical interconnection with the customer.

258_411_983
IT_PRIVATE =

[Deprecated] A private, physical interconnection with the customer.

335_677_007
PARTNER =

A partner-managed interconnection shared between customers via partner.

461_924_520