Class: Google::Cloud::Compute::V1::InterconnectLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents an Interconnect Attachment (VLAN) Location resource.
You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.
Defined Under Namespace
Modules: AvailableFeatures, AvailableLinkTypes, Continent, Status
Instance Attribute Summary collapse
-
#address ⇒ ::String
Output only.
-
#availability_zone ⇒ ::String
[Output Only] Availability zone for this InterconnectLocation.
-
#available_features ⇒ ::Array<::String>
[Output only] List of features available at this InterconnectLocation, which can take one of the following values:.
-
#available_link_types ⇒ ::Array<::String>
[Output only] List of link types available at this InterconnectLocation, which can take one of the following values:.
-
#city ⇒ ::String
[Output Only] Metropolitan area designator that indicates which city an interconnect is located.
-
#continent ⇒ ::String
[Output Only] Continent for this location, which can take one of the following values:.
-
#creation_timestamp ⇒ ::String
Output only.
-
#cross_site_interconnect_infos ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectLocationCrossSiteInterconnectInfo>
[Output Only] A list of InterconnectLocation.CrossSiteInterconnectInfo objects, that describe where Cross-Site Interconnect wires may connect to from this location and associated connection parameters.
-
#description ⇒ ::String
Output only.
-
#facility_provider ⇒ ::String
Output only.
-
#facility_provider_facility_id ⇒ ::String
Output only.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Output only.
-
#peeringdb_facility_id ⇒ ::String
Output only.
-
#region_infos ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectLocationRegionInfo>
Output only.
-
#self_link ⇒ ::String
Output only.
-
#single_region_production_critical_peer_locations ⇒ ::Array<::String>
Output only.
-
#status ⇒ ::String
[Output Only] The status of this InterconnectLocation, which can take one of the following values:.
-
#supports_pzs ⇒ ::Boolean
Output only.
Instance Attribute Details
#address ⇒ ::String
Returns Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#availability_zone ⇒ ::String
Returns [Output Only] Availability zone for this InterconnectLocation. Within a metropolitan area (metro), maintenance will not be simultaneously scheduled in more than one availability zone. Example: "zone1" or "zone2".
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#available_features ⇒ ::Array<::String>
Returns [Output only] List of features available at this InterconnectLocation, which can take one of the following values:
- IF_MACSEC
- IF_CROSS_SITE_NETWORK Check the AvailableFeatures enum for the list of possible values.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#available_link_types ⇒ ::Array<::String>
Returns [Output only] List of link types available at this InterconnectLocation, which can take one of the following values:
- LINK_TYPE_ETHERNET_10G_LR
- LINK_TYPE_ETHERNET_100G_LR
- LINK_TYPE_ETHERNET_400G_LR4 Check the AvailableLinkTypes enum for the list of possible values.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#city ⇒ ::String
Returns [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#continent ⇒ ::String
Returns [Output Only] Continent for this location, which can take one of the following values:
- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA Check the Continent enum for the list of possible values.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#cross_site_interconnect_infos ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectLocationCrossSiteInterconnectInfo>
Returns [Output Only] A list of InterconnectLocation.CrossSiteInterconnectInfo objects, that describe where Cross-Site Interconnect wires may connect to from this location and associated connection parameters. Cross-Site Interconnect isn't allowed to locations which are not listed.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#description ⇒ ::String
Returns Output only. [Output Only] An optional description of the resource.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#facility_provider ⇒ ::String
Returns Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX).
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#facility_provider_facility_id ⇒ ::String
Returns Output only. [Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#interconnectLocation for interconnect locations.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#name ⇒ ::String
Returns Output only. [Output Only] Name of the resource.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#peeringdb_facility_id ⇒ ::String
Returns Output only. [Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#region_infos ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectLocationRegionInfo>
Returns Output only. [Output Only] A list of InterconnectLocation.RegionInfo objects, that describe parameters pertaining to the relation between this InterconnectLocation and various Google Cloud regions.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#single_region_production_critical_peer_locations ⇒ ::Array<::String>
Returns Output only. [Output Only] URLs of the other locations that can pair up with this location to support Single-Region 99.99% SLA. E.g. iad-zone1-1 and iad-zone2-5467 are Single-Region 99.99% peer locations of each other.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#status ⇒ ::String
Returns [Output Only] The status of this InterconnectLocation, which can take one of the following values:
- CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects.
- AVAILABLE: The InterconnectLocation is available for provisioning new Interconnects. Check the Status enum for the list of possible values.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |
#supports_pzs ⇒ ::Boolean
Returns Output only. [Output Only] Reserved for future use.
39242 39243 39244 39245 39246 39247 39248 39249 39250 39251 39252 39253 39254 39255 39256 39257 39258 39259 39260 39261 39262 39263 39264 39265 39266 39267 39268 39269 39270 39271 39272 39273 39274 39275 39276 39277 39278 39279 39280 39281 39282 39283 39284 39285 39286 39287 39288 39289 39290 39291 39292 39293 39294 39295 39296 39297 39298 39299 39300 39301 39302 39303 39304 39305 39306 39307 39308 39309 39310 39311 39312 39313 39314 39315 39316 39317 39318 39319 39320 39321 39322 39323 39324 39325 39326 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39242 class InterconnectLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module AvailableFeatures # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end module AvailableLinkTypes # A value indicating that the enum field is not set. UNDEFINED_AVAILABLE_LINK_TYPES = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end # [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 C_AFRICA = 71_993_846 C_ASIA_PAC = 465_668_089 C_EUROPE = 200_369_438 C_NORTH_AMERICA = 275_697_048 C_SOUTH_AMERICA = 397_149_792 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # [Output Only] The status of this InterconnectLocation, which can take one # of the following values: # # - CLOSED: The InterconnectLocation is closed and is unavailable for # provisioning new Interconnects. # - AVAILABLE: The InterconnectLocation is available for provisioning new # Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectLocation is available for provisioning new Interconnects. AVAILABLE = 442_079_913 # The InterconnectLocation is closed for provisioning new Interconnects. CLOSED = 380_163_436 end end |