Class: Google::Cloud::Compute::V1::InterconnectLocationCrossSiteInterconnectInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectLocationCrossSiteInterconnectInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Information about Cross-Site Interconnect wires which may be created between the containing location and another remote location.
Instance Attribute Summary collapse
-
#city ⇒ ::String
Output only.
-
#max_dynamic_path_bandwidth_gbps ⇒ ::Integer
Output only.
-
#max_fixed_path_bandwidth_gbps ⇒ ::Integer
Output only.
Instance Attribute Details
#city ⇒ ::String
Returns Output only. The remote location for Cross-Site Interconnect wires. This specifies an InterconnectLocation city (metropolitan area designator), which itself may match multiple InterconnectLocations.
39343 39344 39345 39346 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39343 class InterconnectLocationCrossSiteInterconnectInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_dynamic_path_bandwidth_gbps ⇒ ::Integer
Returns Output only. The maximum unmetered bandwidth for dynamic paths allowable per WireGroup for this metro.
39343 39344 39345 39346 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39343 class InterconnectLocationCrossSiteInterconnectInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_fixed_path_bandwidth_gbps ⇒ ::Integer
Returns Output only. The maximum unmetered bandwidth for fixed paths allowable per WireGroup for this metro.
39343 39344 39345 39346 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39343 class InterconnectLocationCrossSiteInterconnectInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |