Class: Google::Cloud::Compute::V1::InterconnectLocationRegionInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Information about any potential InterconnectAttachments between an Interconnect at a specific InterconnectLocation, and a specific Cloud Region.

Defined Under Namespace

Modules: LocationPresence

Instance Attribute Summary collapse

Instance Attribute Details

#expected_rtt_ms ⇒ ::Integer

Returns Output only. Expected round-trip time in milliseconds, from this InterconnectLocation to a VM in this region.

Returns:

  • (::Integer) —

    Output only. Expected round-trip time in milliseconds, from this InterconnectLocation to a VM in this region.



39395
39396
39397
39398
39399
39400
39401
39402
39403
39404
39405
39406
39407
39408
39409
39410
39411
39412
39413
39414
39415
39416
39417
39418
39419
39420
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39395

class InterconnectLocationRegionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Identifies the network presence of this location.
  module LocationPresence
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_PRESENCE = 0

    # This region is not in any common network presence with this
    # InterconnectLocation.
    GLOBAL = 494_663_587

    # This region shares the same regional network presence as this
    # InterconnectLocation.
    LOCAL_REGION = 403_535_464

    # [Deprecated] This region is not in any common network presence with
    # this InterconnectLocation.
    LP_GLOBAL = 429_584_062

    # [Deprecated] This region shares the same regional network presence as
    # this InterconnectLocation.
    LP_LOCAL_REGION = 488_598_851
  end
end

#l2_forwarding_enabled ⇒ ::Boolean

Returns Output only. Identifies whether L2 Interconnect Attachments can be created in this region for interconnects that are in this location.

Returns:

  • (::Boolean) —

    Output only. Identifies whether L2 Interconnect Attachments can be created in this region for interconnects that are in this location.



39395
39396
39397
39398
39399
39400
39401
39402
39403
39404
39405
39406
39407
39408
39409
39410
39411
39412
39413
39414
39415
39416
39417
39418
39419
39420
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39395

class InterconnectLocationRegionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Identifies the network presence of this location.
  module LocationPresence
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_PRESENCE = 0

    # This region is not in any common network presence with this
    # InterconnectLocation.
    GLOBAL = 494_663_587

    # This region shares the same regional network presence as this
    # InterconnectLocation.
    LOCAL_REGION = 403_535_464

    # [Deprecated] This region is not in any common network presence with
    # this InterconnectLocation.
    LP_GLOBAL = 429_584_062

    # [Deprecated] This region shares the same regional network presence as
    # this InterconnectLocation.
    LP_LOCAL_REGION = 488_598_851
  end
end

#location_presence ⇒ ::String

Returns Output only. Identifies the network presence of this location. Check the LocationPresence enum for the list of possible values.

Returns:

  • (::String) —

    Output only. Identifies the network presence of this location. Check the LocationPresence enum for the list of possible values.



39395
39396
39397
39398
39399
39400
39401
39402
39403
39404
39405
39406
39407
39408
39409
39410
39411
39412
39413
39414
39415
39416
39417
39418
39419
39420
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39395

class InterconnectLocationRegionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Identifies the network presence of this location.
  module LocationPresence
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_PRESENCE = 0

    # This region is not in any common network presence with this
    # InterconnectLocation.
    GLOBAL = 494_663_587

    # This region shares the same regional network presence as this
    # InterconnectLocation.
    LOCAL_REGION = 403_535_464

    # [Deprecated] This region is not in any common network presence with
    # this InterconnectLocation.
    LP_GLOBAL = 429_584_062

    # [Deprecated] This region shares the same regional network presence as
    # this InterconnectLocation.
    LP_LOCAL_REGION = 488_598_851
  end
end

#region ⇒ ::String

Returns Output only. URL for the region of this location.

Returns:

  • (::String) —

    Output only. URL for the region of this location.



39395
39396
39397
39398
39399
39400
39401
39402
39403
39404
39405
39406
39407
39408
39409
39410
39411
39412
39413
39414
39415
39416
39417
39418
39419
39420
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39395

class InterconnectLocationRegionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Identifies the network presence of this location.
  module LocationPresence
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_PRESENCE = 0

    # This region is not in any common network presence with this
    # InterconnectLocation.
    GLOBAL = 494_663_587

    # This region shares the same regional network presence as this
    # InterconnectLocation.
    LOCAL_REGION = 403_535_464

    # [Deprecated] This region is not in any common network presence with
    # this InterconnectLocation.
    LP_GLOBAL = 429_584_062

    # [Deprecated] This region shares the same regional network presence as
    # this InterconnectLocation.
    LP_LOCAL_REGION = 488_598_851
  end
end