Class: Google::Cloud::Compute::V1::InterconnectOutageNotification

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Description of a planned outage on this Interconnect.

Defined Under Namespace

Modules: IssueType, Source, State

Instance Attribute Summary collapse

Instance Attribute Details

#affected_circuits::Array<::String>



18395
18396
18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
18432
18433
18434
18435
18436
18437
18438
18439
18440
18441
18442
18443
18444
18445
18446
18447
18448
18449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18395

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#description::String



18395
18396
18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
18432
18433
18434
18435
18436
18437
18438
18439
18440
18441
18442
18443
18444
18445
18446
18447
18448
18449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18395

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#end_time::Integer



18395
18396
18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
18432
18433
18434
18435
18436
18437
18438
18439
18440
18441
18442
18443
18444
18445
18446
18447
18448
18449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18395

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#issue_type::String



18395
18396
18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
18432
18433
18434
18435
18436
18437
18438
18439
18440
18441
18442
18443
18444
18445
18446
18447
18448
18449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18395

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#name::String



18395
18396
18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
18432
18433
18434
18435
18436
18437
18438
18439
18440
18441
18442
18443
18444
18445
18446
18447
18448
18449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18395

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#source::String



18395
18396
18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
18432
18433
18434
18435
18436
18437
18438
18439
18440
18441
18442
18443
18444
18445
18446
18447
18448
18449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18395

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#start_time::Integer



18395
18396
18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
18432
18433
18434
18435
18436
18437
18438
18439
18440
18441
18442
18443
18444
18445
18446
18447
18448
18449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18395

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#state::String



18395
18396
18397
18398
18399
18400
18401
18402
18403
18404
18405
18406
18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
18418
18419
18420
18421
18422
18423
18424
18425
18426
18427
18428
18429
18430
18431
18432
18433
18434
18435
18436
18437
18438
18439
18440
18441
18442
18443
18444
18445
18446
18447
18448
18449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18395

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following values: - OUTAGE: The Interconnect may be completely out of service for some or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth. Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during the expected window. The interconnect as a whole should remain up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end