Module: Google::Cloud::Compute::V1::InterconnectOutageNotification::State

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

State of this notification, which can take one of the following values: - ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling. - CANCELLED: The outage associated with this notification was cancelled before the outage was due to start. - COMPLETED: The outage associated with this notification is complete. Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values.

Constant Summary collapse

UNDEFINED_STATE =

A value indicating that the enum field is not set.

0
ACTIVE =

This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.

314_733_318
CANCELLED =

The outage associated with this notification was cancelled before the outage was due to start.

41_957_681
COMPLETED =

The outage associated with this notification is complete.

309_921_323
NS_ACTIVE =

[Deprecated] This outage notification is active. The event could be in the future, present, or past. See start_time and end_time for scheduling.

252_563_136
NS_CANCELED =

[Deprecated] The outage associated with this notification was canceled before the outage was due to start.

506_579_411