Class: Google::Cloud::Compute::V1::InterconnectRemoteLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Cross-Cloud Interconnect Remote Location resource.

You can use this resource to find remote location details about an Interconnect attachment (VLAN).

Defined Under Namespace

Modules: Continent, Lacp, Status

Instance Attribute Summary collapse

Instance Attribute Details

#address ⇒ ::String

Returns Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character.

Returns:

  • (::String) —

    Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#attachment_configuration_constraints ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentConfigurationConstraints

Returns Output only. [Output Only] Subset of fields from InterconnectAttachment's |configurationConstraints| field that apply to all attachments for this remote location.

Returns:



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#city ⇒ ::String

Returns Output only. [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".

Returns:

  • (::String) —

    Output only. [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#constraints ⇒ ::Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraints

Returns Output only. [Output Only] Constraints on the parameters for creating Cross-Cloud Interconnect and associated InterconnectAttachments.

Returns:



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#continent ⇒ ::String

Returns Output only. [Output Only] Continent for this location, which can take one of the following values:

- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA

Check the Continent enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] Continent for this location, which can take one of the following values:

    - AFRICA
    - ASIA_PAC
    - EUROPE
    - NORTH_AMERICA
    - SOUTH_AMERICA
    

    Check the Continent enum for the list of possible values.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#creation_timestamp ⇒ ::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String) —

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#description ⇒ ::String

Returns Output only. [Output Only] An optional description of the resource.

Returns:

  • (::String) —

    Output only. [Output Only] An optional description of the resource.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#facility_provider ⇒ ::String

Returns Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX).

Returns:

  • (::String) —

    Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX).



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#facility_provider_facility_id ⇒ ::String

Returns Output only. [Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).

Returns:

  • (::String) —

    Output only. [Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#id ⇒ ::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer) —

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#interconnectRemoteLocation for interconnect remote locations.

Returns:

  • (::String) —

    Output only. [Output Only] Type of the resource. Alwayscompute#interconnectRemoteLocation for interconnect remote locations.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#lacp ⇒ ::String

Returns Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED Check the Lacp enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED Check the Lacp enum for the list of possible values.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#max_lag_size100_gbps ⇒ ::Integer

Returns Output only. [Output Only] The maximum number of 100 Gbps ports supported in a link aggregation group (LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed max_lag_size_100_gbps.

Returns:

  • (::Integer) —

    Output only. [Output Only] The maximum number of 100 Gbps ports supported in a link aggregation group (LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed max_lag_size_100_gbps.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#max_lag_size10_gbps ⇒ ::Integer

Returns Output only. [Output Only] The maximum number of 10 Gbps ports supported in a link aggregation group (LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed max_lag_size_10_gbps.

Returns:

  • (::Integer) —

    Output only. [Output Only] The maximum number of 10 Gbps ports supported in a link aggregation group (LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed max_lag_size_10_gbps.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#max_lag_size400_gbps ⇒ ::Integer

Returns Output only. [Output Only] The maximum number of 400 Gbps ports supported in a link aggregation group (LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed max_lag_size_400_gbps.

Returns:

  • (::Integer) —

    Output only. [Output Only] The maximum number of 400 Gbps ports supported in a link aggregation group (LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed max_lag_size_400_gbps.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#name ⇒ ::String

Returns Output only. [Output Only] Name of the resource.

Returns:

  • (::String) —

    Output only. [Output Only] Name of the resource.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#peeringdb_facility_id ⇒ ::String

Returns Output only. [Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).

Returns:

  • (::String) —

    Output only. [Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#permitted_connections ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectRemoteLocationPermittedConnections>

Returns Output only. [Output Only] Permitted connections.

Returns:



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#remote_service ⇒ ::String

Returns Output only. [Output Only] Indicates the service provider present at the remote location. Example values: "Amazon Web Services", "Microsoft Azure".

Returns:

  • (::String) —

    Output only. [Output Only] Indicates the service provider present at the remote location. Example values: "Amazon Web Services", "Microsoft Azure".



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for the resource.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end

#status ⇒ ::String

Returns Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:

- CLOSED: The InterconnectRemoteLocation is closed and is unavailable
for provisioning new Cross-Cloud Interconnects.
- AVAILABLE: The
InterconnectRemoteLocation is available for provisioning new
Cross-Cloud Interconnects.

Check the Status enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:

    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
    for provisioning new Cross-Cloud Interconnects.
    - AVAILABLE: The
    InterconnectRemoteLocation is available for provisioning new
    Cross-Cloud Interconnects.
    

    Check the Status enum for the list of possible values.



39791
39792
39793
39794
39795
39796
39797
39798
39799
39800
39801
39802
39803
39804
39805
39806
39807
39808
39809
39810
39811
39812
39813
39814
39815
39816
39817
39818
39819
39820
39821
39822
39823
39824
39825
39826
39827
39828
39829
39830
39831
39832
39833
39834
39835
39836
39837
39838
39839
39840
39841
39842
39843
39844
39845
39846
39847
39848
39849
39850
39851
39852
39853
39854
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39791

class InterconnectRemoteLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Continent for this location, which can take one of the
  # following values:
  #
  #    - AFRICA
  #    - ASIA_PAC
  #    - EUROPE
  #    - NORTH_AMERICA
  #    - SOUTH_AMERICA
  module Continent
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTINENT = 0

    AFRICA = 317_443_706

    ASIA_PAC = 119_782_269

    EUROPE = 445_819_298

    NORTH_AMERICA = 448_015_508

    SOUTH_AMERICA = 32_597_340
  end

  # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
  # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
  module Lacp
    # A value indicating that the enum field is not set.
    UNDEFINED_LACP = 0

    # LACP_SUPPORTED: LACP is supported, and enabled by default on
    # the Cross-Cloud Interconnect.
    LACP_SUPPORTED = 339_576_113

    # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this
    # port. GetDiagnostics shows bundleAggregationType as "static". GCP does
    # not support LAGs without LACP, so requestedLinkCount must be 1.
    LACP_UNSUPPORTED = 203_930_104
  end

  # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take
  # one of the following values:
  #
  #    - CLOSED: The InterconnectRemoteLocation is closed and is unavailable
  #    for provisioning new Cross-Cloud Interconnects.
  #    - AVAILABLE: The
  #    InterconnectRemoteLocation is available for provisioning new
  #    Cross-Cloud Interconnects.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The InterconnectRemoteLocation is available for provisioning new
    # Cross-Cloud Interconnects.
    AVAILABLE = 442_079_913

    # The InterconnectRemoteLocation is closed for provisioning new
    # Cross-Cloud Interconnects.
    CLOSED = 380_163_436
  end
end