Module: Google::Cloud::Compute::V1::InterconnectRemoteLocation::Continent

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. [Output Only] Continent for this location, which can take one of the following values:

  • AFRICA
  • ASIA_PAC
  • EUROPE
  • NORTH_AMERICA
  • SOUTH_AMERICA

Constant Summary collapse

UNDEFINED_CONTINENT =

A value indicating that the enum field is not set.

0
AFRICA =
317_443_706
ASIA_PAC =
119_782_269
EUROPE =
445_819_298
NORTH_AMERICA =
448_015_508
SOUTH_AMERICA =
32_597_340