Class: Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraints

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: PortPairRemoteLocation, PortPairVlan

Instance Attribute Summary collapse

Instance Attribute Details

#port_pair_remote_location ⇒ ::String

Returns Output only. [Output Only] Port pair remote location constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, PORT_PAIR_MATCHING_REMOTE_LOCATION.

Google Cloud API refers only to individual ports, but the UI uses this field when ordering a pair of ports, to prevent users from accidentally ordering something that is incompatible with their cloud provider. Specifically, when ordering a redundant pair of Cross-Cloud Interconnect ports, and one of them uses a remote location with portPairMatchingRemoteLocation set to matching, the UI requires that both ports use the same remote location. Check the PortPairRemoteLocation enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] Port pair remote location constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, PORT_PAIR_MATCHING_REMOTE_LOCATION.

    Google Cloud API refers only to individual ports, but the UI uses this field when ordering a pair of ports, to prevent users from accidentally ordering something that is incompatible with their cloud provider. Specifically, when ordering a redundant pair of Cross-Cloud Interconnect ports, and one of them uses a remote location with portPairMatchingRemoteLocation set to matching, the UI requires that both ports use the same remote location. Check the PortPairRemoteLocation enum for the list of possible values.



39892
39893
39894
39895
39896
39897
39898
39899
39900
39901
39902
39903
39904
39905
39906
39907
39908
39909
39910
39911
39912
39913
39914
39915
39916
39917
39918
39919
39920
39921
39922
39923
39924
39925
39926
39927
39928
39929
39930
39931
39932
39933
39934
39935
39936
39937
39938
39939
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39892

class InterconnectRemoteLocationConstraints
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Port pair remote location constraints, which can take one
  # of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
  # PORT_PAIR_MATCHING_REMOTE_LOCATION.
  #
  # Google Cloud API refers only to individual ports, but the UI uses this
  # field when ordering a pair of ports, to prevent users from accidentally
  # ordering something that is incompatible with their cloud provider.
  # Specifically, when ordering a redundant pair of Cross-Cloud Interconnect
  # ports, and one of them uses a remote location with
  # portPairMatchingRemoteLocation set to matching, the UI requires that
  # both ports use the same remote location.
  module PortPairRemoteLocation
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_REMOTE_LOCATION = 0

    # If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider
    # allocates ports in pairs, and the user should choose the same remote
    # location for both ports.
    PORT_PAIR_MATCHING_REMOTE_LOCATION = 207_291_859

    # If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision
    # a redundant pair of Cross-Cloud Interconnects using two different
    # remote locations in the same city.
    PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 60_609_829
  end

  # Output only. [Output Only] Port pair VLAN constraints, which can take one of the
  # following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN
  module PortPairVlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_VLAN = 0

    # If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is
    # part of a pair of ports that should have matching VLAN allocations.
    # This occurs with Cross-Cloud Interconnect to Azure remote locations.
    # While GCP's API does not explicitly group pairs of ports, the UI uses
    # this field to ensure matching VLAN ids when configuring a redundant
    # VLAN pair.
    PORT_PAIR_MATCHING_VLAN = 250_295_358

    # PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint.
    PORT_PAIR_UNCONSTRAINED_VLAN = 175_227_948
  end
end

#port_pair_vlan ⇒ ::String

Returns Output only. [Output Only] Port pair VLAN constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN Check the PortPairVlan enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] Port pair VLAN constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN Check the PortPairVlan enum for the list of possible values.



39892
39893
39894
39895
39896
39897
39898
39899
39900
39901
39902
39903
39904
39905
39906
39907
39908
39909
39910
39911
39912
39913
39914
39915
39916
39917
39918
39919
39920
39921
39922
39923
39924
39925
39926
39927
39928
39929
39930
39931
39932
39933
39934
39935
39936
39937
39938
39939
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39892

class InterconnectRemoteLocationConstraints
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Port pair remote location constraints, which can take one
  # of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
  # PORT_PAIR_MATCHING_REMOTE_LOCATION.
  #
  # Google Cloud API refers only to individual ports, but the UI uses this
  # field when ordering a pair of ports, to prevent users from accidentally
  # ordering something that is incompatible with their cloud provider.
  # Specifically, when ordering a redundant pair of Cross-Cloud Interconnect
  # ports, and one of them uses a remote location with
  # portPairMatchingRemoteLocation set to matching, the UI requires that
  # both ports use the same remote location.
  module PortPairRemoteLocation
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_REMOTE_LOCATION = 0

    # If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider
    # allocates ports in pairs, and the user should choose the same remote
    # location for both ports.
    PORT_PAIR_MATCHING_REMOTE_LOCATION = 207_291_859

    # If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision
    # a redundant pair of Cross-Cloud Interconnects using two different
    # remote locations in the same city.
    PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 60_609_829
  end

  # Output only. [Output Only] Port pair VLAN constraints, which can take one of the
  # following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN
  module PortPairVlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_VLAN = 0

    # If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is
    # part of a pair of ports that should have matching VLAN allocations.
    # This occurs with Cross-Cloud Interconnect to Azure remote locations.
    # While GCP's API does not explicitly group pairs of ports, the UI uses
    # this field to ensure matching VLAN ids when configuring a redundant
    # VLAN pair.
    PORT_PAIR_MATCHING_VLAN = 250_295_358

    # PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint.
    PORT_PAIR_UNCONSTRAINED_VLAN = 175_227_948
  end
end

#subnet_length_range ⇒ ::Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraintsSubnetLengthRange

Returns Output only. [Output Only]

[min-length, max-length]

The minimum and maximum value (inclusive) for the IPv4 subnet length.

For example, an interconnectRemoteLocation for Azure has {min: 30, max: 30} because Azure requires /30 subnets.

This range specifies the values supported by both cloud providers. Interconnect currently supports /29 and /30 IPv4 subnet lengths. If a remote cloud has no constraint on IPv4 subnet length, the range would thus be {min: 29, max: 30}.

Returns:

  • (::Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraintsSubnetLengthRange) —

    Output only. [Output Only]

    [min-length, max-length]

    The minimum and maximum value (inclusive) for the IPv4 subnet length.

    For example, an interconnectRemoteLocation for Azure has {min: 30, max: 30} because Azure requires /30 subnets.

    This range specifies the values supported by both cloud providers. Interconnect currently supports /29 and /30 IPv4 subnet lengths. If a remote cloud has no constraint on IPv4 subnet length, the range would thus be {min: 29, max: 30}.



39892
39893
39894
39895
39896
39897
39898
39899
39900
39901
39902
39903
39904
39905
39906
39907
39908
39909
39910
39911
39912
39913
39914
39915
39916
39917
39918
39919
39920
39921
39922
39923
39924
39925
39926
39927
39928
39929
39930
39931
39932
39933
39934
39935
39936
39937
39938
39939
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39892

class InterconnectRemoteLocationConstraints
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Port pair remote location constraints, which can take one
  # of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
  # PORT_PAIR_MATCHING_REMOTE_LOCATION.
  #
  # Google Cloud API refers only to individual ports, but the UI uses this
  # field when ordering a pair of ports, to prevent users from accidentally
  # ordering something that is incompatible with their cloud provider.
  # Specifically, when ordering a redundant pair of Cross-Cloud Interconnect
  # ports, and one of them uses a remote location with
  # portPairMatchingRemoteLocation set to matching, the UI requires that
  # both ports use the same remote location.
  module PortPairRemoteLocation
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_REMOTE_LOCATION = 0

    # If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider
    # allocates ports in pairs, and the user should choose the same remote
    # location for both ports.
    PORT_PAIR_MATCHING_REMOTE_LOCATION = 207_291_859

    # If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision
    # a redundant pair of Cross-Cloud Interconnects using two different
    # remote locations in the same city.
    PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 60_609_829
  end

  # Output only. [Output Only] Port pair VLAN constraints, which can take one of the
  # following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN
  module PortPairVlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_VLAN = 0

    # If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is
    # part of a pair of ports that should have matching VLAN allocations.
    # This occurs with Cross-Cloud Interconnect to Azure remote locations.
    # While GCP's API does not explicitly group pairs of ports, the UI uses
    # this field to ensure matching VLAN ids when configuring a redundant
    # VLAN pair.
    PORT_PAIR_MATCHING_VLAN = 250_295_358

    # PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint.
    PORT_PAIR_UNCONSTRAINED_VLAN = 175_227_948
  end
end