Class: Google::Cloud::Compute::V1::InterconnectRemoteLocationPermittedConnections

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#interconnect_location ⇒ ::String

Returns Output only. [Output Only] URL of an Interconnect location that is permitted to connect to this Interconnect remote location.

Returns:

  • (::String) —

    Output only. [Output Only] URL of an Interconnect location that is permitted to connect to this Interconnect remote location.



39984
39985
39986
39987
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 39984

class InterconnectRemoteLocationPermittedConnections
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end