Class: Google::Cloud::Compute::V1::Interval
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Interval
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.
Instance Attribute Summary collapse
-
#end_time ⇒ ::String
Optional.
-
#start_time ⇒ ::String
Optional.
Instance Attribute Details
#end_time ⇒ ::String
Returns Optional. Exclusive end of the interval.
If specified, a Timestamp matching this interval will have to be before the end.
40026 40027 40028 40029 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 40026 class Interval include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::String
Returns Optional. Inclusive start of the interval.
If specified, a Timestamp matching this interval will have to be the same or after the start.
40026 40027 40028 40029 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 40026 class Interval include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |