Class: Google::Cloud::Compute::V1::LicenseParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Additional license params.

Defined Under Namespace

Classes: ResourceManagerTagsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns Input only. Resource manager tags to be bound to the license. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    Input only. Resource manager tags to be bound to the license. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.



40304
40305
40306
40307
40308
40309
40310
40311
40312
40313
40314
40315
40316
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 40304

class LicenseParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end