Class: Google::Cloud::Compute::V1::ListGlobalOperationsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ListGlobalOperationsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for GlobalOperations.List. See the method description for details.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
A filter expression that filters resources listed in the response.
-
#max_results ⇒ ::Integer
The maximum number of results per page that should be returned.
-
#order_by ⇒ ::String
Sorts list results by a certain order.
-
#page_token ⇒ ::String
Specifies a page token to use.
-
#project ⇒ ::String
Project ID for this request.
-
#return_partial_success ⇒ ::Boolean
Opt-in for partial success behavior which provides partial results in case of failure.
Instance Attribute Details
#filter ⇒ ::String
17967 17968 17969 17970 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17967 class ListGlobalOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_results ⇒ ::Integer
17967 17968 17969 17970 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17967 class ListGlobalOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
17967 17968 17969 17970 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17967 class ListGlobalOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
17967 17968 17969 17970 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17967 class ListGlobalOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
17967 17968 17969 17970 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17967 class ListGlobalOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#return_partial_success ⇒ ::Boolean
17967 17968 17969 17970 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17967 class ListGlobalOperationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |