Class: Google::Cloud::Compute::V1::ListPeeringRoutesNetworksRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ListPeeringRoutesNetworksRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for Networks.ListPeeringRoutes. See the method description for details.
Defined Under Namespace
Modules: Direction
Instance Attribute Summary collapse
-
#direction ⇒ ::String
The direction of the exchanged routes.
-
#filter ⇒ ::String
A filter expression that filters resources listed in the response.
-
#max_results ⇒ ::Integer
The maximum number of results per page that should be returned.
-
#network ⇒ ::String
Name of the network for this request.
-
#order_by ⇒ ::String
Sorts list results by a certain order.
-
#page_token ⇒ ::String
Specifies a page token to use.
-
#peering_name ⇒ ::String
The response will show routes exchanged over the given peering connection.
-
#project ⇒ ::String
Project ID for this request.
-
#region ⇒ ::String
The region of the request.
-
#return_partial_success ⇒ ::Boolean
Opt-in for partial success behavior which provides partial results in case of failure.
Instance Attribute Details
#direction ⇒ ::String
Returns The direction of the exchanged routes. Check the Direction enum for the list of possible values.
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |
#filter ⇒ ::String
Returns A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request.
If you want to use AIP-160, your expression must specify the field name, an
operator, and the value that you want to use for filtering. The value
must be a string, a number, or a boolean. The operator
must be either =, !=, >, <, <=, >= or :.
For example, if you are filtering Compute Engine instances, you can
exclude instances named example-instance by specifying
name != example-instance.
The :* comparison can be used to test whether a key has been defined.
For example, to find all objects with owner label use:
labels.owner:*
You can also filter nested fields. For example, you could specify
scheduling.automaticRestart = false to include instances only
if they are not scheduled for automatic restarts. You can use filtering
on nested fields to filter based onresource labels.
To filter on multiple expressions, provide each separate expression within parentheses. For example:
(scheduling.automaticRestart = true)
(cpuPlatform = "Intel Skylake")
By default, each expression is an AND expression. However, you
can include AND and OR expressions explicitly.
For example:
(cpuPlatform = "Intel Skylake") OR
(cpuPlatform = "Intel Broadwell") AND
(scheduling.automaticRestart = true)
If you want to use a regular expression, use the eq (equal) or ne
(not equal) operator against a single un-parenthesized expression with or
without quotes or against multiple parenthesized expressions. Examples:
fieldname eq unquoted literal
fieldname eq 'single quoted literal'
fieldname eq "double quoted literal"
(fieldname1 eq literal) (fieldname2 ne "literal")
The literal value is interpreted as a regular expression using GoogleRE2 library syntax. The literal value must match the entire field.
For example, to filter for instances that do not end with name "instance",
you would use name ne .*instance.
You cannot combine constraints on multiple fields using regular expressions.
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |
#max_results ⇒ ::Integer
Returns The maximum number of results per page that should be returned.
If the number of available results is larger than maxResults,
Compute Engine returns a nextPageToken that can be used to get
the next page of results in subsequent list requests. Acceptable values are
0 to 500, inclusive. (Default: 500).
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |
#network ⇒ ::String
Returns Name of the network for this request.
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |
#order_by ⇒ ::String
Returns Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.
You can also sort results in descending order based on the creation
timestamp using orderBy="creationTimestamp desc". This sorts
results based on the creationTimestamp field in
reverse chronological order (newest result first). Use this to sort
resources like operations so that the newest operation is returned first.
Currently, only sorting by name or
creationTimestamp desc is supported.
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |
#page_token ⇒ ::String
Returns Specifies a page token to use. Set pageToken to the
nextPageToken returned by a previous list request to get
the next page of results.
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |
#peering_name ⇒ ::String
Returns The response will show routes exchanged over the given peering connection.
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |
#project ⇒ ::String
Returns Project ID for this request.
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |
#region ⇒ ::String
Returns The region of the request. The response will include all subnet routes, static routes and dynamic routes in the region.
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |
#return_partial_success ⇒ ::Boolean
Returns Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.
For example, when partial success behavior is enabled, aggregatedList for a single zone scope either returns all resources in the zone or no resources, with an error code.
44736 44737 44738 44739 44740 44741 44742 44743 44744 44745 44746 44747 44748 44749 44750 44751 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 44736 class ListPeeringRoutesNetworksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction of the exchanged routes. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # For routes exported from peer network. INCOMING = 338_552_870 # For routes exported from local network. OUTGOING = 307_438_444 end end |