Class: Google::Cloud::Compute::V1::LocationPolicyZoneConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#zone ⇒ ::String

Returns The URL of the zone. The zone must exist in the region where the request is called. Zones must be represented as valid partial URLs, such as zones/us-central1-a.

Returns:

  • (::String) —

    The URL of the zone. The zone must exist in the region where the request is called. Zones must be represented as valid partial URLs, such as zones/us-central1-a.



55744
55745
55746
55747
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55744

class LocationPolicyZoneConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end