Class: Google::Cloud::Compute::V1::MachineType
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::MachineType
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Machine Type resource.
You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.
Defined Under Namespace
Modules: Architecture
Instance Attribute Summary collapse
-
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::Accelerators>
[Output Only] A list of accelerator configurations assigned to this machine type.
-
#architecture ⇒ ::String
[Output Only] The architecture of the machine type.
-
#bundled_local_ssds ⇒ ::Google::Cloud::Compute::V1::BundledLocalSsds
[Output Only] The configuration of bundled local SSD for the machine type.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ ::Google::Cloud::Compute::V1::DeprecationStatus
[Output Only] The deprecation status associated with this machine type.
-
#description ⇒ ::String
[Output Only] An optional textual description of the resource.
-
#guest_cpus ⇒ ::Integer
[Output Only] The number of virtual CPUs that are available to the instance.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#image_space_gb ⇒ ::Integer
[Deprecated] This property is deprecated and will never be populated with any relevant values.
-
#is_shared_cpu ⇒ ::Boolean
[Output Only] Whether this machine type has a shared CPU.
-
#kind ⇒ ::String
Output only.
-
#maximum_persistent_disks ⇒ ::Integer
[Output Only] Maximum persistent disks allowed.
-
#maximum_persistent_disks_size_gb ⇒ ::Integer
[Output Only] Maximum total persistent disks size (GB) allowed.
-
#memory_mb ⇒ ::Integer
[Output Only] The amount of physical memory available to the instance, defined in MB.
-
#name ⇒ ::String
[Output Only] Name of the resource.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#zone ⇒ ::String
[Output Only] The name of the zone where the machine type resides, such as us-central1-a.
Instance Attribute Details
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::Accelerators>
Returns [Output Only] A list of accelerator configurations assigned to this machine type.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#architecture ⇒ ::String
Returns [Output Only] The architecture of the machine type. Check the Architecture enum for the list of possible values.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#bundled_local_ssds ⇒ ::Google::Cloud::Compute::V1::BundledLocalSsds
Returns [Output Only] The configuration of bundled local SSD for the machine type.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#creation_timestamp ⇒ ::String
Returns [Output Only] Creation timestamp inRFC3339 text format.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#deprecated ⇒ ::Google::Cloud::Compute::V1::DeprecationStatus
Returns [Output Only] The deprecation status associated with this machine type. Only applicable if the machine type is unavailable.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#description ⇒ ::String
Returns [Output Only] An optional textual description of the resource.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#guest_cpus ⇒ ::Integer
Returns [Output Only] The number of virtual CPUs that are available to the instance.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#image_space_gb ⇒ ::Integer
Returns [Deprecated] This property is deprecated and will never be populated with any relevant values.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#is_shared_cpu ⇒ ::Boolean
Returns [Output Only] Whether this machine type has a shared CPU. SeeShared-core machine types for more information.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] The type of the resource. Alwayscompute#machineType for machine types.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#maximum_persistent_disks ⇒ ::Integer
Returns [Output Only] Maximum persistent disks allowed.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#maximum_persistent_disks_size_gb ⇒ ::Integer
Returns [Output Only] Maximum total persistent disks size (GB) allowed.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#memory_mb ⇒ ::Integer
Returns [Output Only] The amount of physical memory available to the instance, defined in MB.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#name ⇒ ::String
Returns [Output Only] Name of the resource.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |
#zone ⇒ ::String
Returns [Output Only] The name of the zone where the machine type resides, such as us-central1-a.
56009 56010 56011 56012 56013 56014 56015 56016 56017 56018 56019 56020 56021 56022 56023 56024 56025 56026 56027 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56009 class MachineType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The architecture of the machine type. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end end |