Module: Google::Cloud::Compute::V1::ManagedInstance::TargetStatus

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. The eventual status of the instance. The instance group manager will not be identified as stable till each managed instance reaches its targetStatus. Additional supported values which may be not listed in the enum directly due to technical reasons: RUNNING STOPPED SUSPENDED

Constant Summary collapse

UNDEFINED_TARGET_STATUS =

A value indicating that the enum field is not set.

0
ABANDONED =

The managed instance will eventually be ABANDONED, i.e. dissociated from the managed instance group.

81_797_556
DELETED =

The managed instance will eventually be DELETED.

120_962_041
INVALID =

Only present to map the STATUS_INVALID value.

530_283_991