Class: Google::Cloud::Compute::V1::ManagedInstancePropertiesFromFlexibilityPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#machine_type ⇒ ::String

Returns Output only. The machine type to be used for this instance.

Returns:

  • (::String) —

    Output only. The machine type to be used for this instance.



56414
56415
56416
56417
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56414

class ManagedInstancePropertiesFromFlexibilityPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end