Class: Google::Cloud::Compute::V1::Metadata
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Metadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A metadata key/value entry.
Instance Attribute Summary collapse
-
#fingerprint ⇒ ::String
Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#items ⇒ ::Array<::Google::Cloud::Compute::V1::Items>
Array of key/value pairs.
-
#kind ⇒ ::String
Output only.
Instance Attribute Details
#fingerprint ⇒ ::String
Returns Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to retrieve the resource.
53542 53543 53544 53545 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53542 class Metadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#items ⇒ ::Array<::Google::Cloud::Compute::V1::Items>
Returns Array of key/value pairs. The total size of all keys and values must be less than 512 KB.
53542 53543 53544 53545 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53542 class Metadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#metadata for metadata.
53542 53543 53544 53545 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53542 class Metadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |