Class: Google::Cloud::Compute::V1::NamedPort

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The named port. For example: <"http", 80>.

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ ::String

Returns The name for this named port. The name must be 1-63 characters long, and comply withRFC1035.

Returns:

  • (::String) —

    The name for this named port. The name must be 1-63 characters long, and comply withRFC1035.



56768
56769
56770
56771
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56768

class NamedPort
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#port ⇒ ::Integer

Returns The port number, which can be a value between 1 and 65535.

Returns:

  • (::Integer) —

    The port number, which can be a value between 1 and 65535.



56768
56769
56770
56771
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56768

class NamedPort
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end