Class: Google::Cloud::Compute::V1::NatIpInfoNatIpInfoMapping

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains information of a NAT IP.

Defined Under Namespace

Modules: Mode, Usage

Instance Attribute Summary collapse

Instance Attribute Details

#mode ⇒ ::String

Returns Output only. Specifies whether NAT IP is auto or manual. Check the Mode enum for the list of possible values.

Returns:

  • (::String) —

    Output only. Specifies whether NAT IP is auto or manual. Check the Mode enum for the list of possible values.



56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
56861
56862
56863
56864
56865
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56841

class NatIpInfoNatIpInfoMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Specifies whether NAT IP is auto or manual.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    AUTO = 2_020_783

    MANUAL = 119_397_318
  end

  # Output only. Specifies whether NAT IP is currently serving at least one endpoint or
  # not.
  module Usage
    # A value indicating that the enum field is not set.
    UNDEFINED_USAGE = 0

    IN_USE = 17_393_485

    UNUSED = 360_643_030
  end
end

#nat_ip ⇒ ::String

Returns Output only. NAT IP address. For example: 203.0.113.11.

Returns:

  • (::String) —

    Output only. NAT IP address. For example: 203.0.113.11.



56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
56861
56862
56863
56864
56865
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56841

class NatIpInfoNatIpInfoMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Specifies whether NAT IP is auto or manual.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    AUTO = 2_020_783

    MANUAL = 119_397_318
  end

  # Output only. Specifies whether NAT IP is currently serving at least one endpoint or
  # not.
  module Usage
    # A value indicating that the enum field is not set.
    UNDEFINED_USAGE = 0

    IN_USE = 17_393_485

    UNUSED = 360_643_030
  end
end

#usage ⇒ ::String

Returns Output only. Specifies whether NAT IP is currently serving at least one endpoint or not. Check the Usage enum for the list of possible values.

Returns:

  • (::String) —

    Output only. Specifies whether NAT IP is currently serving at least one endpoint or not. Check the Usage enum for the list of possible values.



56841
56842
56843
56844
56845
56846
56847
56848
56849
56850
56851
56852
56853
56854
56855
56856
56857
56858
56859
56860
56861
56862
56863
56864
56865
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56841

class NatIpInfoNatIpInfoMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Specifies whether NAT IP is auto or manual.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    AUTO = 2_020_783

    MANUAL = 119_397_318
  end

  # Output only. Specifies whether NAT IP is currently serving at least one endpoint or
  # not.
  module Usage
    # A value indicating that the enum field is not set.
    UNDEFINED_USAGE = 0

    IN_USE = 17_393_485

    UNUSED = 360_643_030
  end
end