Class: Google::Cloud::Compute::V1::Network
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Network
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a VPC Network resource.
Networks connect resources to each other and to the internet. For more information, readVirtual Private Cloud (VPC) Network.
Defined Under Namespace
Modules: NetworkFirewallPolicyEnforcementOrder
Instance Attribute Summary collapse
-
#auto_create_subnetworks ⇒ ::Boolean
Must be set to create a VPC network.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#enable_ula_internal_ipv6 ⇒ ::Boolean
Enable ULA internal ipv6 on this network.
-
#firewall_policy ⇒ ::String
Output only.
-
#gateway_i_pv4 ⇒ ::String
[Output Only] The gateway address for default routing out of the network, selected by Google Cloud.
-
#I_pv4_range ⇒ ::String
Deprecated in favor of subnet mode networks.
-
#id ⇒ ::Integer
Output only.
-
#internal_ipv6_range ⇒ ::String
When enabling ula internal ipv6, caller optionally can specify the /48 range they want from the google defined ULA prefix fd20::/20.
-
#kind ⇒ ::String
Output only.
-
#mtu ⇒ ::Integer
Maximum Transmission Unit in bytes.
-
#name ⇒ ::String
Name of the resource.
-
#network_firewall_policy_enforcement_order ⇒ ::String
The network firewall policy enforcement order.
-
#network_profile ⇒ ::String
A full or partial URL of the network profile to apply to this network.
-
#params ⇒ ::Google::Cloud::Compute::V1::NetworkParams
Input only.
-
#peerings ⇒ ::Array<::Google::Cloud::Compute::V1::NetworkPeering>
Output only.
-
#routing_config ⇒ ::Google::Cloud::Compute::V1::NetworkRoutingConfig
The network-level routing configuration for this network.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ ::String
Output only.
-
#subnetworks ⇒ ::Array<::String>
[Output Only] Server-defined fully-qualified URLs for all subnetworks in this VPC network.
Instance Attribute Details
#auto_create_subnetworks ⇒ ::Boolean
Returns Must be set to create a VPC network. If not set, a legacy network is created.
When set to true, the VPC network is created in auto mode. When set to false, the VPC network is created in custom mode.
An auto mode VPC network starts with one subnet per region. Each subnet has a predetermined range as described inAuto mode VPC network IP ranges.
For custom mode VPC networks, you can add subnets using the subnetworksinsert method.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this field when you create the resource.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#enable_ula_internal_ipv6 ⇒ ::Boolean
Returns Enable ULA internal ipv6 on this network. Enabling this feature will assign a /48 from google defined ULA prefix fd20::/20. .
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#firewall_policy ⇒ ::String
Returns Output only. [Output Only] URL of the firewall policy the network is associated with.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#gateway_i_pv4 ⇒ ::String
Returns [Output Only] The gateway address for default routing out of the network, selected by Google Cloud.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#I_pv4_range ⇒ ::String
Returns Deprecated in favor of subnet mode networks. The range of internal addresses that are legal on this network. This range is aCIDR specification, for example:192.168.0.0/16. Provided by the client when the network is created.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#internal_ipv6_range ⇒ ::String
Returns When enabling ula internal ipv6, caller optionally can specify the /48 range they want from the google defined ULA prefix fd20::/20. The input must be a valid /48 ULA IPv6 address and must be within the fd20::/20. Operation will fail if the speficied /48 is already in used by another resource. If the field is not speficied, then a /48 range will be randomly allocated from fd20::/20 and returned via this field. .
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#network for networks.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#mtu ⇒ ::Integer
Returns Maximum Transmission Unit in bytes. The minimum value for this field is 1300 and the maximum value is 8896. The suggested value is 1500, which is the default MTU used on the Internet, or 8896 if you want to use Jumbo frames. If unspecified, the value defaults to 1460.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a
lowercase letter, and all following characters (except for the last
character) must be a dash, lowercase letter, or digit. The last character
must be a lowercase letter or digit.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#network_firewall_policy_enforcement_order ⇒ ::String
Returns The network firewall policy enforcement order. Can be either AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to AFTER_CLASSIC_FIREWALL if the field is not specified. Check the NetworkFirewallPolicyEnforcementOrder enum for the list of possible values.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#network_profile ⇒ ::String
Returns A full or partial URL of the network profile to apply to this network. This field can be set only at resource creation time. For example, the following are valid URLs:
- https://www.googleapis.com/compute/\{api_version}/projects/\{project_id}/global/networkProfiles/\{network_profile_name}
- projects/{project_id}/global/networkProfiles/{network_profile_name}.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#params ⇒ ::Google::Cloud::Compute::V1::NetworkParams
Returns Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#peerings ⇒ ::Array<::Google::Cloud::Compute::V1::NetworkPeering>
Returns Output only. [Output Only] A list of network peerings for the resource.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#routing_config ⇒ ::Google::Cloud::Compute::V1::NetworkRoutingConfig
Returns The network-level routing configuration for this network. Used by Cloud Router to determine what type of network-wide routing behavior to enforce.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource with the resource id.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |
#subnetworks ⇒ ::Array<::String>
Returns [Output Only] Server-defined fully-qualified URLs for all subnetworks in this VPC network.
53985 53986 53987 53988 53989 53990 53991 53992 53993 53994 53995 53996 53997 53998 53999 54000 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53985 class Network include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The network firewall policy enforcement order. Can be either # AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to # AFTER_CLASSIC_FIREWALL if the field is not specified. module NetworkFirewallPolicyEnforcementOrder # A value indicating that the enum field is not set. UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER = 0 AFTER_CLASSIC_FIREWALL = 154_582_608 BEFORE_CLASSIC_FIREWALL = 338_458_349 end end |