Class: Google::Cloud::Compute::V1::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ ::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String) —

    [Output Only] Unique identifier for the resource; defined by the server.



57210
57211
57212
57213
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57210

class NetworkAttachmentList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#items ⇒ ::Array<::Google::Cloud::Compute::V1::NetworkAttachment>

Returns A list of NetworkAttachment resources.

Returns:



57210
57211
57212
57213
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57210

class NetworkAttachmentList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind ⇒ ::String

Returns:

  • (::String)


57210
57211
57212
57213
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57210

class NetworkAttachmentList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token ⇒ ::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String) —

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



57210
57211
57212
57213
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57210

class NetworkAttachmentList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns [Output Only] Server-defined URL for this resource.

Returns:

  • (::String) —

    [Output Only] Server-defined URL for this resource.



57210
57211
57212
57213
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57210

class NetworkAttachmentList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



57210
57211
57212
57213
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57210

class NetworkAttachmentList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end