Class: Google::Cloud::Compute::V1::NetworkEndpointGroupCloudFunction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask. Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG.

Instance Attribute Summary collapse

Instance Attribute Details

#function::String



21757
21758
21759
21760
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21757

class NetworkEndpointGroupCloudFunction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#url_mask::String



21757
21758
21759
21760
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21757

class NetworkEndpointGroupCloudFunction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end