Class: Google::Cloud::Compute::V1::NetworkEndpointGroupCloudRun
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkEndpointGroupCloudRun
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask.
Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#service ⇒ ::String
Cloud Run service is the main resource of Cloud Run.
-
#tag ⇒ ::String
Optional Cloud Run tag represents the "named-revision" to provide additional fine-grained traffic routing information.
-
#url_mask ⇒ ::String
An URL mask is one of the main components of the Cloud Function.
Instance Attribute Details
#service ⇒ ::String
Returns Cloud Run service is the main resource of Cloud Run.
The service must be 1-63 characters long, and comply withRFC1035.
Example value: "run-service".
54690 54691 54692 54693 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54690 class NetworkEndpointGroupCloudRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tag ⇒ ::String
Returns Optional Cloud Run tag represents the "named-revision" to provide additional fine-grained traffic routing information.
The tag must be 1-63 characters long, and comply withRFC1035.
Example value: "revision-0010".
54690 54691 54692 54693 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54690 class NetworkEndpointGroupCloudRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#url_mask ⇒ ::String
Returns An URL mask is one of the main components of the Cloud Function.
A template to parse
For example, request URLs foo1.domain.com/bar1 andfoo1.domain.com/bar2 can be backed by the same Serverless
Network Endpoint Group (NEG) with URL mask
54690 54691 54692 54693 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54690 class NetworkEndpointGroupCloudRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |