Class: Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#network_endpoint_groups ⇒ ::Array<::Google::Cloud::Compute::V1::NetworkEndpointGroup>

Returns Output only. [Output Only] The list ofnetwork endpoint groups that are contained in this scope.

Returns:



57863
57864
57865
57866
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57863

class NetworkEndpointGroupsScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns Output only. [Output Only] An informational warning that replaces the list of network endpoint groups when the list is empty.

Returns:



57863
57864
57865
57866
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57863

class NetworkEndpointGroupsScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end