Class: Google::Cloud::Compute::V1::NetworkList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains a list of networks.

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ ::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String) —

    [Output Only] Unique identifier for the resource; defined by the server.



58158
58159
58160
58161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58158

class NetworkList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#items ⇒ ::Array<::Google::Cloud::Compute::V1::Network>

Returns A list of Network resources.

Returns:



58158
58159
58160
58161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58158

class NetworkList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks.

Returns:

  • (::String) —

    Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks.



58158
58159
58160
58161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58158

class NetworkList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token ⇒ ::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String) —

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



58158
58159
58160
58161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58158

class NetworkList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for this resource.



58158
58159
58160
58161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58158

class NetworkList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



58158
58159
58160
58161
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58158

class NetworkList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end