Module: Google::Cloud::Compute::V1::NetworkProfileNetworkFeatures::AllowFirewallPolicy

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specifies whether firewall policy can be attached to the network.

Constant Summary collapse

UNDEFINED_ALLOW_FIREWALL_POLICY =

A value indicating that the enum field is not set.

0
FIREWALL_POLICY_ALLOWED =
388_488_346
FIREWALL_POLICY_BLOCKED =
204_651_742