Class: Google::Cloud::Compute::V1::NetworkRoutingConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.

Defined Under Namespace

Modules: BgpBestPathSelectionMode, BgpInterRegionCost, EffectiveBgpInterRegionCost, RoutingMode

Instance Attribute Summary collapse

Instance Attribute Details

#bgp_always_compare_med ⇒ ::Boolean

Returns Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.

Returns:

  • (::Boolean) —

    Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.



59288
59289
59290
59291
59292
59293
59294
59295
59296
59297
59298
59299
59300
59301
59302
59303
59304
59305
59306
59307
59308
59309
59310
59311
59312
59313
59314
59315
59316
59317
59318
59319
59320
59321
59322
59323
59324
59325
59326
59327
59328
59329
59330
59331
59332
59333
59334
59335
59336
59337
59338
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59288

class NetworkRoutingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BGP best path selection algorithm to be employed within this network
  # for dynamic routes learned by Cloud Routers. Can be LEGACY
  # (default) or STANDARD.
  module BgpBestPathSelectionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0

    LEGACY = 94_234_569

    STANDARD = 484_642_493
  end

  # Allows to define a preferred approach for handling inter-region cost in
  # the selection process when using the STANDARD BGP best path
  # selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
  module BgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_INTER_REGION_COST = 0

    ADD_COST_TO_MED = 490_583_004

    DEFAULT = 115_302_945
  end

  # Output only. [Output Only] Effective value of the bgp_inter_region_cost
  # field.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # ADD_COST_TO_MED
  # DEFAULT
  module EffectiveBgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0
  end

  # The network-wide routing mode to use. If set to REGIONAL,
  # this network's Cloud Routers will only advertise routes with subnets
  # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise
  # routes with all subnets of this network, across regions.
  module RoutingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ROUTING_MODE = 0

    GLOBAL = 494_663_587

    REGIONAL = 92_288_543
  end
end

#bgp_best_path_selection_mode ⇒ ::String

Returns The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. Check the BgpBestPathSelectionMode enum for the list of possible values.

Returns:

  • (::String) —

    The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. Check the BgpBestPathSelectionMode enum for the list of possible values.



59288
59289
59290
59291
59292
59293
59294
59295
59296
59297
59298
59299
59300
59301
59302
59303
59304
59305
59306
59307
59308
59309
59310
59311
59312
59313
59314
59315
59316
59317
59318
59319
59320
59321
59322
59323
59324
59325
59326
59327
59328
59329
59330
59331
59332
59333
59334
59335
59336
59337
59338
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59288

class NetworkRoutingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BGP best path selection algorithm to be employed within this network
  # for dynamic routes learned by Cloud Routers. Can be LEGACY
  # (default) or STANDARD.
  module BgpBestPathSelectionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0

    LEGACY = 94_234_569

    STANDARD = 484_642_493
  end

  # Allows to define a preferred approach for handling inter-region cost in
  # the selection process when using the STANDARD BGP best path
  # selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
  module BgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_INTER_REGION_COST = 0

    ADD_COST_TO_MED = 490_583_004

    DEFAULT = 115_302_945
  end

  # Output only. [Output Only] Effective value of the bgp_inter_region_cost
  # field.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # ADD_COST_TO_MED
  # DEFAULT
  module EffectiveBgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0
  end

  # The network-wide routing mode to use. If set to REGIONAL,
  # this network's Cloud Routers will only advertise routes with subnets
  # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise
  # routes with all subnets of this network, across regions.
  module RoutingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ROUTING_MODE = 0

    GLOBAL = 494_663_587

    REGIONAL = 92_288_543
  end
end

#bgp_inter_region_cost ⇒ ::String

Returns Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT orADD_COST_TO_MED. Check the BgpInterRegionCost enum for the list of possible values.

Returns:

  • (::String) —

    Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT orADD_COST_TO_MED. Check the BgpInterRegionCost enum for the list of possible values.



59288
59289
59290
59291
59292
59293
59294
59295
59296
59297
59298
59299
59300
59301
59302
59303
59304
59305
59306
59307
59308
59309
59310
59311
59312
59313
59314
59315
59316
59317
59318
59319
59320
59321
59322
59323
59324
59325
59326
59327
59328
59329
59330
59331
59332
59333
59334
59335
59336
59337
59338
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59288

class NetworkRoutingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BGP best path selection algorithm to be employed within this network
  # for dynamic routes learned by Cloud Routers. Can be LEGACY
  # (default) or STANDARD.
  module BgpBestPathSelectionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0

    LEGACY = 94_234_569

    STANDARD = 484_642_493
  end

  # Allows to define a preferred approach for handling inter-region cost in
  # the selection process when using the STANDARD BGP best path
  # selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
  module BgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_INTER_REGION_COST = 0

    ADD_COST_TO_MED = 490_583_004

    DEFAULT = 115_302_945
  end

  # Output only. [Output Only] Effective value of the bgp_inter_region_cost
  # field.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # ADD_COST_TO_MED
  # DEFAULT
  module EffectiveBgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0
  end

  # The network-wide routing mode to use. If set to REGIONAL,
  # this network's Cloud Routers will only advertise routes with subnets
  # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise
  # routes with all subnets of this network, across regions.
  module RoutingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ROUTING_MODE = 0

    GLOBAL = 494_663_587

    REGIONAL = 92_288_543
  end
end

#effective_bgp_always_compare_med ⇒ ::Boolean

Returns Output only. [Output Only] Effective value of the bgp_always_compare_med field.

Returns:

  • (::Boolean) —

    Output only. [Output Only] Effective value of the bgp_always_compare_med field.



59288
59289
59290
59291
59292
59293
59294
59295
59296
59297
59298
59299
59300
59301
59302
59303
59304
59305
59306
59307
59308
59309
59310
59311
59312
59313
59314
59315
59316
59317
59318
59319
59320
59321
59322
59323
59324
59325
59326
59327
59328
59329
59330
59331
59332
59333
59334
59335
59336
59337
59338
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59288

class NetworkRoutingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BGP best path selection algorithm to be employed within this network
  # for dynamic routes learned by Cloud Routers. Can be LEGACY
  # (default) or STANDARD.
  module BgpBestPathSelectionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0

    LEGACY = 94_234_569

    STANDARD = 484_642_493
  end

  # Allows to define a preferred approach for handling inter-region cost in
  # the selection process when using the STANDARD BGP best path
  # selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
  module BgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_INTER_REGION_COST = 0

    ADD_COST_TO_MED = 490_583_004

    DEFAULT = 115_302_945
  end

  # Output only. [Output Only] Effective value of the bgp_inter_region_cost
  # field.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # ADD_COST_TO_MED
  # DEFAULT
  module EffectiveBgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0
  end

  # The network-wide routing mode to use. If set to REGIONAL,
  # this network's Cloud Routers will only advertise routes with subnets
  # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise
  # routes with all subnets of this network, across regions.
  module RoutingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ROUTING_MODE = 0

    GLOBAL = 494_663_587

    REGIONAL = 92_288_543
  end
end

#effective_bgp_inter_region_cost ⇒ ::String

Returns Output only. [Output Only] Effective value of the bgp_inter_region_cost field. Check the EffectiveBgpInterRegionCost enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] Effective value of the bgp_inter_region_cost field. Check the EffectiveBgpInterRegionCost enum for the list of possible values.



59288
59289
59290
59291
59292
59293
59294
59295
59296
59297
59298
59299
59300
59301
59302
59303
59304
59305
59306
59307
59308
59309
59310
59311
59312
59313
59314
59315
59316
59317
59318
59319
59320
59321
59322
59323
59324
59325
59326
59327
59328
59329
59330
59331
59332
59333
59334
59335
59336
59337
59338
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59288

class NetworkRoutingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BGP best path selection algorithm to be employed within this network
  # for dynamic routes learned by Cloud Routers. Can be LEGACY
  # (default) or STANDARD.
  module BgpBestPathSelectionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0

    LEGACY = 94_234_569

    STANDARD = 484_642_493
  end

  # Allows to define a preferred approach for handling inter-region cost in
  # the selection process when using the STANDARD BGP best path
  # selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
  module BgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_INTER_REGION_COST = 0

    ADD_COST_TO_MED = 490_583_004

    DEFAULT = 115_302_945
  end

  # Output only. [Output Only] Effective value of the bgp_inter_region_cost
  # field.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # ADD_COST_TO_MED
  # DEFAULT
  module EffectiveBgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0
  end

  # The network-wide routing mode to use. If set to REGIONAL,
  # this network's Cloud Routers will only advertise routes with subnets
  # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise
  # routes with all subnets of this network, across regions.
  module RoutingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ROUTING_MODE = 0

    GLOBAL = 494_663_587

    REGIONAL = 92_288_543
  end
end

#routing_mode ⇒ ::String

Returns The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. Check the RoutingMode enum for the list of possible values.

Returns:

  • (::String) —

    The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. Check the RoutingMode enum for the list of possible values.



59288
59289
59290
59291
59292
59293
59294
59295
59296
59297
59298
59299
59300
59301
59302
59303
59304
59305
59306
59307
59308
59309
59310
59311
59312
59313
59314
59315
59316
59317
59318
59319
59320
59321
59322
59323
59324
59325
59326
59327
59328
59329
59330
59331
59332
59333
59334
59335
59336
59337
59338
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59288

class NetworkRoutingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BGP best path selection algorithm to be employed within this network
  # for dynamic routes learned by Cloud Routers. Can be LEGACY
  # (default) or STANDARD.
  module BgpBestPathSelectionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0

    LEGACY = 94_234_569

    STANDARD = 484_642_493
  end

  # Allows to define a preferred approach for handling inter-region cost in
  # the selection process when using the STANDARD BGP best path
  # selection algorithm. Can be DEFAULT orADD_COST_TO_MED.
  module BgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_BGP_INTER_REGION_COST = 0

    ADD_COST_TO_MED = 490_583_004

    DEFAULT = 115_302_945
  end

  # Output only. [Output Only] Effective value of the bgp_inter_region_cost
  # field.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # ADD_COST_TO_MED
  # DEFAULT
  module EffectiveBgpInterRegionCost
    # A value indicating that the enum field is not set.
    UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0
  end

  # The network-wide routing mode to use. If set to REGIONAL,
  # this network's Cloud Routers will only advertise routes with subnets
  # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise
  # routes with all subnets of this network, across regions.
  module RoutingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ROUTING_MODE = 0

    GLOBAL = 494_663_587

    REGIONAL = 92_288_543
  end
end