Class: Google::Cloud::Compute::V1::NetworksCancelRequestRemovePeeringRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Name of the peering, which should conform to RFC1035.

Returns:

  • (::String)

    Name of the peering, which should conform to RFC1035.



57428
57429
57430
57431
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57428

class NetworksCancelRequestRemovePeeringRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end