Class: Google::Cloud::Compute::V1::NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
[Output Only] Deprecated, please use short name instead.
-
#name ⇒ ::String
[Output Only] The name of the firewall policy.
-
#packet_mirroring_rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
[Output Only] The packet mirroring rules that apply to the network.
-
#priority ⇒ ::Integer
[Output only] Priority of firewall policy association.
-
#rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
[Output Only] The rules that apply to the network.
-
#short_name ⇒ ::String
[Output Only] The short name of the firewall policy.
-
#type ⇒ ::String
[Output Only] The type of the firewall policy.
Instance Attribute Details
#display_name ⇒ ::String
Returns [Output Only] Deprecated, please use short name instead. The display name of the firewall policy.
24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 24723 24724 24725 24726 24727 24728 24729 24730 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24713 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#name ⇒ ::String
Returns [Output Only] The name of the firewall policy.
24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 24723 24724 24725 24726 24727 24728 24729 24730 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24713 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#packet_mirroring_rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
Returns [Output Only] The packet mirroring rules that apply to the network.
24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 24723 24724 24725 24726 24727 24728 24729 24730 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24713 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#priority ⇒ ::Integer
Returns [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.
24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 24723 24724 24725 24726 24727 24728 24729 24730 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24713 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
Returns [Output Only] The rules that apply to the network.
24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 24723 24724 24725 24726 24727 24728 24729 24730 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24713 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#short_name ⇒ ::String
Returns [Output Only] The short name of the firewall policy.
24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 24723 24724 24725 24726 24727 24728 24729 24730 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24713 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#type ⇒ ::String
Returns [Output Only] The type of the firewall policy. Check the Type enum for the list of possible values.
24713 24714 24715 24716 24717 24718 24719 24720 24721 24722 24723 24724 24725 24726 24727 24728 24729 24730 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24713 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |