Class: Google::Cloud::Compute::V1::NodeGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a sole-tenant Node Group resource.

A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, readSole-tenant nodes.

Defined Under Namespace

Modules: MaintenanceInterval, MaintenancePolicy, Status

Instance Attribute Summary collapse

Instance Attribute Details

#autoscaling_policy ⇒ ::Google::Cloud::Compute::V1::NodeGroupAutoscalingPolicy

Returns Specifies how autoscaling should behave.

Returns:



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#creation_timestamp ⇒ ::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String) —

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#description ⇒ ::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String) —

    An optional description of this resource. Provide this property when you create the resource.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#fingerprint ⇒ ::String

Returns:

  • (::String)


59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#id ⇒ ::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer) —

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] The type of the resource. Alwayscompute#nodeGroup for node group.

Returns:

  • (::String) —

    Output only. [Output Only] The type of the resource. Alwayscompute#nodeGroup for node group.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#location_hint ⇒ ::String

Returns An opaque location hint used to place the Node close to other resources. This field is for use by internal tools that use the public API. The location hint here on the NodeGroup overrides any location_hint present in the NodeTemplate.

Returns:

  • (::String) —

    An opaque location hint used to place the Node close to other resources. This field is for use by internal tools that use the public API. The location hint here on the NodeGroup overrides any location_hint present in the NodeTemplate.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#maintenance_interval ⇒ ::String

Returns Specifies the frequency of planned maintenance events. The accepted values are: AS_NEEDED and RECURRENT. Check the MaintenanceInterval enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the frequency of planned maintenance events. The accepted values are: AS_NEEDED and RECURRENT. Check the MaintenanceInterval enum for the list of possible values.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#maintenance_policy ⇒ ::String

Returns Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies. Check the MaintenancePolicy enum for the list of possible values.

Returns:

  • (::String) —

    Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies. Check the MaintenancePolicy enum for the list of possible values.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#maintenance_window ⇒ ::Google::Cloud::Compute::V1::NodeGroupMaintenanceWindow



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#name ⇒ ::String

Returns The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String) —

    The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#node_template ⇒ ::String

Returns URL of the node template to create the node group from.

Returns:

  • (::String) —

    URL of the node template to create the node group from.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for the resource.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#share_settings ⇒ ::Google::Cloud::Compute::V1::ShareSettings

Returns Share-settings for the node group.

Returns:



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#size ⇒ ::Integer

Returns Output only. [Output Only] The total number of nodes in the node group.

Returns:

  • (::Integer) —

    Output only. [Output Only] The total number of nodes in the node group.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#status ⇒ ::String

Returns Check the Status enum for the list of possible values.

Returns:

  • (::String) —

    Check the Status enum for the list of possible values.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end

#zone ⇒ ::String

Returns Output only. [Output Only] The name of the zone where the node group resides, such as us-central1-a.

Returns:

  • (::String) —

    Output only. [Output Only] The name of the zone where the node group resides, such as us-central1-a.



59535
59536
59537
59538
59539
59540
59541
59542
59543
59544
59545
59546
59547
59548
59549
59550
59551
59552
59553
59554
59555
59556
59557
59558
59559
59560
59561
59562
59563
59564
59565
59566
59567
59568
59569
59570
59571
59572
59573
59574
59575
59576
59577
59578
59579
59580
59581
59582
59583
59584
59585
59586
59587
59588
59589
59590
59591
59592
59593
59594
59595
59596
59597
59598
59599
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59535

class NodeGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the frequency of planned maintenance events. The accepted values
  # are: `AS_NEEDED` and `RECURRENT`.
  module MaintenanceInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_INTERVAL = 0

    # VMs are eligible to receive infrastructure and hypervisor updates as they
    # become available.  This may result in more maintenance operations (live
    # migrations or terminations) for the VM than the PERIODIC andRECURRENT options.
    AS_NEEDED = 500_724_834

    # VMs receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean a VM will take longer
    # to receive an update than if it was configured forAS_NEEDED.  Security updates will still be applied as soon
    # as they are available. RECURRENT is used for GEN3 and Slice
    # of Hardware VMs.
    RECURRENT = 194_244_550
  end

  # Specifies how to handle instances when a node in the group undergoes
  # maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP.
  # The default value is DEFAULT. For more information, see
  # Maintenance policies.
  module MaintenancePolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_POLICY = 0

    # Allow the node and corresponding instances to retain default
    # maintenance behavior.
    DEFAULT = 115_302_945

    MAINTENANCE_POLICY_UNSPECIFIED = 72_964_182

    # When maintenance must be done on a node, the instances on that node will
    # be moved to other nodes in the group.
    # Instances with onHostMaintenance = MIGRATE will live migrate to their
    # destinations while instances with onHostMaintenance = TERMINATE will
    # terminate and then restart on their destination nodes if
    # automaticRestart = true.
    MIGRATE_WITHIN_NODE_GROUP = 153_483_394

    # Instances in this group will restart on the same node when maintenance
    # has completed. Instances must have onHostMaintenance = TERMINATE, and
    # they will only restart if automaticRestart = true.
    RESTART_IN_PLACE = 228_647_325
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963
  end
end