Class: Google::Cloud::Compute::V1::NodeGroupAutoscalingPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Attribute Details

#max_nodes ⇒ ::Integer

Returns The maximum number of nodes that the group should have. Must be set if autoscaling is enabled. Maximum value allowed is 100.

Returns:

  • (::Integer) —

    The maximum number of nodes that the group should have. Must be set if autoscaling is enabled. Maximum value allowed is 100.



59654
59655
59656
59657
59658
59659
59660
59661
59662
59663
59664
59665
59666
59667
59668
59669
59670
59671
59672
59673
59674
59675
59676
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59654

class NodeGroupAutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The autoscaling mode. Set to one of: ON, OFF,
  # or ONLY_SCALE_OUT. For more information, see
  # Autoscaler modes.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    MODE_UNSPECIFIED = 371_348_091

    # Autoscaling is disabled.
    OFF = 78_159

    # Autocaling is fully enabled.
    ON = 2527

    # Autoscaling will only scale out and will not remove nodes.
    ONLY_SCALE_OUT = 152_713_670
  end
end

#min_nodes ⇒ ::Integer

Returns The minimum number of nodes that the group should have.

Returns:

  • (::Integer) —

    The minimum number of nodes that the group should have.



59654
59655
59656
59657
59658
59659
59660
59661
59662
59663
59664
59665
59666
59667
59668
59669
59670
59671
59672
59673
59674
59675
59676
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59654

class NodeGroupAutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The autoscaling mode. Set to one of: ON, OFF,
  # or ONLY_SCALE_OUT. For more information, see
  # Autoscaler modes.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    MODE_UNSPECIFIED = 371_348_091

    # Autoscaling is disabled.
    OFF = 78_159

    # Autocaling is fully enabled.
    ON = 2527

    # Autoscaling will only scale out and will not remove nodes.
    ONLY_SCALE_OUT = 152_713_670
  end
end

#mode ⇒ ::String

Returns The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For more information, see Autoscaler modes. Check the Mode enum for the list of possible values.

Returns:

  • (::String) —

    The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For more information, see Autoscaler modes. Check the Mode enum for the list of possible values.



59654
59655
59656
59657
59658
59659
59660
59661
59662
59663
59664
59665
59666
59667
59668
59669
59670
59671
59672
59673
59674
59675
59676
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59654

class NodeGroupAutoscalingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The autoscaling mode. Set to one of: ON, OFF,
  # or ONLY_SCALE_OUT. For more information, see
  # Autoscaler modes.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    MODE_UNSPECIFIED = 371_348_091

    # Autoscaling is disabled.
    OFF = 78_159

    # Autocaling is fully enabled.
    ON = 2527

    # Autoscaling will only scale out and will not remove nodes.
    ONLY_SCALE_OUT = 152_713_670
  end
end