Class: Google::Cloud::Compute::V1::NodeGroupsSimulateMaintenanceEventRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#nodes ⇒ ::Array<::String>

Returns Names of the nodes to go under maintenance simulation.

Returns:

  • (::Array<::String>) —

    Names of the nodes to go under maintenance simulation.



59877
59878
59879
59880
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59877

class NodeGroupsSimulateMaintenanceEventRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end