Class: Google::Cloud::Compute::V1::NodeTemplateList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains a list of node templates.

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ ::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • [Output Only] Unique identifier for the resource; defined by the server.



60065
60066
60067
60068
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60065

class NodeTemplateList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#items ⇒ ::Array<::Google::Cloud::Compute::V1::NodeTemplate>

Returns A list of NodeTemplate resources.

Returns:

  • A list of NodeTemplate resources.



60065
60066
60067
60068
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60065

class NodeTemplateList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates.

Returns:

  • Output only. [Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates.



60065
60066
60067
60068
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60065

class NodeTemplateList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token ⇒ ::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



60065
60066
60067
60068
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60065

class NodeTemplateList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • Output only. [Output Only] Server-defined URL for this resource.



60065
60066
60067
60068
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60065

class NodeTemplateList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:

  • [Output Only] Informational warning message.



60065
60066
60067
60068
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60065

class NodeTemplateList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end