Class: Google::Cloud::Compute::V1::NodeType

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represent a sole-tenant Node Type resource.

Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.

Instance Attribute Summary collapse

Instance Attribute Details

#cpu_platform ⇒ ::String

Returns [Output Only] The CPU platform used by this node type.

Returns:

  • (::String) —

    [Output Only] The CPU platform used by this node type.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#creation_timestamp ⇒ ::String

Returns [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String) —

    [Output Only] Creation timestamp inRFC3339 text format.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deprecated ⇒ ::Google::Cloud::Compute::V1::DeprecationStatus

Returns [Output Only] The deprecation status associated with this node type.

Returns:



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description ⇒ ::String

Returns [Output Only] An optional textual description of the resource.

Returns:

  • (::String) —

    [Output Only] An optional textual description of the resource.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#guest_cpus ⇒ ::Integer

Returns [Output Only] The number of virtual CPUs that are available to the node type.

Returns:

  • (::Integer) —

    [Output Only] The number of virtual CPUs that are available to the node type.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id ⇒ ::Integer

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer) —

    [Output Only] The unique identifier for the resource. This identifier is defined by the server.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind ⇒ ::String

Returns Output only. [Output Only] The type of the resource. Alwayscompute#nodeType for node types.

Returns:

  • (::String) —

    Output only. [Output Only] The type of the resource. Alwayscompute#nodeType for node types.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#local_ssd_gb ⇒ ::Integer

Returns [Output Only] Local SSD available to the node type, defined in GB.

Returns:

  • (::Integer) —

    [Output Only] Local SSD available to the node type, defined in GB.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_vms ⇒ ::Integer

Returns Output only. [Output Only] Maximum number of VMs that can be created for this node type.

Returns:

  • (::Integer) —

    Output only. [Output Only] Maximum number of VMs that can be created for this node type.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#memory_mb ⇒ ::Integer

Returns [Output Only] The amount of physical memory available to the node type, defined in MB.

Returns:

  • (::Integer) —

    [Output Only] The amount of physical memory available to the node type, defined in MB.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String

Returns [Output Only] Name of the resource.

Returns:

  • (::String) —

    [Output Only] Name of the resource.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for the resource.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone ⇒ ::String

Returns Output only. [Output Only] The name of the zone where the node type resides, such as us-central1-a.

Returns:

  • (::String) —

    Output only. [Output Only] The name of the zone where the node type resides, such as us-central1-a.



60144
60145
60146
60147
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60144

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end