Class: Google::Cloud::Compute::V1::NotificationEndpoint
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NotificationEndpoint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a notification endpoint.
A notification endpoint resource defines an endpoint to receive notifications when there are status changes detected by the associated health check service.
For more information, see Health checks overview.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#grpc_settings ⇒ ::Google::Cloud::Compute::V1::NotificationEndpointGrpcSettings
Settings of the gRPC notification endpoint including the endpoint URL and the retry duration.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
58329 58330 58331 58332 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58329 class NotificationEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
58329 58330 58331 58332 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58329 class NotificationEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#grpc_settings ⇒ ::Google::Cloud::Compute::V1::NotificationEndpointGrpcSettings
Returns Settings of the gRPC notification endpoint including the endpoint URL and the retry duration.
58329 58330 58331 58332 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58329 class NotificationEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
Returns Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier.
58329 58330 58331 58332 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58329 class NotificationEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#notificationEndpoint for notification endpoints.
58329 58330 58331 58332 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58329 class NotificationEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
58329 58330 58331 58332 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58329 class NotificationEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the notification endpoint resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
58329 58330 58331 58332 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58329 class NotificationEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
58329 58330 58331 58332 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58329 class NotificationEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |