Class: Google::Cloud::Compute::V1::Operation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents an Operation resource.

Google Compute Engine has three Operation resources:

You can use an operation resource to manage asynchronous API requests. For more information, readHandling API responses.

Operations can be global, regional or zonal.

- For global operations, use the `globalOperations`
resource.
- For regional operations, use the
`regionOperations` resource.
- For zonal operations, use
the `zoneOperations` resource.

For more information, read Global, Regional, and Zonal Resources.

Note that completed Operation resources have a limited retention period.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#client_operation_id ⇒ ::String

Returns [Output Only] The value of requestId if you provided it in the request. Not present otherwise.

Returns:

  • (::String) —

    [Output Only] The value of requestId if you provided it in the request. Not present otherwise.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#creation_timestamp ⇒ ::String

Returns [Deprecated] This field is deprecated.

Returns:

  • (::String) —

    [Deprecated] This field is deprecated.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#description ⇒ ::String

Returns [Output Only] A textual description of the operation, which is set when the operation is created.

Returns:

  • (::String) —

    [Output Only] A textual description of the operation, which is set when the operation is created.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#end_time ⇒ ::String

Returns [Output Only] The time that this operation was completed. This value is inRFC3339 text format.

Returns:

  • (::String) —

    [Output Only] The time that this operation was completed. This value is inRFC3339 text format.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#error ⇒ ::Google::Cloud::Compute::V1::Error

Returns [Output Only] If errors are generated during processing of the operation, this field will be populated.

Returns:



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#get_health_operation_metadata ⇒ ::Google::Cloud::Compute::V1::GetHealthOperationMetadata

Returns Output only. Metadata for GetHealth operations.

Returns:



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#get_version_operation_metadata ⇒ ::Google::Cloud::Compute::V1::GetVersionOperationMetadata



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#http_error_message ⇒ ::String

Returns [Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND.

Returns:

  • (::String) —

    [Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#http_error_status_code ⇒ ::Integer

Returns [Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a 404 means the resource was not found.

Returns:

  • (::Integer) —

    [Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a 404 means the resource was not found.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#id ⇒ ::Integer

Returns [Output Only] The unique identifier for the operation. This identifier is defined by the server.

Returns:

  • (::Integer) —

    [Output Only] The unique identifier for the operation. This identifier is defined by the server.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#insert_time ⇒ ::String

Returns [Output Only] The time that this operation was requested. This value is inRFC3339 text format.

Returns:

  • (::String) —

    [Output Only] The time that this operation was requested. This value is inRFC3339 text format.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#instances_bulk_insert_operation_metadata ⇒ ::Google::Cloud::Compute::V1::InstancesBulkInsertOperationMetadata



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of the resource. Always compute#operation for Operation resources.

Returns:

  • (::String) —

    Output only. [Output Only] Type of the resource. Always compute#operation for Operation resources.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#name ⇒ ::String

Returns [Output Only] Name of the operation.

Returns:

  • (::String) —

    [Output Only] Name of the operation.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#operation_group_id ⇒ ::String

Returns Output only. [Output Only] An ID that represents a group of operations, such as when a group of operations results from a bulkInsert API request.

Returns:

  • (::String) —

    Output only. [Output Only] An ID that represents a group of operations, such as when a group of operations results from a bulkInsert API request.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#operation_type ⇒ ::String

Returns [Output Only] The type of operation, such as insert, update, or delete, and so on.

Returns:

  • (::String) —

    [Output Only] The type of operation, such as insert, update, or delete, and so on.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#progress ⇒ ::Integer

Returns [Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses.

Returns:

  • (::Integer) —

    [Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#region ⇒ ::String

Returns [Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations.

Returns:

  • (::String) —

    [Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String) —

    [Output Only] Server-defined URL for the resource.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#set_common_instance_metadata_operation_metadata ⇒ ::Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadata

Returns Output only. [Output Only] If the operation is for projects.setCommonInstanceMetadata, this field will contain information on all underlying zonal actions and their state.

Returns:



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#start_time ⇒ ::String

Returns [Output Only] The time that this operation was started by the server. This value is inRFC3339 text format.

Returns:

  • (::String) —

    [Output Only] The time that this operation was started by the server. This value is inRFC3339 text format.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#status ⇒ ::Google::Cloud::Compute::V1::Operation::Status

Returns [Output Only] The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE.

Returns:



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#status_message ⇒ ::String

Returns [Output Only] An optional textual description of the current status of the operation.

Returns:

  • (::String) —

    [Output Only] An optional textual description of the current status of the operation.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#target_id ⇒ ::Integer

Returns [Output Only] The unique target ID, which identifies a specific incarnation of the target resource.

Returns:

  • (::Integer) —

    [Output Only] The unique target ID, which identifies a specific incarnation of the target resource.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

Returns [Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the disk that the snapshot was created from.

Returns:

  • (::String) —

    [Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the disk that the snapshot was created from.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#user ⇒ ::String

Returns [Output Only] User who requested the operation, for example: [email protected] or alice_smith_identifier (global/workforcePools/example-com-us-employees).

Returns:

  • (::String) —

    [Output Only] User who requested the operation, for example: [email protected] or alice_smith_identifier (global/workforcePools/example-com-us-employees).



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#warnings ⇒ ::Array<::Google::Cloud::Compute::V1::Warnings>

Returns [Output Only] If warning messages are generated during processing of the operation, this field will be populated.

Returns:



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end

#zone ⇒ ::String

Returns [Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations.

Returns:

  • (::String) —

    [Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations.



60533
60534
60535
60536
60537
60538
60539
60540
60541
60542
60543
60544
60545
60546
60547
60548
60549
60550
60551
60552
60553
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60533

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the operation, which can be one of the
  # following:
  # `PENDING`, `RUNNING`, or `DONE`.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The operation has completed processing successfully or with an error.
    DONE = 2_104_194

    # The operation is waiting to be processed.
    PENDING = 35_394_935

    # The operation is actively being processed.
    RUNNING = 121_282_975
  end
end