Module: Google::Cloud::Compute::V1::Operation::Status

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE.

Constant Summary collapse

UNDEFINED_STATUS =

A value indicating that the enum field is not set.

0
DONE =

The operation has completed processing successfully or with an error.

2_104_194
PENDING =

The operation is waiting to be processed.

35_394_935
RUNNING =

The operation is actively being processed.

121_282_975