Class: Google::Cloud::Compute::V1::PacketIntervals

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Next free: 7

Defined Under Namespace

Modules: Duration, Type

Instance Attribute Summary collapse

Instance Attribute Details

#avg_ms ⇒ ::Integer

Returns Average observed inter-packet interval in milliseconds.

Returns:

  • (::Integer) —

    Average observed inter-packet interval in milliseconds.



60757
60758
60759
60760
60761
60762
60763
60764
60765
60766
60767
60768
60769
60770
60771
60772
60773
60774
60775
60776
60777
60778
60779
60780
60781
60782
60783
60784
60785
60786
60787
60788
60789
60790
60791
60792
60793
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60757

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#duration ⇒ ::String

Returns From how long ago in the past these intervals were observed. Check the Duration enum for the list of possible values.

Returns:

  • (::String) —

    From how long ago in the past these intervals were observed. Check the Duration enum for the list of possible values.



60757
60758
60759
60760
60761
60762
60763
60764
60765
60766
60767
60768
60769
60770
60771
60772
60773
60774
60775
60776
60777
60778
60779
60780
60781
60782
60783
60784
60785
60786
60787
60788
60789
60790
60791
60792
60793
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60757

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#max_ms ⇒ ::Integer

Returns Maximum observed inter-packet interval in milliseconds.

Returns:

  • (::Integer) —

    Maximum observed inter-packet interval in milliseconds.



60757
60758
60759
60760
60761
60762
60763
60764
60765
60766
60767
60768
60769
60770
60771
60772
60773
60774
60775
60776
60777
60778
60779
60780
60781
60782
60783
60784
60785
60786
60787
60788
60789
60790
60791
60792
60793
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60757

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#min_ms ⇒ ::Integer

Returns Minimum observed inter-packet interval in milliseconds.

Returns:

  • (::Integer) —

    Minimum observed inter-packet interval in milliseconds.



60757
60758
60759
60760
60761
60762
60763
60764
60765
60766
60767
60768
60769
60770
60771
60772
60773
60774
60775
60776
60777
60778
60779
60780
60781
60782
60783
60784
60785
60786
60787
60788
60789
60790
60791
60792
60793
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60757

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#num_intervals ⇒ ::Integer

Returns Number of inter-packet intervals from which these statistics were derived.

Returns:

  • (::Integer) —

    Number of inter-packet intervals from which these statistics were derived.



60757
60758
60759
60760
60761
60762
60763
60764
60765
60766
60767
60768
60769
60770
60771
60772
60773
60774
60775
60776
60777
60778
60779
60780
60781
60782
60783
60784
60785
60786
60787
60788
60789
60790
60791
60792
60793
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60757

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#type ⇒ ::String

Returns The type of packets for which inter-packet intervals were computed. Check the Type enum for the list of possible values.

Returns:

  • (::String) —

    The type of packets for which inter-packet intervals were computed. Check the Type enum for the list of possible values.



60757
60758
60759
60760
60761
60762
60763
60764
60765
60766
60767
60768
60769
60770
60771
60772
60773
60774
60775
60776
60777
60778
60779
60780
60781
60782
60783
60784
60785
60786
60787
60788
60789
60790
60791
60792
60793
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60757

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end