Class: Google::Cloud::Compute::V1::PacketMirroringMirroredResourceInfoInstanceInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#canonical_url ⇒ ::String

Returns Output only. [Output Only] Unique identifier for the instance; defined by the server.

Returns:

  • (::String) —

    Output only. [Output Only] Unique identifier for the instance; defined by the server.



61041
61042
61043
61044
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61041

class PacketMirroringMirroredResourceInfoInstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#url ⇒ ::String

Returns Resource URL to the virtual machine instance which is being mirrored.

Returns:

  • (::String) —

    Resource URL to the virtual machine instance which is being mirrored.



61041
61042
61043
61044
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61041

class PacketMirroringMirroredResourceInfoInstanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end