Class: Google::Cloud::Compute::V1::PatchCrossSiteNetworkRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for CrossSiteNetworks.Patch. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#cross_site_network::String

Returns Name of the cross-site network to update.

Returns:

  • (::String)

    Name of the cross-site network to update.



58169
58170
58171
58172
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58169

class PatchCrossSiteNetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cross_site_network_resource::Google::Cloud::Compute::V1::CrossSiteNetwork

Returns The body resource for this request.

Returns:



58169
58170
58171
58172
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58169

class PatchCrossSiteNetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



58169
58170
58171
58172
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58169

class PatchCrossSiteNetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). end_interface: MixerMutationRequestBuilder.

Returns:

  • (::String)

    An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). end_interface: MixerMutationRequestBuilder



58169
58170
58171
58172
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58169

class PatchCrossSiteNetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::String

Returns update_mask indicates fields to be updated as part of this request.

Returns:

  • (::String)

    update_mask indicates fields to be updated as part of this request.



58169
58170
58171
58172
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58169

class PatchCrossSiteNetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns [Input Only] Validate the new configuration, but don't update it.

Returns:

  • (::Boolean)

    [Input Only] Validate the new configuration, but don't update it.



58169
58170
58171
58172
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58169

class PatchCrossSiteNetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end