Class: Google::Cloud::Compute::V1::PathMatcher
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PathMatcher
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A matcher for the path portion of the URL. The BackendService from the longest-matched rule will serve the URL. If no rule was matched, the default service is used.
Instance Attribute Summary collapse
-
#default_custom_error_response_policy ⇒ ::Google::Cloud::Compute::V1::CustomErrorResponsePolicy
DefaultCustomErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceorBackendBucket responds with an error.
-
#default_route_action ⇒ ::Google::Cloud::Compute::V1::HttpRouteAction
DefaultRouteAction takes effect when none of the pathRules or routeRules match.
-
#default_service ⇒ ::String
The full or partial URL to the BackendService resource.
-
#default_url_redirect ⇒ ::Google::Cloud::Compute::V1::HttpRedirectAction
When none of the specified pathRules orrouteRules match, the request is redirected to a URL specified by defaultUrlRedirect.
-
#description ⇒ ::String
An optional description of this resource.
-
#header_action ⇒ ::Google::Cloud::Compute::V1::HttpHeaderAction
Specifies changes to request and response headers that need to take effect for the selected backend service.
-
#name ⇒ ::String
The name to which this PathMatcher is referred by theHostRule.
-
#path_rules ⇒ ::Array<::Google::Cloud::Compute::V1::PathRule>
The list of path rules.
-
#route_rules ⇒ ::Array<::Google::Cloud::Compute::V1::HttpRouteRule>
The list of HTTP route rules.
Instance Attribute Details
#default_custom_error_response_policy ⇒ ::Google::Cloud::Compute::V1::CustomErrorResponsePolicy
Returns defaultCustomErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceorBackendBucket responds with an error.
This policy takes effect at the PathMatcher level and applies only when no policy has been defined for the error code at lower levels likeRouteRule and PathRule within thisPathMatcher. If an error code does not have a policy defined in defaultCustomErrorResponsePolicy, then a policy defined for the error code in UrlMap.defaultCustomErrorResponsePolicy takes effect.
For example, consider a UrlMap with the following configuration:
- UrlMap.defaultCustomErrorResponsePolicy is configured
with policies for 5xx and 4xx errors
- A RouteRule for /coming_soon/ is configured for the
error code 404.
If the request is for www.myotherdomain.com and a404 is encountered, the policy underUrlMap.defaultCustomErrorResponsePolicy takes effect. If a404 response is encountered for the requestwww.example.com/current_events/, the pathMatcher's policy takes effect. If however, the request forwww.example.com/coming_soon/ encounters a 404, the policy in RouteRule.customErrorResponsePolicy takes effect. If any of the requests in this example encounter a 500 error code, the policy atUrlMap.defaultCustomErrorResponsePolicy takes effect.
When used in conjunction withpathMatcher.defaultRouteAction.retryPolicy, retries take precedence. Only once all retries are exhausted, thedefaultCustomErrorResponsePolicy is applied. While attempting a retry, if load balancer is successful in reaching the service, the defaultCustomErrorResponsePolicy is ignored and the response from the service is returned to the client.
defaultCustomErrorResponsePolicy is supported only for global external Application Load Balancers.
60214 60215 60216 60217 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60214 class PathMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#default_route_action ⇒ ::Google::Cloud::Compute::V1::HttpRouteAction
Returns defaultRouteAction takes effect when none of the pathRules or routeRules match. The load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend.
Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set.
URL maps for classic Application Load Balancers only support the urlRewrite action within a path matcher'sdefaultRouteAction.
60214 60215 60216 60217 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60214 class PathMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#default_service ⇒ ::String
Returns The full or partial URL to the BackendService resource. This URL is used if none of the pathRules orrouteRules defined by this PathMatcher are matched. For example, the following are all valid URLs to a BackendService resource:
- https://www.googleapis.com/compute/v1/projects/project/global/backendServices/backendService
- compute/v1/projects/project/global/backendServices/backendService
- global/backendServices/backendService
If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend.
Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set.
Authorization requires one or more of the following Google IAM permissions on the specified resource default_service:
- compute.backendBuckets.use
- compute.backendServices.use.
60214 60215 60216 60217 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60214 class PathMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#default_url_redirect ⇒ ::Google::Cloud::Compute::V1::HttpRedirectAction
Returns When none of the specified pathRules orrouteRules match, the request is redirected to a URL specified by defaultUrlRedirect.
Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set.
Not supported when the URL map is bound to a target gRPC proxy.
60214 60215 60216 60217 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60214 class PathMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
60214 60215 60216 60217 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60214 class PathMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#header_action ⇒ ::Google::Cloud::Compute::V1::HttpHeaderAction
Returns Specifies changes to request and response headers that need to take effect for the selected backend service.
HeaderAction specified here are applied after the matchingHttpRouteRule HeaderAction and before theHeaderAction in the UrlMap
HeaderAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL.
Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
60214 60215 60216 60217 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60214 class PathMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns The name to which this PathMatcher is referred by theHostRule.
60214 60215 60216 60217 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60214 class PathMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#path_rules ⇒ ::Array<::Google::Cloud::Compute::V1::PathRule>
Returns The list of path rules. Use this list instead of routeRules when routing based on simple path matching is all that's required. A path rule can only include a wildcard character (*) after a forward slash character ("/").
The order by which path rules are specified does not matter. Matches are always done on the longest-path-first basis.
For example: a pathRule with a path /a/b/c/* will match before /a/b/* irrespective of the order in which those paths appear in this list.
Within a given pathMatcher, only one ofpathRules or routeRules must be set.
60214 60215 60216 60217 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60214 class PathMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#route_rules ⇒ ::Array<::Google::Cloud::Compute::V1::HttpRouteRule>
Returns The list of HTTP route rules. Use this list instead ofpathRules when advanced route matching and routing actions are desired. routeRules are evaluated in order of priority, from the lowest to highest number.
Within a given pathMatcher, you can set only one ofpathRules or routeRules.
60214 60215 60216 60217 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60214 class PathMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |