Class: Google::Cloud::Compute::V1::PerformMaintenanceReservationSubBlockRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for ReservationSubBlocks.PerformMaintenance. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#parent_name::String

Returns The name of the parent reservation and parent block. In the format of reservations/{reservation_name}/reservationBlocks/{reservation_block_name}.

Returns:

  • (::String)

    The name of the parent reservation and parent block. In the format of reservations/{reservation_name}/reservationBlocks/{reservation_block_name}



60518
60519
60520
60521
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60518

class PerformMaintenanceReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



60518
60519
60520
60521
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60518

class PerformMaintenanceReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



60518
60519
60520
60521
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60518

class PerformMaintenanceReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reservation_sub_block::String

Returns The name of the reservation subBlock. Name should conform to RFC1035 or be a resource ID.

Returns:

  • (::String)

    The name of the reservation subBlock. Name should conform to RFC1035 or be a resource ID.



60518
60519
60520
60521
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60518

class PerformMaintenanceReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns Name of the zone for this request. Zone name should conform to RFC1035.

Returns:

  • (::String)

    Name of the zone for this request. Zone name should conform to RFC1035.



60518
60519
60520
60521
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60518

class PerformMaintenanceReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end