Class: Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: AutoDelete

Instance Attribute Summary collapse

Instance Attribute Details

#auto_delete ⇒ ::String

Returns These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Check the AutoDelete enum for the list of possible values.

Returns:

  • (::String) —

    These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Check the AutoDelete enum for the list of possible values.



63950
63951
63952
63953
63954
63955
63956
63957
63958
63959
63960
63961
63962
63963
63964
63965
63966
63967
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63950

class PreservedStatePreservedNetworkIp
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These stateful IPs will never be released during autohealing,
  # update or VM instance recreate operations.
  # This flag is used to configure if the IP reservation should be deleted
  # after it is no longer used by the group, e.g. when the given instance
  # or the whole group is deleted.
  module AutoDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_AUTO_DELETE = 0

    NEVER = 74_175_084

    ON_PERMANENT_INSTANCE_DELETION = 95_727_719
  end
end

#ip_address ⇒ ::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIpIpAddress

Returns Ip address representation.



63950
63951
63952
63953
63954
63955
63956
63957
63958
63959
63960
63961
63962
63963
63964
63965
63966
63967
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63950

class PreservedStatePreservedNetworkIp
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These stateful IPs will never be released during autohealing,
  # update or VM instance recreate operations.
  # This flag is used to configure if the IP reservation should be deleted
  # after it is no longer used by the group, e.g. when the given instance
  # or the whole group is deleted.
  module AutoDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_AUTO_DELETE = 0

    NEVER = 74_175_084

    ON_PERMANENT_INSTANCE_DELETION = 95_727_719
  end
end