Class: Google::Cloud::Compute::V1::PreviewFeature

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a single Google Compute Engine preview feature.

Defined Under Namespace

Modules: ActivationStatus

Instance Attribute Summary collapse

Instance Attribute Details

#activation_status ⇒ ::String

Returns Specifies whether the feature is enabled or disabled. Check the ActivationStatus enum for the list of possible values.

Returns:

  • (::String) —

    Specifies whether the feature is enabled or disabled. Check the ActivationStatus enum for the list of possible values.



64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64013

class PreviewFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the feature is enabled or disabled.
  module ActivationStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ACTIVATION_STATUS = 0

    ACTIVATION_STATE_UNSPECIFIED = 632_160

    DISABLED = 516_696_700

    ENABLED = 182_130_465
  end
end

#creation_timestamp ⇒ ::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String) —

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64013

class PreviewFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the feature is enabled or disabled.
  module ActivationStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ACTIVATION_STATUS = 0

    ACTIVATION_STATE_UNSPECIFIED = 632_160

    DISABLED = 516_696_700

    ENABLED = 182_130_465
  end
end

#description ⇒ ::String

Returns Output only. [Output Only] Description of the feature.

Returns:

  • (::String) —

    Output only. [Output Only] Description of the feature.



64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64013

class PreviewFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the feature is enabled or disabled.
  module ActivationStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ACTIVATION_STATUS = 0

    ACTIVATION_STATE_UNSPECIFIED = 632_160

    DISABLED = 516_696_700

    ENABLED = 182_130_465
  end
end

#id ⇒ ::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer) —

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64013

class PreviewFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the feature is enabled or disabled.
  module ActivationStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ACTIVATION_STATUS = 0

    ACTIVATION_STATE_UNSPECIFIED = 632_160

    DISABLED = 516_696_700

    ENABLED = 182_130_465
  end
end

#kind ⇒ ::String

Returns Output only. [Output only] The type of the feature. Always "compute#previewFeature" for preview features.

Returns:

  • (::String) —

    Output only. [Output only] The type of the feature. Always "compute#previewFeature" for preview features.



64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64013

class PreviewFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the feature is enabled or disabled.
  module ActivationStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ACTIVATION_STATUS = 0

    ACTIVATION_STATE_UNSPECIFIED = 632_160

    DISABLED = 516_696_700

    ENABLED = 182_130_465
  end
end

#name ⇒ ::String

Returns Name of the feature.

Returns:

  • (::String) —

    Name of the feature.



64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64013

class PreviewFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the feature is enabled or disabled.
  module ActivationStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ACTIVATION_STATUS = 0

    ACTIVATION_STATE_UNSPECIFIED = 632_160

    DISABLED = 516_696_700

    ENABLED = 182_130_465
  end
end

#rollout_operation ⇒ ::Google::Cloud::Compute::V1::PreviewFeatureRolloutOperation

Returns Rollout operation of the feature.

Returns:



64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64013

class PreviewFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the feature is enabled or disabled.
  module ActivationStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ACTIVATION_STATUS = 0

    ACTIVATION_STATE_UNSPECIFIED = 632_160

    DISABLED = 516_696_700

    ENABLED = 182_130_465
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for the resource.



64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64013

class PreviewFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the feature is enabled or disabled.
  module ActivationStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ACTIVATION_STATUS = 0

    ACTIVATION_STATE_UNSPECIFIED = 632_160

    DISABLED = 516_696_700

    ENABLED = 182_130_465
  end
end

#status ⇒ ::Google::Cloud::Compute::V1::PreviewFeatureStatus

Returns Output only. [Output only] Status of the feature.

Returns:



64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64013

class PreviewFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the feature is enabled or disabled.
  module ActivationStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ACTIVATION_STATUS = 0

    ACTIVATION_STATE_UNSPECIFIED = 632_160

    DISABLED = 516_696_700

    ENABLED = 182_130_465
  end
end