Class: Google::Cloud::Compute::V1::ProjectView

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a ProjectView resource.

A ProjectView resource contains read-only project data which is available globally.

Instance Attribute Summary collapse

Instance Attribute Details

#project ⇒ ::Google::Cloud::Compute::V1::Project

Returns The project data. The returned Project data does not contain regional or zonal quota usage data. Global quota limits are present. For accurate, real-time quota usage numbers, query the global projects.get endpoint.

Returns:

  • (::Google::Cloud::Compute::V1::Project) —

    The project data. The returned Project data does not contain regional or zonal quota usage data. Global quota limits are present. For accurate, real-time quota usage numbers, query the global projects.get endpoint.



64314
64315
64316
64317
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64314

class ProjectView
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end