Class: Google::Cloud::Compute::V1::ProjectsListXpnHostsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#organization ⇒ ::String

Returns Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project.

Returns:

  • (::String) —

    Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project.



64360
64361
64362
64363
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64360

class ProjectsListXpnHostsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end