Class: Google::Cloud::Compute::V1::PublicAdvertisedPrefixPublicDelegatedPrefix

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a CIDR range which can be used to assign addresses.

Instance Attribute Summary collapse

Instance Attribute Details

#ip_range ⇒ ::String

Returns The IP address range of the public delegated prefix.

Returns:

  • (::String) —

    The IP address range of the public delegated prefix



64664
64665
64666
64667
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64664

class PublicAdvertisedPrefixPublicDelegatedPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String

Returns The name of the public delegated prefix.

Returns:

  • (::String) —

    The name of the public delegated prefix



64664
64665
64666
64667
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64664

class PublicAdvertisedPrefixPublicDelegatedPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project ⇒ ::String

Returns The project number of the public delegated prefix.

Returns:

  • (::String) —

    The project number of the public delegated prefix



64664
64665
64666
64667
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64664

class PublicAdvertisedPrefixPublicDelegatedPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region ⇒ ::String

Returns The region of the public delegated prefix if it is regional. If absent, the prefix is global.

Returns:

  • (::String) —

    The region of the public delegated prefix if it is regional. If absent, the prefix is global.



64664
64665
64666
64667
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64664

class PublicAdvertisedPrefixPublicDelegatedPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status ⇒ ::String

Returns The status of the public delegated prefix. Possible values are:

INITIALIZING: The public delegated prefix is being initialized and
addresses cannot be created yet.
ANNOUNCED: The public delegated prefix is active.

Returns:

  • (::String) —

    The status of the public delegated prefix. Possible values are:

    INITIALIZING: The public delegated prefix is being initialized and
    addresses cannot be created yet.
    ANNOUNCED: The public delegated prefix is active.
    


64664
64665
64666
64667
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64664

class PublicAdvertisedPrefixPublicDelegatedPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end