Module: Google::Cloud::Compute::V1::PublicDelegatedPrefix::Status

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] The status of the public delegated prefix, which can be one of following values:

 - `INITIALIZING` The public delegated prefix is being initialized and
 addresses cannot be created yet.
 - `READY_TO_ANNOUNCE` The public delegated prefix is a live migration
 prefix and is active.
 - `ANNOUNCED` The public delegated prefix is announced and ready to
 use.
 - `DELETING` The public delegated prefix is being deprovsioned.
 - `ACTIVE` The public delegated prefix is ready to use.

Constant Summary collapse

UNDEFINED_STATUS =

A value indicating that the enum field is not set.

0
ACTIVE =

The public delegated prefix is ready to use.

314_733_318
ANNOUNCED =

The public delegated prefix is announced and ready to use.

365_103_355
ANNOUNCED_TO_GOOGLE =

The prefix is announced within Google network.

454_875_705
ANNOUNCED_TO_INTERNET =

The prefix is announced to Internet and within Google.

177_880_897
DELETING =

The public delegated prefix is being deprovsioned.

528_602_024
INITIALIZING =

The public delegated prefix is being initialized and addresses cannot be created yet.

306_588_749
READY_TO_ANNOUNCE =

The public delegated prefix is currently withdrawn but ready to be announced.

64_641_265