Class: Google::Cloud::Compute::V1::PublicDelegatedPrefixPublicDelegatedSubPrefix

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a sub PublicDelegatedPrefix.

Defined Under Namespace

Modules: Ipv6AccessType, Mode, Status

Instance Attribute Summary collapse

Instance Attribute Details

#allocatable_prefix_length ⇒ ::Integer

Returns The allocatable prefix length supported by this PublicDelegatedSubPrefix.

Returns:

  • (::Integer) —

    The allocatable prefix length supported by this PublicDelegatedSubPrefix.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#delegatee_project ⇒ ::String

Returns Name of the project scoping this PublicDelegatedSubPrefix.

Returns:

  • (::String) —

    Name of the project scoping this PublicDelegatedSubPrefix.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#description ⇒ ::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String) —

    An optional description of this resource. Provide this property when you create the resource.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#enable_enhanced_ipv4_allocation ⇒ ::Boolean

Returns Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only.

Returns:

  • (::Boolean) —

    Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#ip_cidr_range ⇒ ::String

Returns The IP address range, in CIDR format, represented by this sub public delegated prefix.

Returns:

  • (::String) —

    The IP address range, in CIDR format, represented by this sub public delegated prefix.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#ipv6_access_type ⇒ ::String

Returns Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub Prefixes. Inherited from parent prefix. Check the Ipv6AccessType enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub Prefixes. Inherited from parent prefix. Check the Ipv6AccessType enum for the list of possible values.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#is_address ⇒ ::Boolean

Returns Whether the sub prefix is delegated to create Address resources in the delegatee project.

Returns:

  • (::Boolean) —

    Whether the sub prefix is delegated to create Address resources in the delegatee project.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#mode ⇒ ::String

Returns The PublicDelegatedSubPrefix mode for IPv6 only. Check the Mode enum for the list of possible values.

Returns:

  • (::String) —

    The PublicDelegatedSubPrefix mode for IPv6 only. Check the Mode enum for the list of possible values.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#name ⇒ ::String

Returns The name of the sub public delegated prefix.

Returns:

  • (::String) —

    The name of the sub public delegated prefix.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#region ⇒ ::String

Returns Output only. [Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global.

Returns:

  • (::String) —

    Output only. [Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#status ⇒ ::String

Returns Output only. [Output Only] The status of the sub public delegated prefix. Check the Status enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] The status of the sub public delegated prefix. Check the Status enum for the list of possible values.



64983
64984
64985
64986
64987
64988
64989
64990
64991
64992
64993
64994
64995
64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
65025
65026
65027
65028
65029
65030
65031
65032
65033
65034
65035
65036
65037
65038
65039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64983

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end