Class: Google::Cloud::Compute::V1::QuotaStatusWarning

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. [Output Only] Warning of fetching the quotas field for this region. This field is populated only if fetching of the quotas field fails.

Defined Under Namespace

Modules: Code

Instance Attribute Summary collapse

Instance Attribute Details

#code ⇒ ::String

Returns [Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Check the Code enum for the list of possible values.

Returns:

  • (::String) —

    [Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Check the Code enum for the list of possible values.



65480
65481
65482
65483
65484
65485
65486
65487
65488
65489
65490
65491
65492
65493
65494
65495
65496
65497
65498
65499
65500
65501
65502
65503
65504
65505
65506
65507
65508
65509
65510
65511
65512
65513
65514
65515
65516
65517
65518
65519
65520
65521
65522
65523
65524
65525
65526
65527
65528
65529
65530
65531
65532
65533
65534
65535
65536
65537
65538
65539
65540
65541
65542
65543
65544
65545
65546
65547
65548
65549
65550
65551
65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
65573
65574
65575
65576
65577
65578
65579
65580
65581
65582
65583
65584
65585
65586
65587
65588
65589
65590
65591
65592
65593
65594
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65480

class QuotaStatusWarning
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] A warning code, if applicable. For example, Compute
  # Engine returns NO_RESULTS_ON_PAGE if there
  # are no results in the response.
  module Code
    # A value indicating that the enum field is not set.
    UNDEFINED_CODE = 0

    # Warning about failed cleanup of transient changes made by a failed
    # operation.
    CLEANUP_FAILED = 150_308_440

    # A link to a deprecated resource was created.
    DEPRECATED_RESOURCE_USED = 391_835_586

    # When deploying and at least one of the resources has a type marked as
    # deprecated
    DEPRECATED_TYPE_USED = 346_526_230

    # The user created a boot disk that is larger than image size.
    DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369_442_967

    # When deploying and at least one of the resources has a type marked as
    # experimental
    EXPERIMENTAL_TYPE_USED = 451_954_443

    # Warning that is present in an external api call
    EXTERNAL_API_WARNING = 175_546_307

    # Warning that value of a field has been overridden.
    # Deprecated unused field.
    FIELD_VALUE_OVERRIDEN = 329_669_423

    # The operation involved use of an injected kernel, which is deprecated.
    INJECTED_KERNELS_DEPRECATED = 417_377_419

    # A WEIGHTED_MAGLEV backend service is associated with a health check that is
    # not of type HTTP/HTTPS/HTTP2.
    INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 401_542_606

    # When deploying a deployment with a exceedingly large number of resources
    LARGE_DEPLOYMENT_WARNING = 481_440_678

    # Resource can't be retrieved due to list overhead quota exceed
    # which captures the amount of resources filtered out by
    # user-defined list filter.
    LIST_OVERHEAD_QUOTA_EXCEED = 47_618_117

    # A resource depends on a missing type
    MISSING_TYPE_DEPENDENCY = 344_505_463

    # The route's nextHopIp address is not assigned to an instance on the
    # network.
    NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324_964_999

    # The route's next hop instance cannot ip forward.
    NEXT_HOP_CANNOT_IP_FORWARD = 383_382_887

    # The route's nextHopInstance URL refers to an instance that does not have an
    # ipv6 interface on the same network as the route.
    NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 146_748_434

    # The route's nextHopInstance URL refers to an instance that does not exist.
    NEXT_HOP_INSTANCE_NOT_FOUND = 464_250_446

    # The route's nextHopInstance URL refers to an instance that is not on the
    # same network as the route.
    NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243_758_146

    # The route's next hop instance does not have a status of RUNNING.
    NEXT_HOP_NOT_RUNNING = 417_081_265

    # Error which is not critical. We decided to continue the process despite
    # the mentioned error.
    NOT_CRITICAL_ERROR = 105_763_924

    # No results are present on a particular list page.
    NO_RESULTS_ON_PAGE = 30_036_744

    # Success is reported, but some results may be missing due to errors
    PARTIAL_SUCCESS = 39_966_469

    # Quota information is not available to client requests (e.g:
    # regions.list).
    QUOTA_INFO_UNAVAILABLE = 304_294_182

    # The user attempted to use a resource that requires a TOS they have not
    # accepted.
    REQUIRED_TOS_AGREEMENT = 3_745_539

    # Warning that a resource is in use.
    RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496_728_641

    # One or more of the resources set to auto-delete could not be deleted
    # because they were in use.
    RESOURCE_NOT_DELETED = 168_598_460

    # When a resource schema validation is ignored.
    SCHEMA_VALIDATION_IGNORED = 275_245_642

    # Instance template used in instance group manager is valid as such, but
    # its application does not make a lot of sense, because it allows only
    # single instance in instance group.
    SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268_305_617

    # When undeclared properties in the schema are present
    UNDECLARED_PROPERTIES = 390_513_439

    # A given scope cannot be reached.
    UNREACHABLE = 13_328_052
  end
end

#data ⇒ ::Array<::Google::Cloud::Compute::V1::Data>

Returns [Output Only] Metadata about this warning in key: value format. For example:

"data": [ { "key": "scope", "value": "zones/us-east1-d" }].

Returns:

  • (::Array<::Google::Cloud::Compute::V1::Data>) —

    [Output Only] Metadata about this warning in key: value format. For example:

    "data": [ { "key": "scope", "value": "zones/us-east1-d" }]



65480
65481
65482
65483
65484
65485
65486
65487
65488
65489
65490
65491
65492
65493
65494
65495
65496
65497
65498
65499
65500
65501
65502
65503
65504
65505
65506
65507
65508
65509
65510
65511
65512
65513
65514
65515
65516
65517
65518
65519
65520
65521
65522
65523
65524
65525
65526
65527
65528
65529
65530
65531
65532
65533
65534
65535
65536
65537
65538
65539
65540
65541
65542
65543
65544
65545
65546
65547
65548
65549
65550
65551
65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
65573
65574
65575
65576
65577
65578
65579
65580
65581
65582
65583
65584
65585
65586
65587
65588
65589
65590
65591
65592
65593
65594
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65480

class QuotaStatusWarning
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] A warning code, if applicable. For example, Compute
  # Engine returns NO_RESULTS_ON_PAGE if there
  # are no results in the response.
  module Code
    # A value indicating that the enum field is not set.
    UNDEFINED_CODE = 0

    # Warning about failed cleanup of transient changes made by a failed
    # operation.
    CLEANUP_FAILED = 150_308_440

    # A link to a deprecated resource was created.
    DEPRECATED_RESOURCE_USED = 391_835_586

    # When deploying and at least one of the resources has a type marked as
    # deprecated
    DEPRECATED_TYPE_USED = 346_526_230

    # The user created a boot disk that is larger than image size.
    DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369_442_967

    # When deploying and at least one of the resources has a type marked as
    # experimental
    EXPERIMENTAL_TYPE_USED = 451_954_443

    # Warning that is present in an external api call
    EXTERNAL_API_WARNING = 175_546_307

    # Warning that value of a field has been overridden.
    # Deprecated unused field.
    FIELD_VALUE_OVERRIDEN = 329_669_423

    # The operation involved use of an injected kernel, which is deprecated.
    INJECTED_KERNELS_DEPRECATED = 417_377_419

    # A WEIGHTED_MAGLEV backend service is associated with a health check that is
    # not of type HTTP/HTTPS/HTTP2.
    INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 401_542_606

    # When deploying a deployment with a exceedingly large number of resources
    LARGE_DEPLOYMENT_WARNING = 481_440_678

    # Resource can't be retrieved due to list overhead quota exceed
    # which captures the amount of resources filtered out by
    # user-defined list filter.
    LIST_OVERHEAD_QUOTA_EXCEED = 47_618_117

    # A resource depends on a missing type
    MISSING_TYPE_DEPENDENCY = 344_505_463

    # The route's nextHopIp address is not assigned to an instance on the
    # network.
    NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324_964_999

    # The route's next hop instance cannot ip forward.
    NEXT_HOP_CANNOT_IP_FORWARD = 383_382_887

    # The route's nextHopInstance URL refers to an instance that does not have an
    # ipv6 interface on the same network as the route.
    NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 146_748_434

    # The route's nextHopInstance URL refers to an instance that does not exist.
    NEXT_HOP_INSTANCE_NOT_FOUND = 464_250_446

    # The route's nextHopInstance URL refers to an instance that is not on the
    # same network as the route.
    NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243_758_146

    # The route's next hop instance does not have a status of RUNNING.
    NEXT_HOP_NOT_RUNNING = 417_081_265

    # Error which is not critical. We decided to continue the process despite
    # the mentioned error.
    NOT_CRITICAL_ERROR = 105_763_924

    # No results are present on a particular list page.
    NO_RESULTS_ON_PAGE = 30_036_744

    # Success is reported, but some results may be missing due to errors
    PARTIAL_SUCCESS = 39_966_469

    # Quota information is not available to client requests (e.g:
    # regions.list).
    QUOTA_INFO_UNAVAILABLE = 304_294_182

    # The user attempted to use a resource that requires a TOS they have not
    # accepted.
    REQUIRED_TOS_AGREEMENT = 3_745_539

    # Warning that a resource is in use.
    RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496_728_641

    # One or more of the resources set to auto-delete could not be deleted
    # because they were in use.
    RESOURCE_NOT_DELETED = 168_598_460

    # When a resource schema validation is ignored.
    SCHEMA_VALIDATION_IGNORED = 275_245_642

    # Instance template used in instance group manager is valid as such, but
    # its application does not make a lot of sense, because it allows only
    # single instance in instance group.
    SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268_305_617

    # When undeclared properties in the schema are present
    UNDECLARED_PROPERTIES = 390_513_439

    # A given scope cannot be reached.
    UNREACHABLE = 13_328_052
  end
end

#message ⇒ ::String

Returns [Output Only] A human-readable description of the warning code.

Returns:

  • (::String) —

    [Output Only] A human-readable description of the warning code.



65480
65481
65482
65483
65484
65485
65486
65487
65488
65489
65490
65491
65492
65493
65494
65495
65496
65497
65498
65499
65500
65501
65502
65503
65504
65505
65506
65507
65508
65509
65510
65511
65512
65513
65514
65515
65516
65517
65518
65519
65520
65521
65522
65523
65524
65525
65526
65527
65528
65529
65530
65531
65532
65533
65534
65535
65536
65537
65538
65539
65540
65541
65542
65543
65544
65545
65546
65547
65548
65549
65550
65551
65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
65573
65574
65575
65576
65577
65578
65579
65580
65581
65582
65583
65584
65585
65586
65587
65588
65589
65590
65591
65592
65593
65594
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65480

class QuotaStatusWarning
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] A warning code, if applicable. For example, Compute
  # Engine returns NO_RESULTS_ON_PAGE if there
  # are no results in the response.
  module Code
    # A value indicating that the enum field is not set.
    UNDEFINED_CODE = 0

    # Warning about failed cleanup of transient changes made by a failed
    # operation.
    CLEANUP_FAILED = 150_308_440

    # A link to a deprecated resource was created.
    DEPRECATED_RESOURCE_USED = 391_835_586

    # When deploying and at least one of the resources has a type marked as
    # deprecated
    DEPRECATED_TYPE_USED = 346_526_230

    # The user created a boot disk that is larger than image size.
    DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369_442_967

    # When deploying and at least one of the resources has a type marked as
    # experimental
    EXPERIMENTAL_TYPE_USED = 451_954_443

    # Warning that is present in an external api call
    EXTERNAL_API_WARNING = 175_546_307

    # Warning that value of a field has been overridden.
    # Deprecated unused field.
    FIELD_VALUE_OVERRIDEN = 329_669_423

    # The operation involved use of an injected kernel, which is deprecated.
    INJECTED_KERNELS_DEPRECATED = 417_377_419

    # A WEIGHTED_MAGLEV backend service is associated with a health check that is
    # not of type HTTP/HTTPS/HTTP2.
    INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 401_542_606

    # When deploying a deployment with a exceedingly large number of resources
    LARGE_DEPLOYMENT_WARNING = 481_440_678

    # Resource can't be retrieved due to list overhead quota exceed
    # which captures the amount of resources filtered out by
    # user-defined list filter.
    LIST_OVERHEAD_QUOTA_EXCEED = 47_618_117

    # A resource depends on a missing type
    MISSING_TYPE_DEPENDENCY = 344_505_463

    # The route's nextHopIp address is not assigned to an instance on the
    # network.
    NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324_964_999

    # The route's next hop instance cannot ip forward.
    NEXT_HOP_CANNOT_IP_FORWARD = 383_382_887

    # The route's nextHopInstance URL refers to an instance that does not have an
    # ipv6 interface on the same network as the route.
    NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 146_748_434

    # The route's nextHopInstance URL refers to an instance that does not exist.
    NEXT_HOP_INSTANCE_NOT_FOUND = 464_250_446

    # The route's nextHopInstance URL refers to an instance that is not on the
    # same network as the route.
    NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243_758_146

    # The route's next hop instance does not have a status of RUNNING.
    NEXT_HOP_NOT_RUNNING = 417_081_265

    # Error which is not critical. We decided to continue the process despite
    # the mentioned error.
    NOT_CRITICAL_ERROR = 105_763_924

    # No results are present on a particular list page.
    NO_RESULTS_ON_PAGE = 30_036_744

    # Success is reported, but some results may be missing due to errors
    PARTIAL_SUCCESS = 39_966_469

    # Quota information is not available to client requests (e.g:
    # regions.list).
    QUOTA_INFO_UNAVAILABLE = 304_294_182

    # The user attempted to use a resource that requires a TOS they have not
    # accepted.
    REQUIRED_TOS_AGREEMENT = 3_745_539

    # Warning that a resource is in use.
    RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496_728_641

    # One or more of the resources set to auto-delete could not be deleted
    # because they were in use.
    RESOURCE_NOT_DELETED = 168_598_460

    # When a resource schema validation is ignored.
    SCHEMA_VALIDATION_IGNORED = 275_245_642

    # Instance template used in instance group manager is valid as such, but
    # its application does not make a lot of sense, because it allows only
    # single instance in instance group.
    SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268_305_617

    # When undeclared properties in the schema are present
    UNDECLARED_PROPERTIES = 390_513_439

    # A given scope cannot be reached.
    UNREACHABLE = 13_328_052
  end
end