Module: Google::Cloud::Compute::V1::RawDisk::ContainerType

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The format used to encode and transmit the block device, which should be TAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created.

Constant Summary collapse

UNDEFINED_CONTAINER_TYPE =

A value indicating that the enum field is not set.

0
TAR =
82_821