Class: Google::Cloud::Compute::V1::RecreateInstancesInstanceGroupManagerRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RecreateInstancesInstanceGroupManagerRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for InstanceGroupManagers.RecreateInstances. See the method description for details.
Instance Attribute Summary collapse
-
#instance_group_manager ⇒ ::String
The name of the managed instance group.
-
#instance_group_managers_recreate_instances_request_resource ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagersRecreateInstancesRequest
The body resource for this request.
-
#no_graceful_shutdown ⇒ ::Boolean
When set, graceful shutdown is skipped for instance recreation even if it's configured for the instances.
-
#project ⇒ ::String
Project ID for this request.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#zone ⇒ ::String
The name of thezone where the managed instance group is located.
Instance Attribute Details
#instance_group_manager ⇒ ::String
Returns The name of the managed instance group.
64253 64254 64255 64256 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64253 class RecreateInstancesInstanceGroupManagerRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_group_managers_recreate_instances_request_resource ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagersRecreateInstancesRequest
Returns The body resource for this request.
64253 64254 64255 64256 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64253 class RecreateInstancesInstanceGroupManagerRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#no_graceful_shutdown ⇒ ::Boolean
Returns When set, graceful shutdown is skipped for instance recreation even if it's configured for the instances.
64253 64254 64255 64256 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64253 class RecreateInstancesInstanceGroupManagerRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID for this request.
64253 64254 64255 64256 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64253 class RecreateInstancesInstanceGroupManagerRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
64253 64254 64255 64256 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64253 class RecreateInstancesInstanceGroupManagerRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
Returns The name of thezone where the managed instance group is located.
64253 64254 64255 64256 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64253 class RecreateInstancesInstanceGroupManagerRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |