Class: Google::Cloud::Compute::V1::Reference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a reference to a resource.

Instance Attribute Summary collapse

Instance Attribute Details

#kind ⇒ ::String

Returns Output only. [Output Only] Type of the resource. Always compute#reference for references.

Returns:

  • (::String) —

    Output only. [Output Only] Type of the resource. Always compute#reference for references.



65734
65735
65736
65737
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65734

class Reference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reference_type ⇒ ::String

Returns A description of the reference type with no implied semantics. Possible values include:

1. MEMBER_OF.

Returns:

  • (::String) —

    A description of the reference type with no implied semantics. Possible values include:

    1. MEMBER_OF
    


65734
65735
65736
65737
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65734

class Reference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#referrer ⇒ ::String

Returns URL of the resource which refers to the target.

Returns:

  • (::String) —

    URL of the resource which refers to the target.



65734
65735
65736
65737
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65734

class Reference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target ⇒ ::String

Returns URL of the resource to which this reference points.

Returns:

  • (::String) —

    URL of the resource to which this reference points.



65734
65735
65736
65737
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65734

class Reference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end