Class: Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/compute/v1/region_health_sources/rest/client.rb

Overview

REST client for the RegionHealthSources service.

The RegionHealthSources API.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new RegionHealthSources REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the RegionHealthSources client.

Yield Parameters:



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 153

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @region_operations = ::Google::Cloud::Compute::V1::RegionOperations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.universe_domain = @config.universe_domain
  end

  @region_health_sources_stub = ::Google::Cloud::Compute::V1::RegionHealthSources::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @region_health_sources_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Instance Attribute Details

#region_operations::Google::Cloud::Compute::V1::RegionOperations::Rest::Client (readonly)

Get the associated client for long-running operations via RegionOperations.



207
208
209
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 207

def region_operations
  @region_operations
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the RegionHealthSources Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all RegionHealthSources clients
::Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 63

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Compute", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.aggregated_list.timeout = 600.0
    default_config.rpcs.aggregated_list.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.delete.timeout = 600.0

    default_config.rpcs.get.timeout = 600.0
    default_config.rpcs.get.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.get_health.timeout = 600.0
    default_config.rpcs.get_health.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.insert.timeout = 600.0

    default_config.rpcs.list.timeout = 600.0
    default_config.rpcs.list.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.patch.timeout = 600.0

    default_config.rpcs.test_iam_permissions.timeout = 600.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#aggregated_list(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::String, ::Google::Cloud::Compute::V1::HealthSourcesScopedList> #aggregated_list(filter: nil, include_all_scopes: nil, max_results: nil, order_by: nil, page_token: nil, project: nil, return_partial_success: nil, service_project_number: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::String, ::Google::Cloud::Compute::V1::HealthSourcesScopedList>

Retrieves the list of all HealthSource resources (all regional) available to the specified project.

To prevent failure, Google recommends that you set the returnPartialSuccess parameter to true.

Examples:

Basic example

require "google/cloud/compute/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Compute::V1::AggregatedListRegionHealthSourcesRequest.new

# Call the aggregated_list method.
result = client.aggregated_list request

# The returned object is of type Google::Cloud::Compute::V1::HealthSourceAggregatedList.
p result

Overloads:

  • #aggregated_list(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::String, ::Google::Cloud::Compute::V1::HealthSourcesScopedList>

    Pass arguments to aggregated_list via a request object, either of type AggregatedListRegionHealthSourcesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Compute::V1::AggregatedListRegionHealthSourcesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #aggregated_list(filter: nil, include_all_scopes: nil, max_results: nil, order_by: nil, page_token: nil, project: nil, return_partial_success: nil, service_project_number: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::String, ::Google::Cloud::Compute::V1::HealthSourcesScopedList>

    Pass arguments to aggregated_list via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • filter (::String) (defaults to: nil)

      A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request.

      If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either =, !=, >, <, <=, >= or :.

      For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.

      The :* comparison can be used to test whether a key has been defined. For example, to find all objects with owner label use:

      labels.owner:*
      

      You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based onresource labels.

      To filter on multiple expressions, provide each separate expression within parentheses. For example:

      (scheduling.automaticRestart = true)
      (cpuPlatform = "Intel Skylake")
      

      By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example:

      (cpuPlatform = "Intel Skylake") OR
      (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true)
      

      If you want to use a regular expression, use the eq (equal) or ne (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples:

      fieldname eq unquoted literal fieldname eq 'single quoted literal' fieldname eq "double quoted literal" (fieldname1 eq literal) (fieldname2 ne "literal")

      The literal value is interpreted as a regular expression using GoogleRE2 library syntax. The literal value must match the entire field.

      For example, to filter for instances that do not end with name "instance", you would use name ne .*instance.

      You cannot combine constraints on multiple fields using regular expressions.

    • include_all_scopes (::Boolean) (defaults to: nil)

      Indicates whether every visible scope for each scope type (zone, region, global) should be included in the response. For new resource types added after this field, the flag has no effect as new resource types will always include every visible scope for each scope type in response. For resource types which predate this field, if this flag is omitted or false, only scopes of the scope types where the resource type is expected to be found will be included.

    • max_results (::Integer) (defaults to: nil)

      The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)

    • order_by (::String) (defaults to: nil)

      Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.

      You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.

      Currently, only sorting by name or creationTimestamp desc is supported.

    • page_token (::String) (defaults to: nil)

      Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.

    • project (::String) (defaults to: nil)

      Name of the project scoping this request.

    • return_partial_success (::Boolean) (defaults to: nil)

      Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.

      For example, when partial success behavior is enabled, aggregatedList for a single zone scope either returns all resources in the zone or no resources, with an error code.

    • service_project_number (::Integer) (defaults to: nil)

      The Shared VPC service project id or service project number for which aggregated list request is invoked for subnetworks list-usable api.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 366

def aggregated_list request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::AggregatedListRegionHealthSourcesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.aggregated_list..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Compute::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.aggregated_list.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.aggregated_list.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @region_health_sources_stub.aggregated_list request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @region_health_sources_stub, :aggregated_list, "items", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the RegionHealthSources Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



123
124
125
126
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 123

def configure
  yield @config if block_given?
  @config
end

#delete(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation #delete(health_source: nil, project: nil, region: nil, request_id: nil) ⇒ ::Gapic::GenericLRO::Operation

Deletes the specified HealthSource in the given region

Examples:

Basic example

require "google/cloud/compute/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Compute::V1::DeleteRegionHealthSourceRequest.new

# Call the delete method.
result = client.delete request

# The returned object is of type Google::Cloud::Compute::V1::Operation.
p result

Overloads:

  • #delete(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation

    Pass arguments to delete via a request object, either of type DeleteRegionHealthSourceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Compute::V1::DeleteRegionHealthSourceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete(health_source: nil, project: nil, region: nil, request_id: nil) ⇒ ::Gapic::GenericLRO::Operation

    Pass arguments to delete via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • health_source (::String) (defaults to: nil)

      Name of the HealthSource resource to delete.

    • project (::String) (defaults to: nil)

      Project ID for this request.

    • region (::String) (defaults to: nil)

      Name of the region scoping this request.

    • request_id (::String) (defaults to: nil)

      An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

      For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

      The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::GenericLRO::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::GenericLRO::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 464

def delete request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::DeleteRegionHealthSourceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Compute::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @region_health_sources_stub.delete request, options do |result, response|
    result = ::Google::Cloud::Compute::V1::RegionOperations::Rest::NonstandardLro.create_operation(
      operation: result,
      client: region_operations,
      request_values: {
        "project" => request.project,
        "region" => request.region
      },
      options: options
    )
    yield result, response if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get(request, options = nil) ⇒ ::Google::Cloud::Compute::V1::HealthSource #get(health_source: nil, project: nil, region: nil) ⇒ ::Google::Cloud::Compute::V1::HealthSource

Returns the specified HealthSource resource in the given region.

Examples:

Basic example

require "google/cloud/compute/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Compute::V1::GetRegionHealthSourceRequest.new

# Call the get method.
result = client.get request

# The returned object is of type Google::Cloud::Compute::V1::HealthSource.
p result

Overloads:

  • #get(request, options = nil) ⇒ ::Google::Cloud::Compute::V1::HealthSource

    Pass arguments to get via a request object, either of type GetRegionHealthSourceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Compute::V1::GetRegionHealthSourceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get(health_source: nil, project: nil, region: nil) ⇒ ::Google::Cloud::Compute::V1::HealthSource

    Pass arguments to get via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • health_source (::String) (defaults to: nil)

      Name of the HealthSource resource to return.

    • project (::String) (defaults to: nil)

      Project ID for this request.

    • region (::String) (defaults to: nil)

      Name of the region scoping this request.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 556

def get request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::GetRegionHealthSourceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Compute::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @region_health_sources_stub.get request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_health(request, options = nil) ⇒ ::Google::Cloud::Compute::V1::HealthSourceHealth #get_health(health_source: nil, project: nil, region: nil) ⇒ ::Google::Cloud::Compute::V1::HealthSourceHealth

Gets the most recent health check results for this regional HealthSource.

Examples:

Basic example

require "google/cloud/compute/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Compute::V1::GetHealthRegionHealthSourceRequest.new

# Call the get_health method.
result = client.get_health request

# The returned object is of type Google::Cloud::Compute::V1::HealthSourceHealth.
p result

Overloads:

  • #get_health(request, options = nil) ⇒ ::Google::Cloud::Compute::V1::HealthSourceHealth

    Pass arguments to get_health via a request object, either of type GetHealthRegionHealthSourceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Compute::V1::GetHealthRegionHealthSourceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_health(health_source: nil, project: nil, region: nil) ⇒ ::Google::Cloud::Compute::V1::HealthSourceHealth

    Pass arguments to get_health via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • health_source (::String) (defaults to: nil)

      Name of the HealthSource resource to get health for.

    • project (::String) (defaults to: nil)

      Name of the project scoping this request.

    • region (::String) (defaults to: nil)

      Name of the region scoping this request.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 639

def get_health request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::GetHealthRegionHealthSourceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_health..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Compute::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_health.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_health.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @region_health_sources_stub.get_health request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#insert(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation #insert(health_source_resource: nil, project: nil, region: nil, request_id: nil) ⇒ ::Gapic::GenericLRO::Operation

Create a HealthSource in the specified project in the given region using the parameters that are included in the request.

Examples:

Basic example

require "google/cloud/compute/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Compute::V1::InsertRegionHealthSourceRequest.new

# Call the insert method.
result = client.insert request

# The returned object is of type Google::Cloud::Compute::V1::Operation.
p result

Overloads:

  • #insert(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation

    Pass arguments to insert via a request object, either of type InsertRegionHealthSourceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Compute::V1::InsertRegionHealthSourceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #insert(health_source_resource: nil, project: nil, region: nil, request_id: nil) ⇒ ::Gapic::GenericLRO::Operation

    Pass arguments to insert via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • health_source_resource (::Google::Cloud::Compute::V1::HealthSource, ::Hash) (defaults to: nil)

      The body resource for this request

    • project (::String) (defaults to: nil)

      Project ID for this request.

    • region (::String) (defaults to: nil)

      Name of the region scoping this request.

    • request_id (::String) (defaults to: nil)

      An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

      For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

      The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::GenericLRO::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::GenericLRO::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 736

def insert request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::InsertRegionHealthSourceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.insert..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Compute::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.insert.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.insert.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @region_health_sources_stub.insert request, options do |result, response|
    result = ::Google::Cloud::Compute::V1::RegionOperations::Rest::NonstandardLro.create_operation(
      operation: result,
      client: region_operations,
      request_values: {
        "project" => request.project,
        "region" => request.region
      },
      options: options
    )
    yield result, response if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Compute::V1::HealthSource> #list(filter: nil, max_results: nil, order_by: nil, page_token: nil, project: nil, region: nil, return_partial_success: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Compute::V1::HealthSource>

Lists the HealthSources for a project in the given region.

Examples:

Basic example

require "google/cloud/compute/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Compute::V1::ListRegionHealthSourcesRequest.new

# Call the list method.
result = client.list request

# The returned object is of type Google::Cloud::Compute::V1::HealthSourceList.
p result

Overloads:

  • #list(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Compute::V1::HealthSource>

    Pass arguments to list via a request object, either of type ListRegionHealthSourcesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Compute::V1::ListRegionHealthSourcesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list(filter: nil, max_results: nil, order_by: nil, page_token: nil, project: nil, region: nil, return_partial_success: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Compute::V1::HealthSource>

    Pass arguments to list via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • filter (::String) (defaults to: nil)

      A filter expression that filters resources listed in the response. Most Compute resources support two types of filter expressions: expressions that support regular expressions and expressions that follow API improvement proposal AIP-160. These two types of filter expressions cannot be mixed in one request.

      If you want to use AIP-160, your expression must specify the field name, an operator, and the value that you want to use for filtering. The value must be a string, a number, or a boolean. The operator must be either =, !=, >, <, <=, >= or :.

      For example, if you are filtering Compute Engine instances, you can exclude instances named example-instance by specifying name != example-instance.

      The :* comparison can be used to test whether a key has been defined. For example, to find all objects with owner label use:

      labels.owner:*
      

      You can also filter nested fields. For example, you could specify scheduling.automaticRestart = false to include instances only if they are not scheduled for automatic restarts. You can use filtering on nested fields to filter based onresource labels.

      To filter on multiple expressions, provide each separate expression within parentheses. For example:

      (scheduling.automaticRestart = true)
      (cpuPlatform = "Intel Skylake")
      

      By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly. For example:

      (cpuPlatform = "Intel Skylake") OR
      (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true)
      

      If you want to use a regular expression, use the eq (equal) or ne (not equal) operator against a single un-parenthesized expression with or without quotes or against multiple parenthesized expressions. Examples:

      fieldname eq unquoted literal fieldname eq 'single quoted literal' fieldname eq "double quoted literal" (fieldname1 eq literal) (fieldname2 ne "literal")

      The literal value is interpreted as a regular expression using GoogleRE2 library syntax. The literal value must match the entire field.

      For example, to filter for instances that do not end with name "instance", you would use name ne .*instance.

      You cannot combine constraints on multiple fields using regular expressions.

    • max_results (::Integer) (defaults to: nil)

      The maximum number of results per page that should be returned. If the number of available results is larger than maxResults, Compute Engine returns a nextPageToken that can be used to get the next page of results in subsequent list requests. Acceptable values are 0 to 500, inclusive. (Default: 500)

    • order_by (::String) (defaults to: nil)

      Sorts list results by a certain order. By default, results are returned in alphanumerical order based on the resource name.

      You can also sort results in descending order based on the creation timestamp using orderBy="creationTimestamp desc". This sorts results based on the creationTimestamp field in reverse chronological order (newest result first). Use this to sort resources like operations so that the newest operation is returned first.

      Currently, only sorting by name or creationTimestamp desc is supported.

    • page_token (::String) (defaults to: nil)

      Specifies a page token to use. Set pageToken to the nextPageToken returned by a previous list request to get the next page of results.

    • project (::String) (defaults to: nil)

      Project ID for this request.

    • region (::String) (defaults to: nil)

      Name of the region scoping this request.

    • return_partial_success (::Boolean) (defaults to: nil)

      Opt-in for partial success behavior which provides partial results in case of failure. The default value is false.

      For example, when partial success behavior is enabled, aggregatedList for a single zone scope either returns all resources in the zone or no resources, with an error code.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 914

def list request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::ListRegionHealthSourcesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Compute::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @region_health_sources_stub.list request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @region_health_sources_stub, :list, "items", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


214
215
216
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 214

def logger
  @region_health_sources_stub.logger
end

#patch(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation #patch(health_source: nil, health_source_resource: nil, project: nil, region: nil, request_id: nil) ⇒ ::Gapic::GenericLRO::Operation

Updates the specified regional HealthSource resource with the data included in the request. This method supportsPATCH semantics and uses theJSON merge patch format and processing rules.

Examples:

Basic example

require "google/cloud/compute/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Compute::V1::PatchRegionHealthSourceRequest.new

# Call the patch method.
result = client.patch request

# The returned object is of type Google::Cloud::Compute::V1::Operation.
p result

Overloads:

  • #patch(request, options = nil) ⇒ ::Gapic::GenericLRO::Operation

    Pass arguments to patch via a request object, either of type PatchRegionHealthSourceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Compute::V1::PatchRegionHealthSourceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #patch(health_source: nil, health_source_resource: nil, project: nil, region: nil, request_id: nil) ⇒ ::Gapic::GenericLRO::Operation

    Pass arguments to patch via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • health_source (::String) (defaults to: nil)

      Name of the HealthSource to update. The name must be 1-63 characters long, and comply with RFC1035.

    • health_source_resource (::Google::Cloud::Compute::V1::HealthSource, ::Hash) (defaults to: nil)

      The body resource for this request

    • project (::String) (defaults to: nil)

      Project ID for this request.

    • region (::String) (defaults to: nil)

      Name of the region scoping this request.

    • request_id (::String) (defaults to: nil)

      An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

      For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

      The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::GenericLRO::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::GenericLRO::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 1018

def patch request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::PatchRegionHealthSourceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.patch..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Compute::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.patch.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.patch.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @region_health_sources_stub.patch request, options do |result, response|
    result = ::Google::Cloud::Compute::V1::RegionOperations::Rest::NonstandardLro.create_operation(
      operation: result,
      client: region_operations,
      request_values: {
        "project" => request.project,
        "region" => request.region
      },
      options: options
    )
    yield result, response if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#test_iam_permissions(request, options = nil) ⇒ ::Google::Cloud::Compute::V1::TestPermissionsResponse #test_iam_permissions(project: nil, region: nil, resource: nil, test_permissions_request_resource: nil) ⇒ ::Google::Cloud::Compute::V1::TestPermissionsResponse

Returns permissions that a caller has on the specified resource.

Examples:

Basic example

require "google/cloud/compute/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Compute::V1::RegionHealthSources::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Compute::V1::TestIamPermissionsRegionHealthSourceRequest.new

# Call the test_iam_permissions method.
result = client.test_iam_permissions request

# The returned object is of type Google::Cloud::Compute::V1::TestPermissionsResponse.
p result

Overloads:

  • #test_iam_permissions(request, options = nil) ⇒ ::Google::Cloud::Compute::V1::TestPermissionsResponse

    Pass arguments to test_iam_permissions via a request object, either of type TestIamPermissionsRegionHealthSourceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Compute::V1::TestIamPermissionsRegionHealthSourceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #test_iam_permissions(project: nil, region: nil, resource: nil, test_permissions_request_resource: nil) ⇒ ::Google::Cloud::Compute::V1::TestPermissionsResponse

    Pass arguments to test_iam_permissions via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • project (::String) (defaults to: nil)

      Project ID for this request.

    • region (::String) (defaults to: nil)

      The name of the region for this request.

    • resource (::String) (defaults to: nil)

      Name or id of the resource for this request.

    • test_permissions_request_resource (::Google::Cloud::Compute::V1::TestPermissionsRequest, ::Hash) (defaults to: nil)

      The body resource for this request

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 1112

def test_iam_permissions request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Compute::V1::TestIamPermissionsRegionHealthSourceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.test_iam_permissions..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Compute::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.test_iam_permissions.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.test_iam_permissions.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @region_health_sources_stub.test_iam_permissions request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


133
134
135
# File 'lib/google/cloud/compute/v1/region_health_sources/rest/client.rb', line 133

def universe_domain
  @region_health_sources_stub.universe_domain
end