Class: Google::Cloud::Compute::V1::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns:

  • (::String)


63949
63950
63951
63952
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63949

class RegionInstanceGroupManagerResizeRequestsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id::String

Returns Output only. Unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    Output only. Unique identifier for the resource; defined by the server.



63949
63950
63951
63952
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63949

class RegionInstanceGroupManagerResizeRequestsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#items::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequest>

Returns A list of Resize Request resources.

Returns:



63949
63950
63951
63952
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63949

class RegionInstanceGroupManagerResizeRequestsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::String

Returns Output only. Type of the resource. Alwayscompute#regionInstanceGroupManagerResizeRequestList for a list of Resize Requests.

Returns:

  • (::String)

    Output only. Type of the resource. Alwayscompute#regionInstanceGroupManagerResizeRequestList for a list of Resize Requests.



63949
63950
63951
63952
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63949

class RegionInstanceGroupManagerResizeRequestsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



63949
63950
63951
63952
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63949

class RegionInstanceGroupManagerResizeRequestsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Output only. Server-defined URL for this resource.

Returns:

  • (::String)

    Output only. Server-defined URL for this resource.



63949
63950
63951
63952
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63949

class RegionInstanceGroupManagerResizeRequestsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachables::Array<::String>

Returns Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder.

Returns:

  • (::Array<::String>)

    Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder



63949
63950
63951
63952
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63949

class RegionInstanceGroupManagerResizeRequestsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning::Google::Cloud::Compute::V1::Warning

Returns Output only. Informational warning message.

Returns:



63949
63950
63951
63952
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63949

class RegionInstanceGroupManagerResizeRequestsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end