Class: Google::Cloud::Compute::V1::RegionInstanceGroupManagersApplyUpdatesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

RegionInstanceGroupManagers.applyUpdatesToInstances

Defined Under Namespace

Modules: MinimalAction, MostDisruptiveAllowedAction

Instance Attribute Summary collapse

Instance Attribute Details

#all_instances ⇒ ::Boolean

Returns Flag to update all instances instead of specified list of "instances". If the flag is set to true then the instances may not be specified in the request.

Returns:

  • (::Boolean) —

    Flag to update all instances instead of specified list of "instances". If the flag is set to true then the instances may not be specified in the request.



66161
66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
66175
66176
66177
66178
66179
66180
66181
66182
66183
66184
66185
66186
66187
66188
66189
66190
66191
66192
66193
66194
66195
66196
66197
66198
66199
66200
66201
66202
66203
66204
66205
66206
66207
66208
66209
66210
66211
66212
66213
66214
66215
66216
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66161

class RegionInstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#instances ⇒ ::Array<::String>

Returns The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].

Returns:

  • (::Array<::String>) —

    The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].



66161
66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
66175
66176
66177
66178
66179
66180
66181
66182
66183
66184
66185
66186
66187
66188
66189
66190
66191
66192
66193
66194
66195
66196
66197
66198
66199
66200
66201
66202
66203
66204
66205
66206
66207
66208
66209
66210
66211
66212
66213
66214
66215
66216
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66161

class RegionInstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#minimal_action ⇒ ::String

Returns The minimal action that you want to perform on each instance during the update:

 - REPLACE: At minimum, delete the instance and create it
 again.
- RESTART: Stop the instance and start it
 again.
- REFRESH: Do not stop the instance and limit
 disruption as much as possible.
- NONE: Do not
 disrupt the instance at all.

By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.

Returns:

  • (::String) —

    The minimal action that you want to perform on each instance during the update:

     - REPLACE: At minimum, delete the instance and create it
     again.
    - RESTART: Stop the instance and start it
     again.
    - REFRESH: Do not stop the instance and limit
     disruption as much as possible.
    - NONE: Do not
     disrupt the instance at all.
    

    By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.



66161
66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
66175
66176
66177
66178
66179
66180
66181
66182
66183
66184
66185
66186
66187
66188
66189
66190
66191
66192
66193
66194
66195
66196
66197
66198
66199
66200
66201
66202
66203
66204
66205
66206
66207
66208
66209
66210
66211
66212
66213
66214
66215
66216
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66161

class RegionInstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#most_disruptive_allowed_action ⇒ ::String

Returns The most disruptive action that you want to perform on each instance during the update:

 - REPLACE: Delete the instance and create it again.
 - RESTART: Stop the instance and start it again.
 - REFRESH: Do not stop the instance and limit disruption
 as much as possible.
- NONE: Do not disrupt the
 instance at all.

By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.

Returns:

  • (::String) —

    The most disruptive action that you want to perform on each instance during the update:

     - REPLACE: Delete the instance and create it again.
     - RESTART: Stop the instance and start it again.
     - REFRESH: Do not stop the instance and limit disruption
     as much as possible.
    - NONE: Do not disrupt the
     instance at all.
    

    By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.



66161
66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
66175
66176
66177
66178
66179
66180
66181
66182
66183
66184
66185
66186
66187
66188
66189
66190
66191
66192
66193
66194
66195
66196
66197
66198
66199
66200
66201
66202
66203
66204
66205
66206
66207
66208
66209
66210
66211
66212
66213
66214
66215
66216
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66161

class RegionInstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end