Class: Google::Cloud::Compute::V1::RegionInstanceGroupManagersListInstanceConfigsResp
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RegionInstanceGroupManagersListInstanceConfigsResp
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#items ⇒ ::Array<::Google::Cloud::Compute::V1::PerInstanceConfig>
Output only.
-
#next_page_token ⇒ ::String
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Output only.
Instance Attribute Details
#items ⇒ ::Array<::Google::Cloud::Compute::V1::PerInstanceConfig>
Returns Output only. [Output Only] The list of PerInstanceConfig.
63048 63049 63050 63051 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63048 class RegionInstanceGroupManagersListInstanceConfigsResp include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
63048 63049 63050 63051 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63048 class RegionInstanceGroupManagersListInstanceConfigsResp include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Output only. [Output Only] Informational warning message.
63048 63049 63050 63051 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63048 class RegionInstanceGroupManagersListInstanceConfigsResp include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |