Class: Google::Cloud::Compute::V1::RegionInstanceGroupManagersSetTargetPoolsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RegionInstanceGroupManagersSetTargetPoolsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ ::String
Fingerprint of the target pools information, which is a hash of the contents.
-
#target_pools ⇒ ::Array<::String>
The URL of all TargetPool resources to which instances in theinstanceGroup field are added.
Instance Attribute Details
#fingerprint ⇒ ::String
Returns Fingerprint of the target pools information, which is a hash of the contents. This field is used for optimistic locking when you update the target pool entries. This field is optional.
64863 64864 64865 64866 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64863 class RegionInstanceGroupManagersSetTargetPoolsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_pools ⇒ ::Array<::String>
Returns The URL of all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group.
64863 64864 64865 64866 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64863 class RegionInstanceGroupManagersSetTargetPoolsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |