Class: Google::Cloud::Compute::V1::RegionInstanceGroupManagersSuspendInstancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#force_suspend ⇒ ::Boolean

Returns If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them.

Returns:

  • If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them.



66364
66365
66366
66367
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66364

class RegionInstanceGroupManagersSuspendInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instances ⇒ ::Array<::String>

Returns The URLs of one or more instances to suspend. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].

Returns:

  • The URLs of one or more instances to suspend. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].



66364
66365
66366
66367
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66364

class RegionInstanceGroupManagersSuspendInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end