Class: Google::Cloud::Compute::V1::RegionInstanceGroupsListInstances
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RegionInstanceGroupsListInstances
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#id ⇒ ::String
Output only.
-
#items ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceWithNamedPorts>
A list of InstanceWithNamedPorts resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Output only.
Instance Attribute Details
#id ⇒ ::String
Returns Output only. [Output Only] Unique identifier for the resource; defined by the server.
64251 64252 64253 64254 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64251 class RegionInstanceGroupsListInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#items ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceWithNamedPorts>
Returns A list of InstanceWithNamedPorts resources.
64251 64252 64253 64254 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64251 class RegionInstanceGroupsListInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. The resource type.
64251 64252 64253 64254 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64251 class RegionInstanceGroupsListInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
64251 64252 64253 64254 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64251 class RegionInstanceGroupsListInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
64251 64252 64253 64254 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64251 class RegionInstanceGroupsListInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Output only. [Output Only] Informational warning message.
64251 64252 64253 64254 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64251 class RegionInstanceGroupsListInstances include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |