Module: Google::Cloud::Compute::V1::Reservation::EarlyAccessMaintenance

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Indicates the early access maintenance for the reservation. If this field is absent or set to NO_EARLY_ACCESS, the reservation is not enrolled in early access maintenance and the standard notice applies.

Constant Summary collapse

UNDEFINED_EARLY_ACCESS_MAINTENANCE =

A value indicating that the enum field is not set.

0
NO_EARLY_ACCESS =

No early access.

220_751_774
WAVE1 =

Wave 1: Fastest notification period

82_367_576
WAVE2 =

Wave 2: Medium notification period

82_367_577