Module: Google::Cloud::Compute::V1::Reservation::SchedulingType

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The type of maintenance for the reservation.

Constant Summary collapse

UNDEFINED_SCHEDULING_TYPE =

A value indicating that the enum field is not set.

0
GROUPED =

Maintenance on all reserved instances in the reservation is synchronized.

474_540_862
GROUP_MAINTENANCE_TYPE_UNSPECIFIED =

Unknown maintenance type.

447_183_678
INDEPENDENT =

Maintenance is not synchronized for this reservation. Instead, each instance has its own maintenance window.

127_011_674