Class: Google::Cloud::Compute::V1::ReservationAffinity

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specifies the reservations that this instance can consume from.

Defined Under Namespace

Modules: ConsumeReservationType

Instance Attribute Summary collapse

Instance Attribute Details

#consume_reservation_type::String



29720
29721
29722
29723
29724
29725
29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
29737
29738
29739
29740
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29720

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default), SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples.
  module ConsumeReservationType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONSUME_RESERVATION_TYPE = 0

    # Consume any allocation available.
    ANY_RESERVATION = 200_008_121

    # Do not consume from any allocated capacity.
    NO_RESERVATION = 169_322_030

    # Must consume from a specific reservation. Must specify key value fields for specifying the reservations.
    SPECIFIC_RESERVATION = 229_889_055

    UNSPECIFIED = 526_786_327
  end
end

#key::String



29720
29721
29722
29723
29724
29725
29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
29737
29738
29739
29740
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29720

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default), SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples.
  module ConsumeReservationType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONSUME_RESERVATION_TYPE = 0

    # Consume any allocation available.
    ANY_RESERVATION = 200_008_121

    # Do not consume from any allocated capacity.
    NO_RESERVATION = 169_322_030

    # Must consume from a specific reservation. Must specify key value fields for specifying the reservations.
    SPECIFIC_RESERVATION = 229_889_055

    UNSPECIFIED = 526_786_327
  end
end

#values::Array<::String>



29720
29721
29722
29723
29724
29725
29726
29727
29728
29729
29730
29731
29732
29733
29734
29735
29736
29737
29738
29739
29740
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29720

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default), SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples.
  module ConsumeReservationType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONSUME_RESERVATION_TYPE = 0

    # Consume any allocation available.
    ANY_RESERVATION = 200_008_121

    # Do not consume from any allocated capacity.
    NO_RESERVATION = 169_322_030

    # Must consume from a specific reservation. Must specify key value fields for specifying the reservations.
    SPECIFIC_RESERVATION = 229_889_055

    UNSPECIFIED = 526_786_327
  end
end