Class: Google::Cloud::Compute::V1::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#block ⇒ ::String

Returns The hash of the capacity block within the cluster.

Returns:

  • (::String) —

    The hash of the capacity block within the cluster.



67834
67835
67836
67837
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67834

class ReservationBlockPhysicalTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#cluster ⇒ ::String

Returns The cluster name of the reservation block.

Returns:

  • (::String) —

    The cluster name of the reservation block.



67834
67835
67836
67837
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67834

class ReservationBlockPhysicalTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instances ⇒ ::Array<::Google::Cloud::Compute::V1::ReservationBlockPhysicalTopologyInstance>

Returns Output only. The detailed instances information for a given Block.

Returns:



67834
67835
67836
67837
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67834

class ReservationBlockPhysicalTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end