Class: Google::Cloud::Compute::V1::ReservationSlotPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationSlotPhysicalTopology
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#block ⇒ ::String
The unique identifier of the capacity block within the cluster.
-
#cluster ⇒ ::String
The cluster name of the reservation sub-block.
-
#host ⇒ ::String
The unique identifier of the capacity host within the capacity sub-block.
-
#sub_block ⇒ ::String
The unique identifier of the capacity sub-block within the capacity block.
Instance Attribute Details
#block ⇒ ::String
Returns The unique identifier of the capacity block within the cluster.
64724 64725 64726 64727 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64724 class ReservationSlotPhysicalTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cluster ⇒ ::String
Returns The cluster name of the reservation sub-block.
64724 64725 64726 64727 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64724 class ReservationSlotPhysicalTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#host ⇒ ::String
Returns The unique identifier of the capacity host within the capacity sub-block.
64724 64725 64726 64727 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64724 class ReservationSlotPhysicalTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sub_block ⇒ ::String
Returns The unique identifier of the capacity sub-block within the capacity block.
64724 64725 64726 64727 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64724 class ReservationSlotPhysicalTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |