Class: Google::Cloud::Compute::V1::ReservationSlotStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#physical_topology::Google::Cloud::Compute::V1::ReservationSlotPhysicalTopology

Returns Output only. [Output Only] The physical topology of the reservation sub-block.

Returns:



64738
64739
64740
64741
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64738

class ReservationSlotStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rdma_ip_addresses::Array<::String>

Returns Output only. The RDMA IP address of the physical host.

Returns:

  • (::Array<::String>)

    Output only. The RDMA IP address of the physical host.



64738
64739
64740
64741
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64738

class ReservationSlotStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#running_instances::Array<::String>

Returns Output only. The URIs of the instances currently running on this slot.

Returns:

  • (::Array<::String>)

    Output only. The URIs of the instances currently running on this slot.



64738
64739
64740
64741
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64738

class ReservationSlotStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end