Class: Google::Cloud::Compute::V1::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A list of reservation slots within a single reservation.

Instance Attribute Summary collapse

Instance Attribute Details

#id::String

Returns The unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    The unique identifier for the resource; defined by the server.



64795
64796
64797
64798
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64795

class ReservationSlotsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#items::Array<::Google::Cloud::Compute::V1::ReservationSlot>

Returns A list of reservation slot resources.

Returns:



64795
64796
64797
64798
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64795

class ReservationSlotsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::String

Returns The type of resource. Alwayscompute#reservationSlot for a list of reservation slots.

Returns:

  • (::String)

    The type of resource. Alwayscompute#reservationSlot for a list of reservation slots.



64795
64796
64797
64798
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64795

class ReservationSlotsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



64795
64796
64797
64798
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64795

class ReservationSlotsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns The server-defined URL for this resource.

Returns:

  • (::String)

    The server-defined URL for this resource.



64795
64796
64797
64798
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64795

class ReservationSlotsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning::Google::Cloud::Compute::V1::Warning

Returns An informational warning message.

Returns:



64795
64796
64797
64798
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64795

class ReservationSlotsListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end