Class: Google::Cloud::Compute::V1::ReservationSubBlocksReportFaultyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DisruptionSchedule, FailureComponent

Instance Attribute Summary collapse

Instance Attribute Details

#disruption_schedule ⇒ ::String

Returns The disruption schedule for the subBlock. Check the DisruptionSchedule enum for the list of possible values.

Returns:

  • (::String) —

    The disruption schedule for the subBlock. Check the DisruptionSchedule enum for the list of possible values.



68301
68302
68303
68304
68305
68306
68307
68308
68309
68310
68311
68312
68313
68314
68315
68316
68317
68318
68319
68320
68321
68322
68323
68324
68325
68326
68327
68328
68329
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68301

class ReservationSubBlocksReportFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the subBlock.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # All VMs will be disrupted immediately.
    IMMEDIATE = 152_881_041
  end

  # The component that experienced the fault.
  module FailureComponent
    # A value indicating that the enum field is not set.
    UNDEFINED_FAILURE_COMPONENT = 0

    FAILURE_COMPONENT_UNSPECIFIED = 332_003_744

    # Multiple hosts experienced the fault.
    MULTIPLE_FAULTY_HOSTS = 423_545_298

    # The NVLink switch experienced the fault.
    NVLINK_SWITCH = 239_107_153
  end
end

#failure_component ⇒ ::String

Returns The component that experienced the fault. Check the FailureComponent enum for the list of possible values.

Returns:

  • (::String) —

    The component that experienced the fault. Check the FailureComponent enum for the list of possible values.



68301
68302
68303
68304
68305
68306
68307
68308
68309
68310
68311
68312
68313
68314
68315
68316
68317
68318
68319
68320
68321
68322
68323
68324
68325
68326
68327
68328
68329
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68301

class ReservationSubBlocksReportFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the subBlock.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # All VMs will be disrupted immediately.
    IMMEDIATE = 152_881_041
  end

  # The component that experienced the fault.
  module FailureComponent
    # A value indicating that the enum field is not set.
    UNDEFINED_FAILURE_COMPONENT = 0

    FAILURE_COMPONENT_UNSPECIFIED = 332_003_744

    # Multiple hosts experienced the fault.
    MULTIPLE_FAULTY_HOSTS = 423_545_298

    # The NVLink switch experienced the fault.
    NVLINK_SWITCH = 239_107_153
  end
end

#fault_reasons ⇒ ::Array<::Google::Cloud::Compute::V1::ReservationSubBlocksReportFaultyRequestFaultReason>

Returns The reasons for the fault experienced with the subBlock.

Returns:



68301
68302
68303
68304
68305
68306
68307
68308
68309
68310
68311
68312
68313
68314
68315
68316
68317
68318
68319
68320
68321
68322
68323
68324
68325
68326
68327
68328
68329
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68301

class ReservationSubBlocksReportFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the subBlock.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # All VMs will be disrupted immediately.
    IMMEDIATE = 152_881_041
  end

  # The component that experienced the fault.
  module FailureComponent
    # A value indicating that the enum field is not set.
    UNDEFINED_FAILURE_COMPONENT = 0

    FAILURE_COMPONENT_UNSPECIFIED = 332_003_744

    # Multiple hosts experienced the fault.
    MULTIPLE_FAULTY_HOSTS = 423_545_298

    # The NVLink switch experienced the fault.
    NVLINK_SWITCH = 239_107_153
  end
end