Class: Google::Cloud::Compute::V1::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The reason for the fault experienced with the subBlock.

Defined Under Namespace

Modules: Behavior

Instance Attribute Summary collapse

Instance Attribute Details

#behavior ⇒ ::String

Returns The behavior of the fault experienced with the subBlock. Check the Behavior enum for the list of possible values.

Returns:

  • (::String) —

    The behavior of the fault experienced with the subBlock. Check the Behavior enum for the list of possible values.



68339
68340
68341
68342
68343
68344
68345
68346
68347
68348
68349
68350
68351
68352
68353
68354
68355
68356
68357
68358
68359
68360
68361
68362
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68339

class ReservationSubBlocksReportFaultyRequestFaultReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The behavior of the fault experienced with the subBlock.
  module Behavior
    # A value indicating that the enum field is not set.
    UNDEFINED_BEHAVIOR = 0

    FAULT_BEHAVIOR_UNSPECIFIED = 447_660_743

    # The subBlock experienced a GPU error.
    GPU_ERROR = 198_817_909

    # The subBlock experienced performance issues.
    PERFORMANCE = 135_701_520

    # The subBlock experienced silent data corruption.
    SILENT_DATA_CORRUPTION = 111_360_678

    # The subBlock experienced a switch failure.
    SWITCH_FAILURE = 254_909_279
  end
end

#description ⇒ ::String

Returns The description of the fault experienced with the subBlock.

Returns:

  • (::String) —

    The description of the fault experienced with the subBlock.



68339
68340
68341
68342
68343
68344
68345
68346
68347
68348
68349
68350
68351
68352
68353
68354
68355
68356
68357
68358
68359
68360
68361
68362
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68339

class ReservationSubBlocksReportFaultyRequestFaultReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The behavior of the fault experienced with the subBlock.
  module Behavior
    # A value indicating that the enum field is not set.
    UNDEFINED_BEHAVIOR = 0

    FAULT_BEHAVIOR_UNSPECIFIED = 447_660_743

    # The subBlock experienced a GPU error.
    GPU_ERROR = 198_817_909

    # The subBlock experienced performance issues.
    PERFORMANCE = 135_701_520

    # The subBlock experienced silent data corruption.
    SILENT_DATA_CORRUPTION = 111_360_678

    # The subBlock experienced a switch failure.
    SWITCH_FAILURE = 254_909_279
  end
end