Module: Google::Cloud::Compute::V1::ReservationSubBlocksReportFaultyRequestFaultReason::Behavior

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The behavior of the fault experienced with the subBlock.

Constant Summary collapse

UNDEFINED_BEHAVIOR =

A value indicating that the enum field is not set.

0
FAULT_BEHAVIOR_UNSPECIFIED =
447_660_743
GPU_ERROR =

The subBlock experienced a GPU error.

198_817_909
PERFORMANCE =

The subBlock experienced performance issues.

135_701_520
SILENT_DATA_CORRUPTION =

The subBlock experienced silent data corruption.

111_360_678
SWITCH_FAILURE =

The subBlock experienced a switch failure.

254_909_279