Class: Google::Cloud::Compute::V1::ReservationsPerformMaintenanceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: MaintenanceScope

Instance Attribute Summary collapse

Instance Attribute Details

#maintenance_scope ⇒ ::String

Returns Specifies if all, running or unused hosts are in scope for this request. Check the MaintenanceScope enum for the list of possible values.

Returns:

  • (::String) —

    Specifies if all, running or unused hosts are in scope for this request. Check the MaintenanceScope enum for the list of possible values.



68398
68399
68400
68401
68402
68403
68404
68405
68406
68407
68408
68409
68410
68411
68412
68413
68414
68415
68416
68417
68418
68419
68420
68421
68422
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68398

class ReservationsPerformMaintenanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies if all, running or unused hosts are in scope for this request.
  module MaintenanceScope
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_SCOPE = 0

    # Trigger maintenance for all hosts belonging to this reservation
    # irrespective of whether VMs are running on them or not.
    ALL = 64_897

    # Internal only
    MAINTENANCE_SCOPE_UNSPECIFIED = 78_827_328

    # Trigger maintenance only on the hosts belonging to this reservation which
    # have VMs running on them.
    RUNNING_VMS = 535_770_588

    # Trigger maintenance only on the hosts belonging to this reservation which
    # do not have any VMs running on them. This is not allowed for Standard ExR
    UNUSED_CAPACITY = 212_724_995
  end
end