Class: Google::Cloud::Compute::V1::ReservationsScopedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#reservations ⇒ ::Array<::Google::Cloud::Compute::V1::Reservation>

Returns A list of reservations contained in this scope.

Returns:



68440
68441
68442
68443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68440

class ReservationsScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns Informational warning which replaces the list of reservations when the list is empty.

Returns:



68440
68441
68442
68443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68440

class ReservationsScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end