Class: Google::Cloud::Compute::V1::ResourceCommitment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Commitment for a particular hardware resource (a commitment is composed of one or more of these).

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#accelerator_type::String



30325
30326
30327
30328
30329
30330
30331
30332
30333
30334
30335
30336
30337
30338
30339
30340
30341
30342
30343
30344
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30325

class ResourceCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of hardware resource that you want to specify. You can specify any of the following values: - VCPU - MEMORY - LOCAL_SSD - ACCELERATOR Specify as a separate entry in the list for each individual resource type.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    ACCELERATOR = 429_815_371

    LOCAL_SSD = 508_934_896

    MEMORY = 123_056_385

    UNSPECIFIED = 526_786_327

    VCPU = 2_628_978
  end
end

#amount::Integer



30325
30326
30327
30328
30329
30330
30331
30332
30333
30334
30335
30336
30337
30338
30339
30340
30341
30342
30343
30344
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30325

class ResourceCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of hardware resource that you want to specify. You can specify any of the following values: - VCPU - MEMORY - LOCAL_SSD - ACCELERATOR Specify as a separate entry in the list for each individual resource type.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    ACCELERATOR = 429_815_371

    LOCAL_SSD = 508_934_896

    MEMORY = 123_056_385

    UNSPECIFIED = 526_786_327

    VCPU = 2_628_978
  end
end

#type::String



30325
30326
30327
30328
30329
30330
30331
30332
30333
30334
30335
30336
30337
30338
30339
30340
30341
30342
30343
30344
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30325

class ResourceCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of hardware resource that you want to specify. You can specify any of the following values: - VCPU - MEMORY - LOCAL_SSD - ACCELERATOR Specify as a separate entry in the list for each individual resource type.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    ACCELERATOR = 429_815_371

    LOCAL_SSD = 508_934_896

    MEMORY = 123_056_385

    UNSPECIFIED = 526_786_327

    VCPU = 2_628_978
  end
end