Module: Google::Cloud::Compute::V1::ResourceCommitment::Type

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The type of hardware resource that you want to specify. You can specify any of the following values: - VCPU - MEMORY - LOCAL_SSD - ACCELERATOR Specify as a separate entry in the list for each individual resource type.

Constant Summary collapse

UNDEFINED_TYPE =

A value indicating that the enum field is not set.

0
ACCELERATOR =
429_815_371
LOCAL_SSD =
508_934_896
MEMORY =
123_056_385
UNSPECIFIED =
526_786_327
VCPU =
2_628_978