Class: Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained.

Instance Attribute Summary collapse

Instance Attribute Details

#retention_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Returns Retention policy applied to snapshots created by this resource policy.

Returns:



69069
69070
69071
69072
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69069

class ResourcePolicySnapshotSchedulePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schedule ⇒ ::Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicySchedule

Returns A Vm Maintenance Policy specifies what kind of infrastructure maintenance we are allowed to perform on this VM and when. Schedule that is applied to disks covered by this policy.

Returns:



69069
69070
69071
69072
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69069

class ResourcePolicySnapshotSchedulePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#snapshot_properties ⇒ ::Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicySnapshotProperties

Returns Properties with which snapshots are created such as labels, encryption keys.

Returns:



69069
69070
69071
69072
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69069

class ResourcePolicySnapshotSchedulePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end