Class: Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicySnapshotProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specified snapshot properties for scheduled snapshots created by this policy.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#chain_name ⇒ ::String

Returns Chain name that the snapshot is created in.

Returns:

  • (::String) —

    Chain name that the snapshot is created in.



69129
69130
69131
69132
69133
69134
69135
69136
69137
69138
69139
69140
69141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69129

class ResourcePolicySnapshotSchedulePolicySnapshotProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#guest_flush ⇒ ::Boolean

Returns Indication to perform a 'guest aware' snapshot.

Returns:

  • (::Boolean) —

    Indication to perform a 'guest aware' snapshot.



69129
69130
69131
69132
69133
69134
69135
69136
69137
69138
69139
69140
69141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69129

class ResourcePolicySnapshotSchedulePolicySnapshotProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty.



69129
69130
69131
69132
69133
69134
69135
69136
69137
69138
69139
69140
69141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69129

class ResourcePolicySnapshotSchedulePolicySnapshotProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#storage_locations ⇒ ::Array<::String>

Returns Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).

Returns:

  • (::Array<::String>) —

    Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).



69129
69130
69131
69132
69133
69134
69135
69136
69137
69138
69139
69140
69141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69129

class ResourcePolicySnapshotSchedulePolicySnapshotProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end