Class: Google::Cloud::Compute::V1::ResourcePolicyWeeklyCycleDayOfWeek

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Day

Instance Attribute Summary collapse

Instance Attribute Details

#day ⇒ ::String

Returns Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.

Returns:

  • (::String) —

    Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.



69166
69167
69168
69169
69170
69171
69172
69173
69174
69175
69176
69177
69178
69179
69180
69181
69182
69183
69184
69185
69186
69187
69188
69189
69190
69191
69192
69193
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69166

class ResourcePolicyWeeklyCycleDayOfWeek
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines a schedule that runs on specific days of the week. Specify
  # one or more days. The following options are available:
  # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
  module Day
    # A value indicating that the enum field is not set.
    UNDEFINED_DAY = 0

    FRIDAY = 471_398_751

    INVALID = 530_283_991

    MONDAY = 132_310_288

    SATURDAY = 279_037_881

    SUNDAY = 309_626_320

    THURSDAY = 207_198_682

    TUESDAY = 277_509_677

    WEDNESDAY = 422_029_110
  end
end

#duration ⇒ ::String

Returns Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.

Returns:

  • (::String) —

    Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.



69166
69167
69168
69169
69170
69171
69172
69173
69174
69175
69176
69177
69178
69179
69180
69181
69182
69183
69184
69185
69186
69187
69188
69189
69190
69191
69192
69193
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69166

class ResourcePolicyWeeklyCycleDayOfWeek
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines a schedule that runs on specific days of the week. Specify
  # one or more days. The following options are available:
  # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
  module Day
    # A value indicating that the enum field is not set.
    UNDEFINED_DAY = 0

    FRIDAY = 471_398_751

    INVALID = 530_283_991

    MONDAY = 132_310_288

    SATURDAY = 279_037_881

    SUNDAY = 309_626_320

    THURSDAY = 207_198_682

    TUESDAY = 277_509_677

    WEDNESDAY = 422_029_110
  end
end

#start_time ⇒ ::String

Returns Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.

Returns:

  • (::String) —

    Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.



69166
69167
69168
69169
69170
69171
69172
69173
69174
69175
69176
69177
69178
69179
69180
69181
69182
69183
69184
69185
69186
69187
69188
69189
69190
69191
69192
69193
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69166

class ResourcePolicyWeeklyCycleDayOfWeek
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines a schedule that runs on specific days of the week. Specify
  # one or more days. The following options are available:
  # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
  module Day
    # A value indicating that the enum field is not set.
    UNDEFINED_DAY = 0

    FRIDAY = 471_398_751

    INVALID = 530_283_991

    MONDAY = 132_310_288

    SATURDAY = 279_037_881

    SUNDAY = 309_626_320

    THURSDAY = 207_198_682

    TUESDAY = 277_509_677

    WEDNESDAY = 422_029_110
  end
end