Class: Google::Cloud::Compute::V1::ResourcePolicyWorkloadPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents the workload policy.

Defined Under Namespace

Modules: AcceleratorTopologyMode, MaxTopologyDistance, Type

Instance Attribute Summary collapse

Instance Attribute Details

#accelerator_topology ⇒ ::String

Returns Specifies the topology required to create a partition for VMs that have interconnected GPUs.

Returns:

  • (::String) —

    Specifies the topology required to create a partition for VMs that have interconnected GPUs.



69213
69214
69215
69216
69217
69218
69219
69220
69221
69222
69223
69224
69225
69226
69227
69228
69229
69230
69231
69232
69233
69234
69235
69236
69237
69238
69239
69240
69241
69242
69243
69244
69245
69246
69247
69248
69249
69250
69251
69252
69253
69254
69255
69256
69257
69258
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69213

class ResourcePolicyWorkloadPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the connection mode for the accelerator topology. If not
  # specified, the default is AUTO_CONNECT.
  module AcceleratorTopologyMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0

    # The interconnected chips are pre-configured at the time of VM creation.
    AUTO_CONNECT = 491_872_826

    # The interconnected chips are connected on demand. At the time of VM
    # creation, the chips are not connected.
    PROVISION_ONLY = 399_134_966
  end

  # Specifies the maximum distance between instances.
  module MaxTopologyDistance
    # A value indicating that the enum field is not set.
    UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0

    # VMs must be provisioned in the same block.
    BLOCK = 63_294_573

    # VMs must be provisioned in the same cluster.
    CLUSTER = 516_333_018

    # VMs must be provisioned in the same subblock.
    SUBBLOCK = 316_202_573
  end

  # Specifies the intent of the instance placement in the MIG.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG spreads out the instances as much as possible for high availability.
    HIGH_AVAILABILITY = 409_487_576

    # MIG provisions instances as close to each other as possible for high
    # throughput.
    HIGH_THROUGHPUT = 146_499_815
  end
end

#accelerator_topology_mode ⇒ ::String

Returns Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Check the AcceleratorTopologyMode enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Check the AcceleratorTopologyMode enum for the list of possible values.



69213
69214
69215
69216
69217
69218
69219
69220
69221
69222
69223
69224
69225
69226
69227
69228
69229
69230
69231
69232
69233
69234
69235
69236
69237
69238
69239
69240
69241
69242
69243
69244
69245
69246
69247
69248
69249
69250
69251
69252
69253
69254
69255
69256
69257
69258
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69213

class ResourcePolicyWorkloadPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the connection mode for the accelerator topology. If not
  # specified, the default is AUTO_CONNECT.
  module AcceleratorTopologyMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0

    # The interconnected chips are pre-configured at the time of VM creation.
    AUTO_CONNECT = 491_872_826

    # The interconnected chips are connected on demand. At the time of VM
    # creation, the chips are not connected.
    PROVISION_ONLY = 399_134_966
  end

  # Specifies the maximum distance between instances.
  module MaxTopologyDistance
    # A value indicating that the enum field is not set.
    UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0

    # VMs must be provisioned in the same block.
    BLOCK = 63_294_573

    # VMs must be provisioned in the same cluster.
    CLUSTER = 516_333_018

    # VMs must be provisioned in the same subblock.
    SUBBLOCK = 316_202_573
  end

  # Specifies the intent of the instance placement in the MIG.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG spreads out the instances as much as possible for high availability.
    HIGH_AVAILABILITY = 409_487_576

    # MIG provisions instances as close to each other as possible for high
    # throughput.
    HIGH_THROUGHPUT = 146_499_815
  end
end

#max_topology_distance ⇒ ::String

Returns Specifies the maximum distance between instances. Check the MaxTopologyDistance enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the maximum distance between instances. Check the MaxTopologyDistance enum for the list of possible values.



69213
69214
69215
69216
69217
69218
69219
69220
69221
69222
69223
69224
69225
69226
69227
69228
69229
69230
69231
69232
69233
69234
69235
69236
69237
69238
69239
69240
69241
69242
69243
69244
69245
69246
69247
69248
69249
69250
69251
69252
69253
69254
69255
69256
69257
69258
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69213

class ResourcePolicyWorkloadPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the connection mode for the accelerator topology. If not
  # specified, the default is AUTO_CONNECT.
  module AcceleratorTopologyMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0

    # The interconnected chips are pre-configured at the time of VM creation.
    AUTO_CONNECT = 491_872_826

    # The interconnected chips are connected on demand. At the time of VM
    # creation, the chips are not connected.
    PROVISION_ONLY = 399_134_966
  end

  # Specifies the maximum distance between instances.
  module MaxTopologyDistance
    # A value indicating that the enum field is not set.
    UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0

    # VMs must be provisioned in the same block.
    BLOCK = 63_294_573

    # VMs must be provisioned in the same cluster.
    CLUSTER = 516_333_018

    # VMs must be provisioned in the same subblock.
    SUBBLOCK = 316_202_573
  end

  # Specifies the intent of the instance placement in the MIG.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG spreads out the instances as much as possible for high availability.
    HIGH_AVAILABILITY = 409_487_576

    # MIG provisions instances as close to each other as possible for high
    # throughput.
    HIGH_THROUGHPUT = 146_499_815
  end
end

#type ⇒ ::String

Returns Specifies the intent of the instance placement in the MIG. Check the Type enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the intent of the instance placement in the MIG. Check the Type enum for the list of possible values.



69213
69214
69215
69216
69217
69218
69219
69220
69221
69222
69223
69224
69225
69226
69227
69228
69229
69230
69231
69232
69233
69234
69235
69236
69237
69238
69239
69240
69241
69242
69243
69244
69245
69246
69247
69248
69249
69250
69251
69252
69253
69254
69255
69256
69257
69258
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69213

class ResourcePolicyWorkloadPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the connection mode for the accelerator topology. If not
  # specified, the default is AUTO_CONNECT.
  module AcceleratorTopologyMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0

    # The interconnected chips are pre-configured at the time of VM creation.
    AUTO_CONNECT = 491_872_826

    # The interconnected chips are connected on demand. At the time of VM
    # creation, the chips are not connected.
    PROVISION_ONLY = 399_134_966
  end

  # Specifies the maximum distance between instances.
  module MaxTopologyDistance
    # A value indicating that the enum field is not set.
    UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0

    # VMs must be provisioned in the same block.
    BLOCK = 63_294_573

    # VMs must be provisioned in the same cluster.
    CLUSTER = 516_333_018

    # VMs must be provisioned in the same subblock.
    SUBBLOCK = 316_202_573
  end

  # Specifies the intent of the instance placement in the MIG.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG spreads out the instances as much as possible for high availability.
    HIGH_AVAILABILITY = 409_487_576

    # MIG provisions instances as close to each other as possible for high
    # throughput.
    HIGH_THROUGHPUT = 146_499_815
  end
end