Class: Google::Cloud::Compute::V1::ResourceStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourceStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.
Instance Attribute Summary collapse
-
#physical_host ⇒ ::String
[Output Only] The precise location of your instance within the zone's data center, including the block, sub-block, and host.
-
#physical_host_topology ⇒ ::Google::Cloud::Compute::V1::ResourceStatusPhysicalHostTopology
[Output Only] A series of fields containing the global name of the Compute Engine cluster, as well as the ID of the block, sub-block, and host on which the running instance is located.
- #scheduling ⇒ ::Google::Cloud::Compute::V1::ResourceStatusScheduling
- #upcoming_maintenance ⇒ ::Google::Cloud::Compute::V1::UpcomingMaintenance
Instance Attribute Details
#physical_host ⇒ ::String
Returns [Output Only] The precise location of your instance within the zone's data center, including the block, sub-block, and host. The field is formatted as follows: blockId/subBlockId/hostId.
28168 28169 28170 28171 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28168 class ResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#physical_host_topology ⇒ ::Google::Cloud::Compute::V1::ResourceStatusPhysicalHostTopology
Returns [Output Only] A series of fields containing the global name of the Compute Engine cluster, as well as the ID of the block, sub-block, and host on which the running instance is located.
28168 28169 28170 28171 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28168 class ResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scheduling ⇒ ::Google::Cloud::Compute::V1::ResourceStatusScheduling
28168 28169 28170 28171 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28168 class ResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#upcoming_maintenance ⇒ ::Google::Cloud::Compute::V1::UpcomingMaintenance
28168 28169 28170 28171 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28168 class ResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |