Class: Google::Cloud::Compute::V1::ResourceStatusPhysicalHostTopology
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourceStatusPhysicalHostTopology
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents the physical host topology of the host on which the VM is running.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ ::Google::Cloud::Compute::V1::ResourceStatusPhysicalHostTopologyAdditionalAttributes
Output only.
-
#block ⇒ ::String
[Output Only] The ID of the block in which the running instance is located.
-
#cluster ⇒ ::String
[Output Only] The global name of the Compute Engine cluster where the running instance is located.
-
#host ⇒ ::String
[Output Only] The ID of the host on which the running instance is located.
-
#subblock ⇒ ::String
[Output Only] The ID of the sub-block in which the running instance is located.
Instance Attribute Details
#additional_attributes ⇒ ::Google::Cloud::Compute::V1::ResourceStatusPhysicalHostTopologyAdditionalAttributes
Returns Output only. [Output Only] Additional location information of the running instance.
67794 67795 67796 67797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67794 class ResourceStatusPhysicalHostTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#block ⇒ ::String
Returns [Output Only] The ID of the block in which the running instance is located. Instances within the same block experience low network latency.
67794 67795 67796 67797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67794 class ResourceStatusPhysicalHostTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cluster ⇒ ::String
Returns [Output Only] The global name of the Compute Engine cluster where the running instance is located.
67794 67795 67796 67797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67794 class ResourceStatusPhysicalHostTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#host ⇒ ::String
Returns [Output Only] The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency.
67794 67795 67796 67797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67794 class ResourceStatusPhysicalHostTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subblock ⇒ ::String
Returns [Output Only] The ID of the sub-block in which the running instance is located. Instances in the same sub-block experience lower network latency than instances in the same block.
67794 67795 67796 67797 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67794 class ResourceStatusPhysicalHostTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |