Class: Google::Cloud::Compute::V1::ResourceStatusReservationConsumptionInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Reservation consumption information that the instance is consuming from.

Instance Attribute Summary collapse

Instance Attribute Details

#consumed_reservation ⇒ ::String

Returns Output only. [Output Only] The full resource name of the reservation that this instance is consuming from.

Returns:

  • (::String) —

    Output only. [Output Only] The full resource name of the reservation that this instance is consuming from.



69388
69389
69390
69391
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69388

class ResourceStatusReservationConsumptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#consumed_reservation_block ⇒ ::String

Returns Output only. [Output Only] The full resource name of the reservation block that this instance is consuming from.

Returns:

  • (::String) —

    Output only. [Output Only] The full resource name of the reservation block that this instance is consuming from.



69388
69389
69390
69391
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69388

class ResourceStatusReservationConsumptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#consumed_reservation_sub_block ⇒ ::String

Returns Output only. [Output Only] The full resource name of the reservation sub-block that this instance is consuming from.

Returns:

  • (::String) —

    Output only. [Output Only] The full resource name of the reservation sub-block that this instance is consuming from.



69388
69389
69390
69391
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69388

class ResourceStatusReservationConsumptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end