Class: Google::Cloud::Compute::V1::ResourceStatusScheduling

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#availability_domain ⇒ ::Integer

Returns Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance.

Returns:

  • (::Integer) —

    Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance.



69405
69406
69407
69408
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69405

class ResourceStatusScheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#graceful_shutdown_timestamp ⇒ ::String

Returns Output only. Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format.

Returns:

  • (::String) —

    Output only. Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format.



69405
69406
69407
69408
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69405

class ResourceStatusScheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#termination_timestamp ⇒ ::String

Returns Time in future when the instance will be terminated inRFC3339 text format.

Returns:

  • (::String) —

    Time in future when the instance will be terminated inRFC3339 text format.



69405
69406
69407
69408
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69405

class ResourceStatusScheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end