Class: Google::Cloud::Compute::V1::ResumeRolloutRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResumeRolloutRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for Rollouts.Resume. See the method description for details.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
The etag of the Rollout.
-
#project ⇒ ::String
Required.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#rollout ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns The etag of the Rollout. If this is provided, the request will only succeed if the etag matches the current etag of the Rollout.
67964 67965 67966 67967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67964 class ResumeRolloutRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Required. Project ID for this request.
67964 67965 67966 67967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67964 class ResumeRolloutRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
67964 67965 67966 67967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67964 class ResumeRolloutRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rollout ⇒ ::String
Returns Required. Name of the Rollout resource to resume.
67964 67965 67966 67967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67964 class ResumeRolloutRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |