Class: Google::Cloud::Compute::V1::RiskDetailsGlobalDnsInsight

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Detailed insights for a global DNS reliability risk.

Instance Attribute Summary collapse

Instance Attribute Details

#project_default_is_global_dns ⇒ ::Boolean

Returns Indicates whether the project's default DNS setting is global DNS.

Returns:

  • (::Boolean) —

    Indicates whether the project's default DNS setting is global DNS.



69655
69656
69657
69658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69655

class RiskDetailsGlobalDnsInsight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query_observation_window ⇒ ::String

Returns The observation window for the query counts.

Returns:

  • (::String) —

    The observation window for the query counts.



69655
69656
69657
69658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69655

class RiskDetailsGlobalDnsInsight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#risky_query_count ⇒ ::Integer

Returns The number of queries that are risky. This is always less than or equal to total_query_count.

Returns:

  • (::Integer) —

    The number of queries that are risky. This is always less than or equal to total_query_count.



69655
69656
69657
69658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69655

class RiskDetailsGlobalDnsInsight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_query_count ⇒ ::Integer

Returns The total number of queries in the observation window.

Returns:

  • (::Integer) —

    The total number of queries in the observation window.



69655
69656
69657
69658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69655

class RiskDetailsGlobalDnsInsight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end