Module: Google::Cloud::Compute::V1::RolloutPlan::LocationScope

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL.

Constant Summary collapse

UNDEFINED_LOCATION_SCOPE =

A value indicating that the enum field is not set.

0
LOCATION_SCOPE_UNSPECIFIED =

Unspecified value. Considered as ZONAL.

416_410_498
REGIONAL =

Regional scope.

92_288_543
ZONAL =

Zonal scope.

85_547_428