Class: Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptionsDelay

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Options to control the delay, if any, between batches of projects.

Defined Under Namespace

Modules: Delimiter, Type

Instance Attribute Summary collapse

Instance Attribute Details

#delimiter ⇒ ::String

Returns Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location.

Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. Check the Delimiter enum for the list of possible values.

Returns:

  • (::String) —

    Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location.

    Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. Check the Delimiter enum for the list of possible values.



69938
69939
69940
69941
69942
69943
69944
69945
69946
69947
69948
69949
69950
69951
69952
69953
69954
69955
69956
69957
69958
69959
69960
69961
69962
69963
69964
69965
69966
69967
69968
69969
69970
69971
69972
69973
69974
69975
69976
69977
69978
69979
69980
69981
69982
69983
69984
69985
69986
69987
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69938

class RolloutPlanWaveOrchestrationOptionsDelay
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Controls whether the delay should only be added between batches of
  # projects corresponding to different locations, or also between
  # batches of projects corresponding to the same location.
  #
  # Must be set to DELIMITER_UNSPECIFIED if no delay is to be added.
  module Delimiter
    # A value indicating that the enum field is not set.
    UNDEFINED_DELIMITER = 0

    # The delay will also be added between batches of projects
    # corresponding to the same location.
    DELIMITER_BATCH = 253_390_530

    # The delay will only be added between batches of projects
    # corresponding to different locations.
    DELIMITER_LOCATION = 189_398_797

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    DELIMITER_UNSPECIFIED = 372_199_615
  end

  # Optional. Controls whether the specified duration is to be added at the end of
  # each batch, or if the total processing time for each batch will be
  # padded if needed to meet the specified duration.
  #
  # Must be set to TYPE_UNSPECIFIED if no delay is to be added.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The total processing time for each batch of projects will be padded
    # if needed to meet the specified delay duration.
    TYPE_MINIMUM = 234_909_673

    # The specified delay will directly be added after each batch of
    # projects as specified by the delimiter.
    TYPE_OFFSET = 165_747_000

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    TYPE_UNSPECIFIED = 437_714_322
  end
end

#duration ⇒ ::String

Returns Optional. The duration of the delay, if any, to be added between batches of projects. A zero duration corresponds to no delay.

Returns:

  • (::String) —

    Optional. The duration of the delay, if any, to be added between batches of projects. A zero duration corresponds to no delay.



69938
69939
69940
69941
69942
69943
69944
69945
69946
69947
69948
69949
69950
69951
69952
69953
69954
69955
69956
69957
69958
69959
69960
69961
69962
69963
69964
69965
69966
69967
69968
69969
69970
69971
69972
69973
69974
69975
69976
69977
69978
69979
69980
69981
69982
69983
69984
69985
69986
69987
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69938

class RolloutPlanWaveOrchestrationOptionsDelay
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Controls whether the delay should only be added between batches of
  # projects corresponding to different locations, or also between
  # batches of projects corresponding to the same location.
  #
  # Must be set to DELIMITER_UNSPECIFIED if no delay is to be added.
  module Delimiter
    # A value indicating that the enum field is not set.
    UNDEFINED_DELIMITER = 0

    # The delay will also be added between batches of projects
    # corresponding to the same location.
    DELIMITER_BATCH = 253_390_530

    # The delay will only be added between batches of projects
    # corresponding to different locations.
    DELIMITER_LOCATION = 189_398_797

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    DELIMITER_UNSPECIFIED = 372_199_615
  end

  # Optional. Controls whether the specified duration is to be added at the end of
  # each batch, or if the total processing time for each batch will be
  # padded if needed to meet the specified duration.
  #
  # Must be set to TYPE_UNSPECIFIED if no delay is to be added.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The total processing time for each batch of projects will be padded
    # if needed to meet the specified delay duration.
    TYPE_MINIMUM = 234_909_673

    # The specified delay will directly be added after each batch of
    # projects as specified by the delimiter.
    TYPE_OFFSET = 165_747_000

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    TYPE_UNSPECIFIED = 437_714_322
  end
end

#type ⇒ ::String

Returns Optional. Controls whether the specified duration is to be added at the end of each batch, or if the total processing time for each batch will be padded if needed to meet the specified duration.

Must be set to TYPE_UNSPECIFIED if no delay is to be added. Check the Type enum for the list of possible values.

Returns:

  • (::String) —

    Optional. Controls whether the specified duration is to be added at the end of each batch, or if the total processing time for each batch will be padded if needed to meet the specified duration.

    Must be set to TYPE_UNSPECIFIED if no delay is to be added. Check the Type enum for the list of possible values.



69938
69939
69940
69941
69942
69943
69944
69945
69946
69947
69948
69949
69950
69951
69952
69953
69954
69955
69956
69957
69958
69959
69960
69961
69962
69963
69964
69965
69966
69967
69968
69969
69970
69971
69972
69973
69974
69975
69976
69977
69978
69979
69980
69981
69982
69983
69984
69985
69986
69987
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69938

class RolloutPlanWaveOrchestrationOptionsDelay
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Controls whether the delay should only be added between batches of
  # projects corresponding to different locations, or also between
  # batches of projects corresponding to the same location.
  #
  # Must be set to DELIMITER_UNSPECIFIED if no delay is to be added.
  module Delimiter
    # A value indicating that the enum field is not set.
    UNDEFINED_DELIMITER = 0

    # The delay will also be added between batches of projects
    # corresponding to the same location.
    DELIMITER_BATCH = 253_390_530

    # The delay will only be added between batches of projects
    # corresponding to different locations.
    DELIMITER_LOCATION = 189_398_797

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    DELIMITER_UNSPECIFIED = 372_199_615
  end

  # Optional. Controls whether the specified duration is to be added at the end of
  # each batch, or if the total processing time for each batch will be
  # padded if needed to meet the specified duration.
  #
  # Must be set to TYPE_UNSPECIFIED if no delay is to be added.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The total processing time for each batch of projects will be padded
    # if needed to meet the specified delay duration.
    TYPE_MINIMUM = 234_909_673

    # The specified delay will directly be added after each batch of
    # projects as specified by the delimiter.
    TYPE_OFFSET = 165_747_000

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    TYPE_UNSPECIFIED = 437_714_322
  end
end