Module: Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptionsDelay::Delimiter

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location.

Must be set to DELIMITER_UNSPECIFIED if no delay is to be added.

Constant Summary collapse

UNDEFINED_DELIMITER =

A value indicating that the enum field is not set.

0
DELIMITER_BATCH =

The delay will also be added between batches of projects corresponding to the same location.

253_390_530
DELIMITER_LOCATION =

The delay will only be added between batches of projects corresponding to different locations.

189_398_797
DELIMITER_UNSPECIFIED =

No delay will be added between batches of projects. Processing will continue with the next batch as soon as the previous batch of LROs is done.

372_199_615