Class: Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetails
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Details of the wave for products using the Orchestrated integration model.
Defined Under Namespace
Classes: LocationStatusEntry
Instance Attribute Summary collapse
-
#completed_resources_count ⇒ ::Integer
Output only.
-
#estimated_completion_time ⇒ ::String
Output only.
-
#estimated_total_resources_count ⇒ ::Integer
Output only.
-
#failed_locations ⇒ ::Array<::String>
Output only.
-
#failed_resources_count ⇒ ::Integer
Output only.
-
#location_status ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus}
Output only.
Instance Attribute Details
#completed_resources_count ⇒ ::Integer
Returns Output only. Resource completed so far.
70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70168 class RolloutWaveDetailsOrchestratedWaveDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus] class LocationStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#estimated_completion_time ⇒ ::String
Returns Output only. Estimated timestamp at which the wave will complete. Extrapolated from current progress.
70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70168 class RolloutWaveDetailsOrchestratedWaveDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus] class LocationStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#estimated_total_resources_count ⇒ ::Integer
Returns Output only. Estimated total count of resources.
70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70168 class RolloutWaveDetailsOrchestratedWaveDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus] class LocationStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#failed_locations ⇒ ::Array<::String>
Returns Output only. Locations that failed during orchestration, and ProgressiveRollout stopped retrying. There may be some successful resources rolled out in the wave as the location may have failed later in the Rollout.
70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70168 class RolloutWaveDetailsOrchestratedWaveDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus] class LocationStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#failed_resources_count ⇒ ::Integer
Returns Output only. Resources failed.
70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70168 class RolloutWaveDetailsOrchestratedWaveDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus] class LocationStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#location_status ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus}
Returns Output only. Status of each location in the wave. Map keys (locations) must be specified like "us-east1" or "asia-west1-a".
70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70168 class RolloutWaveDetailsOrchestratedWaveDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus] class LocationStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |