Class: Google::Cloud::Compute::V1::RouteAsPath

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: PathSegmentType

Instance Attribute Summary collapse

Instance Attribute Details

#as_lists ⇒ ::Array<::Integer>

Returns [Output Only] The AS numbers of the AS Path.

Returns:

  • (::Array<::Integer>) —

    [Output Only] The AS numbers of the AS Path.



70486
70487
70488
70489
70490
70491
70492
70493
70494
70495
70496
70497
70498
70499
70500
70501
70502
70503
70504
70505
70506
70507
70508
70509
70510
70511
70512
70513
70514
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70486

class RouteAsPath
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The type of the AS Path, which can be one of the following
  # values:
  # - 'AS_SET': unordered set of autonomous systems that the route
  # in has traversed
  # - 'AS_SEQUENCE': ordered set of autonomous
  # systems that the route has traversed
  # - 'AS_CONFED_SEQUENCE':
  # ordered set of Member Autonomous Systems in the local confederation that
  # the route has traversed
  # - 'AS_CONFED_SET': unordered set of
  # Member Autonomous Systems in the local confederation that the route has
  # traversed
  module PathSegmentType
    # A value indicating that the enum field is not set.
    UNDEFINED_PATH_SEGMENT_TYPE = 0

    AS_CONFED_SEQUENCE = 222_152_624

    AS_CONFED_SET = 374_040_307

    AS_SEQUENCE = 106_735_918

    AS_SET = 329_846_453
  end
end

#path_segment_type ⇒ ::String

Returns [Output Only] The type of the AS Path, which can be one of the following values:

  • 'AS_SET': unordered set of autonomous systems that the route in has traversed
  • 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed
  • 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed
  • 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Check the PathSegmentType enum for the list of possible values.

Returns:

  • (::String) —

    [Output Only] The type of the AS Path, which can be one of the following values:

    • 'AS_SET': unordered set of autonomous systems that the route in has traversed
    • 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed
    • 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed
    • 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Check the PathSegmentType enum for the list of possible values.


70486
70487
70488
70489
70490
70491
70492
70493
70494
70495
70496
70497
70498
70499
70500
70501
70502
70503
70504
70505
70506
70507
70508
70509
70510
70511
70512
70513
70514
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70486

class RouteAsPath
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The type of the AS Path, which can be one of the following
  # values:
  # - 'AS_SET': unordered set of autonomous systems that the route
  # in has traversed
  # - 'AS_SEQUENCE': ordered set of autonomous
  # systems that the route has traversed
  # - 'AS_CONFED_SEQUENCE':
  # ordered set of Member Autonomous Systems in the local confederation that
  # the route has traversed
  # - 'AS_CONFED_SET': unordered set of
  # Member Autonomous Systems in the local confederation that the route has
  # traversed
  module PathSegmentType
    # A value indicating that the enum field is not set.
    UNDEFINED_PATH_SEGMENT_TYPE = 0

    AS_CONFED_SEQUENCE = 222_152_624

    AS_CONFED_SET = 374_040_307

    AS_SEQUENCE = 106_735_918

    AS_SET = 329_846_453
  end
end