Module: Google::Cloud::Compute::V1::RouteAsPath::PathSegmentType
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] The type of the AS Path, which can be one of the following values: - 'AS_SET': unordered set of autonomous systems that the route in has traversed - 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed - 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed - 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed
Constant Summary collapse
- UNDEFINED_PATH_SEGMENT_TYPE =
A value indicating that the enum field is not set.
0- AS_CONFED_SEQUENCE =
222_152_624- AS_CONFED_SET =
374_040_307- AS_SEQUENCE =
106_735_918- AS_SET =
329_846_453