Class: Google::Cloud::Compute::V1::RoutePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ ::String

Returns An optional description of route policy.

Returns:

  • (::String) —

    An optional description of route policy.



70599
70600
70601
70602
70603
70604
70605
70606
70607
70608
70609
70610
70611
70612
70613
70614
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70599

class RoutePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The Route Policy is an Export Policy.
    ROUTE_POLICY_TYPE_EXPORT = 293_086_882

    # The Route Policy is an Import Policy.
    ROUTE_POLICY_TYPE_IMPORT = 397_444_755
  end
end

#fingerprint ⇒ ::String

Returns A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy. You must always provide an up-to-date fingerprint hash in order to update or change labels.

To see the latest fingerprint, make a getRoutePolicy() request to retrieve a Route Policy.

Returns:

  • (::String) —

    A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy. You must always provide an up-to-date fingerprint hash in order to update or change labels.

    To see the latest fingerprint, make a getRoutePolicy() request to retrieve a Route Policy.



70599
70600
70601
70602
70603
70604
70605
70606
70607
70608
70609
70610
70611
70612
70613
70614
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70599

class RoutePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The Route Policy is an Export Policy.
    ROUTE_POLICY_TYPE_EXPORT = 293_086_882

    # The Route Policy is an Import Policy.
    ROUTE_POLICY_TYPE_IMPORT = 397_444_755
  end
end

#name ⇒ ::String

Returns Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035.

Returns:

  • (::String) —

    Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035.



70599
70600
70601
70602
70603
70604
70605
70606
70607
70608
70609
70610
70611
70612
70613
70614
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70599

class RoutePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The Route Policy is an Export Policy.
    ROUTE_POLICY_TYPE_EXPORT = 293_086_882

    # The Route Policy is an Import Policy.
    ROUTE_POLICY_TYPE_IMPORT = 397_444_755
  end
end

#terms ⇒ ::Array<::Google::Cloud::Compute::V1::RoutePolicyPolicyTerm>

Returns List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later.

Returns:



70599
70600
70601
70602
70603
70604
70605
70606
70607
70608
70609
70610
70611
70612
70613
70614
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70599

class RoutePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The Route Policy is an Export Policy.
    ROUTE_POLICY_TYPE_EXPORT = 293_086_882

    # The Route Policy is an Import Policy.
    ROUTE_POLICY_TYPE_IMPORT = 397_444_755
  end
end

#type ⇒ ::String

Returns Check the Type enum for the list of possible values.

Returns:

  • (::String) —

    Check the Type enum for the list of possible values.



70599
70600
70601
70602
70603
70604
70605
70606
70607
70608
70609
70610
70611
70612
70613
70614
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70599

class RoutePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The Route Policy is an Export Policy.
    ROUTE_POLICY_TYPE_EXPORT = 293_086_882

    # The Route Policy is an Import Policy.
    ROUTE_POLICY_TYPE_IMPORT = 397_444_755
  end
end