Class: Google::Cloud::Compute::V1::Router
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Router
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Cloud Router resource. For more information about Cloud Router, read the Cloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ ::Google::Cloud::Compute::V1::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ ::Array<::Google::Cloud::Compute::V1::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ ::String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ ::Boolean
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ ::Array<::Google::Cloud::Compute::V1::RouterInterface>
Router interfaces.
-
#kind ⇒ ::String
[Output Only] Type of resource.
-
#md5_authentication_keys ⇒ ::Array<::Google::Cloud::Compute::V1::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
-
#name ⇒ ::String
Name of the resource.
-
#nats ⇒ ::Array<::Google::Cloud::Compute::V1::RouterNat>
A list of NAT services created in this router.
-
#network ⇒ ::String
URI of the network to which this router belongs.
-
#params ⇒ ::Google::Cloud::Compute::V1::RouterParams
Input only.
-
#region ⇒ ::String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
Instance Attribute Details
#bgp ⇒ ::Google::Cloud::Compute::V1::RouterBgp
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bgp_peers ⇒ ::Array<::Google::Cloud::Compute::V1::RouterBgpPeer>
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#creation_timestamp ⇒ ::String
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encrypted_interconnect_router ⇒ ::Boolean
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#interfaces ⇒ ::Array<::Google::Cloud::Compute::V1::RouterInterface>
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#md5_authentication_keys ⇒ ::Array<::Google::Cloud::Compute::V1::RouterMd5AuthenticationKey>
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#nats ⇒ ::Array<::Google::Cloud::Compute::V1::RouterNat>
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network ⇒ ::String
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#params ⇒ ::Google::Cloud::Compute::V1::RouterParams
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
31205 31206 31207 31208 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31205 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |