Class: Google::Cloud::Compute::V1::RouterBgpPeerBfd

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: SessionInitializationMode

Instance Attribute Summary collapse

Instance Attribute Details

#min_receive_interval::Integer

Returns The minimum interval, in milliseconds, between BFD control packets received from the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the transmit interval of the other router.

If set, this value must be between 1000 and 30000.

The default is 1000.

Returns:

  • (::Integer)

    The minimum interval, in milliseconds, between BFD control packets received from the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the transmit interval of the other router.

    If set, this value must be between 1000 and 30000.

    The default is 1000.



66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
66989
66990
66991
66992
66993
66994
66995
66996
66997
66998
66999
67000
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66979

class RouterBgpPeerBfd
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  #
  #
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.
  module SessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end
end

#min_transmit_interval::Integer

Returns The minimum interval, in milliseconds, between BFD control packets transmitted to the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the corresponding receive interval of the other router.

If set, this value must be between 1000 and 30000.

The default is 1000.

Returns:

  • (::Integer)

    The minimum interval, in milliseconds, between BFD control packets transmitted to the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the corresponding receive interval of the other router.

    If set, this value must be between 1000 and 30000.

    The default is 1000.



66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
66989
66990
66991
66992
66993
66994
66995
66996
66997
66998
66999
67000
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66979

class RouterBgpPeerBfd
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  #
  #
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.
  module SessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end
end

#multiplier::Integer

Returns The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable.

If set, the value must be a value between 5 and 16.

The default is 5.

Returns:

  • (::Integer)

    The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable.

    If set, the value must be a value between 5 and 16.

    The default is 5.



66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
66989
66990
66991
66992
66993
66994
66995
66996
66997
66998
66999
67000
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66979

class RouterBgpPeerBfd
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  #
  #
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.
  module SessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end
end

#session_initialization_mode::String

Returns The BFD session initialization mode for this BGP peer.

If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. The default is DISABLED. Check the SessionInitializationMode enum for the list of possible values.

Returns:

  • (::String)

    The BFD session initialization mode for this BGP peer.

    If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. The default is DISABLED. Check the SessionInitializationMode enum for the list of possible values.



66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
66989
66990
66991
66992
66993
66994
66995
66996
66997
66998
66999
67000
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66979

class RouterBgpPeerBfd
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  #
  #
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.
  module SessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end
end