Class: Google::Cloud::Compute::V1::RouterInterface

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: IpVersion, ManagementType

Instance Attribute Summary collapse

Instance Attribute Details

#ip_range ⇒ ::String

Returns IP address and range of the interface.

- For Internet Protocol version 4 (IPv4), the IP range must be in theRFC3927 link-local IP address space. The value must
be a CIDR-formatted string, for example, 169.254.0.1/30.
Note: Do not truncate the IP address, as it represents the IP address of
the interface.
- For Internet Protocol version 6 (IPv6), the value
must be a unique local address (ULA) range from fdff:1::/64
with a mask length of 126 or less. This value should be a CIDR-formatted
string, for example, fdff:1::1/112. Within the router's
VPC, this IPv6 prefix will be reserved exclusively for this connection
and cannot be used for any other purpose.

Returns:

  • (::String) —

    IP address and range of the interface.

    - For Internet Protocol version 4 (IPv4), the IP range must be in theRFC3927 link-local IP address space. The value must
    be a CIDR-formatted string, for example, 169.254.0.1/30.
    Note: Do not truncate the IP address, as it represents the IP address of
    the interface.
    - For Internet Protocol version 6 (IPv6), the value
    must be a unique local address (ULA) range from fdff:1::/64
    with a mask length of 126 or less. This value should be a CIDR-formatted
    string, for example, fdff:1::1/112. Within the router's
    VPC, this IPv6 prefix will be reserved exclusively for this connection
    and cannot be used for any other purpose.


71190
71191
71192
71193
71194
71195
71196
71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71190

class RouterInterface
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IP version of this interface.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343
  end

  # Output only. [Output Only] The resource that configures and manages this interface.
  #
  #    - MANAGED_BY_USER is the default value and can be managed directly
  #    by users.
  #    - MANAGED_BY_ATTACHMENT is an interface that is configured and
  #    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
  #    of type PARTNER. Google automatically creates, updates, and deletes
  #    this type of interface when the PARTNER InterconnectAttachment is
  #    created, updated, or deleted.
  module ManagementType
    # A value indicating that the enum field is not set.
    UNDEFINED_MANAGEMENT_TYPE = 0

    # The interface is automatically created for PARTNER type
    # InterconnectAttachment, Google will automatically create/update/delete
    # this interface when the PARTNER InterconnectAttachment is
    # created/provisioned/deleted.
    # This type of interface cannot be manually managed by user.
    MANAGED_BY_ATTACHMENT = 458_926_411

    # Default value, the interface is manually created and managed by user.
    MANAGED_BY_USER = 317_294_067
  end
end

#ip_version ⇒ ::String

Returns IP version of this interface. Check the IpVersion enum for the list of possible values.

Returns:

  • (::String) —

    IP version of this interface. Check the IpVersion enum for the list of possible values.



71190
71191
71192
71193
71194
71195
71196
71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71190

class RouterInterface
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IP version of this interface.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343
  end

  # Output only. [Output Only] The resource that configures and manages this interface.
  #
  #    - MANAGED_BY_USER is the default value and can be managed directly
  #    by users.
  #    - MANAGED_BY_ATTACHMENT is an interface that is configured and
  #    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
  #    of type PARTNER. Google automatically creates, updates, and deletes
  #    this type of interface when the PARTNER InterconnectAttachment is
  #    created, updated, or deleted.
  module ManagementType
    # A value indicating that the enum field is not set.
    UNDEFINED_MANAGEMENT_TYPE = 0

    # The interface is automatically created for PARTNER type
    # InterconnectAttachment, Google will automatically create/update/delete
    # this interface when the PARTNER InterconnectAttachment is
    # created/provisioned/deleted.
    # This type of interface cannot be manually managed by user.
    MANAGED_BY_ATTACHMENT = 458_926_411

    # Default value, the interface is manually created and managed by user.
    MANAGED_BY_USER = 317_294_067
  end
end

#linked_interconnect_attachment ⇒ ::String

Returns URI of the linked Interconnect attachment. It must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.

Returns:

  • (::String) —

    URI of the linked Interconnect attachment. It must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.



71190
71191
71192
71193
71194
71195
71196
71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71190

class RouterInterface
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IP version of this interface.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343
  end

  # Output only. [Output Only] The resource that configures and manages this interface.
  #
  #    - MANAGED_BY_USER is the default value and can be managed directly
  #    by users.
  #    - MANAGED_BY_ATTACHMENT is an interface that is configured and
  #    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
  #    of type PARTNER. Google automatically creates, updates, and deletes
  #    this type of interface when the PARTNER InterconnectAttachment is
  #    created, updated, or deleted.
  module ManagementType
    # A value indicating that the enum field is not set.
    UNDEFINED_MANAGEMENT_TYPE = 0

    # The interface is automatically created for PARTNER type
    # InterconnectAttachment, Google will automatically create/update/delete
    # this interface when the PARTNER InterconnectAttachment is
    # created/provisioned/deleted.
    # This type of interface cannot be manually managed by user.
    MANAGED_BY_ATTACHMENT = 458_926_411

    # Default value, the interface is manually created and managed by user.
    MANAGED_BY_USER = 317_294_067
  end
end

#linked_vpn_tunnel ⇒ ::String

Returns URI of the linked VPN tunnel, which must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.

Returns:

  • (::String) —

    URI of the linked VPN tunnel, which must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.



71190
71191
71192
71193
71194
71195
71196
71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71190

class RouterInterface
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IP version of this interface.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343
  end

  # Output only. [Output Only] The resource that configures and manages this interface.
  #
  #    - MANAGED_BY_USER is the default value and can be managed directly
  #    by users.
  #    - MANAGED_BY_ATTACHMENT is an interface that is configured and
  #    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
  #    of type PARTNER. Google automatically creates, updates, and deletes
  #    this type of interface when the PARTNER InterconnectAttachment is
  #    created, updated, or deleted.
  module ManagementType
    # A value indicating that the enum field is not set.
    UNDEFINED_MANAGEMENT_TYPE = 0

    # The interface is automatically created for PARTNER type
    # InterconnectAttachment, Google will automatically create/update/delete
    # this interface when the PARTNER InterconnectAttachment is
    # created/provisioned/deleted.
    # This type of interface cannot be manually managed by user.
    MANAGED_BY_ATTACHMENT = 458_926_411

    # Default value, the interface is manually created and managed by user.
    MANAGED_BY_USER = 317_294_067
  end
end

#management_type ⇒ ::String

Returns Output only. [Output Only] The resource that configures and manages this interface.

- MANAGED_BY_USER is the default value and can be managed directly
by users.
- MANAGED_BY_ATTACHMENT is an interface that is configured and
managed by Cloud Interconnect, specifically, by an InterconnectAttachment
of type PARTNER. Google automatically creates, updates, and deletes
this type of interface when the PARTNER InterconnectAttachment is
created, updated, or deleted.

Check the ManagementType enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] The resource that configures and manages this interface.

    - MANAGED_BY_USER is the default value and can be managed directly
    by users.
    - MANAGED_BY_ATTACHMENT is an interface that is configured and
    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
    of type PARTNER. Google automatically creates, updates, and deletes
    this type of interface when the PARTNER InterconnectAttachment is
    created, updated, or deleted.
    

    Check the ManagementType enum for the list of possible values.



71190
71191
71192
71193
71194
71195
71196
71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71190

class RouterInterface
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IP version of this interface.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343
  end

  # Output only. [Output Only] The resource that configures and manages this interface.
  #
  #    - MANAGED_BY_USER is the default value and can be managed directly
  #    by users.
  #    - MANAGED_BY_ATTACHMENT is an interface that is configured and
  #    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
  #    of type PARTNER. Google automatically creates, updates, and deletes
  #    this type of interface when the PARTNER InterconnectAttachment is
  #    created, updated, or deleted.
  module ManagementType
    # A value indicating that the enum field is not set.
    UNDEFINED_MANAGEMENT_TYPE = 0

    # The interface is automatically created for PARTNER type
    # InterconnectAttachment, Google will automatically create/update/delete
    # this interface when the PARTNER InterconnectAttachment is
    # created/provisioned/deleted.
    # This type of interface cannot be manually managed by user.
    MANAGED_BY_ATTACHMENT = 458_926_411

    # Default value, the interface is manually created and managed by user.
    MANAGED_BY_USER = 317_294_067
  end
end

#name ⇒ ::String

Returns Name of this interface entry. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String) —

    Name of this interface entry. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



71190
71191
71192
71193
71194
71195
71196
71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71190

class RouterInterface
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IP version of this interface.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343
  end

  # Output only. [Output Only] The resource that configures and manages this interface.
  #
  #    - MANAGED_BY_USER is the default value and can be managed directly
  #    by users.
  #    - MANAGED_BY_ATTACHMENT is an interface that is configured and
  #    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
  #    of type PARTNER. Google automatically creates, updates, and deletes
  #    this type of interface when the PARTNER InterconnectAttachment is
  #    created, updated, or deleted.
  module ManagementType
    # A value indicating that the enum field is not set.
    UNDEFINED_MANAGEMENT_TYPE = 0

    # The interface is automatically created for PARTNER type
    # InterconnectAttachment, Google will automatically create/update/delete
    # this interface when the PARTNER InterconnectAttachment is
    # created/provisioned/deleted.
    # This type of interface cannot be manually managed by user.
    MANAGED_BY_ATTACHMENT = 458_926_411

    # Default value, the interface is manually created and managed by user.
    MANAGED_BY_USER = 317_294_067
  end
end

#private_ip_address ⇒ ::String

Returns The regional private internal IP address that is used to establish BGP sessions to a VM instance acting as a third-party Router Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN VM.

Returns:

  • (::String) —

    The regional private internal IP address that is used to establish BGP sessions to a VM instance acting as a third-party Router Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN VM.



71190
71191
71192
71193
71194
71195
71196
71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71190

class RouterInterface
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IP version of this interface.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343
  end

  # Output only. [Output Only] The resource that configures and manages this interface.
  #
  #    - MANAGED_BY_USER is the default value and can be managed directly
  #    by users.
  #    - MANAGED_BY_ATTACHMENT is an interface that is configured and
  #    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
  #    of type PARTNER. Google automatically creates, updates, and deletes
  #    this type of interface when the PARTNER InterconnectAttachment is
  #    created, updated, or deleted.
  module ManagementType
    # A value indicating that the enum field is not set.
    UNDEFINED_MANAGEMENT_TYPE = 0

    # The interface is automatically created for PARTNER type
    # InterconnectAttachment, Google will automatically create/update/delete
    # this interface when the PARTNER InterconnectAttachment is
    # created/provisioned/deleted.
    # This type of interface cannot be manually managed by user.
    MANAGED_BY_ATTACHMENT = 458_926_411

    # Default value, the interface is manually created and managed by user.
    MANAGED_BY_USER = 317_294_067
  end
end

#redundant_interface ⇒ ::String

Returns Name of the interface that will be redundant with the current interface you are creating. The redundantInterface must belong to the same Cloud Router as the interface here. To establish the BGP session to a Router Appliance VM, you must create two BGP peers. The two BGP peers must be attached to two separate interfaces that are redundant with each other. The redundant_interface must be 1-63 characters long, and comply withRFC1035. Specifically, the redundant_interface must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String) —

    Name of the interface that will be redundant with the current interface you are creating. The redundantInterface must belong to the same Cloud Router as the interface here. To establish the BGP session to a Router Appliance VM, you must create two BGP peers. The two BGP peers must be attached to two separate interfaces that are redundant with each other. The redundant_interface must be 1-63 characters long, and comply withRFC1035. Specifically, the redundant_interface must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



71190
71191
71192
71193
71194
71195
71196
71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71190

class RouterInterface
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IP version of this interface.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343
  end

  # Output only. [Output Only] The resource that configures and manages this interface.
  #
  #    - MANAGED_BY_USER is the default value and can be managed directly
  #    by users.
  #    - MANAGED_BY_ATTACHMENT is an interface that is configured and
  #    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
  #    of type PARTNER. Google automatically creates, updates, and deletes
  #    this type of interface when the PARTNER InterconnectAttachment is
  #    created, updated, or deleted.
  module ManagementType
    # A value indicating that the enum field is not set.
    UNDEFINED_MANAGEMENT_TYPE = 0

    # The interface is automatically created for PARTNER type
    # InterconnectAttachment, Google will automatically create/update/delete
    # this interface when the PARTNER InterconnectAttachment is
    # created/provisioned/deleted.
    # This type of interface cannot be manually managed by user.
    MANAGED_BY_ATTACHMENT = 458_926_411

    # Default value, the interface is manually created and managed by user.
    MANAGED_BY_USER = 317_294_067
  end
end

#subnetwork ⇒ ::String

Returns The URI of the subnetwork resource that this interface belongs to, which must be in the same region as the Cloud Router. When you establish a BGP session to a VM instance using this interface, the VM instance must belong to the same subnetwork as the subnetwork specified here.

Returns:

  • (::String) —

    The URI of the subnetwork resource that this interface belongs to, which must be in the same region as the Cloud Router. When you establish a BGP session to a VM instance using this interface, the VM instance must belong to the same subnetwork as the subnetwork specified here.



71190
71191
71192
71193
71194
71195
71196
71197
71198
71199
71200
71201
71202
71203
71204
71205
71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71190

class RouterInterface
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IP version of this interface.
  module IpVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_IP_VERSION = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343
  end

  # Output only. [Output Only] The resource that configures and manages this interface.
  #
  #    - MANAGED_BY_USER is the default value and can be managed directly
  #    by users.
  #    - MANAGED_BY_ATTACHMENT is an interface that is configured and
  #    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
  #    of type PARTNER. Google automatically creates, updates, and deletes
  #    this type of interface when the PARTNER InterconnectAttachment is
  #    created, updated, or deleted.
  module ManagementType
    # A value indicating that the enum field is not set.
    UNDEFINED_MANAGEMENT_TYPE = 0

    # The interface is automatically created for PARTNER type
    # InterconnectAttachment, Google will automatically create/update/delete
    # this interface when the PARTNER InterconnectAttachment is
    # created/provisioned/deleted.
    # This type of interface cannot be manually managed by user.
    MANAGED_BY_ATTACHMENT = 458_926_411

    # Default value, the interface is manually created and managed by user.
    MANAGED_BY_USER = 317_294_067
  end
end