Module: Google::Cloud::Compute::V1::RouterNatLogConfig::Filter

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values: - ERRORS_ONLY: Export logs only for connection failures. - TRANSLATIONS_ONLY: Export logs only for successful connections. - ALL: Export logs for all connections, successful and unsuccessful.

Constant Summary collapse

UNDEFINED_FILTER =

A value indicating that the enum field is not set.

0
ALL =

Export logs for all (successful and unsuccessful) connections.

64_897
ERRORS_ONLY =

Export logs for connection failures only.

307_484_672
TRANSLATIONS_ONLY =

Export logs for successful connections only.

357_212_649