Class: Google::Cloud::Compute::V1::RouterNatRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#action::Google::Cloud::Compute::V1::RouterNatRuleAction

Returns The action to be enforced for traffic that matches this rule.

Returns:



67540
67541
67542
67543
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67540

class RouterNatRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns An optional description of this rule.

Returns:

  • (::String)

    An optional description of this rule.



67540
67541
67542
67543
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67540

class RouterNatRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#match::String

Returns CEL expression that specifies the match condition that egress traffic from a VM is evaluated against. If it evaluates to true, the corresponding action is enforced.

The following examples are valid match expressions for public NAT:

inIpRange(destination.ip, '1.1.0.0/16') || inIpRange(destination.ip, '2.2.0.0/16')

destination.ip == '1.1.0.1' || destination.ip == '8.8.8.8'

The following example is a valid match expression for private NAT:

nexthop.hub == '//networkconnectivity.googleapis.com/projects/my-project/locations/global/hubs/hub-1'.

Returns:

  • (::String)

    CEL expression that specifies the match condition that egress traffic from a VM is evaluated against. If it evaluates to true, the corresponding action is enforced.

    The following examples are valid match expressions for public NAT:

    inIpRange(destination.ip, '1.1.0.0/16') || inIpRange(destination.ip, '2.2.0.0/16')

    destination.ip == '1.1.0.1' || destination.ip == '8.8.8.8'

    The following example is a valid match expression for private NAT:

    nexthop.hub == '//networkconnectivity.googleapis.com/projects/my-project/locations/global/hubs/hub-1'



67540
67541
67542
67543
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67540

class RouterNatRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rule_number::Integer

Returns An integer uniquely identifying a rule in the list. The rule number must be a positive value between 0 and 65000, and must be unique among rules within a NAT.

Returns:

  • (::Integer)

    An integer uniquely identifying a rule in the list. The rule number must be a positive value between 0 and 65000, and must be unique among rules within a NAT.



67540
67541
67542
67543
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67540

class RouterNatRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end