Class: Google::Cloud::Compute::V1::RouterStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RouterStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#best_routes ⇒ ::Array<::Google::Cloud::Compute::V1::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
-
#best_routes_for_router ⇒ ::Array<::Google::Cloud::Compute::V1::Route>
A list of the best BGP routes learned by this Cloud Router.
- #bgp_peer_status ⇒ ::Array<::Google::Cloud::Compute::V1::RouterStatusBgpPeerStatus>
- #nat_status ⇒ ::Array<::Google::Cloud::Compute::V1::RouterStatusNatStatus>
-
#ncc_gateway ⇒ ::String
URI of the ncc_gateway to which this router associated.
-
#network ⇒ ::String
URI of the network to which this router belongs.
Instance Attribute Details
#best_routes ⇒ ::Array<::Google::Cloud::Compute::V1::Route>
Returns A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
Lists all of the best routes per prefix that are programmed into this region's VPC data plane.
When global dynamic routing mode is turned on in the VPC network, this list can include cross-region dynamic routes from Cloud Routers in other regions.
71789 71790 71791 71792 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71789 class RouterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#best_routes_for_router ⇒ ::Array<::Google::Cloud::Compute::V1::Route>
Returns A list of the best BGP routes learned by this Cloud Router.
It is possible that routes listed might not be programmed into the data plane, if the Google Cloud control plane finds a more optimal route for a prefix than a route learned by this Cloud Router.
71789 71790 71791 71792 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71789 class RouterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bgp_peer_status ⇒ ::Array<::Google::Cloud::Compute::V1::RouterStatusBgpPeerStatus>
71789 71790 71791 71792 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71789 class RouterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#nat_status ⇒ ::Array<::Google::Cloud::Compute::V1::RouterStatusNatStatus>
71789 71790 71791 71792 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71789 class RouterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ncc_gateway ⇒ ::String
Returns URI of the ncc_gateway to which this router associated.
71789 71790 71791 71792 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71789 class RouterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network ⇒ ::String
Returns URI of the network to which this router belongs.
71789 71790 71791 71792 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71789 class RouterStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |