Class: Google::Cloud::Compute::V1::RoutersListNamedSets

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#etag ⇒ ::String

Returns:

  • (::String)


72056
72057
72058
72059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72056

class RoutersListNamedSets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id ⇒ ::String

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::String) —

    [Output Only] The unique identifier for the resource. This identifier is defined by the server.



72056
72057
72058
72059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72056

class RoutersListNamedSets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#routersListNamedSets for lists of named sets.

Returns:

  • (::String) —

    Output only. [Output Only] Type of resource. Alwayscompute#routersListNamedSets for lists of named sets.



72056
72057
72058
72059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72056

class RoutersListNamedSets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token ⇒ ::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String) —

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



72056
72057
72058
72059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72056

class RoutersListNamedSets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#result ⇒ ::Array<::Google::Cloud::Compute::V1::NamedSet>

Returns [Output Only] A list of named sets.

Returns:



72056
72057
72058
72059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72056

class RoutersListNamedSets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for this resource.



72056
72057
72058
72059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72056

class RoutersListNamedSets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachables ⇒ ::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>) —

    Output only. [Output Only] Unreachable resources.



72056
72057
72058
72059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72056

class RoutersListNamedSets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



72056
72057
72058
72059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72056

class RoutersListNamedSets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end