Class: Google::Cloud::Compute::V1::SSLHealthCheck

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: PortSpecification, ProxyHeader

Instance Attribute Summary collapse

Instance Attribute Details

#port ⇒ ::Integer

Returns The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535.

Returns:

  • (::Integer) —

    The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535.



72164
72165
72166
72167
72168
72169
72170
72171
72172
72173
72174
72175
72176
72177
72178
72179
72180
72181
72182
72183
72184
72185
72186
72187
72188
72189
72190
72191
72192
72193
72194
72195
72196
72197
72198
72199
72200
72201
72202
72203
72204
72205
72206
72207
72208
72209
72210
72211
72212
72213
72214
72215
72216
72217
72218
72219
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72164

class SSLHealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#port_name ⇒ ::String

Returns Not supported.

Returns:

  • (::String) —

    Not supported.



72164
72165
72166
72167
72168
72169
72170
72171
72172
72173
72174
72175
72176
72177
72178
72179
72180
72181
72182
72183
72184
72185
72186
72187
72188
72189
72190
72191
72192
72193
72194
72195
72196
72197
72198
72199
72200
72201
72202
72203
72204
72205
72206
72207
72208
72209
72210
72211
72212
72213
72214
72215
72216
72217
72218
72219
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72164

class SSLHealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#port_specification ⇒ ::String

Returns Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends.

For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Check the PortSpecification enum for the list of possible values.

Returns:

  • (::String) —

    Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends.

    For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Check the PortSpecification enum for the list of possible values.



72164
72165
72166
72167
72168
72169
72170
72171
72172
72173
72174
72175
72176
72177
72178
72179
72180
72181
72182
72183
72184
72185
72186
72187
72188
72189
72190
72191
72192
72193
72194
72195
72196
72197
72198
72199
72200
72201
72202
72203
72204
72205
72206
72207
72208
72209
72210
72211
72212
72213
72214
72215
72216
72217
72218
72219
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72164

class SSLHealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#proxy_header ⇒ ::String

Returns Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Check the ProxyHeader enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Check the ProxyHeader enum for the list of possible values.



72164
72165
72166
72167
72168
72169
72170
72171
72172
72173
72174
72175
72176
72177
72178
72179
72180
72181
72182
72183
72184
72185
72186
72187
72188
72189
72190
72191
72192
72193
72194
72195
72196
72197
72198
72199
72200
72201
72202
72203
72204
72205
72206
72207
72208
72209
72210
72211
72212
72213
72214
72215
72216
72217
72218
72219
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72164

class SSLHealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#request ⇒ ::String

Returns Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection and SSL handshake.

Returns:

  • (::String) —

    Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection and SSL handshake.



72164
72165
72166
72167
72168
72169
72170
72171
72172
72173
72174
72175
72176
72177
72178
72179
72180
72181
72182
72183
72184
72185
72186
72187
72188
72189
72190
72191
72192
72193
72194
72195
72196
72197
72198
72199
72200
72201
72202
72203
72204
72205
72206
72207
72208
72209
72210
72211
72212
72213
72214
72215
72216
72217
72218
72219
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72164

class SSLHealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#response ⇒ ::String

Returns Creates a content-based SSL health check. In addition to establishing a TCP connection and the TLS handshake, you can configure the health check to pass only when the backend sends this exact response ASCII string, up to 1024 bytes in length. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-ssl-tcp.

Returns:



72164
72165
72166
72167
72168
72169
72170
72171
72172
72173
72174
72175
72176
72177
72178
72179
72180
72181
72182
72183
72184
72185
72186
72187
72188
72189
72190
72191
72192
72193
72194
72195
72196
72197
72198
72199
72200
72201
72202
72203
72204
72205
72206
72207
72208
72209
72210
72211
72212
72213
72214
72215
72216
72217
72218
72219
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72164

class SSLHealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end