Class: Google::Cloud::Compute::V1::SavedAttachedDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.

Defined Under Namespace

Modules: Interface, Mode, StorageBytesStatus, Type

Instance Attribute Summary collapse

Instance Attribute Details

#auto_delete ⇒ ::Boolean

Returns Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).

Returns:

  • (::Boolean) —

    Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#boot ⇒ ::Boolean

Returns Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.

Returns:

  • (::Boolean) —

    Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#device_name ⇒ ::String

Returns Specifies the name of the disk attached to the source instance.

Returns:

  • (::String) —

    Specifies the name of the disk attached to the source instance.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#disk_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey

Returns The encryption key for the disk.

Returns:



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#disk_size_gb ⇒ ::Integer

Returns The size of the disk in base-2 GB.

Returns:

  • (::Integer) —

    The size of the disk in base-2 GB.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#disk_type ⇒ ::String

Returns Output only. [Output Only] URL of the disk type resource. For example:projects/project/zones/zone/diskTypes/pd-standard or pd-ssd.

Returns:

  • (::String) —

    Output only. [Output Only] URL of the disk type resource. For example:projects/project/zones/zone/diskTypes/pd-standard or pd-ssd



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#guest_os_features ⇒ ::Array<::Google::Cloud::Compute::V1::GuestOsFeature>

Returns A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::GuestOsFeature>) —

    A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#index ⇒ ::Integer

Returns Output only. Specifies zero-based index of the disk that is attached to the source instance.

Returns:

  • (::Integer) —

    Output only. Specifies zero-based index of the disk that is attached to the source instance.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#interface ⇒ ::String

Returns Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Check the Interface enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Check the Interface enum for the list of possible values.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks.

Returns:

  • (::String) —

    Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#licenses ⇒ ::Array<::String>

Returns Output only. [Output Only] Any valid publicly visible licenses.

Returns:

  • (::Array<::String>) —

    Output only. [Output Only] Any valid publicly visible licenses.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#mode ⇒ ::String

Returns The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Check the Mode enum for the list of possible values.

Returns:

  • (::String) —

    The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Check the Mode enum for the list of possible values.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#source ⇒ ::String

Returns Specifies a URL of the disk attached to the source instance.

Returns:

  • (::String) —

    Specifies a URL of the disk attached to the source instance.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#storage_bytes ⇒ ::Integer

Returns Output only. [Output Only] A size of the storage used by the disk's snapshot by this machine image.

Returns:

  • (::Integer) —

    Output only. [Output Only] A size of the storage used by the disk's snapshot by this machine image.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#storage_bytes_status ⇒ ::String

Returns Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.

Returns:

  • (::String) —

    Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end

#type ⇒ ::String

Returns Specifies the type of the attached disk, either SCRATCH orPERSISTENT. Check the Type enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the type of the attached disk, either SCRATCH orPERSISTENT. Check the Type enum for the list of possible values.



72288
72289
72290
72291
72292
72293
72294
72295
72296
72297
72298
72299
72300
72301
72302
72303
72304
72305
72306
72307
72308
72309
72310
72311
72312
72313
72314
72315
72316
72317
72318
72319
72320
72321
72322
72323
72324
72325
72326
72327
72328
72329
72330
72331
72332
72333
72334
72335
72336
72337
72338
72339
72340
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72288

class SavedAttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end

  # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple virtual machines can use
    # a disk in read-only mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in read-write mode. Only one
    # virtual machine at a time can be attached to a disk in read-write mode.
    READ_WRITE = 173_607_894
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end

  # Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    PERSISTENT = 460_683_927

    SCRATCH = 496_778_970
  end
end