Class: Google::Cloud::Compute::V1::SavedDisk
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SavedDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
An instance-attached disk resource.
Defined Under Namespace
Modules: Architecture, StorageBytesStatus
Instance Attribute Summary collapse
-
#architecture ⇒ ::String
Output only.
-
#kind ⇒ ::String
Output only.
-
#source_disk ⇒ ::String
Output only.
-
#storage_bytes ⇒ ::Integer
Output only.
-
#storage_bytes_status ⇒ ::String
Output only.
Instance Attribute Details
#architecture ⇒ ::String
Returns Output only. [Output Only] The architecture of the attached disk. Check the Architecture enum for the list of possible values.
72366 72367 72368 72369 72370 72371 72372 72373 72374 72375 72376 72377 72378 72379 72380 72381 72382 72383 72384 72385 72386 72387 72388 72389 72390 72391 72392 72393 72394 72395 72396 72397 72398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72366 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#savedDisk for attached disks.
72366 72367 72368 72369 72370 72371 72372 72373 72374 72375 72376 72377 72378 72379 72380 72381 72382 72383 72384 72385 72386 72387 72388 72389 72390 72391 72392 72393 72394 72395 72396 72397 72398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72366 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |
#source_disk ⇒ ::String
Returns Output only. Specifies a URL of the disk attached to the source instance.
72366 72367 72368 72369 72370 72371 72372 72373 72374 72375 72376 72377 72378 72379 72380 72381 72382 72383 72384 72385 72386 72387 72388 72389 72390 72391 72392 72393 72394 72395 72396 72397 72398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72366 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |
#storage_bytes ⇒ ::Integer
Returns Output only. [Output Only] Size of the individual disk snapshot used by this machine image.
72366 72367 72368 72369 72370 72371 72372 72373 72374 72375 72376 72377 72378 72379 72380 72381 72382 72383 72384 72385 72386 72387 72388 72389 72390 72391 72392 72393 72394 72395 72396 72397 72398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72366 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |
#storage_bytes_status ⇒ ::String
Returns Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.
72366 72367 72368 72369 72370 72371 72372 72373 72374 72375 72376 72377 72378 72379 72380 72381 72382 72383 72384 72385 72386 72387 72388 72389 72390 72391 72392 72393 72394 72395 72396 72397 72398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72366 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |