Class: Google::Cloud::Compute::V1::SchedulingNodeAffinity

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Node Affinity: the configuration of desired nodes onto which this Instance could be scheduled.

Defined Under Namespace

Modules: Operator

Instance Attribute Summary collapse

Instance Attribute Details

#key::String

Returns Corresponds to the label key of Node resource.

Returns:

  • (::String)

    Corresponds to the label key of Node resource.



70092
70093
70094
70095
70096
70097
70098
70099
70100
70101
70102
70103
70104
70105
70106
70107
70108
70109
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70092

class SchedulingNodeAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity.
  module Operator
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATOR = 0

    # Requires Compute Engine to seek for matched nodes.
    IN = 2341

    # Requires Compute Engine to avoid certain nodes.
    NOT_IN = 161_144_369

    OPERATOR_UNSPECIFIED = 128_892_924
  end
end

#operator::String

Returns Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity. Check the Operator enum for the list of possible values.

Returns:

  • (::String)

    Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity. Check the Operator enum for the list of possible values.



70092
70093
70094
70095
70096
70097
70098
70099
70100
70101
70102
70103
70104
70105
70106
70107
70108
70109
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70092

class SchedulingNodeAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity.
  module Operator
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATOR = 0

    # Requires Compute Engine to seek for matched nodes.
    IN = 2341

    # Requires Compute Engine to avoid certain nodes.
    NOT_IN = 161_144_369

    OPERATOR_UNSPECIFIED = 128_892_924
  end
end

#values::Array<::String>

Returns Corresponds to the label values of Node resource.

Returns:

  • (::Array<::String>)

    Corresponds to the label values of Node resource.



70092
70093
70094
70095
70096
70097
70098
70099
70100
70101
70102
70103
70104
70105
70106
70107
70108
70109
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70092

class SchedulingNodeAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the operation of node selection. Valid operators areIN for affinity and NOT_IN for anti-affinity.
  module Operator
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATOR = 0

    # Requires Compute Engine to seek for matched nodes.
    IN = 2341

    # Requires Compute Engine to avoid certain nodes.
    NOT_IN = 161_144_369

    OPERATOR_UNSPECIFIED = 128_892_924
  end
end