Class: Google::Cloud::Compute::V1::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#etag ⇒ ::String

Returns:

  • (::String)


72691
72692
72693
72694
72695
72696
72697
72698
72699
72700
72701
72702
72703
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72691

class SecurityPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SecurityPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id ⇒ ::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String) —

    [Output Only] Unique identifier for the resource; defined by the server.



72691
72692
72693
72694
72695
72696
72697
72698
72699
72700
72701
72702
72703
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72691

class SecurityPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SecurityPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SecurityPoliciesScopedList}

Returns A list of SecurityPoliciesScopedList resources.

Returns:



72691
72692
72693
72694
72695
72696
72697
72698
72699
72700
72701
72702
72703
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72691

class SecurityPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SecurityPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyAggregatedList for lists of Security Policies.

Returns:

  • (::String) —

    Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyAggregatedList for lists of Security Policies.



72691
72692
72693
72694
72695
72696
72697
72698
72699
72700
72701
72702
72703
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72691

class SecurityPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SecurityPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token ⇒ ::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String) —

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



72691
72692
72693
72694
72695
72696
72697
72698
72699
72700
72701
72702
72703
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72691

class SecurityPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SecurityPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for this resource.



72691
72692
72693
72694
72695
72696
72697
72698
72699
72700
72701
72702
72703
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72691

class SecurityPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SecurityPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables ⇒ ::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>) —

    Output only. [Output Only] Unreachable resources.



72691
72692
72693
72694
72695
72696
72697
72698
72699
72700
72701
72702
72703
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72691

class SecurityPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SecurityPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



72691
72692
72693
72694
72695
72696
72697
72698
72699
72700
72701
72702
72703
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72691

class SecurityPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SecurityPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end