Class: Google::Cloud::Compute::V1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Configuration options for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR.

Defined Under Namespace

Modules: RuleVisibility

Instance Attribute Summary collapse

Instance Attribute Details

#enable::Boolean



29943
29944
29945
29946
29947
29948
29949
29950
29951
29952
29953
29954
29955
29956
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29943

class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Rule visibility can be one of the following: STANDARD - opaque rules. (default) PREMIUM - transparent rules. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
  module RuleVisibility
    # A value indicating that the enum field is not set.
    UNDEFINED_RULE_VISIBILITY = 0

    PREMIUM = 399_530_551

    STANDARD = 484_642_493
  end
end

#rule_visibility::String



29943
29944
29945
29946
29947
29948
29949
29950
29951
29952
29953
29954
29955
29956
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29943

class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Rule visibility can be one of the following: STANDARD - opaque rules. (default) PREMIUM - transparent rules. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
  module RuleVisibility
    # A value indicating that the enum field is not set.
    UNDEFINED_RULE_VISIBILITY = 0

    PREMIUM = 399_530_551

    STANDARD = 484_642_493
  end
end

#threshold_configs::Array<::Google::Cloud::Compute::V1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig>



29943
29944
29945
29946
29947
29948
29949
29950
29951
29952
29953
29954
29955
29956
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29943

class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Rule visibility can be one of the following: STANDARD - opaque rules. (default) PREMIUM - transparent rules. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
  module RuleVisibility
    # A value indicating that the enum field is not set.
    UNDEFINED_RULE_VISIBILITY = 0

    PREMIUM = 399_530_551

    STANDARD = 484_642_493
  end
end