Class: Google::Cloud::Compute::V1::SecurityPolicyDdosProtectionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyDdosProtectionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: DdosAdaptiveProtection, DdosProtection
Instance Attribute Summary collapse
-
#ddos_adaptive_protection ⇒ ::String
Check the DdosAdaptiveProtection enum for the list of possible values.
-
#ddos_impacted_baseline_threshold ⇒ ::Float
DDoS Protection for Network Load Balancers (and VMs with public IPs) builds DDoS mitigations that minimize collateral damage.
-
#ddos_protection ⇒ ::String
Check the DdosProtection enum for the list of possible values.
Instance Attribute Details
#ddos_adaptive_protection ⇒ ::String
Returns Check the DdosAdaptiveProtection enum for the list of possible values.
73130 73131 73132 73133 73134 73135 73136 73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 73159 73160 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73130 class SecurityPolicyDdosProtectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module DdosAdaptiveProtection # A value indicating that the enum field is not set. UNDEFINED_DDOS_ADAPTIVE_PROTECTION = 0 DDOS_ADAPTIVE_PROTECTION_UNSPECIFIED = 314_527_935 DISABLED = 516_696_700 ENABLED = 182_130_465 PREVIEW = 399_798_184 UNSPECIFIED_ADAPTIVE_PROTECTION = 86_330_138 end module DdosProtection # A value indicating that the enum field is not set. UNDEFINED_DDOS_PROTECTION = 0 ADVANCED = 63_789_090 ADVANCED_PREVIEW = 40_905_867 STANDARD = 484_642_493 end end |
#ddos_impacted_baseline_threshold ⇒ ::Float
Returns DDoS Protection for Network Load Balancers (and VMs with public IPs) builds DDoS mitigations that minimize collateral damage. It quantifies this as the fraction of a non-abuse baseline that's inadvertently blocked.
Rules whose collateral damage exceeds ddosImpactedBaselineThreshold will not be deployed. Using a lower value will prioritize keeping collateral damage low, possibly at the cost of its effectiveness in rate limiting some or all of the attack. It should typically be unset, so Advanced DDoS (and Adaptive Protection) uses the best mitigation it can find. Setting the threshold is advised if there are logs for false positive detections with high collateral damage, and will cause Advanced DDoS to attempt to find a less aggressive rule that satisfies the constraint. If a suitable rule cannot be found, the system falls back to either no mitigation for smaller attacks or broader network throttles for larger ones.
73130 73131 73132 73133 73134 73135 73136 73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 73159 73160 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73130 class SecurityPolicyDdosProtectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module DdosAdaptiveProtection # A value indicating that the enum field is not set. UNDEFINED_DDOS_ADAPTIVE_PROTECTION = 0 DDOS_ADAPTIVE_PROTECTION_UNSPECIFIED = 314_527_935 DISABLED = 516_696_700 ENABLED = 182_130_465 PREVIEW = 399_798_184 UNSPECIFIED_ADAPTIVE_PROTECTION = 86_330_138 end module DdosProtection # A value indicating that the enum field is not set. UNDEFINED_DDOS_PROTECTION = 0 ADVANCED = 63_789_090 ADVANCED_PREVIEW = 40_905_867 STANDARD = 484_642_493 end end |
#ddos_protection ⇒ ::String
Returns Check the DdosProtection enum for the list of possible values.
73130 73131 73132 73133 73134 73135 73136 73137 73138 73139 73140 73141 73142 73143 73144 73145 73146 73147 73148 73149 73150 73151 73152 73153 73154 73155 73156 73157 73158 73159 73160 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73130 class SecurityPolicyDdosProtectionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module DdosAdaptiveProtection # A value indicating that the enum field is not set. UNDEFINED_DDOS_ADAPTIVE_PROTECTION = 0 DDOS_ADAPTIVE_PROTECTION_UNSPECIFIED = 314_527_935 DISABLED = 516_696_700 ENABLED = 182_130_465 PREVIEW = 399_798_184 UNSPECIFIED_ADAPTIVE_PROTECTION = 86_330_138 end module DdosProtection # A value indicating that the enum field is not set. UNDEFINED_DDOS_PROTECTION = 0 ADVANCED = 63_789_090 ADVANCED_PREVIEW = 40_905_867 STANDARD = 484_642_493 end end |