Class: Google::Cloud::Compute::V1::SecurityPolicyRuleNetworkMatcher
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyRuleNetworkMatcher
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a match condition that incoming network traffic is evaluated against.
Instance Attribute Summary collapse
-
#dest_ip_ranges ⇒ ::Array<::String>
Destination IPv4/IPv6 addresses or CIDR prefixes, in standard text format.
-
#dest_ports ⇒ ::Array<::String>
Destination port numbers for TCP/UDP/SCTP.
-
#ip_protocols ⇒ ::Array<::String>
IPv4 protocol / IPv6 next header (after extension headers).
-
#src_asns ⇒ ::Array<::Integer>
BGP Autonomous System Number associated with the source IP address.
-
#src_ip_ranges ⇒ ::Array<::String>
Source IPv4/IPv6 addresses or CIDR prefixes, in standard text format.
-
#src_ports ⇒ ::Array<::String>
Source port numbers for TCP/UDP/SCTP.
-
#src_region_codes ⇒ ::Array<::String>
Two-letter ISO 3166-1 alpha-2 country code associated with the source IP address.
-
#user_defined_fields ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>
User-defined fields.
Instance Attribute Details
#dest_ip_ranges ⇒ ::Array<::String>
30220 30221 30222 30223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30220 class SecurityPolicyRuleNetworkMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dest_ports ⇒ ::Array<::String>
30220 30221 30222 30223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30220 class SecurityPolicyRuleNetworkMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ip_protocols ⇒ ::Array<::String>
30220 30221 30222 30223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30220 class SecurityPolicyRuleNetworkMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#src_asns ⇒ ::Array<::Integer>
30220 30221 30222 30223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30220 class SecurityPolicyRuleNetworkMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#src_ip_ranges ⇒ ::Array<::String>
30220 30221 30222 30223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30220 class SecurityPolicyRuleNetworkMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#src_ports ⇒ ::Array<::String>
30220 30221 30222 30223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30220 class SecurityPolicyRuleNetworkMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#src_region_codes ⇒ ::Array<::String>
30220 30221 30222 30223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30220 class SecurityPolicyRuleNetworkMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_defined_fields ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>
30220 30221 30222 30223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30220 class SecurityPolicyRuleNetworkMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |