Class: Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#request_cookies_to_exclude ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request cookie names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_headers_to_exclude ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request header names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_query_params_to_exclude ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation.
-
#request_uris_to_exclude ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation.
-
#target_rule_ids ⇒ ::Array<::String>
A list of target rule IDs under the WAF rule set to apply the preconfigured WAF exclusion.
-
#target_rule_set ⇒ ::String
Target WAF rule set to apply the preconfigured WAF exclusion.
Instance Attribute Details
#request_cookies_to_exclude ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
Returns A list of request cookie names whose value will be excluded from inspection during preconfigured WAF evaluation.
71781 71782 71783 71784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71781 class SecurityPolicyRulePreconfiguredWafConfigExclusion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_headers_to_exclude ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
Returns A list of request header names whose value will be excluded from inspection during preconfigured WAF evaluation.
71781 71782 71783 71784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71781 class SecurityPolicyRulePreconfiguredWafConfigExclusion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_query_params_to_exclude ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
Returns A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation. Note that the parameter can be in the query string or in the POST body.
71781 71782 71783 71784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71781 class SecurityPolicyRulePreconfiguredWafConfigExclusion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_uris_to_exclude ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>
Returns A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation. When specifying this field, the query or fragment part should be excluded.
71781 71782 71783 71784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71781 class SecurityPolicyRulePreconfiguredWafConfigExclusion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_rule_ids ⇒ ::Array<::String>
Returns A list of target rule IDs under the WAF rule set to apply the preconfigured WAF exclusion. If omitted, it refers to all the rule IDs under the WAF rule set.
71781 71782 71783 71784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71781 class SecurityPolicyRulePreconfiguredWafConfigExclusion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_rule_set ⇒ ::String
Returns Target WAF rule set to apply the preconfigured WAF exclusion.
71781 71782 71783 71784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71781 class SecurityPolicyRulePreconfiguredWafConfigExclusion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |