Class: Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Op

Instance Attribute Summary collapse

Instance Attribute Details

#op ⇒ ::String

Returns The match operator for the field. Check the Op enum for the list of possible values.

Returns:

  • (::String) —

    The match operator for the field. Check the Op enum for the list of possible values.



73521
73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
73540
73541
73542
73543
73544
73545
73546
73547
73548
73549
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73521

class SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The match operator for the field.
  module Op
    # A value indicating that the enum field is not set.
    UNDEFINED_OP = 0

    # The operator matches if the field value contains the specified
    # value.
    CONTAINS = 215_180_831

    # The operator matches if the field value ends with the specified
    # value.
    ENDS_WITH = 490_402_221

    # The operator matches if the field value equals the specified
    # value.
    EQUALS = 442_201_023

    # The operator matches if the field value is any value.
    EQUALS_ANY = 337_226_060

    # The operator matches if the field value starts with the specified
    # value.
    STARTS_WITH = 139_505_652
  end
end

#val ⇒ ::String

Returns The value of the field.

Returns:

  • (::String) —

    The value of the field.



73521
73522
73523
73524
73525
73526
73527
73528
73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
73540
73541
73542
73543
73544
73545
73546
73547
73548
73549
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73521

class SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The match operator for the field.
  module Op
    # A value indicating that the enum field is not set.
    UNDEFINED_OP = 0

    # The operator matches if the field value contains the specified
    # value.
    CONTAINS = 215_180_831

    # The operator matches if the field value ends with the specified
    # value.
    ENDS_WITH = 490_402_221

    # The operator matches if the field value equals the specified
    # value.
    EQUALS = 442_201_023

    # The operator matches if the field value is any value.
    EQUALS_ANY = 337_226_060

    # The operator matches if the field value starts with the specified
    # value.
    STARTS_WITH = 139_505_652
  end
end