Class: Google::Cloud::Compute::V1::SecuritySettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The authentication and authorization settings for a BackendService.

Instance Attribute Summary collapse

Instance Attribute Details

#aws_v4_authentication::Google::Cloud::Compute::V1::AWSV4Signature

Returns The configuration needed to generate a signature for access to private storage buckets that support AWS's Signature Version 4 for authentication. Allowed only for INTERNET_IP_PORT and INTERNET_FQDN_PORT NEG backends.

Returns:

  • (::Google::Cloud::Compute::V1::AWSV4Signature)

    The configuration needed to generate a signature for access to private storage buckets that support AWS's Signature Version 4 for authentication. Allowed only for INTERNET_IP_PORT and INTERNET_FQDN_PORT NEG backends.



69764
69765
69766
69767
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69764

class SecuritySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client_tls_policy::String

Returns Optional. A URL referring to a networksecurity.ClientTlsPolicy resource that describes how clients should authenticate with this service's backends.

clientTlsPolicy only applies to a globalBackendService with the loadBalancingScheme set to INTERNAL_SELF_MANAGED.

If left blank, communications are not encrypted.

Returns:

  • (::String)

    Optional. A URL referring to a networksecurity.ClientTlsPolicy resource that describes how clients should authenticate with this service's backends.

    clientTlsPolicy only applies to a globalBackendService with the loadBalancingScheme set to INTERNAL_SELF_MANAGED.

    If left blank, communications are not encrypted.



69764
69765
69766
69767
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69764

class SecuritySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#subject_alt_names::Array<::String>

Returns Optional. A list of Subject Alternative Names (SANs) that the client verifies during a mutual TLS handshake with an server/endpoint for thisBackendService. When the server presents its X.509 certificate to the client, the client inspects the certificate'ssubjectAltName field. If the field contains one of the specified values, the communication continues. Otherwise, it fails. This additional check enables the client to verify that the server is authorized to run the requested service.

Note that the contents of the server certificate's subjectAltName field are configured by the Public Key Infrastructure which provisions server identities.

Only applies to a global BackendService withloadBalancingScheme set to INTERNAL_SELF_MANAGED. Only applies when BackendService has an attachedclientTlsPolicy with clientCertificate (mTLS mode).

Returns:

  • (::Array<::String>)

    Optional. A list of Subject Alternative Names (SANs) that the client verifies during a mutual TLS handshake with an server/endpoint for thisBackendService. When the server presents its X.509 certificate to the client, the client inspects the certificate'ssubjectAltName field. If the field contains one of the specified values, the communication continues. Otherwise, it fails. This additional check enables the client to verify that the server is authorized to run the requested service.

    Note that the contents of the server certificate's subjectAltName field are configured by the Public Key Infrastructure which provisions server identities.

    Only applies to a global BackendService withloadBalancingScheme set to INTERNAL_SELF_MANAGED. Only applies when BackendService has an attachedclientTlsPolicy with clientCertificate (mTLS mode).



69764
69765
69766
69767
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69764

class SecuritySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end