Class: Google::Cloud::Compute::V1::SerialPortOutput
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SerialPortOutput
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
An instance serial console output.
Instance Attribute Summary collapse
-
#contents ⇒ ::String
[Output Only] The contents of the console output.
-
#kind ⇒ ::String
Output only.
-
#next ⇒ ::Integer
[Output Only] The position of the next byte of content, regardless of whether the content exists, following the output returned in the
contentsproperty. -
#self_link ⇒ ::String
Output only.
-
#start ⇒ ::Integer
The starting byte position of the output that was returned.
Instance Attribute Details
#contents ⇒ ::String
Returns [Output Only] The contents of the console output.
69814 69815 69816 69817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69814 class SerialPortOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#serialPortOutput for serial port output.
69814 69815 69816 69817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69814 class SerialPortOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next ⇒ ::Integer
Returns [Output Only] The position of the next byte of content, regardless of
whether the content exists, following the output returned in the contents
property. Use this value in the next request as the start
parameter.
69814 69815 69816 69817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69814 class SerialPortOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
69814 69815 69816 69817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69814 class SerialPortOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start ⇒ ::Integer
Returns The starting byte position of the output that was returned.
This should match the start parameter sent with the request.
If the serial console output exceeds the size of the buffer (1 MB), older
output is overwritten by newer content. The output start value will
indicate the byte position of the output that was returned, which might be
different than the start value that was specified in the request.
69814 69815 69816 69817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69814 class SerialPortOutput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |