Module: Google::Cloud::Compute::V1::ServerBinding::Type
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Constant Summary collapse
- UNDEFINED_TYPE =
A value indicating that the enum field is not set.
0- RESTART_NODE_ON_ANY_SERVER =
Node may associate with any physical server over its lifetime.
502_950_985- RESTART_NODE_ON_MINIMAL_SERVERS =
Node may associate with minimal physical servers over its lifetime.
204_166_495- SERVER_BINDING_TYPE_UNSPECIFIED =
180_825_512