Class: Google::Cloud::Compute::V1::ServiceAttachment
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ServiceAttachment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a ServiceAttachment resource.
A service attachment represents a service that a producer has exposed. It encapsulates the load balancer which fronts the service runs and a list of NAT IP ranges that the producers uses to represent the consumers connecting to the service.
Defined Under Namespace
Modules: ConnectionPreference Classes: MetadataEntry
Instance Attribute Summary collapse
-
#connected_endpoints ⇒ ::Array<::Google::Cloud::Compute::V1::ServiceAttachmentConnectedEndpoint>
Output only.
-
#connection_preference ⇒ ::String
The connection preference of service attachment.
-
#consumer_accept_lists ⇒ ::Array<::Google::Cloud::Compute::V1::ServiceAttachmentConsumerProjectLimit>
Specifies which consumer projects or networks are allowed to connect to the service attachment.
-
#consumer_reject_lists ⇒ ::Array<::String>
Specifies a list of projects or networks that are not allowed to connect to this service attachment.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#domain_names ⇒ ::Array<::String>
If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS.
-
#enable_proxy_protocol ⇒ ::Boolean
If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
Metadata of the service attachment.
-
#name ⇒ ::String
Name of the resource.
-
#nat_subnets ⇒ ::Array<::String>
An array of URLs where each entry is the URL of a subnet provided by the service producer to use for NAT in this service attachment.
-
#producer_forwarding_rule ⇒ ::String
The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is serving the endpoint identified by this service attachment.
-
#propagated_connection_limit ⇒ ::Integer
The number of consumer spokes that connected Private Service Connect endpoints can be propagated to through Network Connectivity Center.
-
#psc_service_attachment_id ⇒ ::Google::Cloud::Compute::V1::Uint128
Output only.
-
#reconcile_connections ⇒ ::Boolean
This flag determines whether a consumer accept/reject list change can reconcile the statuses of existing ACCEPTED or REJECTED PSC endpoints.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#target_service ⇒ ::String
The URL of a service serving the endpoint identified by this service attachment.
Instance Attribute Details
#connected_endpoints ⇒ ::Array<::Google::Cloud::Compute::V1::ServiceAttachmentConnectedEndpoint>
Returns Output only. [Output Only] An array of connections for all the consumers connected to this service attachment.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#connection_preference ⇒ ::String
Returns The connection preference of service attachment. The value can be set to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service attachment is one that always accepts the connection from consumer forwarding rules. Check the ConnectionPreference enum for the list of possible values.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#consumer_accept_lists ⇒ ::Array<::Google::Cloud::Compute::V1::ServiceAttachmentConsumerProjectLimit>
Returns Specifies which consumer projects or networks are allowed to connect to the service attachment. Each project or network has a connection limit. A given service attachment can manage connections at either the project or network level. Therefore, both the accept and reject lists for a given service attachment must contain either only projects or only networks or only endpoints.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#consumer_reject_lists ⇒ ::Array<::String>
Returns Specifies a list of projects or networks that are not allowed to connect to this service attachment. The project can be specified using its project ID or project number and the network can be specified using its URL. A given service attachment can manage connections at either the project or network level. Therefore, both the reject and accept lists for a given service attachment must contain either only projects or only networks.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#domain_names ⇒ ::Array<::String>
Returns If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS. For example, this is a valid domain name: "p.mycompany.com.". Current max number of domain names supported is 1.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#enable_proxy_protocol ⇒ ::Boolean
Returns If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#fingerprint ⇒ ::String
Returns Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ServiceAttachment. An up-to-date fingerprint must be provided in order to patch/update the ServiceAttachment; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the ServiceAttachment.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#serviceAttachment for service attachments.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Metadata of the service attachment.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#nat_subnets ⇒ ::Array<::String>
Returns An array of URLs where each entry is the URL of a subnet provided by the service producer to use for NAT in this service attachment.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#producer_forwarding_rule ⇒ ::String
Returns The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is serving the endpoint identified by this service attachment.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#propagated_connection_limit ⇒ ::Integer
Returns The number of consumer spokes that connected Private Service Connect endpoints can be propagated to through Network Connectivity Center. This limit lets the service producer limit how many propagated Private Service Connect connections can be established to this service attachment from a single consumer.
If the connection preference of the service attachment is ACCEPT_MANUAL, the limit applies to each project or network that is listed in the consumer accept list. If the connection preference of the service attachment is ACCEPT_AUTOMATIC, the limit applies to each project that contains a connected endpoint.
If unspecified, the default propagated connection limit is 250.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#psc_service_attachment_id ⇒ ::Google::Cloud::Compute::V1::Uint128
Returns Output only. [Output Only] An 128-bit global unique ID of the PSC service attachment.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#reconcile_connections ⇒ ::Boolean
Returns This flag determines whether a consumer accept/reject list change can reconcile the statuses of existing ACCEPTED or REJECTED PSC endpoints.
- If false, connection policy update will only affect existing PENDING
PSC endpoints. Existing ACCEPTED/REJECTED endpoints will remain untouched
regardless how the connection policy is modified .
- If true, update will affect both PENDING and ACCEPTED/REJECTED PSC endpoints. For example, an ACCEPTED PSC endpoint will be moved to REJECTED if its project is added to the reject list.
For newly created service attachment, this boolean defaults to false.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the service attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |
#target_service ⇒ ::String
Returns The URL of a service serving the endpoint identified by this service attachment.
69988 69989 69990 69991 69992 69993 69994 69995 69996 69997 69998 69999 70000 70001 70002 70003 70004 70005 70006 70007 70008 70009 70010 70011 70012 70013 70014 70015 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69988 class ServiceAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The connection preference of service attachment. The value can be set # to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC # service attachment is one that always accepts the connection from consumer # forwarding rules. module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 CONNECTION_PREFERENCE_UNSPECIFIED = 34_590_772 end end |