Class: Google::Cloud::Compute::V1::ServiceAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ServiceAttachmentConnectedEndpoint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] A connection connected to this service attachment.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#consumer_network ⇒ ::String
The url of the consumer network.
-
#endpoint ⇒ ::String
The url of a connected endpoint.
-
#endpoint_with_id ⇒ ::String
The url of a connected endpoint with resource id.
-
#nat_ips ⇒ ::Array<::String>
NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
-
#propagated_connection_count ⇒ ::Integer
The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
-
#psc_connection_id ⇒ ::Integer
The PSC connection id of the connected endpoint.
-
#status ⇒ ::String
The status of a connected endpoint to this service attachment.
Instance Attribute Details
#consumer_network ⇒ ::String
Returns The url of the consumer network.
74314 74315 74316 74317 74318 74319 74320 74321 74322 74323 74324 74325 74326 74327 74328 74329 74330 74331 74332 74333 74334 74335 74336 74337 74338 74339 74340 74341 74342 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74314 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#endpoint ⇒ ::String
Returns The url of a connected endpoint.
74314 74315 74316 74317 74318 74319 74320 74321 74322 74323 74324 74325 74326 74327 74328 74329 74330 74331 74332 74333 74334 74335 74336 74337 74338 74339 74340 74341 74342 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74314 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#endpoint_with_id ⇒ ::String
Returns The url of a connected endpoint with resource id.
74314 74315 74316 74317 74318 74319 74320 74321 74322 74323 74324 74325 74326 74327 74328 74329 74330 74331 74332 74333 74334 74335 74336 74337 74338 74339 74340 74341 74342 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74314 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#nat_ips ⇒ ::Array<::String>
Returns NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
74314 74315 74316 74317 74318 74319 74320 74321 74322 74323 74324 74325 74326 74327 74328 74329 74330 74331 74332 74333 74334 74335 74336 74337 74338 74339 74340 74341 74342 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74314 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#propagated_connection_count ⇒ ::Integer
Returns The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
74314 74315 74316 74317 74318 74319 74320 74321 74322 74323 74324 74325 74326 74327 74328 74329 74330 74331 74332 74333 74334 74335 74336 74337 74338 74339 74340 74341 74342 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74314 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#psc_connection_id ⇒ ::Integer
Returns The PSC connection id of the connected endpoint.
74314 74315 74316 74317 74318 74319 74320 74321 74322 74323 74324 74325 74326 74327 74328 74329 74330 74331 74332 74333 74334 74335 74336 74337 74338 74339 74340 74341 74342 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74314 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#status ⇒ ::String
Returns The status of a connected endpoint to this service attachment. Check the Status enum for the list of possible values.
74314 74315 74316 74317 74318 74319 74320 74321 74322 74323 74324 74325 74326 74327 74328 74329 74330 74331 74332 74333 74334 74335 74336 74337 74338 74339 74340 74341 74342 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74314 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |