Class: Google::Cloud::Compute::V1::ShareSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The share setting for reservations and sole tenancy node groups.

Defined Under Namespace

Modules: ShareType Classes: ProjectMapEntry

Instance Attribute Summary collapse

Instance Attribute Details

#project_map ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::ShareSettingsProjectConfig}

Returns A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS.

Returns:



77149
77150
77151
77152
77153
77154
77155
77156
77157
77158
77159
77160
77161
77162
77163
77164
77165
77166
77167
77168
77169
77170
77171
77172
77173
77174
77175
77176
77177
77178
77179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77149

class ShareSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ShareSettingsProjectConfig]
  class ProjectMapEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of sharing for this shared-reservation
  module ShareType
    # A value indicating that the enum field is not set.
    UNDEFINED_SHARE_TYPE = 0

    # Default value.
    LOCAL = 72_607_563

    # Shared-reservation is open to entire Organization
    ORGANIZATION = 274_978_099

    # Default value. This value is unused.
    SHARE_TYPE_UNSPECIFIED = 494_771_730

    # Shared-reservation is open to specific projects
    SPECIFIC_PROJECTS = 347_838_695
  end
end

#share_type ⇒ ::String

Returns Type of sharing for this shared-reservation Check the ShareType enum for the list of possible values.

Returns:

  • (::String) —

    Type of sharing for this shared-reservation Check the ShareType enum for the list of possible values.



77149
77150
77151
77152
77153
77154
77155
77156
77157
77158
77159
77160
77161
77162
77163
77164
77165
77166
77167
77168
77169
77170
77171
77172
77173
77174
77175
77176
77177
77178
77179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77149

class ShareSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ShareSettingsProjectConfig]
  class ProjectMapEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of sharing for this shared-reservation
  module ShareType
    # A value indicating that the enum field is not set.
    UNDEFINED_SHARE_TYPE = 0

    # Default value.
    LOCAL = 72_607_563

    # Shared-reservation is open to entire Organization
    ORGANIZATION = 274_978_099

    # Default value. This value is unused.
    SHARE_TYPE_UNSPECIFIED = 494_771_730

    # Shared-reservation is open to specific projects
    SPECIFIC_PROJECTS = 347_838_695
  end
end