Class: Google::Cloud::Compute::V1::ShieldedInstanceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A set of Shielded Instance options.

Instance Attribute Summary collapse

Instance Attribute Details

#enable_integrity_monitoring ⇒ ::Boolean

Returns Defines whether the instance has integrity monitoring enabled.Enabled by default.

Returns:

  • (::Boolean) —

    Defines whether the instance has integrity monitoring enabled.Enabled by default.



77204
77205
77206
77207
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77204

class ShieldedInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_secure_boot ⇒ ::Boolean

Returns Defines whether the instance has Secure Boot enabled.Disabled by default.

Returns:

  • (::Boolean) —

    Defines whether the instance has Secure Boot enabled.Disabled by default.



77204
77205
77206
77207
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77204

class ShieldedInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_vtpm ⇒ ::Boolean

Returns Defines whether the instance has the vTPM enabled.Enabled by default.

Returns:

  • (::Boolean) —

    Defines whether the instance has the vTPM enabled.Enabled by default.



77204
77205
77206
77207
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77204

class ShieldedInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end