Class: Google::Cloud::Compute::V1::ShieldedInstanceIntegrityPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The policy describes the baseline against which Instance boot integrity is measured.

Instance Attribute Summary collapse

Instance Attribute Details

#update_auto_learn_policy ⇒ ::Boolean

Returns Updates the integrity policy baseline using the measurements from the VM instance's most recent boot.

Returns:

  • (::Boolean) —

    Updates the integrity policy baseline using the measurements from the VM instance's most recent boot.



77253
77254
77255
77256
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77253

class ShieldedInstanceIntegrityPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end