Module: Google::Cloud::Compute::V1::Snapshot::StorageBytesStatus

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. [Deprecated] Instead, check the storageBytes field. After snapshot creation, the storageBytesStatus field is alwaysUP_TO_DATE. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be unset, meaning the snapshot is being created, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.

Constant Summary collapse

UNDEFINED_STORAGE_BYTES_STATUS =

A value indicating that the enum field is not set.

0
UPDATING =
494_614_342
UP_TO_DATE =
101_306_702