Method: Google::Cloud::Compute::V1::SnapshotSettings#storage_location

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

#storage_location::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettings

Returns Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out.

Returns:



35683
35684
35685
35686
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35683

class SnapshotSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end