Class: Google::Cloud::Compute::V1::SourceDiskEncryptionKey
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SourceDiskEncryptionKey
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#disk_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source disk.
-
#source_disk ⇒ ::String
URL of the disk attached to the source instance.
Instance Attribute Details
#disk_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Returns Thecustomer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key.
73603 73604 73605 73606 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73603 class SourceDiskEncryptionKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_disk ⇒ ::String
Returns URL of the disk attached to the source instance. This can be a full or valid partial URL. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk.
73603 73604 73605 73606 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73603 class SourceDiskEncryptionKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |