Class: Google::Cloud::Compute::V1::SourceInstanceProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.

Defined Under Namespace

Modules: KeyRevocationActionType Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#can_ip_forward::Boolean



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#deletion_protection::Boolean



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#description::String



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#disks::Array<::Google::Cloud::Compute::V1::SavedAttachedDisk>



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#guest_accelerators::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#key_revocation_action_type::String



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#labels::Google::Protobuf::Map{::String => ::String}



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#machine_type::String



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#metadata::Google::Cloud::Compute::V1::Metadata



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#min_cpu_platform::String



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#network_interfaces::Array<::Google::Cloud::Compute::V1::NetworkInterface>



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#scheduling::Google::Cloud::Compute::V1::Scheduling



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#service_accounts::Array<::Google::Cloud::Compute::V1::ServiceAccount>



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end

#tags::Google::Cloud::Compute::V1::Tags



35799
35800
35801
35802
35803
35804
35805
35806
35807
35808
35809
35810
35811
35812
35813
35814
35815
35816
35817
35818
35819
35820
35821
35822
35823
35824
35825
35826
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end
end