Class: Google::Cloud::Compute::V1::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#etag ⇒ ::String

Returns:

  • (::String)


78289
78290
78291
78292
78293
78294
78295
78296
78297
78298
78299
78300
78301
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78289

class SslPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SslPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id ⇒ ::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String) —

    [Output Only] Unique identifier for the resource; defined by the server.



78289
78290
78291
78292
78293
78294
78295
78296
78297
78298
78299
78300
78301
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78289

class SslPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SslPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SslPoliciesScopedList}

Returns A list of SslPoliciesScopedList resources.

Returns:



78289
78290
78291
78292
78293
78294
78295
78296
78297
78298
78299
78300
78301
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78289

class SslPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SslPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#sslPolicyAggregatedList for lists of SSL Policies.

Returns:

  • (::String) —

    Output only. [Output Only] Type of resource. Alwayscompute#sslPolicyAggregatedList for lists of SSL Policies.



78289
78290
78291
78292
78293
78294
78295
78296
78297
78298
78299
78300
78301
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78289

class SslPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SslPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token ⇒ ::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String) —

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



78289
78290
78291
78292
78293
78294
78295
78296
78297
78298
78299
78300
78301
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78289

class SslPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SslPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for this resource.



78289
78290
78291
78292
78293
78294
78295
78296
78297
78298
78299
78300
78301
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78289

class SslPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SslPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables ⇒ ::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>) —

    Output only. [Output Only] Unreachable resources.



78289
78290
78291
78292
78293
78294
78295
78296
78297
78298
78299
78300
78301
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78289

class SslPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SslPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



78289
78290
78291
78292
78293
78294
78295
78296
78297
78298
78299
78300
78301
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78289

class SslPoliciesAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SslPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end