Module: Google::Cloud::Compute::V1::SslPolicy::PostQuantumKeyExchange

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates X25519MLKEM768 key exchange when clients advertise support for it. When set to DEFAULT, or if no SSL Policy is attached to the target proxy, the load balancer disallows X25519MLKEM768 key exchange before October 2026, and allows it afterward. When set to ENABLED, the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key exchange until October 2027, and allows it afterward.

Constant Summary collapse

UNDEFINED_POST_QUANTUM_KEY_EXCHANGE =

A value indicating that the enum field is not set.

0
DEFAULT =

Default behavior: disabled until October 2026, enabled afterward.

115_302_945
DEFERRED =

Disabled until October 2027, enabled afterward.

356_775_903
ENABLED =

Enabled now.

182_130_465