Class: Google::Cloud::Compute::V1::Status
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Status
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.
Instance Attribute Summary collapse
-
#code ⇒ ::Integer
The status code, which should be an enum value of google.rpc.Code.
-
#details ⇒ ::Array<::Google::Protobuf::Any>
A list of messages that carry the error details.
-
#message ⇒ ::String
A developer-facing error message, which should be in English.
Instance Attribute Details
#code ⇒ ::Integer
36407 36408 36409 36410 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36407 class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#details ⇒ ::Array<::Google::Protobuf::Any>
36407 36408 36409 36410 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36407 class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#message ⇒ ::String
36407 36408 36409 36410 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36407 class Status include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |