Module: Google::Cloud::Compute::V1::Subnetwork::ResolveSubnetMask

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Configures subnet mask resolution for this subnetwork.

Constant Summary collapse

UNDEFINED_RESOLVE_SUBNET_MASK =

A value indicating that the enum field is not set.

0
ARP_ALL_RANGES =

All ranges assigned to the VM NIC will respond to ARP.

445_655_380
ARP_BROADCAST_PRIMARY_RANGE =

VMs will receive an ARP response from a VM instance owning the target IP address within the subnetwork's primary CIDR range, if such a VM instance exists and is running.

123_887_458
ARP_BROADCAST_PRIMARY_RANGE_WITH_LEARNING =

Combines ARP_BROADCAST_PRIMARY_RANGE with MAC learning. Enables cache mapping between IP addresses and custom MAC addresses of instances and use of it to set the correct destination MAC address. If this option is chosen, the subnetwork must have /24 or a smaller CIDR range.

425_592_922
ARP_PRIMARY_RANGE =

Only the primary range of the VM NIC will respond to ARP.

120_210_048