Module: Google::Cloud::Compute::V1::Subnetwork::State

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Output only. [Output Only] The state of the subnetwork, which can be one of the following values:READY: Subnetwork is created and ready to useDRAINING: only applicable to subnetworks that have the purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load balancer are being drained. A subnetwork that is draining cannot be used or modified until it reaches a status ofREADY

Constant Summary collapse

UNDEFINED_STATE =

A value indicating that the enum field is not set.

0
DRAINING =

Subnetwork is being drained.

480_455_402
READY =

Subnetwork is ready for use.

77_848_963