Class: Google::Cloud::Compute::V1::SubnetworkParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Additional subnetwork parameters.

Defined Under Namespace

Classes: ResourceManagerTagsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns Tag keys/values directly bound to this resource. Tag keys and values have the same definition as resource manager tags. The field is allowed for INSERT only. The keys/values to set on the resource should be specified in either ID { : } or Namespaced format { : }. For example the following are valid inputs:

  • {"tagKeys/333" : "tagValues/444", "tagKeys/123" : "tagValues/456"}
  • {"123/environment" : "production", "345/abc" : "xyz"} Note:
  • Invalid combinations of ID & namespaced format is not supported. For instance: {"123/environment" : "tagValues/444"} is invalid.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    Tag keys/values directly bound to this resource. Tag keys and values have the same definition as resource manager tags. The field is allowed for INSERT only. The keys/values to set on the resource should be specified in either ID { : } or Namespaced format { : }. For example the following are valid inputs:

    • {"tagKeys/333" : "tagValues/444", "tagKeys/123" : "tagValues/456"}
    • {"123/environment" : "production", "345/abc" : "xyz"} Note:
    • Invalid combinations of ID & namespaced format is not supported. For instance: {"123/environment" : "tagValues/444"} is invalid.


80238
80239
80240
80241
80242
80243
80244
80245
80246
80247
80248
80249
80250
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80238

class SubnetworkParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end