Class: Google::Cloud::Compute::V1::SubnetworkSecondaryRange
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SubnetworkSecondaryRange
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a secondary IP range of a subnetwork.
Defined Under Namespace
Modules: IpVersion
Instance Attribute Summary collapse
-
#ip_cidr_range ⇒ ::String
The range of IP addresses belonging to this subnetwork secondary range.
-
#ip_collection ⇒ ::String
Reference to a Public Delegated Prefix (PDP) for BYOIP.
-
#ip_version ⇒ ::String
Check the IpVersion enum for the list of possible values.
-
#range_name ⇒ ::String
The name associated with this subnetwork secondary range, used when adding an alias IP/IPv6 range to a VM instance.
-
#reserved_internal_range ⇒ ::String
The URL of the reserved internal range.
Instance Attribute Details
#ip_cidr_range ⇒ ::String
Returns The range of IP addresses belonging to this subnetwork secondary range. Provide this property when you create the subnetwork. Ranges must be unique and non-overlapping with all primary and secondary IP ranges within a network. Both IPv4 and IPv6 ranges are supported. For IPv4, the range can be any range listed in theValid ranges list.
For IPv6:
The range must have a /64 prefix length.
The range must be omitted, for auto-allocation from Google-defined ULA
IPv6 range.
For BYOGUA internal IPv6 secondary range, the range may be specified
along with the ipCollection field.
If an ipCollection is specified, the requested ip_cidr_range must lie
within the range of the PDP referenced by the ipCollection field for
allocation.
If ipCollection field is specified, but ip_cidr_range is not,
the range is auto-allocated from the PDP referenced by the ipCollection
field.
78510 78511 78512 78513 78514 78515 78516 78517 78518 78519 78520 78521 78522 78523 78524 78525 78526 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78510 class SubnetworkSecondaryRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 # Treated as IPV4 for backward-compatibility. IP_VERSION_UNSPECIFIED = 92_360_440 end end |
#ip_collection ⇒ ::String
Returns Reference to a Public Delegated Prefix (PDP) for BYOIP.
This field should be specified for configuring BYOGUA internal IPv6
secondary range.
When specified along with the ip_cidr_range, the ip_cidr_range must lie
within the PDP referenced by the ipCollection field.
When specified without the ip_cidr_range, the range is auto-allocated
from the PDP referenced by the ipCollection field.
78510 78511 78512 78513 78514 78515 78516 78517 78518 78519 78520 78521 78522 78523 78524 78525 78526 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78510 class SubnetworkSecondaryRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 # Treated as IPV4 for backward-compatibility. IP_VERSION_UNSPECIFIED = 92_360_440 end end |
#ip_version ⇒ ::String
Returns Check the IpVersion enum for the list of possible values.
78510 78511 78512 78513 78514 78515 78516 78517 78518 78519 78520 78521 78522 78523 78524 78525 78526 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78510 class SubnetworkSecondaryRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 # Treated as IPV4 for backward-compatibility. IP_VERSION_UNSPECIFIED = 92_360_440 end end |
#range_name ⇒ ::String
Returns The name associated with this subnetwork secondary range, used when adding an alias IP/IPv6 range to a VM instance. The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the subnetwork.
78510 78511 78512 78513 78514 78515 78516 78517 78518 78519 78520 78521 78522 78523 78524 78525 78526 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78510 class SubnetworkSecondaryRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 # Treated as IPV4 for backward-compatibility. IP_VERSION_UNSPECIFIED = 92_360_440 end end |
#reserved_internal_range ⇒ ::String
Returns The URL of the reserved internal range. Only IPv4 is supported.
78510 78511 78512 78513 78514 78515 78516 78517 78518 78519 78520 78521 78522 78523 78524 78525 78526 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78510 class SubnetworkSecondaryRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 # Treated as IPV4 for backward-compatibility. IP_VERSION_UNSPECIFIED = 92_360_440 end end |