Class: Google::Cloud::Compute::V1::SubnetworksScopedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#subnetworks ⇒ ::Array<::Google::Cloud::Compute::V1::Subnetwork>

Returns A list of subnetworks contained in this scope.

Returns:



80374
80375
80376
80377
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80374

class SubnetworksScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns An informational warning that appears when the list of addresses is empty.

Returns:



80374
80375
80376
80377
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80374

class SubnetworksScopedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end