Class: Google::Cloud::Compute::V1::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#scope_name ⇒ ::String

Returns Name of the scope containing this set of Subnetworks.

Returns:

  • (::String) —

    Name of the scope containing this set of Subnetworks.



80385
80386
80387
80388
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80385

class SubnetworksScopedWarning
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns An informational warning about unreachable scope.

Returns:



80385
80386
80387
80388
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80385

class SubnetworksScopedWarning
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end