Class: Google::Cloud::Compute::V1::Subsetting
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Subsetting
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director.
Defined Under Namespace
Modules: Policy
Instance Attribute Summary collapse
-
#policy ⇒ ::String
Check the Policy enum for the list of possible values.
Instance Attribute Details
#policy ⇒ ::String
Returns Check the Policy enum for the list of possible values.
80403 80404 80405 80406 80407 80408 80409 80410 80411 80412 80413 80414 80415 80416 80417 80418 80419 80420 80421 80422 80423 80424 80425 80426 80427 80428 80429 80430 80431 80432 80433 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80403 class Subsetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Subsetting based on consistent hashing. # # For Traffic Director, the number of backends per backend group # (the subset size) is based on the `subset_size` parameter. # # For Internal HTTP(S) load balancing, the number of backends per backend # group (the subset size) is dynamically adjusted in two cases: # - As the number of proxy instances participating in Internal HTTP(S) load # balancing increases, the subset size decreases. # - When the total number of backends in a network exceeds the capacity of # a single proxy instance, subset sizes are reduced automatically for # each service that has backend subsetting enabled. CONSISTENT_HASH_SUBSETTING = 108_989_492 # No Subsetting. # # Clients may open connections and send traffic to all backends of this # backend service. This can lead to performance issues if there is # substantial imbalance in the count of clients and backends. NONE = 2_402_104 end end |