Class: Google::Cloud::Compute::V1::TargetGrpcProxy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetGrpcProxy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Target gRPC Proxy resource.
A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic. Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#url_map ⇒ ::String
URL to the UrlMap resource that defines the mapping from URL to the BackendService.
-
#validate_for_proxyless ⇒ ::Boolean
If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fingerprint ⇒ ::String
Returns Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetGrpcProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetGrpcProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetGrpcProxy.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL with id for the resource.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#url_map ⇒ ::String
Returns URL to the UrlMap resource that defines the mapping from URL to the BackendService. The protocol field in the BackendService must be set to GRPC.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_for_proxyless ⇒ ::Boolean
Returns If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy. This will enable configuration checks on urlMap and its referenced BackendServices to not allow unsupported features. A gRPC application must use "xds:///" scheme in the target URI of the service it is connecting to. If false, indicates that the BackendServices referenced by the urlMap will be accessed by gRPC applications via a sidecar proxy. In this case, a gRPC application must not use "xds:///" scheme in the target URI of the service it is connecting to.
76395 76396 76397 76398 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76395 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |