Class: Google::Cloud::Compute::V1::TargetHttpsProxiesSetCertificateMapRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetHttpsProxiesSetCertificateMapRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#certificate_map ⇒ ::String
URL of the Certificate Map to associate with this TargetHttpsProxy.
Instance Attribute Details
#certificate_map ⇒ ::String
Returns URL of the Certificate Map to associate with this TargetHttpsProxy.
Accepted format is//certificatemanager.googleapis.com/projects/{project}/locations/{location}/certificateMaps/{resourceName}.
78313 78314 78315 78316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78313 class TargetHttpsProxiesSetCertificateMapRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |