Class: Google::Cloud::Compute::V1::TargetHttpsProxiesSetQuicOverrideRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: QuicOverride

Instance Attribute Summary collapse

Instance Attribute Details

#quic_override ⇒ ::String

Returns QUIC policy for the TargetHttpsProxy resource. Check the QuicOverride enum for the list of possible values.

Returns:

  • (::String) —

    QUIC policy for the TargetHttpsProxy resource. Check the QuicOverride enum for the list of possible values.



80981
80982
80983
80984
80985
80986
80987
80988
80989
80990
80991
80992
80993
80994
80995
80996
80997
80998
80999
81000
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80981

class TargetHttpsProxiesSetQuicOverrideRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # QUIC policy for the TargetHttpsProxy resource.
  module QuicOverride
    # A value indicating that the enum field is not set.
    UNDEFINED_QUIC_OVERRIDE = 0

    # The load balancer will not attempt to negotiate QUIC with clients.
    DISABLE = 241_807_048

    # The load balancer will attempt to negotiate QUIC with clients.
    ENABLE = 438_835_587

    # No overrides to the default QUIC policy. This option is implicit if
    # no QUIC override has been specified in the request.
    NONE = 2_402_104
  end
end