Class: Google::Cloud::Compute::V1::TargetInstance
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetInstance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Target Instance resource.
You can use a target instance to handle traffic for one or more forwarding rules, which is ideal for forwarding protocol traffic that is managed by a single source. For example, ESP, AH, TCP, or UDP. For more information, readTarget instances.
Defined Under Namespace
Modules: NatPolicy
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#instance ⇒ ::String
A URL to the virtual machine instance that handles traffic for this target instance.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#nat_policy ⇒ ::String
Must have a value of NO_NAT.
-
#network ⇒ ::String
The URL of the network this target instance uses to forward traffic.
-
#security_policy ⇒ ::String
[Output Only] The resource URL for the security policy associated with this target instance.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#instance ⇒ ::String
Returns A URL to the virtual machine instance that handles traffic for this target instance. When creating a target instance, you can provide the fully-qualified URL or a valid partial URL to the desired virtual machine. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
- projects/project/zones/zone/instances/instance
- zones/zone/instances/instance.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] The type of the resource. Alwayscompute#targetInstance for target instances.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#nat_policy ⇒ ::String
Returns Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance. Check the NatPolicy enum for the list of possible values.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#network ⇒ ::String
Returns The URL of the network this target instance uses to forward traffic. If not specified, the traffic will be forwarded to the network that the default network interface belongs to.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#security_policy ⇒ ::String
Returns [Output Only] The resource URL for the security policy associated with this target instance.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |
#zone ⇒ ::String
Returns Output only. [Output Only] URL of the zone where the target instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
78771 78772 78773 78774 78775 78776 78777 78778 78779 78780 78781 78782 78783 78784 78785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78771 class TargetInstance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Must have a value of NO_NAT. # Protocol forwarding delivers packets while preserving the destination IP # address of the forwarding rule referencing the target instance. module NatPolicy # A value indicating that the enum field is not set. UNDEFINED_NAT_POLICY = 0 # No NAT performed. NO_NAT = 161_455_491 end end |