Class: Google::Cloud::Compute::V1::TargetPoolsAddInstanceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#instances ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceReference>

Returns A full or partial URL to an instance to add to this target pool. This can be a full or partial URL. For example, the following are valid URLs:

- https://www.googleapis.com/compute/v1/projects/project-id/zones/zone/instances/instance-name
- projects/project-id/zones/zone/instances/instance-name
- zones/zone/instances/instance-name.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::InstanceReference>) —

    A full or partial URL to an instance to add to this target pool. This can be a full or partial URL. For example, the following are valid URLs:

    - https://www.googleapis.com/compute/v1/projects/project-id/zones/zone/instances/instance-name
    - projects/project-id/zones/zone/instances/instance-name
    - zones/zone/instances/instance-name


81780
81781
81782
81783
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81780

class TargetPoolsAddInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end