Class: Google::Cloud::Compute::V1::TargetPoolsRemoveHealthCheckRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#health_checks ⇒ ::Array<::Google::Cloud::Compute::V1::HealthCheckReference>

Returns Health check URL to be removed. This can be a full or valid partial URL. For example, the following are valid URLs:

- https://www.googleapis.com/compute/beta/projects/project/global/httpHealthChecks/health-check
- projects/project/global/httpHealthChecks/health-check
- global/httpHealthChecks/health-check.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::HealthCheckReference>) —

    Health check URL to be removed. This can be a full or valid partial URL. For example, the following are valid URLs:

    - https://www.googleapis.com/compute/beta/projects/project/global/httpHealthChecks/health-check
    - projects/project/global/httpHealthChecks/health-check
    - global/httpHealthChecks/health-check


81793
81794
81795
81796
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81793

class TargetPoolsRemoveHealthCheckRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end