Class: Google::Cloud::Compute::V1::TargetSslProxiesSetCertificateMapRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#certificate_map::String

Returns URL of the Certificate Map to associate with this TargetSslProxy.

Accepted format is//certificatemanager.googleapis.com/projects/{project}/locations/{location}/certificateMaps/{resourceName}.

Returns:

  • (::String)

    URL of the Certificate Map to associate with this TargetSslProxy.

    Accepted format is//certificatemanager.googleapis.com/projects/{project}/locations/{location}/certificateMaps/{resourceName}.



77479
77480
77481
77482
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77479

class TargetSslProxiesSetCertificateMapRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end