Class: Google::Cloud::Compute::V1::TargetSslProxy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetSslProxy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Target SSL Proxy resource.
A target SSL proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target SSL proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.
Defined Under Namespace
Modules: ProxyHeader
Instance Attribute Summary collapse
-
#certificate_map ⇒ ::String
URL of a certificate map that identifies a certificate map associated with the given target proxy.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#proxy_header ⇒ ::String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#service ⇒ ::String
URL to the BackendService resource.
-
#ssl_certificates ⇒ ::Array<::String>
URLs to SslCertificate resources that are used to authenticate connections to Backends.
-
#ssl_policy ⇒ ::String
URL of SslPolicy resource that will be associated with the TargetSslProxy resource.
Instance Attribute Details
#certificate_map ⇒ ::String
Returns URL of a certificate map that identifies a certificate map associated with the given target proxy. This field can only be set for global target proxies. If set, sslCertificates will be ignored.
Accepted format is//certificatemanager.googleapis.com/projects/{project}/locations/{location}/certificateMaps/{resourceName}.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#targetSslProxy for target SSL proxies.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#proxy_header ⇒ ::String
Returns Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Check the ProxyHeader enum for the list of possible values.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#service ⇒ ::String
Returns URL to the BackendService resource.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#ssl_certificates ⇒ ::Array<::String>
Returns URLs to SslCertificate resources that are used to authenticate connections to Backends. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates. sslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#ssl_policy ⇒ ::String
Returns URL of SslPolicy resource that will be associated with the TargetSslProxy resource. If not set, the TargetSslProxy resource will not have any SSL policy configured.
77577 77578 77579 77580 77581 77582 77583 77584 77585 77586 77587 77588 77589 77590 77591 77592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77577 class TargetSslProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |