Class: Google::Cloud::Compute::V1::TargetTcpProxiesSetProxyHeaderRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: ProxyHeader

Instance Attribute Summary collapse

Instance Attribute Details

#proxy_header ⇒ ::String

Returns The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed. Check the ProxyHeader enum for the list of possible values.

Returns:

  • (::String) —

    The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed. Check the ProxyHeader enum for the list of possible values.



82006
82007
82008
82009
82010
82011
82012
82013
82014
82015
82016
82017
82018
82019
82020
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82006

class TargetTcpProxiesSetProxyHeaderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The new type of proxy header to append before sending data to the
  # backend.  NONE or PROXY_V1 are allowed.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end