Class: Google::Cloud::Compute::V1::TargetTcpProxy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Target TCP Proxy resource.

A target TCP proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target TCP proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.

Defined Under Namespace

Modules: LoadBalancingScheme, ProxyHeader

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp ⇒ ::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String) —

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#description ⇒ ::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String) —

    An optional description of this resource. Provide this property when you create the resource.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#id ⇒ ::Integer

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer) —

    [Output Only] The unique identifier for the resource. This identifier is defined by the server.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#targetTcpProxy for target TCP proxies.

Returns:

  • (::String) —

    Output only. [Output Only] Type of the resource. Alwayscompute#targetTcpProxy for target TCP proxies.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#load_balancing_scheme ⇒ ::String

Returns Specifies the type of load balancing scheme used by this target proxy. Check the LoadBalancingScheme enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the type of load balancing scheme used by this target proxy. Check the LoadBalancingScheme enum for the list of possible values.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#name ⇒ ::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String) —

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#proxy_bind ⇒ ::Boolean

Returns This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.

When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them.

The default is false.

Returns:

  • (::Boolean) —

    This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.

    When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them.

    The default is false.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#proxy_header ⇒ ::String

Returns Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Check the ProxyHeader enum for the list of possible values.

Returns:

  • (::String) —

    Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Check the ProxyHeader enum for the list of possible values.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#region ⇒ ::String

Returns Output only. [Output Only] URL of the region where the regional TCP proxy resides. This field is not applicable to global TCP proxy.

Returns:

  • (::String) —

    Output only. [Output Only] URL of the region where the regional TCP proxy resides. This field is not applicable to global TCP proxy.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String) —

    [Output Only] Server-defined URL for the resource.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#service ⇒ ::String

Returns URL to the BackendService resource.

Returns:

  • (::String) —

    URL to the BackendService resource.



82085
82086
82087
82088
82089
82090
82091
82092
82093
82094
82095
82096
82097
82098
82099
82100
82101
82102
82103
82104
82105
82106
82107
82108
82109
82110
82111
82112
82113
82114
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82085

class TargetTcpProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of load balancing scheme used by this target proxy.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    EXTERNAL = 35_607_499

    EXTERNAL_MANAGED = 512_006_923

    INTERNAL_MANAGED = 37_350_397

    LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end