Class: Google::Cloud::Compute::V1::TargetTcpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetTcpProxyAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::TargetTcpProxiesScopedList}
A list of TargetTcpProxiesScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
82142 82143 82144 82145 82146 82147 82148 82149 82150 82151 82152 82153 82154 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82142 class TargetTcpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetTcpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::TargetTcpProxiesScopedList}
Returns A list of TargetTcpProxiesScopedList resources.
82142 82143 82144 82145 82146 82147 82148 82149 82150 82151 82152 82153 82154 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82142 class TargetTcpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetTcpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Alwayscompute#targetTcpProxyAggregatedList for lists of Target TCP Proxies.
82142 82143 82144 82145 82146 82147 82148 82149 82150 82151 82152 82153 82154 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82142 class TargetTcpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetTcpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
82142 82143 82144 82145 82146 82147 82148 82149 82150 82151 82152 82153 82154 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82142 class TargetTcpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetTcpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
82142 82143 82144 82145 82146 82147 82148 82149 82150 82151 82152 82153 82154 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82142 class TargetTcpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetTcpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
82142 82143 82144 82145 82146 82147 82148 82149 82150 82151 82152 82153 82154 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82142 class TargetTcpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetTcpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
82142 82143 82144 82145 82146 82147 82148 82149 82150 82151 82152 82153 82154 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82142 class TargetTcpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetTcpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |