Class: Google::Cloud::Compute::V1::TargetVpnGatewayParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ResourceManagerTagsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#resource_manager_tags::Google::Protobuf::Map{::String => ::String}

Returns Tag keys/values directly bound to this resource. Tag keys and values have the same definition as resource manager tags. The field is allowed for INSERT only. The keys/values to set on the resource should be specified in either ID { : } or Namespaced format { : }. For example the following are valid inputs:

  • {"tagKeys/333" : "tagValues/444", "tagKeys/123" : "tagValues/456"}
  • {"123/environment" : "production", "345/abc" : "xyz"} Note:
  • Invalid combinations of ID & namespaced format is not supported. For instance: {"123/environment" : "tagValues/444"} is invalid.
  • Inconsistent format is not supported. For instance: {"tagKeys/333" : "tagValues/444", "123/env" : "prod"} is invalid.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Tag keys/values directly bound to this resource. Tag keys and values have the same definition as resource manager tags. The field is allowed for INSERT only. The keys/values to set on the resource should be specified in either ID { : } or Namespaced format { : }. For example the following are valid inputs:

    • {"tagKeys/333" : "tagValues/444", "tagKeys/123" : "tagValues/456"}
    • {"123/environment" : "production", "345/abc" : "xyz"} Note:
    • Invalid combinations of ID & namespaced format is not supported. For instance: {"123/environment" : "tagValues/444"} is invalid.
    • Inconsistent format is not supported. For instance: {"tagKeys/333" : "tagValues/444", "123/env" : "prod"} is invalid.


77994
77995
77996
77997
77998
77999
78000
78001
78002
78003
78004
78005
78006
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77994

class TargetVpnGatewayParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end