Class: Google::Cloud::Compute::V1::TestFailure

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#actual_output_url ⇒ ::String

Returns The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.

Returns:

  • (::String) —

    The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.



82430
82431
82432
82433
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82430

class TestFailure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#actual_redirect_response_code ⇒ ::Integer

Returns Actual HTTP status code for rule with urlRedirect calculated by load balancer.

Returns:

  • (::Integer) —

    Actual HTTP status code for rule with urlRedirect calculated by load balancer



82430
82431
82432
82433
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82430

class TestFailure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#actual_service ⇒ ::String

Returns BackendService or BackendBucket returned by load balancer.

Returns:

  • (::String) —

    BackendService or BackendBucket returned by load balancer.



82430
82431
82432
82433
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82430

class TestFailure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expected_output_url ⇒ ::String

Returns The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.

Returns:

  • (::String) —

    The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.



82430
82431
82432
82433
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82430

class TestFailure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expected_redirect_response_code ⇒ ::Integer

Returns Expected HTTP status code for rule with urlRedirect calculated by load balancer.

Returns:

  • (::Integer) —

    Expected HTTP status code for rule with urlRedirect calculated by load balancer



82430
82431
82432
82433
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82430

class TestFailure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expected_service ⇒ ::String

Returns Expected BackendService or BackendBucket resource the given URL should be mapped to.

Returns:

  • (::String) —

    Expected BackendService or BackendBucket resource the given URL should be mapped to.



82430
82431
82432
82433
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82430

class TestFailure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#headers ⇒ ::Array<::Google::Cloud::Compute::V1::UrlMapTestHeader>

Returns HTTP headers of the request.

Returns:



82430
82431
82432
82433
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82430

class TestFailure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#host ⇒ ::String

Returns Host portion of the URL.

Returns:

  • (::String) —

    Host portion of the URL.



82430
82431
82432
82433
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82430

class TestFailure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path ⇒ ::String

Returns Path portion including query parameters in the URL.

Returns:

  • (::String) —

    Path portion including query parameters in the URL.



82430
82431
82432
82433
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82430

class TestFailure
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end