Class: Google::Cloud::Compute::V1::TestIamPermissionsRegionSnapshotRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for RegionSnapshots.TestIamPermissions. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#project ⇒ ::String

Returns Project ID for this request.

Returns:

  • (::String) —

    Project ID for this request.



83138
83139
83140
83141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83138

class TestIamPermissionsRegionSnapshotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region ⇒ ::String

Returns The name of the region for this request.

Returns:

  • (::String) —

    The name of the region for this request.



83138
83139
83140
83141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83138

class TestIamPermissionsRegionSnapshotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource ⇒ ::String

Returns Name or id of the resource for this request.

Returns:

  • (::String) —

    Name or id of the resource for this request.



83138
83139
83140
83141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83138

class TestIamPermissionsRegionSnapshotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#test_permissions_request_resource ⇒ ::Google::Cloud::Compute::V1::TestPermissionsRequest

Returns The body resource for this request.

Returns:



83138
83139
83140
83141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83138

class TestIamPermissionsRegionSnapshotRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end