Class: Google::Cloud::Compute::V1::TestPermissionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#permissions ⇒ ::Array<::String>

Returns The set of permissions to check for the 'resource'. Permissions with wildcards (such as '' or 'storage.') are not allowed.

Returns:

  • The set of permissions to check for the 'resource'. Permissions with wildcards (such as '' or 'storage.') are not allowed.



83408
83409
83410
83411
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83408

class TestPermissionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end