Class: Google::Cloud::Compute::V1::UpcomingMaintenance

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Upcoming Maintenance notification information.

Defined Under Namespace

Modules: MaintenanceReasons, MaintenanceStatus, Type

Instance Attribute Summary collapse

Instance Attribute Details

#can_reschedule ⇒ ::Boolean

Returns Indicates if the maintenance can be customer triggered.

Returns:

  • (::Boolean) —

    Indicates if the maintenance can be customer triggered.



83474
83475
83476
83477
83478
83479
83480
83481
83482
83483
83484
83485
83486
83487
83488
83489
83490
83491
83492
83493
83494
83495
83496
83497
83498
83499
83500
83501
83502
83503
83504
83505
83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83474

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module MaintenanceReasons
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_REASONS = 0

    # Maintenance due to disk errors.
    FAILURE_DISK = 8_573_778

    # Maintenance due to GPU errors.
    FAILURE_GPU = 467_876_919

    # Maintenance due to customer reported multiple faulty hosts via R&R
    # Subblock API.
    FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959

    # Maintenance due to customer reported NVLink switch failure via R&R
    # Subblock API.
    FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838

    # Maintenance due to high GPU temperature.
    FAILURE_GPU_TEMPERATURE = 24_926_540

    # Maintenance due to GPU xid failure.
    FAILURE_GPU_XID = 51_956_587

    # Maintenance due to infrastructure errors.
    FAILURE_INFRA = 270_541_467

    # Maintenance due to interface errors.
    FAILURE_INTERFACE = 390_068_356

    # Maintenance due to memory errors.
    FAILURE_MEMORY = 440_132_982

    # Maintenance due to network errors.
    FAILURE_NETWORK = 42_811_449

    # Maintenance due to NVLink failure.
    FAILURE_NVLINK = 484_426_295

    # Maintenance due to redundant hardware fault.
    FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530

    # Maintenance due to TPU errors.
    FAILURE_TPU = 467_889_412

    # Maintenance due to infrastructure relocation.
    INFRASTRUCTURE_RELOCATION = 359_845_636

    # Unknown maintenance reason. Do not use this value.
    MAINTENANCE_REASON_UNKNOWN = 50_570_235

    # Maintenance due to planned network update.
    PLANNED_NETWORK_UPDATE = 135_494_677

    # Maintenance due to planned update to the instance.
    PLANNED_UPDATE = 161_733_572
  end

  module MaintenanceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_STATUS = 0

    # There is ongoing maintenance on this VM.
    ONGOING = 473_158_491

    # There is pending maintenance.
    PENDING = 35_394_935

    # Unknown maintenance status. Do not use this value.
    UNKNOWN = 433_141_802
  end

  # Defines the type of maintenance.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Multiple maintenance types in one window.
    # This is only intended to be used for groups.
    MULTIPLE = 362_714_640

    # Scheduled maintenance (e.g. maintenance after uptime guarantee is
    # complete).
    SCHEDULED = 478_400_653

    # No type specified. Do not use this value.
    UNKNOWN_TYPE = 490_705_455

    # Unscheduled maintenance (e.g. emergency maintenance during
    # uptime guarantee).
    UNSCHEDULED = 450_077_204
  end
end

#latest_window_start_time ⇒ ::String

Returns The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format.

Returns:

  • (::String) —

    The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format.



83474
83475
83476
83477
83478
83479
83480
83481
83482
83483
83484
83485
83486
83487
83488
83489
83490
83491
83492
83493
83494
83495
83496
83497
83498
83499
83500
83501
83502
83503
83504
83505
83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83474

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module MaintenanceReasons
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_REASONS = 0

    # Maintenance due to disk errors.
    FAILURE_DISK = 8_573_778

    # Maintenance due to GPU errors.
    FAILURE_GPU = 467_876_919

    # Maintenance due to customer reported multiple faulty hosts via R&R
    # Subblock API.
    FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959

    # Maintenance due to customer reported NVLink switch failure via R&R
    # Subblock API.
    FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838

    # Maintenance due to high GPU temperature.
    FAILURE_GPU_TEMPERATURE = 24_926_540

    # Maintenance due to GPU xid failure.
    FAILURE_GPU_XID = 51_956_587

    # Maintenance due to infrastructure errors.
    FAILURE_INFRA = 270_541_467

    # Maintenance due to interface errors.
    FAILURE_INTERFACE = 390_068_356

    # Maintenance due to memory errors.
    FAILURE_MEMORY = 440_132_982

    # Maintenance due to network errors.
    FAILURE_NETWORK = 42_811_449

    # Maintenance due to NVLink failure.
    FAILURE_NVLINK = 484_426_295

    # Maintenance due to redundant hardware fault.
    FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530

    # Maintenance due to TPU errors.
    FAILURE_TPU = 467_889_412

    # Maintenance due to infrastructure relocation.
    INFRASTRUCTURE_RELOCATION = 359_845_636

    # Unknown maintenance reason. Do not use this value.
    MAINTENANCE_REASON_UNKNOWN = 50_570_235

    # Maintenance due to planned network update.
    PLANNED_NETWORK_UPDATE = 135_494_677

    # Maintenance due to planned update to the instance.
    PLANNED_UPDATE = 161_733_572
  end

  module MaintenanceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_STATUS = 0

    # There is ongoing maintenance on this VM.
    ONGOING = 473_158_491

    # There is pending maintenance.
    PENDING = 35_394_935

    # Unknown maintenance status. Do not use this value.
    UNKNOWN = 433_141_802
  end

  # Defines the type of maintenance.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Multiple maintenance types in one window.
    # This is only intended to be used for groups.
    MULTIPLE = 362_714_640

    # Scheduled maintenance (e.g. maintenance after uptime guarantee is
    # complete).
    SCHEDULED = 478_400_653

    # No type specified. Do not use this value.
    UNKNOWN_TYPE = 490_705_455

    # Unscheduled maintenance (e.g. emergency maintenance during
    # uptime guarantee).
    UNSCHEDULED = 450_077_204
  end
end

#maintenance_on_shutdown ⇒ ::Boolean

Returns Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.

Returns:

  • (::Boolean) —

    Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.



83474
83475
83476
83477
83478
83479
83480
83481
83482
83483
83484
83485
83486
83487
83488
83489
83490
83491
83492
83493
83494
83495
83496
83497
83498
83499
83500
83501
83502
83503
83504
83505
83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83474

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module MaintenanceReasons
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_REASONS = 0

    # Maintenance due to disk errors.
    FAILURE_DISK = 8_573_778

    # Maintenance due to GPU errors.
    FAILURE_GPU = 467_876_919

    # Maintenance due to customer reported multiple faulty hosts via R&R
    # Subblock API.
    FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959

    # Maintenance due to customer reported NVLink switch failure via R&R
    # Subblock API.
    FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838

    # Maintenance due to high GPU temperature.
    FAILURE_GPU_TEMPERATURE = 24_926_540

    # Maintenance due to GPU xid failure.
    FAILURE_GPU_XID = 51_956_587

    # Maintenance due to infrastructure errors.
    FAILURE_INFRA = 270_541_467

    # Maintenance due to interface errors.
    FAILURE_INTERFACE = 390_068_356

    # Maintenance due to memory errors.
    FAILURE_MEMORY = 440_132_982

    # Maintenance due to network errors.
    FAILURE_NETWORK = 42_811_449

    # Maintenance due to NVLink failure.
    FAILURE_NVLINK = 484_426_295

    # Maintenance due to redundant hardware fault.
    FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530

    # Maintenance due to TPU errors.
    FAILURE_TPU = 467_889_412

    # Maintenance due to infrastructure relocation.
    INFRASTRUCTURE_RELOCATION = 359_845_636

    # Unknown maintenance reason. Do not use this value.
    MAINTENANCE_REASON_UNKNOWN = 50_570_235

    # Maintenance due to planned network update.
    PLANNED_NETWORK_UPDATE = 135_494_677

    # Maintenance due to planned update to the instance.
    PLANNED_UPDATE = 161_733_572
  end

  module MaintenanceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_STATUS = 0

    # There is ongoing maintenance on this VM.
    ONGOING = 473_158_491

    # There is pending maintenance.
    PENDING = 35_394_935

    # Unknown maintenance status. Do not use this value.
    UNKNOWN = 433_141_802
  end

  # Defines the type of maintenance.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Multiple maintenance types in one window.
    # This is only intended to be used for groups.
    MULTIPLE = 362_714_640

    # Scheduled maintenance (e.g. maintenance after uptime guarantee is
    # complete).
    SCHEDULED = 478_400_653

    # No type specified. Do not use this value.
    UNKNOWN_TYPE = 490_705_455

    # Unscheduled maintenance (e.g. emergency maintenance during
    # uptime guarantee).
    UNSCHEDULED = 450_077_204
  end
end

#maintenance_reasons ⇒ ::Array<::String>

Returns The reasons for the maintenance. Only valid for vms. Check the MaintenanceReasons enum for the list of possible values.

Returns:

  • (::Array<::String>) —

    The reasons for the maintenance. Only valid for vms. Check the MaintenanceReasons enum for the list of possible values.



83474
83475
83476
83477
83478
83479
83480
83481
83482
83483
83484
83485
83486
83487
83488
83489
83490
83491
83492
83493
83494
83495
83496
83497
83498
83499
83500
83501
83502
83503
83504
83505
83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83474

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module MaintenanceReasons
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_REASONS = 0

    # Maintenance due to disk errors.
    FAILURE_DISK = 8_573_778

    # Maintenance due to GPU errors.
    FAILURE_GPU = 467_876_919

    # Maintenance due to customer reported multiple faulty hosts via R&R
    # Subblock API.
    FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959

    # Maintenance due to customer reported NVLink switch failure via R&R
    # Subblock API.
    FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838

    # Maintenance due to high GPU temperature.
    FAILURE_GPU_TEMPERATURE = 24_926_540

    # Maintenance due to GPU xid failure.
    FAILURE_GPU_XID = 51_956_587

    # Maintenance due to infrastructure errors.
    FAILURE_INFRA = 270_541_467

    # Maintenance due to interface errors.
    FAILURE_INTERFACE = 390_068_356

    # Maintenance due to memory errors.
    FAILURE_MEMORY = 440_132_982

    # Maintenance due to network errors.
    FAILURE_NETWORK = 42_811_449

    # Maintenance due to NVLink failure.
    FAILURE_NVLINK = 484_426_295

    # Maintenance due to redundant hardware fault.
    FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530

    # Maintenance due to TPU errors.
    FAILURE_TPU = 467_889_412

    # Maintenance due to infrastructure relocation.
    INFRASTRUCTURE_RELOCATION = 359_845_636

    # Unknown maintenance reason. Do not use this value.
    MAINTENANCE_REASON_UNKNOWN = 50_570_235

    # Maintenance due to planned network update.
    PLANNED_NETWORK_UPDATE = 135_494_677

    # Maintenance due to planned update to the instance.
    PLANNED_UPDATE = 161_733_572
  end

  module MaintenanceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_STATUS = 0

    # There is ongoing maintenance on this VM.
    ONGOING = 473_158_491

    # There is pending maintenance.
    PENDING = 35_394_935

    # Unknown maintenance status. Do not use this value.
    UNKNOWN = 433_141_802
  end

  # Defines the type of maintenance.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Multiple maintenance types in one window.
    # This is only intended to be used for groups.
    MULTIPLE = 362_714_640

    # Scheduled maintenance (e.g. maintenance after uptime guarantee is
    # complete).
    SCHEDULED = 478_400_653

    # No type specified. Do not use this value.
    UNKNOWN_TYPE = 490_705_455

    # Unscheduled maintenance (e.g. emergency maintenance during
    # uptime guarantee).
    UNSCHEDULED = 450_077_204
  end
end

#maintenance_status ⇒ ::String

Returns Check the MaintenanceStatus enum for the list of possible values.

Returns:

  • (::String) —

    Check the MaintenanceStatus enum for the list of possible values.



83474
83475
83476
83477
83478
83479
83480
83481
83482
83483
83484
83485
83486
83487
83488
83489
83490
83491
83492
83493
83494
83495
83496
83497
83498
83499
83500
83501
83502
83503
83504
83505
83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83474

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module MaintenanceReasons
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_REASONS = 0

    # Maintenance due to disk errors.
    FAILURE_DISK = 8_573_778

    # Maintenance due to GPU errors.
    FAILURE_GPU = 467_876_919

    # Maintenance due to customer reported multiple faulty hosts via R&R
    # Subblock API.
    FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959

    # Maintenance due to customer reported NVLink switch failure via R&R
    # Subblock API.
    FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838

    # Maintenance due to high GPU temperature.
    FAILURE_GPU_TEMPERATURE = 24_926_540

    # Maintenance due to GPU xid failure.
    FAILURE_GPU_XID = 51_956_587

    # Maintenance due to infrastructure errors.
    FAILURE_INFRA = 270_541_467

    # Maintenance due to interface errors.
    FAILURE_INTERFACE = 390_068_356

    # Maintenance due to memory errors.
    FAILURE_MEMORY = 440_132_982

    # Maintenance due to network errors.
    FAILURE_NETWORK = 42_811_449

    # Maintenance due to NVLink failure.
    FAILURE_NVLINK = 484_426_295

    # Maintenance due to redundant hardware fault.
    FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530

    # Maintenance due to TPU errors.
    FAILURE_TPU = 467_889_412

    # Maintenance due to infrastructure relocation.
    INFRASTRUCTURE_RELOCATION = 359_845_636

    # Unknown maintenance reason. Do not use this value.
    MAINTENANCE_REASON_UNKNOWN = 50_570_235

    # Maintenance due to planned network update.
    PLANNED_NETWORK_UPDATE = 135_494_677

    # Maintenance due to planned update to the instance.
    PLANNED_UPDATE = 161_733_572
  end

  module MaintenanceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_STATUS = 0

    # There is ongoing maintenance on this VM.
    ONGOING = 473_158_491

    # There is pending maintenance.
    PENDING = 35_394_935

    # Unknown maintenance status. Do not use this value.
    UNKNOWN = 433_141_802
  end

  # Defines the type of maintenance.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Multiple maintenance types in one window.
    # This is only intended to be used for groups.
    MULTIPLE = 362_714_640

    # Scheduled maintenance (e.g. maintenance after uptime guarantee is
    # complete).
    SCHEDULED = 478_400_653

    # No type specified. Do not use this value.
    UNKNOWN_TYPE = 490_705_455

    # Unscheduled maintenance (e.g. emergency maintenance during
    # uptime guarantee).
    UNSCHEDULED = 450_077_204
  end
end

#type ⇒ ::String

Returns Defines the type of maintenance. Check the Type enum for the list of possible values.

Returns:

  • (::String) —

    Defines the type of maintenance. Check the Type enum for the list of possible values.



83474
83475
83476
83477
83478
83479
83480
83481
83482
83483
83484
83485
83486
83487
83488
83489
83490
83491
83492
83493
83494
83495
83496
83497
83498
83499
83500
83501
83502
83503
83504
83505
83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83474

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module MaintenanceReasons
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_REASONS = 0

    # Maintenance due to disk errors.
    FAILURE_DISK = 8_573_778

    # Maintenance due to GPU errors.
    FAILURE_GPU = 467_876_919

    # Maintenance due to customer reported multiple faulty hosts via R&R
    # Subblock API.
    FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959

    # Maintenance due to customer reported NVLink switch failure via R&R
    # Subblock API.
    FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838

    # Maintenance due to high GPU temperature.
    FAILURE_GPU_TEMPERATURE = 24_926_540

    # Maintenance due to GPU xid failure.
    FAILURE_GPU_XID = 51_956_587

    # Maintenance due to infrastructure errors.
    FAILURE_INFRA = 270_541_467

    # Maintenance due to interface errors.
    FAILURE_INTERFACE = 390_068_356

    # Maintenance due to memory errors.
    FAILURE_MEMORY = 440_132_982

    # Maintenance due to network errors.
    FAILURE_NETWORK = 42_811_449

    # Maintenance due to NVLink failure.
    FAILURE_NVLINK = 484_426_295

    # Maintenance due to redundant hardware fault.
    FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530

    # Maintenance due to TPU errors.
    FAILURE_TPU = 467_889_412

    # Maintenance due to infrastructure relocation.
    INFRASTRUCTURE_RELOCATION = 359_845_636

    # Unknown maintenance reason. Do not use this value.
    MAINTENANCE_REASON_UNKNOWN = 50_570_235

    # Maintenance due to planned network update.
    PLANNED_NETWORK_UPDATE = 135_494_677

    # Maintenance due to planned update to the instance.
    PLANNED_UPDATE = 161_733_572
  end

  module MaintenanceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_STATUS = 0

    # There is ongoing maintenance on this VM.
    ONGOING = 473_158_491

    # There is pending maintenance.
    PENDING = 35_394_935

    # Unknown maintenance status. Do not use this value.
    UNKNOWN = 433_141_802
  end

  # Defines the type of maintenance.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Multiple maintenance types in one window.
    # This is only intended to be used for groups.
    MULTIPLE = 362_714_640

    # Scheduled maintenance (e.g. maintenance after uptime guarantee is
    # complete).
    SCHEDULED = 478_400_653

    # No type specified. Do not use this value.
    UNKNOWN_TYPE = 490_705_455

    # Unscheduled maintenance (e.g. emergency maintenance during
    # uptime guarantee).
    UNSCHEDULED = 450_077_204
  end
end

#window_end_time ⇒ ::String

Returns The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format.

Returns:

  • (::String) —

    The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format.



83474
83475
83476
83477
83478
83479
83480
83481
83482
83483
83484
83485
83486
83487
83488
83489
83490
83491
83492
83493
83494
83495
83496
83497
83498
83499
83500
83501
83502
83503
83504
83505
83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83474

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module MaintenanceReasons
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_REASONS = 0

    # Maintenance due to disk errors.
    FAILURE_DISK = 8_573_778

    # Maintenance due to GPU errors.
    FAILURE_GPU = 467_876_919

    # Maintenance due to customer reported multiple faulty hosts via R&R
    # Subblock API.
    FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959

    # Maintenance due to customer reported NVLink switch failure via R&R
    # Subblock API.
    FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838

    # Maintenance due to high GPU temperature.
    FAILURE_GPU_TEMPERATURE = 24_926_540

    # Maintenance due to GPU xid failure.
    FAILURE_GPU_XID = 51_956_587

    # Maintenance due to infrastructure errors.
    FAILURE_INFRA = 270_541_467

    # Maintenance due to interface errors.
    FAILURE_INTERFACE = 390_068_356

    # Maintenance due to memory errors.
    FAILURE_MEMORY = 440_132_982

    # Maintenance due to network errors.
    FAILURE_NETWORK = 42_811_449

    # Maintenance due to NVLink failure.
    FAILURE_NVLINK = 484_426_295

    # Maintenance due to redundant hardware fault.
    FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530

    # Maintenance due to TPU errors.
    FAILURE_TPU = 467_889_412

    # Maintenance due to infrastructure relocation.
    INFRASTRUCTURE_RELOCATION = 359_845_636

    # Unknown maintenance reason. Do not use this value.
    MAINTENANCE_REASON_UNKNOWN = 50_570_235

    # Maintenance due to planned network update.
    PLANNED_NETWORK_UPDATE = 135_494_677

    # Maintenance due to planned update to the instance.
    PLANNED_UPDATE = 161_733_572
  end

  module MaintenanceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_STATUS = 0

    # There is ongoing maintenance on this VM.
    ONGOING = 473_158_491

    # There is pending maintenance.
    PENDING = 35_394_935

    # Unknown maintenance status. Do not use this value.
    UNKNOWN = 433_141_802
  end

  # Defines the type of maintenance.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Multiple maintenance types in one window.
    # This is only intended to be used for groups.
    MULTIPLE = 362_714_640

    # Scheduled maintenance (e.g. maintenance after uptime guarantee is
    # complete).
    SCHEDULED = 478_400_653

    # No type specified. Do not use this value.
    UNKNOWN_TYPE = 490_705_455

    # Unscheduled maintenance (e.g. emergency maintenance during
    # uptime guarantee).
    UNSCHEDULED = 450_077_204
  end
end

#window_start_time ⇒ ::String

Returns The current start time of the maintenance window. This timestamp value is in RFC3339 text format.

Returns:

  • (::String) —

    The current start time of the maintenance window. This timestamp value is in RFC3339 text format.



83474
83475
83476
83477
83478
83479
83480
83481
83482
83483
83484
83485
83486
83487
83488
83489
83490
83491
83492
83493
83494
83495
83496
83497
83498
83499
83500
83501
83502
83503
83504
83505
83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83474

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module MaintenanceReasons
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_REASONS = 0

    # Maintenance due to disk errors.
    FAILURE_DISK = 8_573_778

    # Maintenance due to GPU errors.
    FAILURE_GPU = 467_876_919

    # Maintenance due to customer reported multiple faulty hosts via R&R
    # Subblock API.
    FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959

    # Maintenance due to customer reported NVLink switch failure via R&R
    # Subblock API.
    FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838

    # Maintenance due to high GPU temperature.
    FAILURE_GPU_TEMPERATURE = 24_926_540

    # Maintenance due to GPU xid failure.
    FAILURE_GPU_XID = 51_956_587

    # Maintenance due to infrastructure errors.
    FAILURE_INFRA = 270_541_467

    # Maintenance due to interface errors.
    FAILURE_INTERFACE = 390_068_356

    # Maintenance due to memory errors.
    FAILURE_MEMORY = 440_132_982

    # Maintenance due to network errors.
    FAILURE_NETWORK = 42_811_449

    # Maintenance due to NVLink failure.
    FAILURE_NVLINK = 484_426_295

    # Maintenance due to redundant hardware fault.
    FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530

    # Maintenance due to TPU errors.
    FAILURE_TPU = 467_889_412

    # Maintenance due to infrastructure relocation.
    INFRASTRUCTURE_RELOCATION = 359_845_636

    # Unknown maintenance reason. Do not use this value.
    MAINTENANCE_REASON_UNKNOWN = 50_570_235

    # Maintenance due to planned network update.
    PLANNED_NETWORK_UPDATE = 135_494_677

    # Maintenance due to planned update to the instance.
    PLANNED_UPDATE = 161_733_572
  end

  module MaintenanceStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_MAINTENANCE_STATUS = 0

    # There is ongoing maintenance on this VM.
    ONGOING = 473_158_491

    # There is pending maintenance.
    PENDING = 35_394_935

    # Unknown maintenance status. Do not use this value.
    UNKNOWN = 433_141_802
  end

  # Defines the type of maintenance.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Multiple maintenance types in one window.
    # This is only intended to be used for groups.
    MULTIPLE = 362_714_640

    # Scheduled maintenance (e.g. maintenance after uptime guarantee is
    # complete).
    SCHEDULED = 478_400_653

    # No type specified. Do not use this value.
    UNKNOWN_TYPE = 490_705_455

    # Unscheduled maintenance (e.g. emergency maintenance during
    # uptime guarantee).
    UNSCHEDULED = 450_077_204
  end
end