Class: Google::Cloud::Compute::V1::UpdateBackendBucketRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UpdateBackendBucketRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for BackendBuckets.Update. See the method description for details.
Instance Attribute Summary collapse
-
#backend_bucket ⇒ ::String
Name of the BackendBucket resource to update.
-
#backend_bucket_resource ⇒ ::Google::Cloud::Compute::V1::BackendBucket
The body resource for this request.
-
#project ⇒ ::String
Project ID for this request.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
Instance Attribute Details
#backend_bucket ⇒ ::String
Returns Name of the BackendBucket resource to update.
37000 37001 37002 37003 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37000 class UpdateBackendBucketRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#backend_bucket_resource ⇒ ::Google::Cloud::Compute::V1::BackendBucket
Returns The body resource for this request.
37000 37001 37002 37003 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37000 class UpdateBackendBucketRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID for this request.
37000 37001 37002 37003 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37000 class UpdateBackendBucketRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported ( 00000000-0000-0000-0000-000000000000).
37000 37001 37002 37003 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37000 class UpdateBackendBucketRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |