Class: Google::Cloud::Compute::V1::UpdateNamedSetRouterRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UpdateNamedSetRouterRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for Routers.UpdateNamedSet. See the method description for details.
Instance Attribute Summary collapse
-
#named_set_resource ⇒ ::Google::Cloud::Compute::V1::NamedSet
The body resource for this request.
-
#project ⇒ ::String
Project ID for this request.
-
#region ⇒ ::String
Name of the region for this request.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#router ⇒ ::String
Name of the Router resource where Named Set is defined.
Instance Attribute Details
#named_set_resource ⇒ ::Google::Cloud::Compute::V1::NamedSet
Returns The body resource for this request.
82384 82385 82386 82387 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82384 class UpdateNamedSetRouterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID for this request.
82384 82385 82386 82387 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82384 class UpdateNamedSetRouterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns Name of the region for this request.
82384 82385 82386 82387 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82384 class UpdateNamedSetRouterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
82384 82385 82386 82387 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82384 class UpdateNamedSetRouterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#router ⇒ ::String
Returns Name of the Router resource where Named Set is defined.
82384 82385 82386 82387 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82384 class UpdateNamedSetRouterRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |