Class: Google::Cloud::Compute::V1::UpdatePreviewFeatureRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UpdatePreviewFeatureRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for PreviewFeatures.Update. See the method description for details.
Instance Attribute Summary collapse
-
#preview_feature ⇒ ::String
Name of the PreviewFeature for this request.
-
#preview_feature_resource ⇒ ::Google::Cloud::Compute::V1::PreviewFeature
The body resource for this request.
-
#project ⇒ ::String
Project ID for this request.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
Instance Attribute Details
#preview_feature ⇒ ::String
Returns Name of the PreviewFeature for this request.
79883 79884 79885 79886 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79883 class UpdatePreviewFeatureRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#preview_feature_resource ⇒ ::Google::Cloud::Compute::V1::PreviewFeature
Returns The body resource for this request.
79883 79884 79885 79886 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79883 class UpdatePreviewFeatureRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Project ID for this request.
79883 79884 79885 79886 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79883 class UpdatePreviewFeatureRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
79883 79884 79885 79886 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79883 class UpdatePreviewFeatureRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |