Class: Google::Cloud::Compute::V1::UpdateReservationSlotRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UpdateReservationSlotRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for ReservationSlots.Update. See the method description for details.
Instance Attribute Summary collapse
-
#parent_name ⇒ ::String
The name of the sub-block resource.
-
#project ⇒ ::String
The project ID for this request.
-
#reservation_slot ⇒ ::String
The name of the slot resource.
-
#reservation_slot_resource ⇒ ::Google::Cloud::Compute::V1::ReservationSlot
The body resource for this request.
-
#update_mask ⇒ ::String
The fields to be updated as part of this request.
-
#zone ⇒ ::String
The name of the zone for this request, formatted as RFC1035.
Instance Attribute Details
#parent_name ⇒ ::String
Returns The name of the sub-block resource.
80142 80143 80144 80145 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80142 class UpdateReservationSlotRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns The project ID for this request.
80142 80143 80144 80145 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80142 class UpdateReservationSlotRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reservation_slot ⇒ ::String
Returns The name of the slot resource.
80142 80143 80144 80145 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80142 class UpdateReservationSlotRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reservation_slot_resource ⇒ ::Google::Cloud::Compute::V1::ReservationSlot
Returns The body resource for this request.
80142 80143 80144 80145 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80142 class UpdateReservationSlotRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::String
Returns The fields to be updated as part of this request.
80142 80143 80144 80145 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80142 class UpdateReservationSlotRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
Returns The name of the zone for this request, formatted as RFC1035.
80142 80143 80144 80145 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80142 class UpdateReservationSlotRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |