Class: Google::Cloud::Compute::V1::UrlMapValidationResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Message representing the validation result for a UrlMap.

Instance Attribute Summary collapse

Instance Attribute Details

#load_errors ⇒ ::Array<::String>

Returns:

  • (::Array<::String>)


85092
85093
85094
85095
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85092

class UrlMapValidationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#load_succeeded ⇒ ::Boolean

Returns Whether the given UrlMap can be successfully loaded. If false, 'loadErrors' indicates the reasons.

Returns:

  • (::Boolean) —

    Whether the given UrlMap can be successfully loaded. If false, 'loadErrors' indicates the reasons.



85092
85093
85094
85095
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85092

class UrlMapValidationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#test_failures ⇒ ::Array<::Google::Cloud::Compute::V1::TestFailure>



85092
85093
85094
85095
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85092

class UrlMapValidationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#test_passed ⇒ ::Boolean

Returns If successfully loaded, this field indicates whether the test passed. If false, 'testFailures's indicate the reason of failure.

Returns:

  • (::Boolean) —

    If successfully loaded, this field indicates whether the test passed. If false, 'testFailures's indicate the reason of failure.



85092
85093
85094
85095
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85092

class UrlMapValidationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end