Class: Google::Cloud::Compute::V1::UsageExportLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix.

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_name::String

Returns The name of an existing bucket in Cloud Storage where the usage report object is stored. The Google Service Account is granted write access to this bucket. This can either be the bucket name by itself, such asexample-bucket, or the bucket name with gs:// or https://storage.googleapis.com/ in front of it, such as gs://example-bucket.

Returns:

  • (::String)

    The name of an existing bucket in Cloud Storage where the usage report object is stored. The Google Service Account is granted write access to this bucket. This can either be the bucket name by itself, such asexample-bucket, or the bucket name with gs:// or https://storage.googleapis.com/ in front of it, such as gs://example-bucket.



80996
80997
80998
80999
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80996

class UsageExportLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#report_name_prefix::String

Returns An optional prefix for the name of the usage report object stored inbucketName. If not supplied, defaults tousage_gce. The report is stored as a CSV file namedreport_name_prefix_gce_YYYYMMDD.csv whereYYYYMMDD is the day of the usage according to Pacific Time. If you supply a prefix, it should conform to Cloud Storageobject naming conventions.

Returns:

  • (::String)

    An optional prefix for the name of the usage report object stored inbucketName. If not supplied, defaults tousage_gce. The report is stored as a CSV file namedreport_name_prefix_gce_YYYYMMDD.csv whereYYYYMMDD is the day of the usage according to Pacific Time. If you supply a prefix, it should conform to Cloud Storageobject naming conventions.



80996
80997
80998
80999
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80996

class UsageExportLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end