Class: Google::Cloud::Compute::V1::VmEndpointNatMappingsInterfaceNatMappings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contain information of Nat mapping for an interface of this endpoint.

Instance Attribute Summary collapse

Instance Attribute Details

#drain_nat_ip_port_ranges::Array<::String>

Returns Output only. List of all drain IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].

Returns:

  • (::Array<::String>)

    Output only. List of all drain IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].



81078
81079
81080
81081
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81078

class VmEndpointNatMappingsInterfaceNatMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#nat_ip_port_ranges::Array<::String>

Returns Output only. A list of all IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].

Returns:

  • (::Array<::String>)

    Output only. A list of all IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].



81078
81079
81080
81081
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81078

class VmEndpointNatMappingsInterfaceNatMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#num_total_drain_nat_ports::Integer

Returns Output only. Total number of drain ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field drain_nat_ip_port_ranges.

Returns:

  • (::Integer)

    Output only. Total number of drain ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field drain_nat_ip_port_ranges.



81078
81079
81080
81081
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81078

class VmEndpointNatMappingsInterfaceNatMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#num_total_nat_ports::Integer

Returns Output only. Total number of ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field nat_ip_port_ranges.

Returns:

  • (::Integer)

    Output only. Total number of ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field nat_ip_port_ranges.



81078
81079
81080
81081
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81078

class VmEndpointNatMappingsInterfaceNatMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rule_mappings::Array<::Google::Cloud::Compute::V1::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>

Returns Output only. Information about mappings provided by rules in this NAT.

Returns:



81078
81079
81080
81081
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81078

class VmEndpointNatMappingsInterfaceNatMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_alias_ip_range::String

Returns Output only. Alias IP range for this interface endpoint. It will be a private (RFC 1918) IP range. Examples: "10.33.4.55/32", or "192.168.5.0/24".

Returns:

  • (::String)

    Output only. Alias IP range for this interface endpoint. It will be a private (RFC 1918) IP range. Examples: "10.33.4.55/32", or "192.168.5.0/24".



81078
81079
81080
81081
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81078

class VmEndpointNatMappingsInterfaceNatMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_virtual_ip::String

Returns Output only. Primary IP of the VM for this NIC.

Returns:

  • (::String)

    Output only. Primary IP of the VM for this NIC.



81078
81079
81080
81081
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81078

class VmEndpointNatMappingsInterfaceNatMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end