Class: Google::Cloud::Compute::V1::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains information of NAT Mappings provided by a NAT Rule.

Instance Attribute Summary collapse

Instance Attribute Details

#drain_nat_ip_port_ranges::Array<::String>

Returns Output only. List of all drain IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].

Returns:

  • (::Array<::String>)

    Output only. List of all drain IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].



81112
81113
81114
81115
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81112

class VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#nat_ip_port_ranges::Array<::String>

Returns Output only. A list of all IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].

Returns:

  • (::Array<::String>)

    Output only. A list of all IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"].



81112
81113
81114
81115
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81112

class VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#num_total_drain_nat_ports::Integer

Returns Output only. Total number of drain ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field drain_nat_ip_port_ranges.

Returns:

  • (::Integer)

    Output only. Total number of drain ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field drain_nat_ip_port_ranges.



81112
81113
81114
81115
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81112

class VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#num_total_nat_ports::Integer

Returns Output only. Total number of ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field nat_ip_port_ranges.

Returns:

  • (::Integer)

    Output only. Total number of ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field nat_ip_port_ranges.



81112
81113
81114
81115
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81112

class VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rule_number::Integer

Returns Output only. Rule number of the NAT Rule.

Returns:

  • (::Integer)

    Output only. Rule number of the NAT Rule.



81112
81113
81114
81115
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81112

class VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end