Class: Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#vm_extension_policies ⇒ ::Array<::Google::Cloud::Compute::V1::VmExtensionPolicy>
List of VmExtensionPolicy resources contained in this scope.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Informational warning which replaces the list of backend services when the list is empty.
Instance Attribute Details
#vm_extension_policies ⇒ ::Array<::Google::Cloud::Compute::V1::VmExtensionPolicy>
Returns List of VmExtensionPolicy resources contained in this scope.
82883 82884 82885 82886 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82883 class VmExtensionPoliciesScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Informational warning which replaces the list of backend services when the list is empty.
82883 82884 82885 82886 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82883 class VmExtensionPoliciesScopedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |