Module: Google::Cloud::Compute::V1::VmExtensionPolicy::State

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING.

Constant Summary collapse

UNDEFINED_STATE =

A value indicating that the enum field is not set.

0
ACTIVE =

The policy is active and applied to matching VMs. Newly created VMs that match the policy will also receive the extension policy.

314_733_318
DELETING =

The policy is in the process of being deleted. After the extension is removed from all matching VMs, the policy will be deleted.

528_602_024
STATE_UNSPECIFIED =

Default value. Do not use.

470_755_401