Class: Google::Cloud::Compute::V1::VmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Response for the aggregated list of VM extension policies.

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#etag ⇒ ::String

Returns:

  • (::String)


85738
85739
85740
85741
85742
85743
85744
85745
85746
85747
85748
85749
85750
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85738

class VmExtensionPolicyAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id ⇒ ::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String) —

    [Output Only] Unique identifier for the resource; defined by the server.



85738
85739
85740
85741
85742
85743
85744
85745
85746
85747
85748
85749
85750
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85738

class VmExtensionPolicyAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList}

Returns A list of VmExtensionPoliciesScopedList resources.

Returns:



85738
85739
85740
85741
85742
85743
85744
85745
85746
85747
85748
85749
85750
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85738

class VmExtensionPolicyAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies.

Returns:

  • (::String) —

    Output only. [Output Only] Type of resource. Alwayscompute#VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies.



85738
85739
85740
85741
85742
85743
85744
85745
85746
85747
85748
85749
85750
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85738

class VmExtensionPolicyAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token ⇒ ::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String) —

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



85738
85739
85740
85741
85742
85743
85744
85745
85746
85747
85748
85749
85750
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85738

class VmExtensionPolicyAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for this resource.



85738
85739
85740
85741
85742
85743
85744
85745
85746
85747
85748
85749
85750
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85738

class VmExtensionPolicyAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables ⇒ ::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>) —

    Output only. [Output Only] Unreachable resources.



85738
85739
85740
85741
85742
85743
85744
85745
85746
85747
85748
85749
85750
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85738

class VmExtensionPolicyAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



85738
85739
85740
85741
85742
85743
85744
85745
85746
85747
85748
85749
85750
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85738

class VmExtensionPolicyAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::VmExtensionPoliciesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end