Class: Google::Cloud::Compute::V1::VmExtensionPolicyList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Output only. [Output Only] Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy.

To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy.

Returns:

  • (::String)

    Output only. [Output Only] Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy.

    To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy.



81325
81326
81327
81328
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81325

class VmExtensionPolicyList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id::String

Returns Output only. [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    Output only. [Output Only] Unique identifier for the resource; defined by the server.



81325
81326
81327
81328
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81325

class VmExtensionPolicyList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#items::Array<::Google::Cloud::Compute::V1::VmExtensionPolicy>

Returns Output only. [Output Only] A list of VM extension policy resources.

Returns:



81325
81326
81327
81328
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81325

class VmExtensionPolicyList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::String

Returns Output only. Type of resource.

Returns:

  • (::String)

    Output only. Type of resource.



81325
81326
81327
81328
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81325

class VmExtensionPolicyList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



81325
81326
81327
81328
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81325

class VmExtensionPolicyList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource.



81325
81326
81327
81328
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81325

class VmExtensionPolicyList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachables::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Unreachable resources.



81325
81326
81327
81328
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81325

class VmExtensionPolicyList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warning::Google::Cloud::Compute::V1::Warning

Returns Output only. [Output Only] Informational warning message.

Returns:



81325
81326
81327
81328
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81325

class VmExtensionPolicyList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end