Class: Google::Cloud::Compute::V1::VpnGateway
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::VpnGateway
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a HA VPN gateway.
HA VPN is a high-availability (HA) Cloud VPN solution that lets you securely connect your on-premises network to your Google Cloud Virtual Private Cloud network through an IPsec VPN connection in a single region. For more information about Cloud HA VPN solutions, see Cloud VPN topologies .
Defined Under Namespace
Modules: GatewayIpVersion, StackType Classes: LabelsEntry
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#gateway_ip_version ⇒ ::String
The IP family of the gateway IPs for the HA-VPN gateway interfaces.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#label_fingerprint ⇒ ::String
A fingerprint for the labels being applied to this VpnGateway, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels for this resource.
-
#name ⇒ ::String
Name of the resource.
-
#network ⇒ ::String
URL of the network to which this VPN gateway is attached.
-
#params ⇒ ::Google::Cloud::Compute::V1::VpnGatewayParams
Input only.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#stack_type ⇒ ::String
The stack type for this VPN gateway to identify the IP protocols that are enabled.
-
#vpn_interfaces ⇒ ::Array<::Google::Cloud::Compute::V1::VpnGatewayVpnGatewayInterface>
The list of VPN interfaces associated with this VPN gateway.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#gateway_ip_version ⇒ ::String
Returns The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not specified, IPV4 will be used. Check the GatewayIpVersion enum for the list of possible values.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#label_fingerprint ⇒ ::String
Returns A fingerprint for the labels being applied to this VpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to retrieve a VpnGateway.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#network ⇒ ::String
Returns URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#params ⇒ ::Google::Cloud::Compute::V1::VpnGatewayParams
Returns Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the VPN gateway resides.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#stack_type ⇒ ::String
Returns The stack type for this VPN gateway to identify the IP protocols that are enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. Check the StackType enum for the list of possible values.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |
#vpn_interfaces ⇒ ::Array<::Google::Cloud::Compute::V1::VpnGatewayVpnGatewayInterface>
Returns The list of VPN interfaces associated with this VPN gateway.
84126 84127 84128 84129 84130 84131 84132 84133 84134 84135 84136 84137 84138 84139 84140 84141 84142 84143 84144 84145 84146 84147 84148 84149 84150 84151 84152 84153 84154 84155 84156 84157 84158 84159 84160 84161 84162 84163 84164 84165 84166 84167 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84126 class VpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not # specified, IPV4 will be used. module GatewayIpVersion # A value indicating that the enum field is not set. UNDEFINED_GATEWAY_IP_VERSION = 0 # Every HA-VPN gateway interface is configured with an IPv4 address. IPV4 = 2_254_341 # Every HA-VPN gateway interface is configured with an IPv6 address. IPV6 = 2_254_343 end # The stack type for this VPN gateway to identify the IP protocols that are # enabled. Possible values are: IPV4_ONLY,IPV4_IPV6, IPV6_ONLY. If not specified,IPV4_ONLY is used if the gateway IP version isIPV4, or IPV4_IPV6 if the gateway IP version isIPV6. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # Enable VPN gateway with both IPv4 and IPv6 protocols. IPV4_IPV6 = 22_197_249 # Enable VPN gateway with only IPv4 protocol. IPV4_ONLY = 22_373_798 # Enable VPN gateway with only IPv6 protocol. IPV6_ONLY = 79_632_100 end end |