Class: Google::Cloud::Compute::V1::VpnGatewayStatusHighAvailabilityRequirementState

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.

Defined Under Namespace

Modules: State, UnsatisfiedReason

Instance Attribute Summary collapse

Instance Attribute Details

#state ⇒ ::String

Returns Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Check the State enum for the list of possible values.

Returns:

  • (::String) —

    Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Check the State enum for the list of possible values.



86078
86079
86080
86081
86082
86083
86084
86085
86086
86087
86088
86089
86090
86091
86092
86093
86094
86095
86096
86097
86098
86099
86100
86101
86102
86103
86104
86105
86106
86107
86108
86109
86110
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 86078

class VpnGatewayStatusHighAvailabilityRequirementState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the high availability requirement state for the VPN connection.
  # Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # VPN tunnels are configured with adequate redundancy from Cloud VPN
    # gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP
    # connections, the adequate redundancy is a pre-requirement for users to
    # get 99.99% availability on GCP side; please note that for any
    # connection, end-to-end 99.99% availability is subject to proper
    # configuration on the peer VPN gateway.
    CONNECTION_REDUNDANCY_MET = 505_242_907

    # VPN tunnels are not configured with adequate redundancy from the Cloud
    # VPN gateway to the peer gateway
    CONNECTION_REDUNDANCY_NOT_MET = 511_863_311
  end

  # Indicates the reason why the VPN connection does not meet the high
  # availability redundancy criteria/requirement.
  # Valid values is INCOMPLETE_TUNNELS_COVERAGE.
  module UnsatisfiedReason
    # A value indicating that the enum field is not set.
    UNDEFINED_UNSATISFIED_REASON = 0

    INCOMPLETE_TUNNELS_COVERAGE = 55_917_437
  end
end

#unsatisfied_reason ⇒ ::String

Returns Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE. Check the UnsatisfiedReason enum for the list of possible values.

Returns:

  • (::String) —

    Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE. Check the UnsatisfiedReason enum for the list of possible values.



86078
86079
86080
86081
86082
86083
86084
86085
86086
86087
86088
86089
86090
86091
86092
86093
86094
86095
86096
86097
86098
86099
86100
86101
86102
86103
86104
86105
86106
86107
86108
86109
86110
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 86078

class VpnGatewayStatusHighAvailabilityRequirementState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the high availability requirement state for the VPN connection.
  # Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # VPN tunnels are configured with adequate redundancy from Cloud VPN
    # gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP
    # connections, the adequate redundancy is a pre-requirement for users to
    # get 99.99% availability on GCP side; please note that for any
    # connection, end-to-end 99.99% availability is subject to proper
    # configuration on the peer VPN gateway.
    CONNECTION_REDUNDANCY_MET = 505_242_907

    # VPN tunnels are not configured with adequate redundancy from the Cloud
    # VPN gateway to the peer gateway
    CONNECTION_REDUNDANCY_NOT_MET = 511_863_311
  end

  # Indicates the reason why the VPN connection does not meet the high
  # availability redundancy criteria/requirement.
  # Valid values is INCOMPLETE_TUNNELS_COVERAGE.
  module UnsatisfiedReason
    # A value indicating that the enum field is not set.
    UNDEFINED_UNSATISFIED_REASON = 0

    INCOMPLETE_TUNNELS_COVERAGE = 55_917_437
  end
end