Class: Google::Cloud::Compute::V1::VpnGatewayStatusTunnel

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains some information about a VPN tunnel.

Instance Attribute Summary collapse

Instance Attribute Details

#local_gateway_interface ⇒ ::Integer

Returns Output only. The VPN gateway interface this VPN tunnel is associated with.

Returns:

  • (::Integer) —

    Output only. The VPN gateway interface this VPN tunnel is associated with.



86124
86125
86126
86127
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 86124

class VpnGatewayStatusTunnel
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#peer_gateway_interface ⇒ ::Integer

Returns Output only. The peer gateway interface this VPN tunnel is connected to, the peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.

Returns:

  • (::Integer) —

    Output only. The peer gateway interface this VPN tunnel is connected to, the peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.



86124
86125
86126
86127
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 86124

class VpnGatewayStatusTunnel
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tunnel_url ⇒ ::String

Returns Output only. URL reference to the VPN tunnel.

Returns:

  • (::String) —

    Output only. URL reference to the VPN tunnel.



86124
86125
86126
86127
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 86124

class VpnGatewayStatusTunnel
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end