Class: Google::Cloud::Compute::V1::VpnGatewayVpnGatewayInterface
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::VpnGatewayVpnGatewayInterface
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A VPN gateway interface.
Instance Attribute Summary collapse
-
#id ⇒ ::Integer
Output only.
-
#interconnect_attachment ⇒ ::String
URL of the VLAN attachment (interconnectAttachment) resource for this VPN gateway interface.
-
#ip_address ⇒ ::String
Output only.
-
#ipv6_address ⇒ ::String
Output only.
Instance Attribute Details
#id ⇒ ::Integer
Returns Output only. [Output Only] Numeric identifier for this VPN interface associated with the VPN gateway.
81673 81674 81675 81676 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81673 class VpnGatewayVpnGatewayInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#interconnect_attachment ⇒ ::String
Returns URL of the VLAN attachment (interconnectAttachment) resource for this VPN gateway interface. When the value of this field is present, the VPN gateway is used for HA VPN over Cloud Interconnect; all egress or ingress traffic for this VPN gateway interface goes through the specified VLAN attachment resource.
81673 81674 81675 81676 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81673 class VpnGatewayVpnGatewayInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ip_address ⇒ ::String
Returns Output only. [Output Only] IP address for this VPN interface associated with the VPN gateway. The IP address could be either a regional external IP address or a regional internal IP address. The two IP addresses for a VPN gateway must be all regional external or regional internal IP addresses. There cannot be a mix of regional external IP addresses and regional internal IP addresses. For HA VPN over Cloud Interconnect, the IP addresses for both interfaces could either be regional internal IP addresses or regional external IP addresses. For regular (non HA VPN over Cloud Interconnect) HA VPN tunnels, the IP address must be a regional external IP address.
81673 81674 81675 81676 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81673 class VpnGatewayVpnGatewayInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ipv6_address ⇒ ::String
Returns Output only. [Output Only] IPv6 address for this VPN interface associated with the VPN gateway. The IPv6 address must be a regional external IPv6 address. The format is RFC 5952 format (e.g. 2001:db8::2d9:51:0:0).
81673 81674 81675 81676 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81673 class VpnGatewayVpnGatewayInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |