Module: Google::Cloud::Compute::V1::VpnTunnel::Status

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] The status of the VPN tunnel, which can be one of the following:

- PROVISIONING: Resource is being allocated for the VPN tunnel.
- WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs
from
 the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route
 resources are needed to setup the VPN tunnel.
- FIRST_HANDSHAKE: Successful first handshake with the peer VPN.
- ESTABLISHED: Secure session is successfully established with the peer
VPN.
- NETWORK_ERROR: Deprecated, replaced by
NO_INCOMING_PACKETS
- AUTHORIZATION_ERROR: Auth error (for example,
bad shared secret).
- NEGOTIATION_FAILURE: Handshake failed.
- DEPROVISIONING: Resources are being deallocated for the VPN
tunnel.
- FAILED: Tunnel creation has failed and the tunnel is not
ready to be used.
- NO_INCOMING_PACKETS: No incoming packets from
peer.
- REJECTED: Tunnel configuration was rejected, can be result
of being denied access.
- ALLOCATING_RESOURCES: Cloud VPN is in the
process of allocating all required resources.
- STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted
for Classic VPN tunnels or the project is in frozen state.
- PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP,
probably behind NAT.
- TS_NARROWING_NOT_ALLOWED: Traffic selector
narrowing not allowed for an HA-VPN tunnel.

Constant Summary collapse

UNDEFINED_STATUS =

A value indicating that the enum field is not set.

0
ALLOCATING_RESOURCES =

Cloud VPN is in the process of allocating all required resources (specifically, a borg task).

320_922_816
AUTHORIZATION_ERROR =

Auth error (e.g. bad shared secret).

23_580_290
DEPROVISIONING =

Resources is being deallocated for the VPN tunnel.

428_935_662
ESTABLISHED =

Secure session is successfully established with peer VPN.

88_852_344
FAILED =

Tunnel creation has failed and the tunnel is not ready to be used.

455_706_685
FIRST_HANDSHAKE =

Successful first handshake with peer VPN.

191_393_000
NEGOTIATION_FAILURE =

Handshake failed.

360_325_868
NETWORK_ERROR =

Deprecated, replaced by NO_INCOMING_PACKETS

193_912_951
NO_INCOMING_PACKETS =

No incoming packets from peer

119_983_216
PROVISIONING =

Resource is being allocated for the VPN tunnel.

290_896_621
REJECTED =

Tunnel configuration was rejected, can be result of being denylisted.

174_130_302
STOPPED =

Tunnel is stopped due to its Forwarding Rules being deleted.

444_276_141
WAITING_FOR_FULL_CONFIG =

Waiting to receive all VPN-related configs from user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule and Route resources are needed to setup VPN tunnel.

41_640_522