Class: Google::Cloud::Compute::V1::WafExpressionSetExpression
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::WafExpressionSetExpression
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#id ⇒ ::String
Expression ID should uniquely identify the origin of the expression.
Instance Attribute Details
#id ⇒ ::String
Returns Expression ID should uniquely identify the origin of the expression. E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set version 2.9.1 rule id 973337. The ID could be used to determine the individual attack definition that has been detected. It could also be used to exclude it from the policy in case of false positive. required.
31123 31124 31125 31126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31123 class WafExpressionSetExpression include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |