Class: Google::Cloud::Compute::V1::Wire

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A pseudowire that connects two Interconnect connections.

Instance Attribute Summary collapse

Instance Attribute Details

#admin_enabled::Boolean

Returns Output only. [Output Only] Indicates whether the wire is enabled. When false, the wire is disabled. When true and when the wire group of the wire is also enabled, the wire is enabled. Defaults to true.

Returns:

  • (::Boolean)

    Output only. [Output Only] Indicates whether the wire is enabled. When false, the wire is disabled. When true and when the wire group of the wire is also enabled, the wire is enabled. Defaults to true.



82524
82525
82526
82527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82524

class Wire
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#endpoints::Array<::Google::Cloud::Compute::V1::WireEndpoint>

Returns Output only. Wire endpoints are specific Interconnect connections.

Returns:



82524
82525
82526
82527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82524

class Wire
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#label::String

Returns Output only. [Output Only] A label that identifies the wire. The format of this label combines the existing labels of the wire group endpoints and Interconnect connections used by this wire in alphabetical order as follows: ENDPOINT_A+CONNECTION_A1,ENDPOINT_B+CONNECTION_B1, where:

  • ENDPOINT_A and ENDPOINT_B: are the labels that you entered as map keys when you specified the wire group endpoint objects.
  • CONNECTION_A1 and CONNECTION_B1: are the labels that you entered as map keys when you specified the wire group Interconnect objects.

Returns:

  • (::String)

    Output only. [Output Only] A label that identifies the wire. The format of this label combines the existing labels of the wire group endpoints and Interconnect connections used by this wire in alphabetical order as follows: ENDPOINT_A+CONNECTION_A1,ENDPOINT_B+CONNECTION_B1, where:

    • ENDPOINT_A and ENDPOINT_B: are the labels that you entered as map keys when you specified the wire group endpoint objects.
    • CONNECTION_A1 and CONNECTION_B1: are the labels that you entered as map keys when you specified the wire group Interconnect objects.


82524
82525
82526
82527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82524

class Wire
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#wire_properties::Google::Cloud::Compute::V1::WireProperties

Returns Output only. [Output Only] Properties of the wire.

Returns:



82524
82525
82526
82527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82524

class Wire
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end