Class: Google::Cloud::Compute::V1::WireGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A resource that represents a group of redundant wires.

Defined Under Namespace

Classes: EndpointsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#admin_enabled::Boolean

Returns Indicates whether the wires in the wire group are enabled. When false, the wires in the wire group are disabled. When true and when there is simultaneously no wire-specific override of adminEnabled to false, a given wire is enabled. Defaults to true.

Returns:

  • (::Boolean)

    Indicates whether the wires in the wire group are enabled. When false, the wires in the wire group are disabled. When true and when there is simultaneously no wire-specific override of adminEnabled to false, a given wire is enabled. Defaults to true.



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns An optional description of the wire group.

Returns:

  • (::String)

    An optional description of the wire group.



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#endpoints::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::WireGroupEndpoint}

Returns A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:

  • Key: an RFC1035 user-specified label.
  • Value: an Endpoint object.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::WireGroupEndpoint})

    A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:

    • Key: an RFC1035 user-specified label.
    • Value: an Endpoint object.


84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups.



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#reconciling::Boolean

Returns Output only. [Output Only] Indicates whether there are wire changes yet to be processed.

Returns:

  • (::Boolean)

    Output only. [Output Only] Indicates whether there are wire changes yet to be processed.



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for the resource.



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#topology::Google::Cloud::Compute::V1::WireGroupTopology

Returns Output only. Topology details for the wire group configuration.

Returns:



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#wire_properties::Google::Cloud::Compute::V1::WireProperties

Returns Properties for all wires in the wire group.

Returns:



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#wires::Array<::Google::Cloud::Compute::V1::Wire>

Returns Output only. The single/redundant wire(s) managed by the wire group.

Returns:



84375
84376
84377
84378
84379
84380
84381
84382
84383
84384
84385
84386
84387
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84375

class WireGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpoint]
  class EndpointsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end