Class: Google::Cloud::Compute::V1::WireGroupEndpoint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A logical endpoint for the wire group. An endpoint represents a metro that contains redundant Interconnect connections. A wire group is created between two endpoints.

Defined Under Namespace

Classes: InterconnectsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#interconnects ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::WireGroupEndpointInterconnect}

Returns A map that contains the redundant Interconnect connections. Specify key-value pairs for the map as follows:

- Key: an RFC1035 user-specified label.
- Value: an Interconnect object.

Returns:



87126
87127
87128
87129
87130
87131
87132
87133
87134
87135
87136
87137
87138
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87126

class WireGroupEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::WireGroupEndpointInterconnect]
  class InterconnectsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end