Class: Google::Cloud::Compute::V1::WireGroupEndpointInterconnect

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The redundant Interconnect connections for this endpoint.

Instance Attribute Summary collapse

Instance Attribute Details

#interconnect ⇒ ::String

Returns Required. An Interconnect connection. You can specify the connection as a partial or full URL. If the connection is in a different project from the cross-site network, use a format that specifies the project. See the following examples of partial and full URLs:

  global/interconnects/NAME

   projects/PROJECT_ID/global/interconnects/NAME

-
  https://compute.googleapis.com/compute/projects/PROJECT_ID/global/interconnects/NAME.

Returns:

  • (::String) —

    Required. An Interconnect connection. You can specify the connection as a partial or full URL. If the connection is in a different project from the cross-site network, use a format that specifies the project. See the following examples of partial and full URLs:

      global/interconnects/NAME
    
       projects/PROJECT_ID/global/interconnects/NAME
    
    -
      https://compute.googleapis.com/compute/projects/PROJECT_ID/global/interconnects/NAME


87174
87175
87176
87177
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87174

class WireGroupEndpointInterconnect
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#vlan_tags ⇒ ::Array<::Integer>

Returns Required. To configure the wire group for VLAN mode, enter a VLAN tag, which is a number from 2 to 4093. You can autoallocate a tag by entering 0. To configure the wire group for port mode, enter -1. Review the following guidelines:

- A VLAN tag must be unique for an Interconnect connection across all
attachments and wire groups.
- Both endpoints of a wire must use the same VLAN tag value.
- Single wire and redundant type wire groups must have only one
VLAN tag.
- Port mode pseudowires must have a single VLAN tag with a value of
`-1` for both endpoints.
- Box and cross type wire groups must have two VLAN tags. The first
is for the same-zone pseudowire, and the second is for the cross-zone
pseudowire.

Returns:

  • (::Array<::Integer>) —

    Required. To configure the wire group for VLAN mode, enter a VLAN tag, which is a number from 2 to 4093. You can autoallocate a tag by entering 0. To configure the wire group for port mode, enter -1. Review the following guidelines:

    - A VLAN tag must be unique for an Interconnect connection across all
    attachments and wire groups.
    - Both endpoints of a wire must use the same VLAN tag value.
    - Single wire and redundant type wire groups must have only one
    VLAN tag.
    - Port mode pseudowires must have a single VLAN tag with a value of
    `-1` for both endpoints.
    - Box and cross type wire groups must have two VLAN tags. The first
    is for the same-zone pseudowire, and the second is for the cross-zone
    pseudowire.


87174
87175
87176
87177
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87174

class WireGroupEndpointInterconnect
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end