Class: Google::Cloud::Compute::V1::WireProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The properties of a wire.

Defined Under Namespace

Modules: BandwidthAllocation, FaultResponse

Instance Attribute Summary collapse

Instance Attribute Details

#bandwidth_allocation ⇒ ::String

Returns The configuration of the bandwidth allocation, one of the following:

- ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation
(and associated charges) for each wire in the group.
- SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures
one unmetered bandwidth allocation for the wire group. The unmetered
bandwidth is divided equally across each wire in the group, but dynamic
throttling reallocates unused unmetered bandwidth from unused or underused
wires to other wires in the group.

Check the BandwidthAllocation enum for the list of possible values.

Returns:

  • (::String) —

    The configuration of the bandwidth allocation, one of the following:

    - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation
    (and associated charges) for each wire in the group.
    - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures
    one unmetered bandwidth allocation for the wire group. The unmetered
    bandwidth is divided equally across each wire in the group, but dynamic
    throttling reallocates unused unmetered bandwidth from unused or underused
    wires to other wires in the group.
    

    Check the BandwidthAllocation enum for the list of possible values.



87261
87262
87263
87264
87265
87266
87267
87268
87269
87270
87271
87272
87273
87274
87275
87276
87277
87278
87279
87280
87281
87282
87283
87284
87285
87286
87287
87288
87289
87290
87291
87292
87293
87294
87295
87296
87297
87298
87299
87300
87301
87302
87303
87304
87305
87306
87307
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87261

class WireProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of the bandwidth allocation, one of the following:
  #
  #    - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation
  #    (and associated charges) for each wire in the group.
  #    - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures
  #    one unmetered bandwidth allocation for the wire group. The unmetered
  #    bandwidth is divided equally across each wire in the group, but dynamic
  #    throttling reallocates unused unmetered bandwidth from unused or underused
  #    wires to other wires in the group.
  module BandwidthAllocation
    # A value indicating that the enum field is not set.
    UNDEFINED_BANDWIDTH_ALLOCATION = 0

    # Configures a separate unmetered bandwidth allocation (and associated
    # charges) for each wire in the group.
    ALLOCATE_PER_WIRE = 358_730_057

    # This is the default behavior. Configures one unmetered bandwidth
    # allocation for the wire group. The unmetered bandwidth is divided equally
    # across each wire in the group, but dynamic throttling reallocates unused
    # unmetered bandwidth from unused or underused wires to other wires in the
    # group.
    SHARED_WITH_WIRE_GROUP = 286_454_628
  end

  # Response when a fault is detected in a pseudowire:
  #
  #    - NONE: default.
  #    - DISABLE_PORT: set the port line protocol down when inline probes
  #    detect a fault. This setting is only permitted on port mode
  #    pseudowires.
  module FaultResponse
    # A value indicating that the enum field is not set.
    UNDEFINED_FAULT_RESPONSE = 0

    # Set the port line protocol down when inline probes detect a fault. This
    # setting is only permitted on port mode pseudowires.
    DISABLE_PORT = 287_086_488

    # Default.
    NONE = 2_402_104
  end
end

#bandwidth_unmetered ⇒ ::Integer

Returns The unmetered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0.

Returns:

  • (::Integer) —

    The unmetered bandwidth in Gigabits per second, using decimal units. 10 is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0.



87261
87262
87263
87264
87265
87266
87267
87268
87269
87270
87271
87272
87273
87274
87275
87276
87277
87278
87279
87280
87281
87282
87283
87284
87285
87286
87287
87288
87289
87290
87291
87292
87293
87294
87295
87296
87297
87298
87299
87300
87301
87302
87303
87304
87305
87306
87307
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87261

class WireProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of the bandwidth allocation, one of the following:
  #
  #    - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation
  #    (and associated charges) for each wire in the group.
  #    - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures
  #    one unmetered bandwidth allocation for the wire group. The unmetered
  #    bandwidth is divided equally across each wire in the group, but dynamic
  #    throttling reallocates unused unmetered bandwidth from unused or underused
  #    wires to other wires in the group.
  module BandwidthAllocation
    # A value indicating that the enum field is not set.
    UNDEFINED_BANDWIDTH_ALLOCATION = 0

    # Configures a separate unmetered bandwidth allocation (and associated
    # charges) for each wire in the group.
    ALLOCATE_PER_WIRE = 358_730_057

    # This is the default behavior. Configures one unmetered bandwidth
    # allocation for the wire group. The unmetered bandwidth is divided equally
    # across each wire in the group, but dynamic throttling reallocates unused
    # unmetered bandwidth from unused or underused wires to other wires in the
    # group.
    SHARED_WITH_WIRE_GROUP = 286_454_628
  end

  # Response when a fault is detected in a pseudowire:
  #
  #    - NONE: default.
  #    - DISABLE_PORT: set the port line protocol down when inline probes
  #    detect a fault. This setting is only permitted on port mode
  #    pseudowires.
  module FaultResponse
    # A value indicating that the enum field is not set.
    UNDEFINED_FAULT_RESPONSE = 0

    # Set the port line protocol down when inline probes detect a fault. This
    # setting is only permitted on port mode pseudowires.
    DISABLE_PORT = 287_086_488

    # Default.
    NONE = 2_402_104
  end
end

#fault_response ⇒ ::String

Returns Response when a fault is detected in a pseudowire:

- NONE: default.
- DISABLE_PORT: set the port line protocol down when inline probes
detect a fault. This setting is only permitted on port mode
pseudowires.

Check the FaultResponse enum for the list of possible values.

Returns:

  • (::String) —

    Response when a fault is detected in a pseudowire:

    - NONE: default.
    - DISABLE_PORT: set the port line protocol down when inline probes
    detect a fault. This setting is only permitted on port mode
    pseudowires.
    

    Check the FaultResponse enum for the list of possible values.



87261
87262
87263
87264
87265
87266
87267
87268
87269
87270
87271
87272
87273
87274
87275
87276
87277
87278
87279
87280
87281
87282
87283
87284
87285
87286
87287
87288
87289
87290
87291
87292
87293
87294
87295
87296
87297
87298
87299
87300
87301
87302
87303
87304
87305
87306
87307
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87261

class WireProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration of the bandwidth allocation, one of the following:
  #
  #    - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation
  #    (and associated charges) for each wire in the group.
  #    - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures
  #    one unmetered bandwidth allocation for the wire group. The unmetered
  #    bandwidth is divided equally across each wire in the group, but dynamic
  #    throttling reallocates unused unmetered bandwidth from unused or underused
  #    wires to other wires in the group.
  module BandwidthAllocation
    # A value indicating that the enum field is not set.
    UNDEFINED_BANDWIDTH_ALLOCATION = 0

    # Configures a separate unmetered bandwidth allocation (and associated
    # charges) for each wire in the group.
    ALLOCATE_PER_WIRE = 358_730_057

    # This is the default behavior. Configures one unmetered bandwidth
    # allocation for the wire group. The unmetered bandwidth is divided equally
    # across each wire in the group, but dynamic throttling reallocates unused
    # unmetered bandwidth from unused or underused wires to other wires in the
    # group.
    SHARED_WITH_WIRE_GROUP = 286_454_628
  end

  # Response when a fault is detected in a pseudowire:
  #
  #    - NONE: default.
  #    - DISABLE_PORT: set the port line protocol down when inline probes
  #    detect a fault. This setting is only permitted on port mode
  #    pseudowires.
  module FaultResponse
    # A value indicating that the enum field is not set.
    UNDEFINED_FAULT_RESPONSE = 0

    # Set the port line protocol down when inline probes detect a fault. This
    # setting is only permitted on port mode pseudowires.
    DISABLE_PORT = 287_086_488

    # Default.
    NONE = 2_402_104
  end
end