Module: Google::Cloud::Compute::V1::WireProperties::FaultResponse

Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Response when a fault is detected in a pseudowire:

  • NONE: default.
  • DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires.

Constant Summary collapse

UNDEFINED_FAULT_RESPONSE =

A value indicating that the enum field is not set.

0
DISABLE_PORT =

Set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires.

287_086_488
NONE =

Default.

2_402_104