Class: Google::Cloud::Compute::V1::Zone

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Zone resource. A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-b is located in the us-east1 region. For more information, read Regions and Zones.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#available_cpu_platforms::Array<::String>



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#creation_timestamp::String



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#deprecated::Google::Cloud::Compute::V1::DeprecationStatus



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#description::String



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#id::Integer



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#kind::String



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#name::String



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#region::String



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end


41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#status::String



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#supports_pzs::Boolean



41430
41431
41432
41433
41434
41435
41436
41437
41438
41439
41440
41441
41442
41443
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 41430

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP or DOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end