Module: Google::Cloud::Compute::V1::AcceleratorTopologiesInfoAcceleratorTopologyInfoInfoPerTopologyState::State
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The state of the accelerator topology.
Constant Summary collapse
- UNDEFINED_STATE =
A value indicating that the enum field is not set.
0- AVAILABLE =
The accelerator topology is available.
442_079_913- DEGRADED =
The accelerator topology is degraded. The underlying capacity is not in a healthy state and is not available.
396_890_926- RUNNING =
The accelerator topology is running. If there are both running and degraded hosts within a topology, DEGRADED state will be returned.
121_282_975- TOPOLOGY_STATE_UNSPECIFIED =
The state of the topology is unspecified.
188_327_545- UNHEALTHY =
This value has been deprecated and is no longer used.
462_118_084