Class: Google::Cloud::Compute::V1::AddAssociationOrganizationSecurityPolicyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for OrganizationSecurityPolicies.AddAssociation. See the method description for details.

Instance Attribute Summary collapse

Instance Attribute Details

#replace_existing_association::Boolean

Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.

Returns:

  • (::Boolean)

    Indicates whether or not to replace it if an association of the attachment already exists. This is false by default, in which case an error will be returned if an association already exists.



567
568
569
570
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 567

class AddAssociationOrganizationSecurityPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



567
568
569
570
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 567

class AddAssociationOrganizationSecurityPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#security_policy::String

Returns Name of the security policy to update.

Returns:

  • (::String)

    Name of the security policy to update.



567
568
569
570
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 567

class AddAssociationOrganizationSecurityPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#security_policy_association_resource::Google::Cloud::Compute::V1::SecurityPolicyAssociation

Returns The body resource for this request.

Returns:



567
568
569
570
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 567

class AddAssociationOrganizationSecurityPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end