Class: Google::Cloud::Compute::V1::AdvanceRolloutRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AdvanceRolloutRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for Rollouts.Advance. See the method description for details.
Instance Attribute Summary collapse
-
#current_wave_number ⇒ ::Integer
Required.
-
#project ⇒ ::String
Required.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#rollout ⇒ ::String
Required.
Instance Attribute Details
#current_wave_number ⇒ ::Integer
Returns Required. Wave number of the current wave.
1613 1614 1615 1616 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1613 class AdvanceRolloutRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Required. Project ID for this request.
1613 1614 1615 1616 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1613 class AdvanceRolloutRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
1613 1614 1615 1616 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1613 class AdvanceRolloutRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rollout ⇒ ::String
Returns Required. Name of the Rollout resource to advance.
1613 1614 1615 1616 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1613 class AdvanceRolloutRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |