Class: Google::Cloud::Compute::V1::AdvancedMachineFeatures
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AdvancedMachineFeatures
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled).
Defined Under Namespace
Modules: PerformanceMonitoringUnit
Instance Attribute Summary collapse
-
#enable_nested_virtualization ⇒ ::Boolean
Whether to enable nested virtualization or not (default is false).
-
#enable_uefi_networking ⇒ ::Boolean
Whether to enable UEFI networking for instance creation.
-
#performance_monitoring_unit ⇒ ::String
Type of Performance Monitoring Unit requested on instance.
-
#threads_per_core ⇒ ::Integer
The number of threads per physical core.
-
#turbo_mode ⇒ ::String
Turbo frequency mode to use for the instance.
-
#visible_core_count ⇒ ::Integer
The number of physical cores to expose to an instance.
Instance Attribute Details
#enable_nested_virtualization ⇒ ::Boolean
Returns Whether to enable nested virtualization or not (default is false).
1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1675 class AdvancedMachineFeatures include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of Performance Monitoring Unit requested on instance. module PerformanceMonitoringUnit # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_MONITORING_UNIT = 0 # Architecturally defined non-LLC events. ARCHITECTURAL = 155_113_693 # Most documented core/L2 and LLC events. ENHANCED = 476_873_590 PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 429_210_692 # Most documented core/L2 events. STANDARD = 484_642_493 end end |
#enable_uefi_networking ⇒ ::Boolean
Returns Whether to enable UEFI networking for instance creation.
1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1675 class AdvancedMachineFeatures include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of Performance Monitoring Unit requested on instance. module PerformanceMonitoringUnit # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_MONITORING_UNIT = 0 # Architecturally defined non-LLC events. ARCHITECTURAL = 155_113_693 # Most documented core/L2 and LLC events. ENHANCED = 476_873_590 PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 429_210_692 # Most documented core/L2 events. STANDARD = 484_642_493 end end |
#performance_monitoring_unit ⇒ ::String
Returns Type of Performance Monitoring Unit requested on instance. Check the PerformanceMonitoringUnit enum for the list of possible values.
1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1675 class AdvancedMachineFeatures include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of Performance Monitoring Unit requested on instance. module PerformanceMonitoringUnit # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_MONITORING_UNIT = 0 # Architecturally defined non-LLC events. ARCHITECTURAL = 155_113_693 # Most documented core/L2 and LLC events. ENHANCED = 476_873_590 PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 429_210_692 # Most documented core/L2 events. STANDARD = 484_642_493 end end |
#threads_per_core ⇒ ::Integer
Returns The number of threads per physical core. To disable simultaneous multithreading (SMT) set this to 1. If unset, the maximum number of threads supported per core by the underlying processor is assumed.
1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1675 class AdvancedMachineFeatures include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of Performance Monitoring Unit requested on instance. module PerformanceMonitoringUnit # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_MONITORING_UNIT = 0 # Architecturally defined non-LLC events. ARCHITECTURAL = 155_113_693 # Most documented core/L2 and LLC events. ENHANCED = 476_873_590 PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 429_210_692 # Most documented core/L2 events. STANDARD = 484_642_493 end end |
#turbo_mode ⇒ ::String
Returns Turbo frequency mode to use for the instance. Supported modes include:
- ALL_CORE_MAX
Using empty string or not setting this field will use the platform-specific default turbo mode.
1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1675 class AdvancedMachineFeatures include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of Performance Monitoring Unit requested on instance. module PerformanceMonitoringUnit # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_MONITORING_UNIT = 0 # Architecturally defined non-LLC events. ARCHITECTURAL = 155_113_693 # Most documented core/L2 and LLC events. ENHANCED = 476_873_590 PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 429_210_692 # Most documented core/L2 events. STANDARD = 484_642_493 end end |
#visible_core_count ⇒ ::Integer
Returns The number of physical cores to expose to an instance. Multiply by the number of threads per core to compute the total number of virtual CPUs to expose to the instance. If unset, the number of cores is inferred from the instance's nominal CPU count and the underlying platform's SMT width.
1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 1675 class AdvancedMachineFeatures include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of Performance Monitoring Unit requested on instance. module PerformanceMonitoringUnit # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_MONITORING_UNIT = 0 # Architecturally defined non-LLC events. ARCHITECTURAL = 155_113_693 # Most documented core/L2 and LLC events. ENHANCED = 476_873_590 PERFORMANCE_MONITORING_UNIT_UNSPECIFIED = 429_210_692 # Most documented core/L2 events. STANDARD = 484_642_493 end end |