Class: Google::Cloud::Compute::V1::AllocationAggregateReservation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AllocationAggregateReservation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation.
Defined Under Namespace
Modules: VmFamily, WorkloadType
Instance Attribute Summary collapse
-
#in_use_resources ⇒ ::Array<::Google::Cloud::Compute::V1::AllocationAggregateReservationReservedResourceInfo>
Output only.
-
#reserved_resources ⇒ ::Array<::Google::Cloud::Compute::V1::AllocationAggregateReservationReservedResourceInfo>
List of reserved resources (CPUs, memory, accelerators).
-
#vm_family ⇒ ::String
The VM family that all instances scheduled against this reservation must belong to.
-
#workload_type ⇒ ::String
The workload type of the instances that will target this reservation.
Instance Attribute Details
#in_use_resources ⇒ ::Array<::Google::Cloud::Compute::V1::AllocationAggregateReservationReservedResourceInfo>
Returns Output only. [Output only] List of resources currently in use.
7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7670 class AllocationAggregateReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation must # belong to. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # The workload type of the instances that will target this reservation. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |
#reserved_resources ⇒ ::Array<::Google::Cloud::Compute::V1::AllocationAggregateReservationReservedResourceInfo>
Returns List of reserved resources (CPUs, memory, accelerators).
7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7670 class AllocationAggregateReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation must # belong to. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # The workload type of the instances that will target this reservation. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |
#vm_family ⇒ ::String
Returns The VM family that all instances scheduled against this reservation must belong to. Check the VmFamily enum for the list of possible values.
7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7670 class AllocationAggregateReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation must # belong to. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # The workload type of the instances that will target this reservation. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |
#workload_type ⇒ ::String
Returns The workload type of the instances that will target this reservation. Check the WorkloadType enum for the list of possible values.
7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 7689 7690 7691 7692 7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7670 class AllocationAggregateReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation must # belong to. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # The workload type of the instances that will target this reservation. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |