Class: Google::Cloud::Compute::V1::AllocationReservationSharingPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AllocationReservationSharingPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: ServiceShareType
Instance Attribute Summary collapse
-
#service_share_type ⇒ ::String
Sharing config for all Google Cloud services.
Instance Attribute Details
#service_share_type ⇒ ::String
Returns Sharing config for all Google Cloud services. Check the ServiceShareType enum for the list of possible values.
7896 7897 7898 7899 7900 7901 7902 7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7896 class AllocationReservationSharingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Sharing config for all Google Cloud services. module ServiceShareType # A value indicating that the enum field is not set. UNDEFINED_SERVICE_SHARE_TYPE = 0 # Allow all Google Cloud managed services to share reservations. ALLOW_ALL = 475_536_235 # [Default] Disallow sharing with all Google Cloud services. DISALLOW_ALL = 277_786_301 SERVICE_SHARE_TYPE_UNSPECIFIED = 279_057_148 end end |