Class: Google::Cloud::Compute::V1::AllocationReservationSharingPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: ServiceShareType

Instance Attribute Summary collapse

Instance Attribute Details

#service_share_type::String

Returns Sharing config for all Google Cloud services. Check the ServiceShareType enum for the list of possible values.

Returns:

  • (::String)

    Sharing config for all Google Cloud services. Check the ServiceShareType enum for the list of possible values.



7853
7854
7855
7856
7857
7858
7859
7860
7861
7862
7863
7864
7865
7866
7867
7868
7869
7870
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7853

class AllocationReservationSharingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Sharing config for all Google Cloud services.
  module ServiceShareType
    # A value indicating that the enum field is not set.
    UNDEFINED_SERVICE_SHARE_TYPE = 0

    # Allow all Google Cloud managed services to share reservations.
    ALLOW_ALL = 475_536_235

    # [Default] Disallow sharing with all Google Cloud services.
    DISALLOW_ALL = 277_786_301

    SERVICE_SHARE_TYPE_UNSPECIFIED = 279_057_148
  end
end