Class: Google::Cloud::Compute::V1::AllocationReservationSharingPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AllocationReservationSharingPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: ServiceShareType
Instance Attribute Summary collapse
-
#service_share_type ⇒ ::String
Sharing config for all Google Cloud services.
Instance Attribute Details
#service_share_type ⇒ ::String
Returns Sharing config for all Google Cloud services. Check the ServiceShareType enum for the list of possible values.
7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7738 class AllocationReservationSharingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Sharing config for all Google Cloud services. module ServiceShareType # A value indicating that the enum field is not set. UNDEFINED_SERVICE_SHARE_TYPE = 0 # Allow all Google Cloud managed services to share reservations. ALLOW_ALL = 475_536_235 # [Default] Disallow sharing with all Google Cloud services. DISALLOW_ALL = 277_786_301 SERVICE_SHARE_TYPE_UNSPECIFIED = 279_057_148 end end |