Module: Google::Cloud::Compute::V1::AllocationReservationSharingPolicy::ServiceShareType
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Sharing config for all Google Cloud services.
Constant Summary collapse
- UNDEFINED_SERVICE_SHARE_TYPE =
A value indicating that the enum field is not set.
0- ALLOW_ALL =
Allow all Google Cloud managed services to share reservations.
475_536_235- DISALLOW_ALL =
[Default] Disallow sharing with all Google Cloud services.
277_786_301- SERVICE_SHARE_TYPE_UNSPECIFIED =
279_057_148