Class: Google::Cloud::Compute::V1::AllocationResourceStatusHealthInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Health information for the reservation.

Defined Under Namespace

Modules: HealthStatus

Instance Attribute Summary collapse

Instance Attribute Details

#degraded_block_count::Integer

Returns The number of reservation blocks that are degraded.

Returns:

  • (::Integer)

    The number of reservation blocks that are degraded.



7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7944

class AllocationResourceStatusHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation is degraded.
    DEGRADED = 396_890_926

    # The reservation is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#health_status::String

Returns The health status of the reservation. Check the HealthStatus enum for the list of possible values.

Returns:

  • (::String)

    The health status of the reservation. Check the HealthStatus enum for the list of possible values.



7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7944

class AllocationResourceStatusHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation is degraded.
    DEGRADED = 396_890_926

    # The reservation is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#healthy_block_count::Integer

Returns The number of reservation blocks that are healthy.

Returns:

  • (::Integer)

    The number of reservation blocks that are healthy.



7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7944

class AllocationResourceStatusHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation is degraded.
    DEGRADED = 396_890_926

    # The reservation is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end