Class: Google::Cloud::Compute::V1::AllocationResourceStatusHealthInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AllocationResourceStatusHealthInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Health information for the reservation.
Defined Under Namespace
Modules: HealthStatus
Instance Attribute Summary collapse
-
#degraded_block_count ⇒ ::Integer
The number of reservation blocks that are degraded.
-
#health_status ⇒ ::String
The health status of the reservation.
-
#healthy_block_count ⇒ ::Integer
The number of reservation blocks that are healthy.
Instance Attribute Details
#degraded_block_count ⇒ ::Integer
Returns The number of reservation blocks that are degraded.
7901 7902 7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7901 class AllocationResourceStatusHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation is degraded. DEGRADED = 396_890_926 # The reservation is healthy. HEALTHY = 439_801_213 # The health status of the reservation is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |
#health_status ⇒ ::String
Returns The health status of the reservation. Check the HealthStatus enum for the list of possible values.
7901 7902 7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7901 class AllocationResourceStatusHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation is degraded. DEGRADED = 396_890_926 # The reservation is healthy. HEALTHY = 439_801_213 # The health status of the reservation is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |
#healthy_block_count ⇒ ::Integer
Returns The number of reservation blocks that are healthy.
7901 7902 7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7901 class AllocationResourceStatusHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation is degraded. DEGRADED = 396_890_926 # The reservation is healthy. HEALTHY = 439_801_213 # The health status of the reservation is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |