Class: Google::Cloud::Compute::V1::AllocationResourceStatusHealthInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Health information for the reservation.

Defined Under Namespace

Modules: HealthStatus

Instance Attribute Summary collapse

Instance Attribute Details

#degraded_block_count::Integer

Returns The number of reservation blocks that are degraded.

Returns:

  • (::Integer)

    The number of reservation blocks that are degraded.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7786

class AllocationResourceStatusHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation is degraded.
    DEGRADED = 396_890_926

    # The reservation is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#health_status::String

Returns The health status of the reservation. Check the HealthStatus enum for the list of possible values.

Returns:

  • (::String)

    The health status of the reservation. Check the HealthStatus enum for the list of possible values.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7786

class AllocationResourceStatusHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation is degraded.
    DEGRADED = 396_890_926

    # The reservation is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#healthy_block_count::Integer

Returns The number of reservation blocks that are healthy.

Returns:

  • (::Integer)

    The number of reservation blocks that are healthy.



7786
7787
7788
7789
7790
7791
7792
7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7786

class AllocationResourceStatusHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation is degraded.
    DEGRADED = 396_890_926

    # The reservation is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end