Class: Google::Cloud::Compute::V1::AllocationResourceStatusSpecificSKUAllocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AllocationResourceStatusSpecificSKUAllocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Contains Properties set for the reservation.
Defined Under Namespace
Classes: UtilizationsEntry
Instance Attribute Summary collapse
-
#source_instance_template_id ⇒ ::String
ID of the instance template used to populate reservation properties.
-
#utilizations ⇒ ::Google::Protobuf::Map{::String => ::Integer}
Per service utilization breakdown.
Instance Attribute Details
#source_instance_template_id ⇒ ::String
Returns ID of the instance template used to populate reservation properties.
7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7814 class AllocationResourceStatusSpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Integer] class UtilizationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#utilizations ⇒ ::Google::Protobuf::Map{::String => ::Integer}
Returns Per service utilization breakdown. The Key is the Google Cloud managed service name.
7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7814 class AllocationResourceStatusSpecificSKUAllocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Integer] class UtilizationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |