Class: Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Interface

Instance Attribute Summary collapse

Instance Attribute Details

#disk_size_gb::Integer

Returns Specifies the size of the disk in base-2 GB.

Returns:

  • (::Integer)

    Specifies the size of the disk in base-2 GB.



7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
8010
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7995

class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME. The default isSCSI.
  # For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end

#interface::String

Returns Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance. Check the Interface enum for the list of possible values.

Returns:

  • (::String)

    Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance. Check the Interface enum for the list of possible values.



7995
7996
7997
7998
7999
8000
8001
8002
8003
8004
8005
8006
8007
8008
8009
8010
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7995

class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME. The default isSCSI.
  # For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end