Class: Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Interface

Instance Attribute Summary collapse

Instance Attribute Details

#disk_size_gb::Integer

Returns Specifies the size of the disk in base-2 GB.

Returns:

  • (::Integer)

    Specifies the size of the disk in base-2 GB.



7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
7963
7964
7965
7966
7967
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7952

class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME. The default isSCSI.
  # For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end

#interface::String

Returns Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance. Check the Interface enum for the list of possible values.

Returns:

  • (::String)

    Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance. Check the Interface enum for the list of possible values.



7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
7963
7964
7965
7966
7967
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7952

class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME. The default isSCSI.
  # For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end