Class: Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Interface

Instance Attribute Summary collapse

Instance Attribute Details

#disk_size_gb::Integer

Returns Specifies the size of the disk in base-2 GB.

Returns:

  • (::Integer)

    Specifies the size of the disk in base-2 GB.



7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
7850
7851
7852
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7837

class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME. The default isSCSI.
  # For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end

#interface::String

Returns Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance. Check the Interface enum for the list of possible values.

Returns:

  • (::String)

    Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. For performance characteristics of SCSI over NVMe, seeLocal SSD performance. Check the Interface enum for the list of possible values.



7837
7838
7839
7840
7841
7842
7843
7844
7845
7846
7847
7848
7849
7850
7851
7852
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7837

class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is
  # either SCSI or NVME. The default isSCSI.
  # For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end