Class: Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Interface

Instance Attribute Summary collapse

Instance Attribute Details

#disk_size_gb::Integer



2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 2484

class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default is SCSI. For performance characteristics of SCSI over NVMe, see Local SSD performance.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end

#interface::String



2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 2484

class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default is SCSI. For performance characteristics of SCSI over NVMe, see Local SSD performance.
  module Interface
    # A value indicating that the enum field is not set.
    UNDEFINED_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end