Class: Google::Cloud::Compute::V1::AllocationSpecificSKUReservation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AllocationSpecificSKUReservation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
This reservation type allows to pre allocate specific instance configuration.
Instance Attribute Summary collapse
-
#assured_count ⇒ ::Integer
Output only.
-
#count ⇒ ::Integer
Specifies the number of resources that are allocated.
-
#in_use_count ⇒ ::Integer
Output only.
-
#instance_properties ⇒ ::Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationReservedInstanceProperties
The instance properties for the reservation.
-
#source_instance_template ⇒ ::String
Specifies the instance template to create the reservation.
Instance Attribute Details
#assured_count ⇒ ::Integer
Returns Output only. [Output Only] Indicates how many instances are actually usable currently.
7907 7908 7909 7910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7907 class AllocationSpecificSKUReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#count ⇒ ::Integer
Returns Specifies the number of resources that are allocated.
7907 7908 7909 7910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7907 class AllocationSpecificSKUReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#in_use_count ⇒ ::Integer
Returns Output only. [Output Only] Indicates how many instances are in use.
7907 7908 7909 7910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7907 class AllocationSpecificSKUReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_properties ⇒ ::Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationReservedInstanceProperties
Returns The instance properties for the reservation.
7907 7908 7909 7910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7907 class AllocationSpecificSKUReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_instance_template ⇒ ::String
Returns Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field.
This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template:
- https://www.googleapis.com/compute/v1/projects/project/global/instanceTemplates/instanceTemplate
- projects/project/global/instanceTemplates/instanceTemplate
- global/instanceTemplates/instanceTemplate.
7907 7908 7909 7910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7907 class AllocationSpecificSKUReservation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |