Class: Google::Cloud::Compute::V1::AttachedDiskInitializeParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance.

This field is persisted and returned for instanceTemplate and not returned in the context of instance.

This property is mutually exclusive with the source property; you can only define one or the other, but not both.

Defined Under Namespace

Modules: Architecture, OnUpdateAction Classes: LabelsEntry, ResourceManagerTagsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#architecture::String

Returns The architecture of the attached disk. Valid values are arm64 or x86_64. Check the Architecture enum for the list of possible values.

Returns:

  • (::String)

    The architecture of the attached disk. Valid values are arm64 or x86_64. Check the Architecture enum for the list of possible values.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#description::String

Returns An optional description. Provide this property when creating the disk.

Returns:

  • (::String)

    An optional description. Provide this property when creating the disk.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#disk_name::String

Returns Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created.

Returns:

  • (::String)

    Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#disk_size_gb::Integer

Returns Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB.

Returns:

  • (::Integer)

    Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#disk_type::String

Returns Specifies the disk type to use to create the instance. If not specified, the default is pd-standard, specified using the full URL. For example:

https://www.googleapis.com/compute/v1/projects/project/zones/zone/diskTypes/pd-standard

For a full list of acceptable values, seePersistent disk types. If you specify this field when creating a VM, you can provide either the full or partial URL. For example, the following values are valid:

 - https://www.googleapis.com/compute/v1/projects/project/zones/zone/diskTypes/diskType
  • projects/project/zones/zone/diskTypes/diskType
  • zones/zone/diskTypes/diskType

If you specify this field when creating or updating an instance template or all-instances configuration, specify the type of the disk, not the URL. For example: pd-standard.

Returns:

  • (::String)

    Specifies the disk type to use to create the instance. If not specified, the default is pd-standard, specified using the full URL. For example:

    https://www.googleapis.com/compute/v1/projects/project/zones/zone/diskTypes/pd-standard

    For a full list of acceptable values, seePersistent disk types. If you specify this field when creating a VM, you can provide either the full or partial URL. For example, the following values are valid:

     - https://www.googleapis.com/compute/v1/projects/project/zones/zone/diskTypes/diskType
    
    • projects/project/zones/zone/diskTypes/diskType
    • zones/zone/diskTypes/diskType

    If you specify this field when creating or updating an instance template or all-instances configuration, specify the type of the disk, not the URL. For example: pd-standard.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#enable_confidential_compute::Boolean

Returns Whether this disk is using confidential compute mode.

Returns:

  • (::Boolean)

    Whether this disk is using confidential compute mode.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Labels to apply to this disk. These can be later modified by thedisks.setLabels method. This field is only applicable for persistent disks.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Labels to apply to this disk. These can be later modified by thedisks.setLabels method. This field is only applicable for persistent disks.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#licenses::Array<::String>

Returns A list of publicly visible licenses. Reserved for Google's use.

Returns:

  • (::Array<::String>)

    A list of publicly visible licenses. Reserved for Google's use.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#on_update_action::String

Returns Specifies which action to take on instance update with this disk. Default is to use the existing disk. Check the OnUpdateAction enum for the list of possible values.

Returns:

  • (::String)

    Specifies which action to take on instance update with this disk. Default is to use the existing disk. Check the OnUpdateAction enum for the list of possible values.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#provisioned_iops::Integer

Returns Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation.

Returns:

  • (::Integer)

    Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#provisioned_throughput::Integer

Returns Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must greater than or equal to 1.

Returns:

  • (::Integer)

    Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must greater than or equal to 1.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#replica_zones::Array<::String>

Returns Required for each regional disk associated with the instance. Specify the URLs of the zones where the disk should be replicated to. You must provide exactly two replica zones, and one zone must be the same as the instance zone.

Returns:

  • (::Array<::String>)

    Required for each regional disk associated with the instance. Specify the URLs of the zones where the disk should be replicated to. You must provide exactly two replica zones, and one zone must be the same as the instance zone.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#resource_manager_tags::Google::Protobuf::Map{::String => ::String}

Returns Input only. Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Input only. Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#resource_policies::Array<::String>

Returns Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name.

Returns:

  • (::Array<::String>)

    Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#source_image::String

Returns The source image to create this disk. When creating a new instance boot disk, one of initializeParams.sourceImage orinitializeParams.sourceSnapshot or disks.source is required.

To create a disk with one of the public operating system images, specify the image by its family name. For example, specifyfamily/debian-9 to use the latest Debian 9 image:

projects/debian-cloud/global/images/family/debian-9

Alternatively, use a specific version of a public operating system image:

projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD

To create a disk with a custom image that you created, specify the image name in the following format:

global/images/my-custom-image

You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name:

global/images/family/my-image-family

If the source image is deleted later, this field will not be set.

Returns:

  • (::String)

    The source image to create this disk. When creating a new instance boot disk, one of initializeParams.sourceImage orinitializeParams.sourceSnapshot or disks.source is required.

    To create a disk with one of the public operating system images, specify the image by its family name. For example, specifyfamily/debian-9 to use the latest Debian 9 image:

    projects/debian-cloud/global/images/family/debian-9

    Alternatively, use a specific version of a public operating system image:

    projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD

    To create a disk with a custom image that you created, specify the image name in the following format:

    global/images/my-custom-image

    You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name:

    global/images/family/my-image-family

    If the source image is deleted later, this field will not be set.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#source_image_encryption_key::Google::Cloud::Compute::V1::CustomerEncryptionKey

Returns Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key.

InstanceTemplate and InstancePropertiesPatch do not storecustomer-supplied encryption keys, so you cannot create disks for instances in a managed instance group if the source images are encrypted with your own keys.

Returns:

  • (::Google::Cloud::Compute::V1::CustomerEncryptionKey)

    Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key.

    InstanceTemplate and InstancePropertiesPatch do not storecustomer-supplied encryption keys, so you cannot create disks for instances in a managed instance group if the source images are encrypted with your own keys.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#source_snapshot::String

Returns The source snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot orinitializeParams.sourceImage or disks.source is required.

To create a disk with a snapshot that you created, specify the snapshot name in the following format:

global/snapshots/my-backup

If the source snapshot is deleted later, this field will not be set.

Note: You cannot create VMs in bulk using a snapshot as the source. Use an image instead when you create VMs using the bulk insert method.

Returns:

  • (::String)

    The source snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot orinitializeParams.sourceImage or disks.source is required.

    To create a disk with a snapshot that you created, specify the snapshot name in the following format:

    global/snapshots/my-backup

    If the source snapshot is deleted later, this field will not be set.

    Note: You cannot create VMs in bulk using a snapshot as the source. Use an image instead when you create VMs using the bulk insert method.



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#source_snapshot_encryption_key::Google::Cloud::Compute::V1::CustomerEncryptionKey

Returns Thecustomer-supplied encryption key of the source snapshot.

Returns:



8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end

#storage_pool::String

Returns The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

 - https://www.googleapis.com/compute/v1/projects/project/zones/zone/storagePools/storagePool
 - projects/project/zones/zone/storagePools/storagePool
  • zones/zone/storagePools/storagePool.

Returns:

  • (::String)

    The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

     - https://www.googleapis.com/compute/v1/projects/project/zones/zone/storagePools/storagePool
     - projects/project/zones/zone/storagePools/storagePool
    
    • zones/zone/storagePools/storagePool


8653
8654
8655
8656
8657
8658
8659
8660
8661
8662
8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
8704
8705
8706
8707
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8653

class AttachedDiskInitializeParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The architecture of the attached disk. Valid values are
  # arm64 or x86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Specifies which action to take on instance update with this disk. Default
  # is to use the existing disk.
  module OnUpdateAction
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_UPDATE_ACTION = 0

    # Always recreate the disk.
    RECREATE_DISK = 494_767_853

    # Recreate the disk if source (image, snapshot) of this disk is different
    # from source of existing disk.
    RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712

    # Use the existing disk, this is the default behaviour.
    USE_EXISTING_DISK = 232_682_233
  end
end