Class: Google::Cloud::Compute::V1::AttachedDiskInitializeParams
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AttachedDiskInitializeParams
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance.
This field is persisted and returned for instanceTemplate and not returned in the context of instance.
This property is mutually exclusive with the source property; you can only define one or the other, but not both.
Defined Under Namespace
Modules: Architecture, OnUpdateAction Classes: LabelsEntry, ResourceManagerTagsEntry
Instance Attribute Summary collapse
-
#architecture ⇒ ::String
The architecture of the attached disk.
-
#description ⇒ ::String
An optional description.
-
#disk_name ⇒ ::String
Specifies the disk name.
-
#disk_size_gb ⇒ ::Integer
Specifies the size of the disk in base-2 GB.
-
#disk_type ⇒ ::String
Specifies the disk type used for the boot disk or an additional data disk.
-
#enable_confidential_compute ⇒ ::Boolean
Whether this disk is using confidential compute mode.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels to apply to this disk.
-
#licenses ⇒ ::Array<::String>
A list of publicly visible licenses.
-
#on_update_action ⇒ ::String
Specifies which action to take on instance update with this disk.
-
#provisioned_iops ⇒ ::Integer
Indicates how many IOPS to provision for the disk.
-
#provisioned_throughput ⇒ ::Integer
Indicates how much throughput to provision for the disk.
-
#replica_zones ⇒ ::Array<::String>
Required for each regional disk associated with the instance.
-
#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Input only.
-
#resource_policies ⇒ ::Array<::String>
Resource policies applied to this disk for automatic snapshot creations.
-
#source_image ⇒ ::String
The source image to create this disk.
-
#source_image_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source image.
-
#source_snapshot ⇒ ::String
The source snapshot to create this disk.
-
#source_snapshot_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Thecustomer-supplied encryption key of the source snapshot.
-
#storage_pool ⇒ ::String
The storage pool in which the new disk is created.
Instance Attribute Details
#architecture ⇒ ::String
Returns The architecture of the attached disk. Valid values are arm64 or x86_64. Check the Architecture enum for the list of possible values.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#description ⇒ ::String
Returns An optional description. Provide this property when creating the disk.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#disk_name ⇒ ::String
Returns Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#disk_size_gb ⇒ ::Integer
Returns Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#disk_type ⇒ ::String
Returns Specifies the disk type used for the boot disk or an additional data disk. For valid disk type values, see Supported types for Hyperdisk volumes and Persistent Disk type variables.
When creating a single instance, you must provide either the full or partial URL of the disk type. For example, the following values are valid:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/diskTypes/diskType
- projects/project/zones/zone/diskTypes/diskType
- zones/zone/diskTypes/diskType
When creating an instance template, instance flexibility policy, or when creating or updating an all-instances configuration, you specify the disk type without a URL, for example, hyperdisk-balanced.
If you omit this field for a disk, the default disk type depends on the instance's machine series, as follows.
- For first- and second-generation machine series like N1, N2, T2, and
M1, the
default disk type is Standard Persistent Disk
(pd-standard).
- For C3, C3D, and M3 the default is Balanced Persistent Disk
(pd-balanced).
- For other third-generation machine
series like A3, H3, Z3, all
fourth-generation types like C4, N4, M4, and newer machine series,
the default is Hyperdisk Balanced
(hyperdisk-balanced).
The disk type you specify must be compatible with the instance's machine series. For a list of machine series that support Persistent Disk, see Machine series support for Persistent Disk.
For a list of machine series that support Hyperdisk, seeMachine series support for Hyperdisk.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#enable_confidential_compute ⇒ ::Boolean
Returns Whether this disk is using confidential compute mode.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels to apply to this disk. These can be later modified by thedisks.setLabels method. This field is only applicable for persistent disks.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#licenses ⇒ ::Array<::String>
Returns A list of publicly visible licenses. Reserved for Google's use.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#on_update_action ⇒ ::String
Returns Specifies which action to take on instance update with this disk. Default is to use the existing disk. Check the OnUpdateAction enum for the list of possible values.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#provisioned_iops ⇒ ::Integer
Returns Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#provisioned_throughput ⇒ ::Integer
Returns Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must greater than or equal to 1.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#replica_zones ⇒ ::Array<::String>
Returns Required for each regional disk associated with the instance. Specify the URLs of the zones where the disk should be replicated to. You must provide exactly two replica zones, and one zone must be the same as the instance zone.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Input only. Resource manager tags to be bound to the disk. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in
namespaced format such as {org_id|project_id}/{tag_key_short_name} and
{tag_value_short_name}. The field is ignored (both PUT & PATCH) when
empty.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#resource_policies ⇒ ::Array<::String>
Returns Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#source_image ⇒ ::String
Returns The source image to create this disk. When creating a new instance boot disk, one of initializeParams.sourceImage orinitializeParams.sourceSnapshot or disks.source is required.
To create a disk with one of the public operating system images, specify the image by its family name. For example, specifyfamily/debian-9 to use the latest Debian 9 image:
projects/debian-cloud/global/images/family/debian-9
Alternatively, use a specific version of a public operating system image:
projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD
To create a disk with a custom image that you created, specify the image name in the following format:
global/images/my-custom-image
You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name:
global/images/family/my-image-family
If the source image is deleted later, this field will not be set.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#source_image_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Returns Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key.
InstanceTemplate and InstancePropertiesPatch do not storecustomer-supplied encryption keys, so you cannot create disks for instances in a managed instance group if the source images are encrypted with your own keys.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#source_snapshot ⇒ ::String
Returns The source snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot orinitializeParams.sourceImage or disks.source is required.
To create a disk with a snapshot that you created, specify the snapshot name in the following format:
global/snapshots/my-backup
If the source snapshot is deleted later, this field will not be set.
Note: You cannot create VMs in bulk using a snapshot as the source. Use an image instead when you create VMs using the bulk insert method.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#source_snapshot_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Returns Thecustomer-supplied encryption key of the source snapshot.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |
#storage_pool ⇒ ::String
Returns The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/storagePools/storagePool
- projects/project/zones/zone/storagePools/storagePool
- zones/zone/storagePools/storagePool.
8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8740 class AttachedDiskInitializeParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The architecture of the attached disk. Valid values are # arm64 or x86_64. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Specifies which action to take on instance update with this disk. Default # is to use the existing disk. module OnUpdateAction # A value indicating that the enum field is not set. UNDEFINED_ON_UPDATE_ACTION = 0 # Always recreate the disk. RECREATE_DISK = 494_767_853 # Recreate the disk if source (image, snapshot) of this disk is different # from source of existing disk. RECREATE_DISK_IF_SOURCE_CHANGED = 398_099_712 # Use the existing disk, this is the default behaviour. USE_EXISTING_DISK = 232_682_233 end end |