Class: Google::Cloud::Compute::V1::AuditLogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AuditLogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Provides the configuration for logging a type of permissions. Example:
{
"audit_log_configs": [
{
"log_type": "DATA_READ",
"exempted_members": [
"user:jose@example.com"
]
},
{
"log_type": "DATA_WRITE"
}
]
}
This enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting jose@example.com from DATA_READ logging.
Defined Under Namespace
Modules: LogType
Instance Attribute Summary collapse
-
#exempted_members ⇒ ::Array<::String>
Specifies the identities that do not cause logging for this type of permission.
- #ignore_child_exemptions ⇒ ::Boolean
-
#log_type ⇒ ::String
The log type that this config enables.
Instance Attribute Details
#exempted_members ⇒ ::Array<::String>
Returns Specifies the identities that do not cause logging for this type of permission. Follows the same format of Binding.members.
8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 8816 8817 8818 8819 8820 8821 8822 8823 8824 8825 8826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8805 class AuditLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The log type that this config enables. module LogType # A value indicating that the enum field is not set. UNDEFINED_LOG_TYPE = 0 # Admin reads. Example: CloudIAM getIamPolicy ADMIN_READ = 128_951_462 # Data reads. Example: CloudSQL Users list DATA_READ = 305_224_971 # Data writes. Example: CloudSQL Users create DATA_WRITE = 340_181_738 # Default case. Should never be this. LOG_TYPE_UNSPECIFIED = 154_527_053 end end |
#ignore_child_exemptions ⇒ ::Boolean
8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 8816 8817 8818 8819 8820 8821 8822 8823 8824 8825 8826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8805 class AuditLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The log type that this config enables. module LogType # A value indicating that the enum field is not set. UNDEFINED_LOG_TYPE = 0 # Admin reads. Example: CloudIAM getIamPolicy ADMIN_READ = 128_951_462 # Data reads. Example: CloudSQL Users list DATA_READ = 305_224_971 # Data writes. Example: CloudSQL Users create DATA_WRITE = 340_181_738 # Default case. Should never be this. LOG_TYPE_UNSPECIFIED = 154_527_053 end end |
#log_type ⇒ ::String
Returns The log type that this config enables. Check the LogType enum for the list of possible values.
8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 8816 8817 8818 8819 8820 8821 8822 8823 8824 8825 8826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8805 class AuditLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The log type that this config enables. module LogType # A value indicating that the enum field is not set. UNDEFINED_LOG_TYPE = 0 # Admin reads. Example: CloudIAM getIamPolicy ADMIN_READ = 128_951_462 # Data reads. Example: CloudSQL Users list DATA_READ = 305_224_971 # Data writes. Example: CloudSQL Users create DATA_WRITE = 340_181_738 # Default case. Should never be this. LOG_TYPE_UNSPECIFIED = 154_527_053 end end |