Class: Google::Cloud::Compute::V1::AuditLogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AuditLogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Provides the configuration for logging a type of permissions. Example:
{
"audit_log_configs": [
{
"log_type": "DATA_READ",
"exempted_members": [
"user:[email protected]"
]
},
{
"log_type": "DATA_WRITE"
}
]
}
This enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting [email protected] from DATA_READ logging.
Defined Under Namespace
Modules: LogType
Instance Attribute Summary collapse
-
#exempted_members ⇒ ::Array<::String>
Specifies the identities that do not cause logging for this type of permission.
- #ignore_child_exemptions ⇒ ::Boolean
-
#log_type ⇒ ::String
The log type that this config enables.
Instance Attribute Details
#exempted_members ⇒ ::Array<::String>
Returns Specifies the identities that do not cause logging for this type of permission. Follows the same format of Binding.members.
8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 8905 8906 8907 8908 8909 8910 8911 8912 8913 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8892 class AuditLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The log type that this config enables. module LogType # A value indicating that the enum field is not set. UNDEFINED_LOG_TYPE = 0 # Admin reads. Example: CloudIAM getIamPolicy ADMIN_READ = 128_951_462 # Data reads. Example: CloudSQL Users list DATA_READ = 305_224_971 # Data writes. Example: CloudSQL Users create DATA_WRITE = 340_181_738 # Default case. Should never be this. LOG_TYPE_UNSPECIFIED = 154_527_053 end end |
#ignore_child_exemptions ⇒ ::Boolean
8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 8905 8906 8907 8908 8909 8910 8911 8912 8913 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8892 class AuditLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The log type that this config enables. module LogType # A value indicating that the enum field is not set. UNDEFINED_LOG_TYPE = 0 # Admin reads. Example: CloudIAM getIamPolicy ADMIN_READ = 128_951_462 # Data reads. Example: CloudSQL Users list DATA_READ = 305_224_971 # Data writes. Example: CloudSQL Users create DATA_WRITE = 340_181_738 # Default case. Should never be this. LOG_TYPE_UNSPECIFIED = 154_527_053 end end |
#log_type ⇒ ::String
Returns The log type that this config enables. Check the LogType enum for the list of possible values.
8892 8893 8894 8895 8896 8897 8898 8899 8900 8901 8902 8903 8904 8905 8906 8907 8908 8909 8910 8911 8912 8913 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8892 class AuditLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The log type that this config enables. module LogType # A value indicating that the enum field is not set. UNDEFINED_LOG_TYPE = 0 # Admin reads. Example: CloudIAM getIamPolicy ADMIN_READ = 128_951_462 # Data reads. Example: CloudSQL Users list DATA_READ = 305_224_971 # Data writes. Example: CloudSQL Users create DATA_WRITE = 340_181_738 # Default case. Should never be this. LOG_TYPE_UNSPECIFIED = 154_527_053 end end |