Class: Google::Cloud::Compute::V1::Autoscaler

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents an Autoscaler resource.

Google Compute Engine has two Autoscaler resources:

Use autoscalers to automatically add or delete instances from a managed instance group according to your defined autoscaling policy. For more information, read Autoscaling Groups of Instances.

For zonal managed instance groups resource, use the autoscaler resource.

For regional managed instance groups, use theregionAutoscalers resource.

Defined Under Namespace

Modules: Status Classes: ScalingScheduleStatusEntry

Instance Attribute Summary collapse

Instance Attribute Details

#autoscaling_policy::Google::Cloud::Compute::V1::AutoscalingPolicy

Returns The configuration parameters for the autoscaling algorithm. You can define one or more signals for an autoscaler: cpuUtilization,customMetricUtilizations, andloadBalancingUtilization.

If none of these are specified, the default will be to autoscale based oncpuUtilization to 0.6 or 60%.

Returns:

  • (::Google::Cloud::Compute::V1::AutoscalingPolicy)

    The configuration parameters for the autoscaling algorithm. You can define one or more signals for an autoscaler: cpuUtilization,customMetricUtilizations, andloadBalancingUtilization.

    If none of these are specified, the default will be to autoscale based oncpuUtilization to 0.6 or 60%.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Always compute#autoscaler for autoscalers.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Always compute#autoscaler for autoscalers.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#name::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

Returns Output only. [Output Only] Target recommended MIG size (number of instances) computed by autoscaler. Autoscaler calculates the recommended MIG size even when the autoscaling policy mode is different from ON. This field is empty when autoscaler is not connected to an existing managed instance group or autoscaler did not generate its prediction.

Returns:

  • (::Integer)

    Output only. [Output Only] Target recommended MIG size (number of instances) computed by autoscaler. Autoscaler calculates the recommended MIG size even when the autoscaling policy mode is different from ON. This field is empty when autoscaler is not connected to an existing managed instance group or autoscaler did not generate its prediction.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#region::String

Returns Output only. [Output Only] URL of theregion where the instance group resides (for autoscalers living in regional scope).

Returns:

  • (::String)

    Output only. [Output Only] URL of theregion where the instance group resides (for autoscalers living in regional scope).



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#scaling_schedule_status::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::ScalingScheduleStatus}

Returns Output only. [Output Only] Status information of existing scaling schedules.

Returns:



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for the resource.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#status::String

Returns [Output Only] The status of the autoscaler configuration. Current set of possible values:

  • PENDING: Autoscaler backend hasn't read new/updated configuration.
  • DELETING: Configuration is being deleted.
  • ACTIVE: Configuration is acknowledged to be effective. Some warnings might be present in the statusDetails field.
  • ERROR: Configuration has errors. Actionable for users. Details are present in the statusDetails field.

New values might be added in the future. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] The status of the autoscaler configuration. Current set of possible values:

    • PENDING: Autoscaler backend hasn't read new/updated configuration.
    • DELETING: Configuration is being deleted.
    • ACTIVE: Configuration is acknowledged to be effective. Some warnings might be present in the statusDetails field.
    • ERROR: Configuration has errors. Actionable for users. Details are present in the statusDetails field.

    New values might be added in the future. Check the Status enum for the list of possible values.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#status_details::Array<::Google::Cloud::Compute::V1::AutoscalerStatusDetails>

[Output Only] Human-readable details about the current state of the autoscaler. Read the documentation forCommonly returned status messages for examples of status messages you might encounter.

Returns:



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#target::String

Returns URL of the managed instance group that this autoscaler will scale. This field is required when creating an autoscaler.

Returns:

  • (::String)

    URL of the managed instance group that this autoscaler will scale. This field is required when creating an autoscaler.



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end

#zone::String

Returns Output only. [Output Only] URL of thezone where the instance group resides (for autoscalers living in zonal scope).

Returns:

  • (::String)

    Output only. [Output Only] URL of thezone where the instance group resides (for autoscalers living in zonal scope).



8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
8845
8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8810

class Autoscaler
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ScalingScheduleStatus]
  class ScalingScheduleStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # [Output Only] The status of the autoscaler configuration. Current set of
  # possible values:
  #
  #    - PENDING:
  #      Autoscaler backend hasn't read new/updated configuration.
  #    - DELETING:
  #      Configuration is being deleted.
  #    - ACTIVE:
  #      Configuration is acknowledged to be effective. Some warnings might
  #      be present in the statusDetails field.
  #    - ERROR:
  #      Configuration has errors. Actionable for users. Details are present in
  #      the statusDetails field.
  #
  #
  # New values might be added in the future.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Configuration is acknowledged to be effective
    ACTIVE = 314_733_318

    # Configuration is being deleted
    DELETING = 528_602_024

    # Configuration has errors. Actionable for users.
    ERROR = 66_247_144

    # Autoscaler backend hasn't read new/updated configuration
    PENDING = 35_394_935
  end
end