Class: Google::Cloud::Compute::V1::AutoscalerAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AutoscalerAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::AutoscalersScopedList}
A list of AutoscalersScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8884 class AutoscalerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::AutoscalersScopedList}
Returns A list of AutoscalersScopedList resources.
8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8884 class AutoscalerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Alwayscompute#autoscalerAggregatedList for aggregated lists of autoscalers.
8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8884 class AutoscalerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8884 class AutoscalerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8884 class AutoscalerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder.
8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8884 class AutoscalerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8884 class AutoscalerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |