Class: Google::Cloud::Compute::V1::AutoscalerStatusDetails
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AutoscalerStatusDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#message ⇒ ::String
The status message.
-
#type ⇒ ::String
The type of error, warning, or notice returned.
Instance Attribute Details
#message ⇒ ::String
Returns The status message.
9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 9146 9147 9148 9149 9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 9163 9164 9165 9166 9167 9168 9169 9170 9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 9195 9196 9197 9198 9199 9200 9201 9202 9203 9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9102 class AutoscalerStatusDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of error, warning, or notice returned. Current set of possible # values: # # - ALL_INSTANCES_UNHEALTHY (WARNING): # All instances in the instance group are unhealthy (not in RUNNING # state). # - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): # There is no backend service attached to the instance group. # - CAPPED_AT_MAX_NUM_REPLICAS (WARNING): # Autoscaler recommends a size greater than maxNumReplicas. # - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): # The custom metric samples are not exported often enough to be # a credible base for autoscaling. # - CUSTOM_METRIC_INVALID (ERROR): # The custom metric that was specified does not exist or does not have # the necessary labels. # - MIN_EQUALS_MAX (WARNING): # The minNumReplicas is equal to maxNumReplicas. This means the # autoscaler cannot add or remove instances from the instance group. # - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): # The autoscaler did not receive any data from the custom metric # configured for autoscaling. # - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): # The autoscaler is configured to scale based on a load balancing signal # but the instance group has not received any requests from the load # balancer. # - MODE_OFF (WARNING): # Autoscaling is turned off. The number of instances in the group won't # change automatically. The autoscaling configuration is preserved. # - MODE_ONLY_UP (WARNING): # Autoscaling is in the "Autoscale only out" mode. The autoscaler can add # instances but not remove any. # - MORE_THAN_ONE_BACKEND_SERVICE (ERROR): # The instance group cannot be autoscaled because it has more than one # backend service attached to it. # - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): # There is insufficient quota for the necessary resources, such as CPU or # number of instances. # - REGION_RESOURCE_STOCKOUT (ERROR): # Shown only for regional autoscalers: there is a resource stockout in # the chosen region. # - SCALING_TARGET_DOES_NOT_EXIST (ERROR): # The target to be scaled does not exist. # - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION # (ERROR): Autoscaling does not work with an HTTP/S load balancer that # has been configured for maxRate. # - ZONE_RESOURCE_STOCKOUT (ERROR): # For zonal autoscalers: there is a resource stockout in the chosen zone. # For regional autoscalers: in at least one of the zones you're using # there is a resource stockout. # # # New values might be added in the future. Some of the values might not be # available in all API versions. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # All instances in the instance group are unhealthy (not in RUNNING state). ALL_INSTANCES_UNHEALTHY = 404_965_477 # There is no backend service attached to the instance group. BACKEND_SERVICE_DOES_NOT_EXIST = 191_417_626 # Autoscaler recommends a size greater than maxNumReplicas. CAPPED_AT_MAX_NUM_REPLICAS = 518_617 # The custom metric samples are not exported often enough to be a credible # base for autoscaling. CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE = 328_964_659 # The custom metric that was specified does not exist or does not have the # necessary labels. CUSTOM_METRIC_INVALID = 204_430_550 # The minNumReplicas is equal to maxNumReplicas. This means the autoscaler # cannot add or remove instances from the instance group. MIN_EQUALS_MAX = 2_821_361 # The autoscaler did not receive any data from the custom metric configured # for autoscaling. MISSING_CUSTOM_METRIC_DATA_POINTS = 94_885_086 # The autoscaler is configured to scale based on a load balancing signal # but the instance group has not received any requests from the load # balancer. MISSING_LOAD_BALANCING_DATA_POINTS = 509_858_898 # Autoscaling is turned off. The number of instances in the group won't # change automatically. The autoscaling configuration is preserved. MODE_OFF = 164_169_907 # Autoscaling is in the "Autoscale only scale out" mode. # Instances in the group will be only added. MODE_ONLY_SCALE_OUT = 3_840_994 # Autoscaling is in the "Autoscale only out" mode. Instances in the group # will be only added. MODE_ONLY_UP = 100_969_842 # The instance group cannot be autoscaled because it has more than one # backend service attached to it. MORE_THAN_ONE_BACKEND_SERVICE = 151_922_141 # There is insufficient quota for the necessary resources, such as CPU or # number of instances. NOT_ENOUGH_QUOTA_AVAILABLE = 403_101_631 # Showed only for regional autoscalers: there is a resource stockout in # the chosen region. REGION_RESOURCE_STOCKOUT = 528_622_846 # The target to be scaled does not exist. SCALING_TARGET_DOES_NOT_EXIST = 122_636_699 # For some scaling schedules minRequiredReplicas is greater than # maxNumReplicas. Autoscaler always recommends at most maxNumReplicas # instances. SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX = 29_275_586 # For some scaling schedules minRequiredReplicas is less than # minNumReplicas. Autoscaler always recommends at least minNumReplicas # instances. SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN = 398_287_669 UNKNOWN = 433_141_802 # Autoscaling does not work with an HTTP/S load balancer that has been # configured for maxRate. UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION = 330_845_009 # For zonal autoscalers: there is a resource stockout in the chosen zone. # For regional autoscalers: in at least one of the zones you're using there # is a resource stockout. ZONE_RESOURCE_STOCKOUT = 210_200_502 end end |
#type ⇒ ::String
Returns The type of error, warning, or notice returned. Current set of possible values:
- ALL_INSTANCES_UNHEALTHY (WARNING): All instances in the instance group are unhealthy (not in RUNNING state).
- BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service attached to the instance group.
- CAPPED_AT_MAX_NUM_REPLICAS (WARNING): Autoscaler recommends a size greater than maxNumReplicas.
- CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric samples are not exported often enough to be a credible base for autoscaling.
- CUSTOM_METRIC_INVALID (ERROR): The custom metric that was specified does not exist or does not have the necessary labels.
- MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas. This means the autoscaler cannot add or remove instances from the instance group.
- MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The autoscaler did not receive any data from the custom metric configured for autoscaling.
- MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The autoscaler is configured to scale based on a load balancing signal but the instance group has not received any requests from the load balancer.
- MODE_OFF (WARNING): Autoscaling is turned off. The number of instances in the group won't change automatically. The autoscaling configuration is preserved.
- MODE_ONLY_UP (WARNING): Autoscaling is in the "Autoscale only out" mode. The autoscaler can add instances but not remove any.
- MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group cannot be autoscaled because it has more than one backend service attached to it.
- NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is insufficient quota for the necessary resources, such as CPU or number of instances.
- REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional autoscalers: there is a resource stockout in the chosen region.
- SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not exist.
- UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR): Autoscaling does not work with an HTTP/S load balancer that has been configured for maxRate.
- ZONE_RESOURCE_STOCKOUT (ERROR): For zonal autoscalers: there is a resource stockout in the chosen zone. For regional autoscalers: in at least one of the zones you're using there is a resource stockout.
New values might be added in the future. Some of the values might not be available in all API versions. Check the Type enum for the list of possible values.
9102 9103 9104 9105 9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 9146 9147 9148 9149 9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 9163 9164 9165 9166 9167 9168 9169 9170 9171 9172 9173 9174 9175 9176 9177 9178 9179 9180 9181 9182 9183 9184 9185 9186 9187 9188 9189 9190 9191 9192 9193 9194 9195 9196 9197 9198 9199 9200 9201 9202 9203 9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 9218 9219 9220 9221 9222 9223 9224 9225 9226 9227 9228 9229 9230 9231 9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9102 class AutoscalerStatusDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of error, warning, or notice returned. Current set of possible # values: # # - ALL_INSTANCES_UNHEALTHY (WARNING): # All instances in the instance group are unhealthy (not in RUNNING # state). # - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): # There is no backend service attached to the instance group. # - CAPPED_AT_MAX_NUM_REPLICAS (WARNING): # Autoscaler recommends a size greater than maxNumReplicas. # - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): # The custom metric samples are not exported often enough to be # a credible base for autoscaling. # - CUSTOM_METRIC_INVALID (ERROR): # The custom metric that was specified does not exist or does not have # the necessary labels. # - MIN_EQUALS_MAX (WARNING): # The minNumReplicas is equal to maxNumReplicas. This means the # autoscaler cannot add or remove instances from the instance group. # - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): # The autoscaler did not receive any data from the custom metric # configured for autoscaling. # - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): # The autoscaler is configured to scale based on a load balancing signal # but the instance group has not received any requests from the load # balancer. # - MODE_OFF (WARNING): # Autoscaling is turned off. The number of instances in the group won't # change automatically. The autoscaling configuration is preserved. # - MODE_ONLY_UP (WARNING): # Autoscaling is in the "Autoscale only out" mode. The autoscaler can add # instances but not remove any. # - MORE_THAN_ONE_BACKEND_SERVICE (ERROR): # The instance group cannot be autoscaled because it has more than one # backend service attached to it. # - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): # There is insufficient quota for the necessary resources, such as CPU or # number of instances. # - REGION_RESOURCE_STOCKOUT (ERROR): # Shown only for regional autoscalers: there is a resource stockout in # the chosen region. # - SCALING_TARGET_DOES_NOT_EXIST (ERROR): # The target to be scaled does not exist. # - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION # (ERROR): Autoscaling does not work with an HTTP/S load balancer that # has been configured for maxRate. # - ZONE_RESOURCE_STOCKOUT (ERROR): # For zonal autoscalers: there is a resource stockout in the chosen zone. # For regional autoscalers: in at least one of the zones you're using # there is a resource stockout. # # # New values might be added in the future. Some of the values might not be # available in all API versions. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # All instances in the instance group are unhealthy (not in RUNNING state). ALL_INSTANCES_UNHEALTHY = 404_965_477 # There is no backend service attached to the instance group. BACKEND_SERVICE_DOES_NOT_EXIST = 191_417_626 # Autoscaler recommends a size greater than maxNumReplicas. CAPPED_AT_MAX_NUM_REPLICAS = 518_617 # The custom metric samples are not exported often enough to be a credible # base for autoscaling. CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE = 328_964_659 # The custom metric that was specified does not exist or does not have the # necessary labels. CUSTOM_METRIC_INVALID = 204_430_550 # The minNumReplicas is equal to maxNumReplicas. This means the autoscaler # cannot add or remove instances from the instance group. MIN_EQUALS_MAX = 2_821_361 # The autoscaler did not receive any data from the custom metric configured # for autoscaling. MISSING_CUSTOM_METRIC_DATA_POINTS = 94_885_086 # The autoscaler is configured to scale based on a load balancing signal # but the instance group has not received any requests from the load # balancer. MISSING_LOAD_BALANCING_DATA_POINTS = 509_858_898 # Autoscaling is turned off. The number of instances in the group won't # change automatically. The autoscaling configuration is preserved. MODE_OFF = 164_169_907 # Autoscaling is in the "Autoscale only scale out" mode. # Instances in the group will be only added. MODE_ONLY_SCALE_OUT = 3_840_994 # Autoscaling is in the "Autoscale only out" mode. Instances in the group # will be only added. MODE_ONLY_UP = 100_969_842 # The instance group cannot be autoscaled because it has more than one # backend service attached to it. MORE_THAN_ONE_BACKEND_SERVICE = 151_922_141 # There is insufficient quota for the necessary resources, such as CPU or # number of instances. NOT_ENOUGH_QUOTA_AVAILABLE = 403_101_631 # Showed only for regional autoscalers: there is a resource stockout in # the chosen region. REGION_RESOURCE_STOCKOUT = 528_622_846 # The target to be scaled does not exist. SCALING_TARGET_DOES_NOT_EXIST = 122_636_699 # For some scaling schedules minRequiredReplicas is greater than # maxNumReplicas. Autoscaler always recommends at most maxNumReplicas # instances. SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX = 29_275_586 # For some scaling schedules minRequiredReplicas is less than # minNumReplicas. Autoscaler always recommends at least minNumReplicas # instances. SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN = 398_287_669 UNKNOWN = 433_141_802 # Autoscaling does not work with an HTTP/S load balancer that has been # configured for maxRate. UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION = 330_845_009 # For zonal autoscalers: there is a resource stockout in the chosen zone. # For regional autoscalers: in at least one of the zones you're using there # is a resource stockout. ZONE_RESOURCE_STOCKOUT = 210_200_502 end end |