Class: Google::Cloud::Compute::V1::AutoscalerStatusDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#message::String

Returns The status message.

Returns:

  • (::String)

    The status message.



8987
8988
8989
8990
8991
8992
8993
8994
8995
8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
9006
9007
9008
9009
9010
9011
9012
9013
9014
9015
9016
9017
9018
9019
9020
9021
9022
9023
9024
9025
9026
9027
9028
9029
9030
9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
9080
9081
9082
9083
9084
9085
9086
9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
9107
9108
9109
9110
9111
9112
9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
9124
9125
9126
9127
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8987

class AutoscalerStatusDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of error, warning, or notice returned. Current set of possible
  # values:
  #
  #    - ALL_INSTANCES_UNHEALTHY (WARNING):
  #      All instances in the instance group are unhealthy (not in RUNNING
  #      state).
  #    - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR):
  #      There is no backend service attached to the instance group.
  #    - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
  #      Autoscaler recommends a size greater than maxNumReplicas.
  #    - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING):
  #      The custom metric samples are not exported often enough to be
  #      a credible base for autoscaling.
  #    - CUSTOM_METRIC_INVALID (ERROR):
  #      The custom metric that was specified does not exist or does not have
  #      the necessary labels.
  #    - MIN_EQUALS_MAX (WARNING):
  #      The minNumReplicas is equal to maxNumReplicas. This means the
  #      autoscaler cannot add or remove instances from the instance group.
  #    - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING):
  #      The autoscaler did not receive any data from the custom metric
  #      configured for autoscaling.
  #    - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING):
  #      The autoscaler is configured to scale based on a load balancing signal
  #      but the instance group has not received any requests from the load
  #      balancer.
  #    - MODE_OFF (WARNING):
  #      Autoscaling is turned off. The number of instances in the group won't
  #      change automatically. The autoscaling configuration is preserved.
  #    - MODE_ONLY_UP (WARNING):
  #      Autoscaling is in the "Autoscale only out" mode. The autoscaler can add
  #      instances but not remove any.
  #    - MORE_THAN_ONE_BACKEND_SERVICE (ERROR):
  #      The instance group cannot be autoscaled because it has more than one
  #      backend service attached to it.
  #    - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR):
  #      There is insufficient quota for the necessary resources, such as CPU or
  #      number of instances.
  #    - REGION_RESOURCE_STOCKOUT (ERROR):
  #      Shown only for regional autoscalers: there is a resource stockout in
  #      the chosen region.
  #    - SCALING_TARGET_DOES_NOT_EXIST (ERROR):
  #      The target to be scaled does not exist.
  #    - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION
  #      (ERROR): Autoscaling does not work with an HTTP/S load balancer that
  #      has been configured for maxRate.
  #    - ZONE_RESOURCE_STOCKOUT (ERROR):
  #      For zonal autoscalers: there is a resource stockout in the chosen zone.
  #      For regional autoscalers: in at least one of the zones you're using
  #      there is a resource stockout.
  #
  #
  # New values might be added in the future. Some of the values might not be
  # available in all API versions.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # All instances in the instance group are unhealthy (not in RUNNING state).
    ALL_INSTANCES_UNHEALTHY = 404_965_477

    # There is no backend service attached to the instance group.
    BACKEND_SERVICE_DOES_NOT_EXIST = 191_417_626

    # Autoscaler recommends a size greater than maxNumReplicas.
    CAPPED_AT_MAX_NUM_REPLICAS = 518_617

    # The custom metric samples are not exported often enough to be a credible
    # base for autoscaling.
    CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE = 328_964_659

    # The custom metric that was specified does not exist or does not have the
    # necessary labels.
    CUSTOM_METRIC_INVALID = 204_430_550

    # The minNumReplicas is equal to maxNumReplicas. This means the autoscaler
    # cannot add or remove instances from the instance group.
    MIN_EQUALS_MAX = 2_821_361

    # The autoscaler did not receive any data from the custom metric configured
    # for autoscaling.
    MISSING_CUSTOM_METRIC_DATA_POINTS = 94_885_086

    # The autoscaler is configured to scale based on a load balancing signal
    # but the instance group has not received any requests from the load
    # balancer.
    MISSING_LOAD_BALANCING_DATA_POINTS = 509_858_898

    # Autoscaling is turned off. The number of instances in the group won't
    # change automatically. The autoscaling configuration is preserved.
    MODE_OFF = 164_169_907

    # Autoscaling is in the "Autoscale only scale out" mode.
    # Instances in the group will be only added.
    MODE_ONLY_SCALE_OUT = 3_840_994

    # Autoscaling is in the "Autoscale only out" mode. Instances in the group
    # will be only added.
    MODE_ONLY_UP = 100_969_842

    # The instance group cannot be autoscaled because it has more than one
    # backend service attached to it.
    MORE_THAN_ONE_BACKEND_SERVICE = 151_922_141

    # There is insufficient quota for the necessary resources, such as CPU or
    # number of instances.
    NOT_ENOUGH_QUOTA_AVAILABLE = 403_101_631

    # Showed only for regional autoscalers: there is a resource stockout in
    # the chosen region.
    REGION_RESOURCE_STOCKOUT = 528_622_846

    # The target to be scaled does not exist.
    SCALING_TARGET_DOES_NOT_EXIST = 122_636_699

    # For some scaling schedules minRequiredReplicas is greater than
    # maxNumReplicas. Autoscaler always recommends at most maxNumReplicas
    # instances.
    SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX = 29_275_586

    # For some scaling schedules minRequiredReplicas is less than
    # minNumReplicas. Autoscaler always recommends at least minNumReplicas
    # instances.
    SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN = 398_287_669

    UNKNOWN = 433_141_802

    # Autoscaling does not work with an HTTP/S load balancer that has been
    # configured for maxRate.
    UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION = 330_845_009

    # For zonal autoscalers: there is a resource stockout in the chosen zone.
    # For regional autoscalers: in at least one of the zones you're using there
    # is a resource stockout.
    ZONE_RESOURCE_STOCKOUT = 210_200_502
  end
end

#type::String

Returns The type of error, warning, or notice returned. Current set of possible values:

  • ALL_INSTANCES_UNHEALTHY (WARNING): All instances in the instance group are unhealthy (not in RUNNING state).
  • BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service attached to the instance group.
  • CAPPED_AT_MAX_NUM_REPLICAS (WARNING): Autoscaler recommends a size greater than maxNumReplicas.
  • CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric samples are not exported often enough to be a credible base for autoscaling.
  • CUSTOM_METRIC_INVALID (ERROR): The custom metric that was specified does not exist or does not have the necessary labels.
  • MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas. This means the autoscaler cannot add or remove instances from the instance group.
  • MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The autoscaler did not receive any data from the custom metric configured for autoscaling.
  • MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The autoscaler is configured to scale based on a load balancing signal but the instance group has not received any requests from the load balancer.
  • MODE_OFF (WARNING): Autoscaling is turned off. The number of instances in the group won't change automatically. The autoscaling configuration is preserved.
  • MODE_ONLY_UP (WARNING): Autoscaling is in the "Autoscale only out" mode. The autoscaler can add instances but not remove any.
  • MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group cannot be autoscaled because it has more than one backend service attached to it.
  • NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is insufficient quota for the necessary resources, such as CPU or number of instances.
  • REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional autoscalers: there is a resource stockout in the chosen region.
  • SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not exist.
  • UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR): Autoscaling does not work with an HTTP/S load balancer that has been configured for maxRate.
  • ZONE_RESOURCE_STOCKOUT (ERROR): For zonal autoscalers: there is a resource stockout in the chosen zone. For regional autoscalers: in at least one of the zones you're using there is a resource stockout.

New values might be added in the future. Some of the values might not be available in all API versions. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    The type of error, warning, or notice returned. Current set of possible values:

    • ALL_INSTANCES_UNHEALTHY (WARNING): All instances in the instance group are unhealthy (not in RUNNING state).
    • BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service attached to the instance group.
    • CAPPED_AT_MAX_NUM_REPLICAS (WARNING): Autoscaler recommends a size greater than maxNumReplicas.
    • CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric samples are not exported often enough to be a credible base for autoscaling.
    • CUSTOM_METRIC_INVALID (ERROR): The custom metric that was specified does not exist or does not have the necessary labels.
    • MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas. This means the autoscaler cannot add or remove instances from the instance group.
    • MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The autoscaler did not receive any data from the custom metric configured for autoscaling.
    • MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The autoscaler is configured to scale based on a load balancing signal but the instance group has not received any requests from the load balancer.
    • MODE_OFF (WARNING): Autoscaling is turned off. The number of instances in the group won't change automatically. The autoscaling configuration is preserved.
    • MODE_ONLY_UP (WARNING): Autoscaling is in the "Autoscale only out" mode. The autoscaler can add instances but not remove any.
    • MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group cannot be autoscaled because it has more than one backend service attached to it.
    • NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is insufficient quota for the necessary resources, such as CPU or number of instances.
    • REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional autoscalers: there is a resource stockout in the chosen region.
    • SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not exist.
    • UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR): Autoscaling does not work with an HTTP/S load balancer that has been configured for maxRate.
    • ZONE_RESOURCE_STOCKOUT (ERROR): For zonal autoscalers: there is a resource stockout in the chosen zone. For regional autoscalers: in at least one of the zones you're using there is a resource stockout.

    New values might be added in the future. Some of the values might not be available in all API versions. Check the Type enum for the list of possible values.



8987
8988
8989
8990
8991
8992
8993
8994
8995
8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
9006
9007
9008
9009
9010
9011
9012
9013
9014
9015
9016
9017
9018
9019
9020
9021
9022
9023
9024
9025
9026
9027
9028
9029
9030
9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
9080
9081
9082
9083
9084
9085
9086
9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
9107
9108
9109
9110
9111
9112
9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
9124
9125
9126
9127
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8987

class AutoscalerStatusDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of error, warning, or notice returned. Current set of possible
  # values:
  #
  #    - ALL_INSTANCES_UNHEALTHY (WARNING):
  #      All instances in the instance group are unhealthy (not in RUNNING
  #      state).
  #    - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR):
  #      There is no backend service attached to the instance group.
  #    - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
  #      Autoscaler recommends a size greater than maxNumReplicas.
  #    - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING):
  #      The custom metric samples are not exported often enough to be
  #      a credible base for autoscaling.
  #    - CUSTOM_METRIC_INVALID (ERROR):
  #      The custom metric that was specified does not exist or does not have
  #      the necessary labels.
  #    - MIN_EQUALS_MAX (WARNING):
  #      The minNumReplicas is equal to maxNumReplicas. This means the
  #      autoscaler cannot add or remove instances from the instance group.
  #    - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING):
  #      The autoscaler did not receive any data from the custom metric
  #      configured for autoscaling.
  #    - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING):
  #      The autoscaler is configured to scale based on a load balancing signal
  #      but the instance group has not received any requests from the load
  #      balancer.
  #    - MODE_OFF (WARNING):
  #      Autoscaling is turned off. The number of instances in the group won't
  #      change automatically. The autoscaling configuration is preserved.
  #    - MODE_ONLY_UP (WARNING):
  #      Autoscaling is in the "Autoscale only out" mode. The autoscaler can add
  #      instances but not remove any.
  #    - MORE_THAN_ONE_BACKEND_SERVICE (ERROR):
  #      The instance group cannot be autoscaled because it has more than one
  #      backend service attached to it.
  #    - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR):
  #      There is insufficient quota for the necessary resources, such as CPU or
  #      number of instances.
  #    - REGION_RESOURCE_STOCKOUT (ERROR):
  #      Shown only for regional autoscalers: there is a resource stockout in
  #      the chosen region.
  #    - SCALING_TARGET_DOES_NOT_EXIST (ERROR):
  #      The target to be scaled does not exist.
  #    - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION
  #      (ERROR): Autoscaling does not work with an HTTP/S load balancer that
  #      has been configured for maxRate.
  #    - ZONE_RESOURCE_STOCKOUT (ERROR):
  #      For zonal autoscalers: there is a resource stockout in the chosen zone.
  #      For regional autoscalers: in at least one of the zones you're using
  #      there is a resource stockout.
  #
  #
  # New values might be added in the future. Some of the values might not be
  # available in all API versions.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # All instances in the instance group are unhealthy (not in RUNNING state).
    ALL_INSTANCES_UNHEALTHY = 404_965_477

    # There is no backend service attached to the instance group.
    BACKEND_SERVICE_DOES_NOT_EXIST = 191_417_626

    # Autoscaler recommends a size greater than maxNumReplicas.
    CAPPED_AT_MAX_NUM_REPLICAS = 518_617

    # The custom metric samples are not exported often enough to be a credible
    # base for autoscaling.
    CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE = 328_964_659

    # The custom metric that was specified does not exist or does not have the
    # necessary labels.
    CUSTOM_METRIC_INVALID = 204_430_550

    # The minNumReplicas is equal to maxNumReplicas. This means the autoscaler
    # cannot add or remove instances from the instance group.
    MIN_EQUALS_MAX = 2_821_361

    # The autoscaler did not receive any data from the custom metric configured
    # for autoscaling.
    MISSING_CUSTOM_METRIC_DATA_POINTS = 94_885_086

    # The autoscaler is configured to scale based on a load balancing signal
    # but the instance group has not received any requests from the load
    # balancer.
    MISSING_LOAD_BALANCING_DATA_POINTS = 509_858_898

    # Autoscaling is turned off. The number of instances in the group won't
    # change automatically. The autoscaling configuration is preserved.
    MODE_OFF = 164_169_907

    # Autoscaling is in the "Autoscale only scale out" mode.
    # Instances in the group will be only added.
    MODE_ONLY_SCALE_OUT = 3_840_994

    # Autoscaling is in the "Autoscale only out" mode. Instances in the group
    # will be only added.
    MODE_ONLY_UP = 100_969_842

    # The instance group cannot be autoscaled because it has more than one
    # backend service attached to it.
    MORE_THAN_ONE_BACKEND_SERVICE = 151_922_141

    # There is insufficient quota for the necessary resources, such as CPU or
    # number of instances.
    NOT_ENOUGH_QUOTA_AVAILABLE = 403_101_631

    # Showed only for regional autoscalers: there is a resource stockout in
    # the chosen region.
    REGION_RESOURCE_STOCKOUT = 528_622_846

    # The target to be scaled does not exist.
    SCALING_TARGET_DOES_NOT_EXIST = 122_636_699

    # For some scaling schedules minRequiredReplicas is greater than
    # maxNumReplicas. Autoscaler always recommends at most maxNumReplicas
    # instances.
    SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX = 29_275_586

    # For some scaling schedules minRequiredReplicas is less than
    # minNumReplicas. Autoscaler always recommends at least minNumReplicas
    # instances.
    SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN = 398_287_669

    UNKNOWN = 433_141_802

    # Autoscaling does not work with an HTTP/S load balancer that has been
    # configured for maxRate.
    UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION = 330_845_009

    # For zonal autoscalers: there is a resource stockout in the chosen zone.
    # For regional autoscalers: in at least one of the zones you're using there
    # is a resource stockout.
    ZONE_RESOURCE_STOCKOUT = 210_200_502
  end
end