Class: Google::Cloud::Compute::V1::AutoscalingPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AutoscalingPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Cloud Autoscaler policy.
Defined Under Namespace
Modules: Mode Classes: ScalingSchedulesEntry
Instance Attribute Summary collapse
-
#cool_down_period_sec ⇒ ::Integer
The number of seconds that your application takes to initialize on a VM instance.
-
#cpu_utilization ⇒ ::Google::Cloud::Compute::V1::AutoscalingPolicyCpuUtilization
Defines the CPU utilization policy that allows the autoscaler to scale based on the average CPU utilization of a managed instance group.
-
#custom_metric_utilizations ⇒ ::Array<::Google::Cloud::Compute::V1::AutoscalingPolicyCustomMetricUtilization>
Configuration parameters of autoscaling based on a custom metric.
-
#load_balancing_utilization ⇒ ::Google::Cloud::Compute::V1::AutoscalingPolicyLoadBalancingUtilization
Configuration parameters of autoscaling based on load balancer.
-
#max_num_replicas ⇒ ::Integer
The maximum number of instances that the autoscaler can scale out to.
-
#min_num_replicas ⇒ ::Integer
The minimum number of replicas that the autoscaler can scale in to.
-
#mode ⇒ ::String
Defines the operating mode for this policy.
- #scale_in_control ⇒ ::Google::Cloud::Compute::V1::AutoscalingPolicyScaleInControl
-
#scaling_schedules ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule}
Scaling schedules defined for an autoscaler.
-
#stabilization_period_sec ⇒ ::Integer
The number of seconds that autoscaler waits for load stabilization before making scale-in decisions.
Instance Attribute Details
#cool_down_period_sec ⇒ ::Integer
Returns The number of seconds that your application takes to initialize on a VM instance. This is referred to as the initialization period. Specifying an accurate initialization period improves autoscaler decisions. For example, when scaling out, the autoscaler ignores data from VMs that are still initializing because those VMs might not yet represent normal usage of your application. The default initialization period is 60 seconds.
Initialization periods might vary because of numerous factors. We recommend that you test how long your application takes to initialize. To do this, create a VM and time your application's startup process.
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |
#cpu_utilization ⇒ ::Google::Cloud::Compute::V1::AutoscalingPolicyCpuUtilization
Returns Defines the CPU utilization policy that allows the autoscaler to scale based on the average CPU utilization of a managed instance group.
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |
#custom_metric_utilizations ⇒ ::Array<::Google::Cloud::Compute::V1::AutoscalingPolicyCustomMetricUtilization>
Returns Configuration parameters of autoscaling based on a custom metric.
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |
#load_balancing_utilization ⇒ ::Google::Cloud::Compute::V1::AutoscalingPolicyLoadBalancingUtilization
Returns Configuration parameters of autoscaling based on load balancer.
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |
#max_num_replicas ⇒ ::Integer
Returns The maximum number of instances that the autoscaler can scale out to. This is required when creating or updating an autoscaler. The maximum number of replicas must not be lower than minimal number of replicas.
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |
#min_num_replicas ⇒ ::Integer
Returns The minimum number of replicas that the autoscaler can scale in to. This cannot be less than 0. If not provided, autoscaler chooses a default value depending on maximum number of instances allowed.
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |
#mode ⇒ ::String
Returns Defines the operating mode for this policy. The following modes are available:
- OFF: Disables the autoscaler but maintains its
configuration.
- ONLY_SCALE_OUT: Restricts the autoscaler to add
VM instances only.
- ON: Enables all autoscaler activities according to its
policy.
For more information, see "Turning off or restricting an autoscaler" Check the Mode enum for the list of possible values.
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |
#scale_in_control ⇒ ::Google::Cloud::Compute::V1::AutoscalingPolicyScaleInControl
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |
#scaling_schedules ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule}
Returns Scaling schedules defined for an autoscaler. Multiple schedules can be set on an autoscaler, and they can overlap. During overlapping periods the greatest min_required_replicas of all scaling schedules is applied. Up to 128 scaling schedules are allowed.
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |
#stabilization_period_sec ⇒ ::Integer
Returns The number of seconds that autoscaler waits for load stabilization before making scale-in decisions. This is referred to as the stabilization period. This might appear as a delay in scaling in but it is an important mechanism for your application to not have fluctuating size due to short term load fluctuations.
The default stabilization period is 600 seconds.
9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9413 class AutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::AutoscalingPolicyScalingSchedule] class ScalingSchedulesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the operating mode for this policy. # The following modes are available: # # - OFF: Disables the autoscaler but maintains its # configuration. # - ONLY_SCALE_OUT: Restricts the autoscaler to add # VM instances only. # - ON: Enables all autoscaler activities according to its # policy. # # # For more information, see # "Turning off or restricting an autoscaler" module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Do not automatically scale the MIG in or out. # The recommended_size field contains the size of MIG that would be set if # the actuation mode was enabled. OFF = 78_159 # Automatically scale the MIG in and out according to the policy. ON = 2527 # Automatically create VMs according to the policy, but do not scale # the MIG in. ONLY_SCALE_OUT = 152_713_670 # Automatically create VMs according to the policy, but do not scale # the MIG in. # It's recommended to use ONLY_SCALE_OUT instead of ONLY_UP. ONLY_UP = 478_095_374 end end |