Class: Google::Cloud::Compute::V1::AutoscalingPolicyCpuUtilization
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::AutoscalingPolicyCpuUtilization
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
CPU utilization policy.
Defined Under Namespace
Modules: PredictiveMethod
Instance Attribute Summary collapse
-
#predictive_method ⇒ ::String
Indicates whether predictive autoscaling based on CPU metric is enabled.
-
#utilization_target ⇒ ::Float
The target CPU utilization that the autoscaler maintains.
Instance Attribute Details
#predictive_method ⇒ ::String
Returns Indicates whether predictive autoscaling based on CPU metric is enabled. Valid values are:
- NONE (default). No predictive method is used. The autoscaler scales the group to meet current demand based on real-time metrics.
- OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by monitoring daily and weekly load patterns and scaling out ahead of anticipated demand. Check the PredictiveMethod enum for the list of possible values.
9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9400 class AutoscalingPolicyCpuUtilization include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether predictive autoscaling based on CPU metric is enabled. # Valid values are: # # * NONE (default). No predictive method is used. The autoscaler scales the # group to meet current demand based on real-time metrics. # * OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by # monitoring daily and weekly load patterns and scaling out ahead of # anticipated demand. module PredictiveMethod # A value indicating that the enum field is not set. UNDEFINED_PREDICTIVE_METHOD = 0 # No predictive method is used. The autoscaler scales the group to meet # current demand based on real-time metrics NONE = 2_402_104 # Predictive autoscaling improves availability by monitoring daily and # weekly load patterns and scaling out ahead of anticipated demand. OPTIMIZE_AVAILABILITY = 11_629_437 end end |
#utilization_target ⇒ ::Float
Returns The target CPU utilization that the autoscaler maintains. Must be a float value in the range (0, 1]. If not specified, the default is0.6.
If the CPU level is below the target utilization, the autoscaler scales in the number of instances until it reaches the minimum number of instances you specified or until the average CPU of your instances reaches the target utilization.
If the average CPU is above the target utilization, the autoscaler scales out until it reaches the maximum number of instances you specified or until the average utilization reaches the target utilization.
9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9400 class AutoscalingPolicyCpuUtilization include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether predictive autoscaling based on CPU metric is enabled. # Valid values are: # # * NONE (default). No predictive method is used. The autoscaler scales the # group to meet current demand based on real-time metrics. # * OPTIMIZE_AVAILABILITY. Predictive autoscaling improves availability by # monitoring daily and weekly load patterns and scaling out ahead of # anticipated demand. module PredictiveMethod # A value indicating that the enum field is not set. UNDEFINED_PREDICTIVE_METHOD = 0 # No predictive method is used. The autoscaler scales the group to meet # current demand based on real-time metrics NONE = 2_402_104 # Predictive autoscaling improves availability by monitoring daily and # weekly load patterns and scaling out ahead of anticipated demand. OPTIMIZE_AVAILABILITY = 11_629_437 end end |