Class: Google::Cloud::Compute::V1::Backend
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Backend
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Message containing information of one individual backend.
Defined Under Namespace
Modules: BalancingMode, Preference
Instance Attribute Summary collapse
-
#balancing_mode ⇒ ::String
Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded.
-
#capacity_scaler ⇒ ::Float
A multiplier applied to the backend's target capacity of its balancing mode.
-
#custom_metrics ⇒ ::Array<::Google::Cloud::Compute::V1::BackendCustomMetric>
List of custom metrics that are used for CUSTOM_METRICS BalancingMode.
-
#description ⇒ ::String
An optional description of this resource.
-
#failover ⇒ ::Boolean
This field designates whether this is a failover backend.
-
#group ⇒ ::String
The fully-qualified URL of an instance group or network endpoint group (NEG) resource.
-
#max_connections ⇒ ::Integer
Defines a target maximum number of simultaneous connections.
-
#max_connections_per_endpoint ⇒ ::Integer
Defines a target maximum number of simultaneous connections.
-
#max_connections_per_instance ⇒ ::Integer
Defines a target maximum number of simultaneous connections.
-
#max_rate ⇒ ::Integer
Defines a maximum number of HTTP requests per second (RPS).
-
#max_rate_per_endpoint ⇒ ::Float
Defines a maximum target for requests per second (RPS).
-
#max_rate_per_instance ⇒ ::Float
Defines a maximum target for requests per second (RPS).
-
#max_utilization ⇒ ::Float
Optional parameter to define a target capacity for the UTILIZATION balancing mode.
-
#preference ⇒ ::String
This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference.
Instance Attribute Details
#balancing_mode ⇒ ::String
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#capacity_scaler ⇒ ::Float
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#custom_metrics ⇒ ::Array<::Google::Cloud::Compute::V1::BackendCustomMetric>
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#description ⇒ ::String
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#failover ⇒ ::Boolean
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#group ⇒ ::String
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#max_connections ⇒ ::Integer
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#max_connections_per_endpoint ⇒ ::Integer
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#max_connections_per_instance ⇒ ::Integer
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#max_rate ⇒ ::Integer
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#max_rate_per_endpoint ⇒ ::Float
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#max_rate_per_instance ⇒ ::Float
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#max_utilization ⇒ ::Float
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |
#preference ⇒ ::String
3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3485 class Backend include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded. For usage guidelines, see Connection balancing mode. Backends must use compatible balancing modes. For more information, see Supported balancing modes and target capacity settings and Restrictions and guidance for instance groups. Note: Currently, if you use the API to configure incompatible balancing modes, the configuration might be accepted even though it has no impact and is ignored. Specifically, Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the future, this incompatible combination will be rejected. module BalancingMode # A value indicating that the enum field is not set. UNDEFINED_BALANCING_MODE = 0 # Balance based on the number of simultaneous connections. CONNECTION = 246_311_646 # Based on custom defined and reported metrics. CUSTOM_METRICS = 331_575_765 # Balance based on requests per second (RPS). RATE = 2_508_000 # Balance based on the backend utilization. UTILIZATION = 157_008_386 end # This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference. The possible values are: - PREFERRED: Backends with this preference level will be filled up to their capacity limits first, based on RTT. - DEFAULT: If preferred backends don't have enough capacity, backends in this layer would be used and traffic would be assigned based on the load balancing algorithm you use. This is the default module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # No preference. DEFAULT = 115_302_945 # If preference is unspecified, we set it to the DEFAULT value PREFERENCE_UNSPECIFIED = 496_219_571 # Traffic will be sent to this backend first. PREFERRED = 418_847_841 end end |