Module: Google::Cloud::Compute::V1::Backend::TrafficDuration
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Constant Summary collapse
- UNDEFINED_TRAFFIC_DURATION =
A value indicating that the enum field is not set.
0- LONG =
Most of the requests are expected to take more than multiple seconds to finish.
2_342_524- SHORT =
Most requests are expected to finish with a sub-second latency.
78_875_740- TRAFFIC_DURATION_UNSPECIFIED =
Traffic duration is unspecified.
265_201_166