Class: Google::Cloud::Compute::V1::BackendBackendOrchestrationInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendBackendOrchestrationInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A message containing information about the resource or system that manages the backend.
Instance Attribute Summary collapse
-
#resource_uri ⇒ ::String
The URI of the resource or system that manages the backend.
Instance Attribute Details
#resource_uri ⇒ ::String
Returns The URI of the resource or system that manages the backend.
9700 9701 9702 9703 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9700 class BackendBackendOrchestrationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |