Class: Google::Cloud::Compute::V1::BackendBucket

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Cloud Storage Bucket resource.

This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, readBackend Buckets.

Defined Under Namespace

Modules: CompressionMode, LoadBalancingScheme

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_name::String

Returns Cloud Storage bucket name.

Returns:

  • (::String)

    Cloud Storage bucket name.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#cdn_policy::Google::Cloud::Compute::V1::BackendBucketCdnPolicy

Returns Cloud CDN configuration for this BackendBucket.

Returns:



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#compression_mode::String

Returns Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header. Check the CompressionMode enum for the list of possible values.

Returns:

  • (::String)

    Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header. Check the CompressionMode enum for the list of possible values.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#creation_timestamp::String

Returns [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    [Output Only] Creation timestamp inRFC3339 text format.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#custom_response_headers::Array<::String>

Returns Headers that the Application Load Balancer should add to proxied responses.

Returns:

  • (::Array<::String>)

    Headers that the Application Load Balancer should add to proxied responses.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#description::String

Returns An optional textual description of the resource; provided by the client when the resource is created.

Returns:

  • (::String)

    An optional textual description of the resource; provided by the client when the resource is created.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#edge_security_policy::String

Returns [Output Only] The resource URL for the edge security policy associated with this backend bucket.

Returns:

  • (::String)

    [Output Only] The resource URL for the edge security policy associated with this backend bucket.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#enable_cdn::Boolean

Returns If true, enable Cloud CDN for this BackendBucket.

Returns:

  • (::Boolean)

    If true, enable Cloud CDN for this BackendBucket.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#id::Integer

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::Integer)

    [Output Only] Unique identifier for the resource; defined by the server.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#kind::String

Returns Output only. Type of the resource.

Returns:

  • (::String)

    Output only. Type of the resource.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#load_balancing_scheme::String

Returns The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer.

If loadBalancingScheme is not specified, the backend bucket can be used by classic global external load balancers, or global application external load balancers, or both. Check the LoadBalancingScheme enum for the list of possible values.

Returns:

  • (::String)

    The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer.

    If loadBalancingScheme is not specified, the backend bucket can be used by classic global external load balancers, or global application external load balancers, or both. Check the LoadBalancingScheme enum for the list of possible values.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#name::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#params::Google::Cloud::Compute::V1::BackendBucketParams

Returns Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.

Returns:



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#region::String

Returns Output only. [Output Only] URL of the region where the regional backend bucket resides. This field is not applicable to global backend buckets. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Returns:

  • (::String)

    Output only. [Output Only] URL of the region where the regional backend bucket resides. This field is not applicable to global backend buckets. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for the resource.



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end

#used_by::Array<::Google::Cloud::Compute::V1::BackendBucketUsedBy>

Returns Output only. [Output Only] List of resources referencing that backend bucket.

Returns:



9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
9800
9801
9802
9803
9804
9805
9806
9807
9808
9809
9810
9811
9812
9813
9814
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 9778

class BackendBucket
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compress text responses using Brotli or gzip compression, based on
  # the client's Accept-Encoding header.
  module CompressionMode
    # A value indicating that the enum field is not set.
    UNDEFINED_COMPRESSION_MODE = 0

    # Automatically uses the best compression based on the Accept-Encoding
    # header sent by the client.
    AUTOMATIC = 165_298_699

    # Disables compression. Existing compressed responses cached by
    # Cloud CDN will not be served to clients.
    DISABLED = 516_696_700
  end

  # The value can only be INTERNAL_MANAGED for cross-region internal layer 7
  # load balancer.
  #
  # If loadBalancingScheme is not specified, the backend bucket can be used by
  # classic global external load balancers, or global application external load
  # balancers, or both.
  module LoadBalancingScheme
    # A value indicating that the enum field is not set.
    UNDEFINED_LOAD_BALANCING_SCHEME = 0

    # Signifies that this will be used for regional external Application Load
    # Balancers.
    EXTERNAL_MANAGED = 512_006_923

    # Signifies that this will be used for internal Application Load Balancers.
    INTERNAL_MANAGED = 37_350_397
  end
end