Class: Google::Cloud::Compute::V1::BackendServiceConnectionTrackingPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceConnectionTrackingPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Connection Tracking configuration for this BackendService.
Defined Under Namespace
Modules: ConnectionPersistenceOnUnhealthyBackends, TrackingMode
Instance Attribute Summary collapse
-
#connection_persistence_on_unhealthy_backends ⇒ ::String
Specifies connection persistence when backends are unhealthy.
-
#enable_strong_affinity ⇒ ::Boolean
Enable Strong Session Affinity for external passthrough Network Load Balancers.
-
#idle_timeout_sec ⇒ ::Integer
Specifies how long to keep a Connection Tracking entry while there is no matching traffic (in seconds).
-
#tracking_mode ⇒ ::String
Specifies the key used for connection tracking.
Instance Attribute Details
#connection_persistence_on_unhealthy_backends ⇒ ::String
Returns Specifies connection persistence when backends are unhealthy. The default value is DEFAULT_FOR_PROTOCOL.
If set to DEFAULT_FOR_PROTOCOL, the existing connections persist on unhealthy backends only for connection-oriented protocols (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session Affinity is configured for 5-tuple. They do not persist forUDP.
If set to NEVER_PERSIST, after a backend becomes unhealthy, the existing connections on the unhealthy backend are never persisted on the unhealthy backend. They are always diverted to newly selected healthy backends (unless all backends are unhealthy).
If set to ALWAYS_PERSIST, existing connections always persist on unhealthy backends regardless of protocol and session affinity. It is generally not recommended to use this mode overriding the default.
For more details, see Connection Persistence for Network Load Balancing and Connection Persistence for Internal TCP/UDP Load Balancing. Check the ConnectionPersistenceOnUnhealthyBackends enum for the list of possible values.
11500 11501 11502 11503 11504 11505 11506 11507 11508 11509 11510 11511 11512 11513 11514 11515 11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 11526 11527 11528 11529 11530 11531 11532 11533 11534 11535 11536 11537 11538 11539 11540 11541 11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 11552 11553 11554 11555 11556 11557 11558 11559 11560 11561 11562 11563 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11500 class BackendServiceConnectionTrackingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies connection persistence when backends are unhealthy. The default # value is DEFAULT_FOR_PROTOCOL. # # If set to DEFAULT_FOR_PROTOCOL, the existing connections # persist on unhealthy backends only for connection-oriented protocols # (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session # Affinity is configured for 5-tuple. They do not persist forUDP. # # If set to NEVER_PERSIST, after a backend becomes unhealthy, # the existing connections on the unhealthy backend are never persisted on # the unhealthy backend. They are always diverted to newly selected healthy # backends (unless all backends are unhealthy). # # If set to ALWAYS_PERSIST, existing connections always # persist on unhealthy backends regardless of protocol and session # affinity. It is generally not recommended to use this mode overriding the # default. # # For more details, see [Connection Persistence for Network Load # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence) # and [Connection Persistence for Internal TCP/UDP Load # Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence). module ConnectionPersistenceOnUnhealthyBackends # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS = 0 ALWAYS_PERSIST = 38_400_900 DEFAULT_FOR_PROTOCOL = 145_265_356 NEVER_PERSIST = 138_646_241 end # Specifies the key used for connection tracking. There are two # options: # # - PER_CONNECTION: This is the default mode. The Connection # Tracking is performed as per the Connection Key (default Hash Method) for # the specific protocol. # - PER_SESSION: The Connection Tracking is performed as per # the configured Session Affinity. It matches the configured Session # Affinity. # # # # For more details, see [Tracking Mode for Network Load # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode) # and [Tracking Mode for Internal TCP/UDP Load # Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode). module TrackingMode # A value indicating that the enum field is not set. UNDEFINED_TRACKING_MODE = 0 INVALID_TRACKING_MODE = 49_234_371 PER_CONNECTION = 85_162_848 PER_SESSION = 182_099_252 end end |
#enable_strong_affinity ⇒ ::Boolean
Returns Enable Strong Session Affinity for external passthrough Network Load Balancers. This option is not available publicly.
11500 11501 11502 11503 11504 11505 11506 11507 11508 11509 11510 11511 11512 11513 11514 11515 11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 11526 11527 11528 11529 11530 11531 11532 11533 11534 11535 11536 11537 11538 11539 11540 11541 11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 11552 11553 11554 11555 11556 11557 11558 11559 11560 11561 11562 11563 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11500 class BackendServiceConnectionTrackingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies connection persistence when backends are unhealthy. The default # value is DEFAULT_FOR_PROTOCOL. # # If set to DEFAULT_FOR_PROTOCOL, the existing connections # persist on unhealthy backends only for connection-oriented protocols # (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session # Affinity is configured for 5-tuple. They do not persist forUDP. # # If set to NEVER_PERSIST, after a backend becomes unhealthy, # the existing connections on the unhealthy backend are never persisted on # the unhealthy backend. They are always diverted to newly selected healthy # backends (unless all backends are unhealthy). # # If set to ALWAYS_PERSIST, existing connections always # persist on unhealthy backends regardless of protocol and session # affinity. It is generally not recommended to use this mode overriding the # default. # # For more details, see [Connection Persistence for Network Load # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence) # and [Connection Persistence for Internal TCP/UDP Load # Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence). module ConnectionPersistenceOnUnhealthyBackends # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS = 0 ALWAYS_PERSIST = 38_400_900 DEFAULT_FOR_PROTOCOL = 145_265_356 NEVER_PERSIST = 138_646_241 end # Specifies the key used for connection tracking. There are two # options: # # - PER_CONNECTION: This is the default mode. The Connection # Tracking is performed as per the Connection Key (default Hash Method) for # the specific protocol. # - PER_SESSION: The Connection Tracking is performed as per # the configured Session Affinity. It matches the configured Session # Affinity. # # # # For more details, see [Tracking Mode for Network Load # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode) # and [Tracking Mode for Internal TCP/UDP Load # Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode). module TrackingMode # A value indicating that the enum field is not set. UNDEFINED_TRACKING_MODE = 0 INVALID_TRACKING_MODE = 49_234_371 PER_CONNECTION = 85_162_848 PER_SESSION = 182_099_252 end end |
#idle_timeout_sec ⇒ ::Integer
Returns Specifies how long to keep a Connection Tracking entry while there is no matching traffic (in seconds).
For internal passthrough Network Load Balancers:
- The minimum (default) is 10 minutes and the maximum is 16 hours.
- It can be set only if Connection Tracking is less than 5-tuple (i.e. Session Affinity is CLIENT_IP_NO_DESTINATION,CLIENT_IP or CLIENT_IP_PROTO, and Tracking Mode is PER_SESSION).
For external passthrough Network Load Balancers the default is 60 seconds. This option is not available publicly.
11500 11501 11502 11503 11504 11505 11506 11507 11508 11509 11510 11511 11512 11513 11514 11515 11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 11526 11527 11528 11529 11530 11531 11532 11533 11534 11535 11536 11537 11538 11539 11540 11541 11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 11552 11553 11554 11555 11556 11557 11558 11559 11560 11561 11562 11563 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11500 class BackendServiceConnectionTrackingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies connection persistence when backends are unhealthy. The default # value is DEFAULT_FOR_PROTOCOL. # # If set to DEFAULT_FOR_PROTOCOL, the existing connections # persist on unhealthy backends only for connection-oriented protocols # (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session # Affinity is configured for 5-tuple. They do not persist forUDP. # # If set to NEVER_PERSIST, after a backend becomes unhealthy, # the existing connections on the unhealthy backend are never persisted on # the unhealthy backend. They are always diverted to newly selected healthy # backends (unless all backends are unhealthy). # # If set to ALWAYS_PERSIST, existing connections always # persist on unhealthy backends regardless of protocol and session # affinity. It is generally not recommended to use this mode overriding the # default. # # For more details, see [Connection Persistence for Network Load # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence) # and [Connection Persistence for Internal TCP/UDP Load # Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence). module ConnectionPersistenceOnUnhealthyBackends # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS = 0 ALWAYS_PERSIST = 38_400_900 DEFAULT_FOR_PROTOCOL = 145_265_356 NEVER_PERSIST = 138_646_241 end # Specifies the key used for connection tracking. There are two # options: # # - PER_CONNECTION: This is the default mode. The Connection # Tracking is performed as per the Connection Key (default Hash Method) for # the specific protocol. # - PER_SESSION: The Connection Tracking is performed as per # the configured Session Affinity. It matches the configured Session # Affinity. # # # # For more details, see [Tracking Mode for Network Load # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode) # and [Tracking Mode for Internal TCP/UDP Load # Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode). module TrackingMode # A value indicating that the enum field is not set. UNDEFINED_TRACKING_MODE = 0 INVALID_TRACKING_MODE = 49_234_371 PER_CONNECTION = 85_162_848 PER_SESSION = 182_099_252 end end |
#tracking_mode ⇒ ::String
Returns Specifies the key used for connection tracking. There are two options:
- PER_CONNECTION: This is the default mode. The Connection Tracking is performed as per the Connection Key (default Hash Method) for the specific protocol.
- PER_SESSION: The Connection Tracking is performed as per the configured Session Affinity. It matches the configured Session Affinity.
For more details, see Tracking Mode for Network Load Balancing and Tracking Mode for Internal TCP/UDP Load Balancing. Check the TrackingMode enum for the list of possible values.
11500 11501 11502 11503 11504 11505 11506 11507 11508 11509 11510 11511 11512 11513 11514 11515 11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 11526 11527 11528 11529 11530 11531 11532 11533 11534 11535 11536 11537 11538 11539 11540 11541 11542 11543 11544 11545 11546 11547 11548 11549 11550 11551 11552 11553 11554 11555 11556 11557 11558 11559 11560 11561 11562 11563 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11500 class BackendServiceConnectionTrackingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies connection persistence when backends are unhealthy. The default # value is DEFAULT_FOR_PROTOCOL. # # If set to DEFAULT_FOR_PROTOCOL, the existing connections # persist on unhealthy backends only for connection-oriented protocols # (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session # Affinity is configured for 5-tuple. They do not persist forUDP. # # If set to NEVER_PERSIST, after a backend becomes unhealthy, # the existing connections on the unhealthy backend are never persisted on # the unhealthy backend. They are always diverted to newly selected healthy # backends (unless all backends are unhealthy). # # If set to ALWAYS_PERSIST, existing connections always # persist on unhealthy backends regardless of protocol and session # affinity. It is generally not recommended to use this mode overriding the # default. # # For more details, see [Connection Persistence for Network Load # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence) # and [Connection Persistence for Internal TCP/UDP Load # Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence). module ConnectionPersistenceOnUnhealthyBackends # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS = 0 ALWAYS_PERSIST = 38_400_900 DEFAULT_FOR_PROTOCOL = 145_265_356 NEVER_PERSIST = 138_646_241 end # Specifies the key used for connection tracking. There are two # options: # # - PER_CONNECTION: This is the default mode. The Connection # Tracking is performed as per the Connection Key (default Hash Method) for # the specific protocol. # - PER_SESSION: The Connection Tracking is performed as per # the configured Session Affinity. It matches the configured Session # Affinity. # # # # For more details, see [Tracking Mode for Network Load # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode) # and [Tracking Mode for Internal TCP/UDP Load # Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode). module TrackingMode # A value indicating that the enum field is not set. UNDEFINED_TRACKING_MODE = 0 INVALID_TRACKING_MODE = 49_234_371 PER_CONNECTION = 85_162_848 PER_SESSION = 182_099_252 end end |