Class: Google::Cloud::Compute::V1::BackendServiceConnectionTrackingPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Connection Tracking configuration for this BackendService.

Defined Under Namespace

Modules: ConnectionPersistenceOnUnhealthyBackends, TrackingMode

Instance Attribute Summary collapse

Instance Attribute Details

#connection_persistence_on_unhealthy_backends::String

Returns Specifies connection persistence when backends are unhealthy. The default value is DEFAULT_FOR_PROTOCOL.

If set to DEFAULT_FOR_PROTOCOL, the existing connections persist on unhealthy backends only for connection-oriented protocols (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session Affinity is configured for 5-tuple. They do not persist forUDP.

If set to NEVER_PERSIST, after a backend becomes unhealthy, the existing connections on the unhealthy backend are never persisted on the unhealthy backend. They are always diverted to newly selected healthy backends (unless all backends are unhealthy).

If set to ALWAYS_PERSIST, existing connections always persist on unhealthy backends regardless of protocol and session affinity. It is generally not recommended to use this mode overriding the default.

For more details, see Connection Persistence for Network Load Balancing and Connection Persistence for Internal TCP/UDP Load Balancing. Check the ConnectionPersistenceOnUnhealthyBackends enum for the list of possible values.

Returns:

  • (::String)

    Specifies connection persistence when backends are unhealthy. The default value is DEFAULT_FOR_PROTOCOL.

    If set to DEFAULT_FOR_PROTOCOL, the existing connections persist on unhealthy backends only for connection-oriented protocols (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session Affinity is configured for 5-tuple. They do not persist forUDP.

    If set to NEVER_PERSIST, after a backend becomes unhealthy, the existing connections on the unhealthy backend are never persisted on the unhealthy backend. They are always diverted to newly selected healthy backends (unless all backends are unhealthy).

    If set to ALWAYS_PERSIST, existing connections always persist on unhealthy backends regardless of protocol and session affinity. It is generally not recommended to use this mode overriding the default.

    For more details, see Connection Persistence for Network Load Balancing and Connection Persistence for Internal TCP/UDP Load Balancing. Check the ConnectionPersistenceOnUnhealthyBackends enum for the list of possible values.



11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
11390
11391
11392
11393
11394
11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
11418
11419
11420
11421
11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11375

class BackendServiceConnectionTrackingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies connection persistence when backends are unhealthy. The default
  # value is DEFAULT_FOR_PROTOCOL.
  #
  # If set to DEFAULT_FOR_PROTOCOL, the existing connections
  # persist on unhealthy backends only for connection-oriented protocols
  # (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session
  # Affinity is configured for 5-tuple. They do not persist forUDP.
  #
  # If set to NEVER_PERSIST, after a backend becomes unhealthy,
  # the existing connections on the unhealthy backend are never persisted on
  # the unhealthy backend. They are always diverted to newly selected healthy
  # backends (unless all backends are unhealthy).
  #
  # If set to ALWAYS_PERSIST, existing connections always
  # persist on unhealthy backends regardless of protocol and session
  # affinity. It is generally not recommended to use this mode overriding the
  # default.
  #
  # For more details, see [Connection Persistence for Network Load
  # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence)
  # and [Connection Persistence for Internal TCP/UDP Load
  # Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence).
  module ConnectionPersistenceOnUnhealthyBackends
    # A value indicating that the enum field is not set.
    UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS = 0

    ALWAYS_PERSIST = 38_400_900

    DEFAULT_FOR_PROTOCOL = 145_265_356

    NEVER_PERSIST = 138_646_241
  end

  # Specifies the key used for connection tracking. There are two
  # options:
  #
  #    - PER_CONNECTION: This is the default mode. The Connection
  #    Tracking is performed as per the Connection Key (default Hash Method) for
  #    the specific protocol.
  #    - PER_SESSION: The Connection Tracking is performed as per
  #    the configured Session Affinity. It matches the configured Session
  #    Affinity.
  #
  #
  #
  # For more details, see [Tracking Mode for Network Load
  # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode)
  # and [Tracking Mode for Internal TCP/UDP Load
  # Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode).
  module TrackingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_TRACKING_MODE = 0

    INVALID_TRACKING_MODE = 49_234_371

    PER_CONNECTION = 85_162_848

    PER_SESSION = 182_099_252
  end
end

#enable_strong_affinity::Boolean

Returns Enable Strong Session Affinity for external passthrough Network Load Balancers. This option is not available publicly.

Returns:

  • (::Boolean)

    Enable Strong Session Affinity for external passthrough Network Load Balancers. This option is not available publicly.



11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
11390
11391
11392
11393
11394
11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
11418
11419
11420
11421
11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11375

class BackendServiceConnectionTrackingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies connection persistence when backends are unhealthy. The default
  # value is DEFAULT_FOR_PROTOCOL.
  #
  # If set to DEFAULT_FOR_PROTOCOL, the existing connections
  # persist on unhealthy backends only for connection-oriented protocols
  # (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session
  # Affinity is configured for 5-tuple. They do not persist forUDP.
  #
  # If set to NEVER_PERSIST, after a backend becomes unhealthy,
  # the existing connections on the unhealthy backend are never persisted on
  # the unhealthy backend. They are always diverted to newly selected healthy
  # backends (unless all backends are unhealthy).
  #
  # If set to ALWAYS_PERSIST, existing connections always
  # persist on unhealthy backends regardless of protocol and session
  # affinity. It is generally not recommended to use this mode overriding the
  # default.
  #
  # For more details, see [Connection Persistence for Network Load
  # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence)
  # and [Connection Persistence for Internal TCP/UDP Load
  # Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence).
  module ConnectionPersistenceOnUnhealthyBackends
    # A value indicating that the enum field is not set.
    UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS = 0

    ALWAYS_PERSIST = 38_400_900

    DEFAULT_FOR_PROTOCOL = 145_265_356

    NEVER_PERSIST = 138_646_241
  end

  # Specifies the key used for connection tracking. There are two
  # options:
  #
  #    - PER_CONNECTION: This is the default mode. The Connection
  #    Tracking is performed as per the Connection Key (default Hash Method) for
  #    the specific protocol.
  #    - PER_SESSION: The Connection Tracking is performed as per
  #    the configured Session Affinity. It matches the configured Session
  #    Affinity.
  #
  #
  #
  # For more details, see [Tracking Mode for Network Load
  # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode)
  # and [Tracking Mode for Internal TCP/UDP Load
  # Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode).
  module TrackingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_TRACKING_MODE = 0

    INVALID_TRACKING_MODE = 49_234_371

    PER_CONNECTION = 85_162_848

    PER_SESSION = 182_099_252
  end
end

#idle_timeout_sec::Integer

Returns Specifies how long to keep a Connection Tracking entry while there is no matching traffic (in seconds).

For internal passthrough Network Load Balancers:

  • The minimum (default) is 10 minutes and the maximum is 16 hours.
  • It can be set only if Connection Tracking is less than 5-tuple (i.e. Session Affinity is CLIENT_IP_NO_DESTINATION,CLIENT_IP or CLIENT_IP_PROTO, and Tracking Mode is PER_SESSION).

For external passthrough Network Load Balancers the default is 60 seconds. This option is not available publicly.

Returns:

  • (::Integer)

    Specifies how long to keep a Connection Tracking entry while there is no matching traffic (in seconds).

    For internal passthrough Network Load Balancers:

    • The minimum (default) is 10 minutes and the maximum is 16 hours.
    • It can be set only if Connection Tracking is less than 5-tuple (i.e. Session Affinity is CLIENT_IP_NO_DESTINATION,CLIENT_IP or CLIENT_IP_PROTO, and Tracking Mode is PER_SESSION).

    For external passthrough Network Load Balancers the default is 60 seconds. This option is not available publicly.



11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
11390
11391
11392
11393
11394
11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
11418
11419
11420
11421
11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11375

class BackendServiceConnectionTrackingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies connection persistence when backends are unhealthy. The default
  # value is DEFAULT_FOR_PROTOCOL.
  #
  # If set to DEFAULT_FOR_PROTOCOL, the existing connections
  # persist on unhealthy backends only for connection-oriented protocols
  # (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session
  # Affinity is configured for 5-tuple. They do not persist forUDP.
  #
  # If set to NEVER_PERSIST, after a backend becomes unhealthy,
  # the existing connections on the unhealthy backend are never persisted on
  # the unhealthy backend. They are always diverted to newly selected healthy
  # backends (unless all backends are unhealthy).
  #
  # If set to ALWAYS_PERSIST, existing connections always
  # persist on unhealthy backends regardless of protocol and session
  # affinity. It is generally not recommended to use this mode overriding the
  # default.
  #
  # For more details, see [Connection Persistence for Network Load
  # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence)
  # and [Connection Persistence for Internal TCP/UDP Load
  # Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence).
  module ConnectionPersistenceOnUnhealthyBackends
    # A value indicating that the enum field is not set.
    UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS = 0

    ALWAYS_PERSIST = 38_400_900

    DEFAULT_FOR_PROTOCOL = 145_265_356

    NEVER_PERSIST = 138_646_241
  end

  # Specifies the key used for connection tracking. There are two
  # options:
  #
  #    - PER_CONNECTION: This is the default mode. The Connection
  #    Tracking is performed as per the Connection Key (default Hash Method) for
  #    the specific protocol.
  #    - PER_SESSION: The Connection Tracking is performed as per
  #    the configured Session Affinity. It matches the configured Session
  #    Affinity.
  #
  #
  #
  # For more details, see [Tracking Mode for Network Load
  # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode)
  # and [Tracking Mode for Internal TCP/UDP Load
  # Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode).
  module TrackingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_TRACKING_MODE = 0

    INVALID_TRACKING_MODE = 49_234_371

    PER_CONNECTION = 85_162_848

    PER_SESSION = 182_099_252
  end
end

#tracking_mode::String

Returns Specifies the key used for connection tracking. There are two options:

  • PER_CONNECTION: This is the default mode. The Connection Tracking is performed as per the Connection Key (default Hash Method) for the specific protocol.
  • PER_SESSION: The Connection Tracking is performed as per the configured Session Affinity. It matches the configured Session Affinity.

For more details, see Tracking Mode for Network Load Balancing and Tracking Mode for Internal TCP/UDP Load Balancing. Check the TrackingMode enum for the list of possible values.

Returns:

  • (::String)

    Specifies the key used for connection tracking. There are two options:

    • PER_CONNECTION: This is the default mode. The Connection Tracking is performed as per the Connection Key (default Hash Method) for the specific protocol.
    • PER_SESSION: The Connection Tracking is performed as per the configured Session Affinity. It matches the configured Session Affinity.

    For more details, see Tracking Mode for Network Load Balancing and Tracking Mode for Internal TCP/UDP Load Balancing. Check the TrackingMode enum for the list of possible values.



11375
11376
11377
11378
11379
11380
11381
11382
11383
11384
11385
11386
11387
11388
11389
11390
11391
11392
11393
11394
11395
11396
11397
11398
11399
11400
11401
11402
11403
11404
11405
11406
11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
11418
11419
11420
11421
11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11375

class BackendServiceConnectionTrackingPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies connection persistence when backends are unhealthy. The default
  # value is DEFAULT_FOR_PROTOCOL.
  #
  # If set to DEFAULT_FOR_PROTOCOL, the existing connections
  # persist on unhealthy backends only for connection-oriented protocols
  # (TCP and SCTP) and only if the Tracking Mode isPER_CONNECTION (default tracking mode) or the Session
  # Affinity is configured for 5-tuple. They do not persist forUDP.
  #
  # If set to NEVER_PERSIST, after a backend becomes unhealthy,
  # the existing connections on the unhealthy backend are never persisted on
  # the unhealthy backend. They are always diverted to newly selected healthy
  # backends (unless all backends are unhealthy).
  #
  # If set to ALWAYS_PERSIST, existing connections always
  # persist on unhealthy backends regardless of protocol and session
  # affinity. It is generally not recommended to use this mode overriding the
  # default.
  #
  # For more details, see [Connection Persistence for Network Load
  # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence)
  # and [Connection Persistence for Internal TCP/UDP Load
  # Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence).
  module ConnectionPersistenceOnUnhealthyBackends
    # A value indicating that the enum field is not set.
    UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS = 0

    ALWAYS_PERSIST = 38_400_900

    DEFAULT_FOR_PROTOCOL = 145_265_356

    NEVER_PERSIST = 138_646_241
  end

  # Specifies the key used for connection tracking. There are two
  # options:
  #
  #    - PER_CONNECTION: This is the default mode. The Connection
  #    Tracking is performed as per the Connection Key (default Hash Method) for
  #    the specific protocol.
  #    - PER_SESSION: The Connection Tracking is performed as per
  #    the configured Session Affinity. It matches the configured Session
  #    Affinity.
  #
  #
  #
  # For more details, see [Tracking Mode for Network Load
  # Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode)
  # and [Tracking Mode for Internal TCP/UDP Load
  # Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode).
  module TrackingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_TRACKING_MODE = 0

    INVALID_TRACKING_MODE = 49_234_371

    PER_CONNECTION = 85_162_848

    PER_SESSION = 182_099_252
  end
end