Class: Google::Cloud::Compute::V1::BackendServiceGroupHealth
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceGroupHealth
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: AnnotationsEntry
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Metadata defined as annotations on the network endpoint group.
-
#health_status ⇒ ::Array<::Google::Cloud::Compute::V1::HealthStatus>
Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.
-
#kind ⇒ ::String
Output only.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Metadata defined as annotations on the network endpoint group.
11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11649 class BackendServiceGroupHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#health_status ⇒ ::Array<::Google::Cloud::Compute::V1::HealthStatus>
Returns Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.
11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11649 class BackendServiceGroupHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Alwayscompute#backendServiceGroupHealth for the health of backend services.
11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11649 class BackendServiceGroupHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |