Class: Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The configuration for a built-in load balancing policy.
Defined Under Namespace
Modules: Name
Instance Attribute Summary collapse
-
#name ⇒ ::String
The name of a locality load-balancing policy.
Instance Attribute Details
#name ⇒ ::String
Returns The name of a locality load-balancing policy. Valid values include ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about these values, see the description of localityLbPolicy.
Do not specify the same policy more than once for a backend. If you do, the configuration is rejected. Check the Name enum for the list of possible values.
12042 12043 12044 12045 12046 12047 12048 12049 12050 12051 12052 12053 12054 12055 12056 12057 12058 12059 12060 12061 12062 12063 12064 12065 12066 12067 12068 12069 12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 12086 12087 12088 12089 12090 12091 12092 12093 12094 12095 12096 12097 12098 12099 12100 12101 12102 12103 12104 12105 12106 12107 12108 12109 12110 12111 12112 12113 12114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12042 class BackendServiceLocalityLoadBalancingPolicyConfigPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The name of a locality load-balancing policy. Valid values include # ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information # about these values, see the description of localityLbPolicy. # # Do not specify the same policy more than once for a # backend. If you do, the configuration is rejected. module Name # A value indicating that the enum field is not set. UNDEFINED_NAME = 0 INVALID_LB_POLICY = 323_318_707 # An O(1) algorithm which selects two random healthy hosts and # picks the host which has fewer active requests. LEAST_REQUEST = 46_604_921 # This algorithm implements consistent hashing to backends. Maglev can be # used as a drop in replacement for the ring hash load balancer. Maglev is # not as stable as ring hash but has faster table lookup build times and # host selection times. For more information about Maglev, seeMaglev: # A Fast and Reliable Software Network Load Balancer. MAGLEV = 119_180_266 # Backend host is selected based on the client connection metadata, i.e., # connections are opened to the same address as the destination address of # the incoming connection before the connection was redirected to the load # balancer. ORIGINAL_DESTINATION = 166_297_216 # The load balancer selects a random healthy host. RANDOM = 262_527_171 # The ring/modulo hash load balancer implements consistent hashing to # backends. The algorithm has the property that the addition/removal # of a host from a set of N hosts only affects 1/N of the requests. RING_HASH = 432_795_069 # This is a simple policy in which each healthy backend is selected # in round robin order. This is the default. ROUND_ROBIN = 153_895_801 # Per-instance weighted Load Balancing via health check reported weights. # In internal passthrough network load balancing, it is weighted # rendezvous hashing. # This option is only supported in internal passthrough network load # balancing. WEIGHTED_GCP_RENDEZVOUS = 82_501_640 # Per-instance weighted Load Balancing via health check reported weights. # If set, the Backend Service must configure a non legacy HTTP-based Health # Check, and health check replies are expected to contain non-standard HTTP # response header field X-Load-Balancing-Endpoint-Weight to specify the # per-instance weights. # If set, Load Balancing is weighted based on the # per-instance weights reported in the last processed health check replies, # as long as every instance either reported a valid weight or had # UNAVAILABLE_WEIGHT. Otherwise, Load Balancing remains equal-weight. # This option is only supported in Network Load Balancing. WEIGHTED_MAGLEV = 254_930_962 # Per-endpoint weighted round-robin Load Balancing using weights computed # from Backend reported Custom Metrics. If set, the Backend Service # responses are expected to contain non-standard HTTP response header field # Endpoint-Load-Metrics. The reported metrics # to use for computing the weights are specified via the # customMetrics fields. WEIGHTED_ROUND_ROBIN = 5_584_977 end end |