Class: Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The configuration for a built-in load balancing policy.
Defined Under Namespace
Modules: Name
Instance Attribute Summary collapse
-
#name ⇒ ::String
The name of a locality load-balancing policy.
Instance Attribute Details
#name ⇒ ::String
Returns The name of a locality load-balancing policy. Valid values include ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about these values, see the description of localityLbPolicy.
Do not specify the same policy more than once for a backend. If you do, the configuration is rejected. Check the Name enum for the list of possible values.
11894 11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 11906 11907 11908 11909 11910 11911 11912 11913 11914 11915 11916 11917 11918 11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 11931 11932 11933 11934 11935 11936 11937 11938 11939 11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 11962 11963 11964 11965 11966 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11894 class BackendServiceLocalityLoadBalancingPolicyConfigPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The name of a locality load-balancing policy. Valid values include # ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information # about these values, see the description of localityLbPolicy. # # Do not specify the same policy more than once for a # backend. If you do, the configuration is rejected. module Name # A value indicating that the enum field is not set. UNDEFINED_NAME = 0 INVALID_LB_POLICY = 323_318_707 # An O(1) algorithm which selects two random healthy hosts and # picks the host which has fewer active requests. LEAST_REQUEST = 46_604_921 # This algorithm implements consistent hashing to backends. Maglev can be # used as a drop in replacement for the ring hash load balancer. Maglev is # not as stable as ring hash but has faster table lookup build times and # host selection times. For more information about Maglev, seeMaglev: # A Fast and Reliable Software Network Load Balancer. MAGLEV = 119_180_266 # Backend host is selected based on the client connection metadata, i.e., # connections are opened to the same address as the destination address of # the incoming connection before the connection was redirected to the load # balancer. ORIGINAL_DESTINATION = 166_297_216 # The load balancer selects a random healthy host. RANDOM = 262_527_171 # The ring/modulo hash load balancer implements consistent hashing to # backends. The algorithm has the property that the addition/removal # of a host from a set of N hosts only affects 1/N of the requests. RING_HASH = 432_795_069 # This is a simple policy in which each healthy backend is selected # in round robin order. This is the default. ROUND_ROBIN = 153_895_801 # Per-instance weighted Load Balancing via health check reported weights. # In internal passthrough network load balancing, it is weighted # rendezvous hashing. # This option is only supported in internal passthrough network load # balancing. WEIGHTED_GCP_RENDEZVOUS = 82_501_640 # Per-instance weighted Load Balancing via health check reported weights. # If set, the Backend Service must configure a non legacy HTTP-based Health # Check, and health check replies are expected to contain non-standard HTTP # response header field X-Load-Balancing-Endpoint-Weight to specify the # per-instance weights. # If set, Load Balancing is weighted based on the # per-instance weights reported in the last processed health check replies, # as long as every instance either reported a valid weight or had # UNAVAILABLE_WEIGHT. Otherwise, Load Balancing remains equal-weight. # This option is only supported in Network Load Balancing. WEIGHTED_MAGLEV = 254_930_962 # Per-endpoint weighted round-robin Load Balancing using weights computed # from Backend reported Custom Metrics. If set, the Backend Service # responses are expected to contain non-standard HTTP response header field # Endpoint-Load-Metrics. The reported metrics # to use for computing the weights are specified via the # customMetrics fields. WEIGHTED_ROUND_ROBIN = 5_584_977 end end |