Class: Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The configuration for a built-in load balancing policy.
Defined Under Namespace
Modules: Name
Instance Attribute Summary collapse
-
#name ⇒ ::String
The name of a locality load-balancing policy.
Instance Attribute Details
#name ⇒ ::String
Returns The name of a locality load-balancing policy. Valid values include ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about these values, see the description of localityLbPolicy. Do not specify the same policy more than once for a backend. If you do, the configuration is rejected. Check the Name enum for the list of possible values.
4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 4361 4362 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 4327 class BackendServiceLocalityLoadBalancingPolicyConfigPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The name of a locality load-balancing policy. Valid values include ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about these values, see the description of localityLbPolicy. Do not specify the same policy more than once for a backend. If you do, the configuration is rejected. module Name # A value indicating that the enum field is not set. UNDEFINED_NAME = 0 INVALID_LB_POLICY = 323_318_707 # An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests. LEAST_REQUEST = 46_604_921 # This algorithm implements consistent hashing to backends. Maglev can be used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, see https://ai.google/research/pubs/pub44824 MAGLEV = 119_180_266 # Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer. ORIGINAL_DESTINATION = 166_297_216 # The load balancer selects a random healthy host. RANDOM = 262_527_171 # The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests. RING_HASH = 432_795_069 # This is a simple policy in which each healthy backend is selected in round robin order. This is the default. ROUND_ROBIN = 153_895_801 # Per-instance weighted Load Balancing via health check reported weights. If set, the Backend Service must configure a non legacy HTTP-based Health Check, and health check replies are expected to contain non-standard HTTP response header field X-Load-Balancing-Endpoint-Weight to specify the per-instance weights. If set, Load Balancing is weighted based on the per-instance weights reported in the last processed health check replies, as long as every instance either reported a valid weight or had UNAVAILABLE_WEIGHT. Otherwise, Load Balancing remains equal-weight. This option is only supported in Network Load Balancing. WEIGHTED_MAGLEV = 254_930_962 # Per-endpoint weighted round-robin Load Balancing using weights computed from Backend reported Custom Metrics. If set, the Backend Service responses are expected to contain non-standard HTTP response header field X-Endpoint-Load-Metrics. The reported metrics to use for computing the weights are specified via the backends[].customMetrics fields. WEIGHTED_ROUND_ROBIN = 5_584_977 end end |