Class: Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The configuration for a built-in load balancing policy.

Defined Under Namespace

Modules: Name

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns The name of a locality load balancer policy to be used. The value should be one of the predefined ones as supported by localityLbPolicy, although at the moment only ROUND_ROBIN is supported. This field should only be populated when the customPolicy field is not used. Note that specifying the same policy more than once for a backend is not a valid configuration and will be rejected. Check the Name enum for the list of possible values.

Returns:

  • (::String)

    The name of a locality load balancer policy to be used. The value should be one of the predefined ones as supported by localityLbPolicy, although at the moment only ROUND_ROBIN is supported. This field should only be populated when the customPolicy field is not used. Note that specifying the same policy more than once for a backend is not a valid configuration and will be rejected. Check the Name enum for the list of possible values.



3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
3590
3591
3592
3593
3594
3595
3596
3597
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 3568

class BackendServiceLocalityLoadBalancingPolicyConfigPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The name of a locality load balancer policy to be used. The value should be one of the predefined ones as supported by localityLbPolicy, although at the moment only ROUND_ROBIN is supported. This field should only be populated when the customPolicy field is not used. Note that specifying the same policy more than once for a backend is not a valid configuration and will be rejected.
  module Name
    # A value indicating that the enum field is not set.
    UNDEFINED_NAME = 0

    INVALID_LB_POLICY = 323318707

    # An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests.
    LEAST_REQUEST = 46604921

    # This algorithm implements consistent hashing to backends. Maglev can be used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, see https://ai.google/research/pubs/pub44824
    MAGLEV = 119180266

    # Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer.
    ORIGINAL_DESTINATION = 166297216

    # The load balancer selects a random healthy host.
    RANDOM = 262527171

    # The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests.
    RING_HASH = 432795069

    # This is a simple policy in which each healthy backend is selected in round robin order. This is the default.
    ROUND_ROBIN = 153895801
  end
end