Class: Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceLocalityLoadBalancingPolicyConfigPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The configuration for a built-in load balancing policy.
Defined Under Namespace
Modules: Name
Instance Attribute Summary collapse
-
#name ⇒ ::String
The name of a locality load-balancing policy.
Instance Attribute Details
#name ⇒ ::String
Returns The name of a locality load-balancing policy. Valid values include ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about these values, see the description of localityLbPolicy.
Do not specify the same policy more than once for a backend. If you do, the configuration is rejected. Check the Name enum for the list of possible values.
12171 12172 12173 12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 12184 12185 12186 12187 12188 12189 12190 12191 12192 12193 12194 12195 12196 12197 12198 12199 12200 12201 12202 12203 12204 12205 12206 12207 12208 12209 12210 12211 12212 12213 12214 12215 12216 12217 12218 12219 12220 12221 12222 12223 12224 12225 12226 12227 12228 12229 12230 12231 12232 12233 12234 12235 12236 12237 12238 12239 12240 12241 12242 12243 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12171 class BackendServiceLocalityLoadBalancingPolicyConfigPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The name of a locality load-balancing policy. Valid values include # ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information # about these values, see the description of localityLbPolicy. # # Do not specify the same policy more than once for a # backend. If you do, the configuration is rejected. module Name # A value indicating that the enum field is not set. UNDEFINED_NAME = 0 INVALID_LB_POLICY = 323_318_707 # An O(1) algorithm which selects two random healthy hosts and # picks the host which has fewer active requests. LEAST_REQUEST = 46_604_921 # This algorithm implements consistent hashing to backends. Maglev can be # used as a drop in replacement for the ring hash load balancer. Maglev is # not as stable as ring hash but has faster table lookup build times and # host selection times. For more information about Maglev, seeMaglev: # A Fast and Reliable Software Network Load Balancer. MAGLEV = 119_180_266 # Backend host is selected based on the client connection metadata, i.e., # connections are opened to the same address as the destination address of # the incoming connection before the connection was redirected to the load # balancer. ORIGINAL_DESTINATION = 166_297_216 # The load balancer selects a random healthy host. RANDOM = 262_527_171 # The ring/modulo hash load balancer implements consistent hashing to # backends. The algorithm has the property that the addition/removal # of a host from a set of N hosts only affects 1/N of the requests. RING_HASH = 432_795_069 # This is a simple policy in which each healthy backend is selected # in round robin order. This is the default. ROUND_ROBIN = 153_895_801 # Per-instance weighted Load Balancing via health check reported weights. # In internal passthrough network load balancing, it is weighted # rendezvous hashing. # This option is only supported in internal passthrough network load # balancing. WEIGHTED_GCP_RENDEZVOUS = 82_501_640 # Per-instance weighted Load Balancing via health check reported weights. # If set, the Backend Service must configure a non legacy HTTP-based Health # Check, and health check replies are expected to contain non-standard HTTP # response header field X-Load-Balancing-Endpoint-Weight to specify the # per-instance weights. # If set, Load Balancing is weighted based on the # per-instance weights reported in the last processed health check replies, # as long as every instance either reported a valid weight or had # UNAVAILABLE_WEIGHT. Otherwise, Load Balancing remains equal-weight. # This option is only supported in Network Load Balancing. WEIGHTED_MAGLEV = 254_930_962 # Per-endpoint weighted round-robin Load Balancing using weights computed # from Backend reported Custom Metrics. If set, the Backend Service # responses are expected to contain non-standard HTTP response header field # Endpoint-Load-Metrics. The reported metrics # to use for computing the weights are specified via the # customMetrics fields. WEIGHTED_ROUND_ROBIN = 5_584_977 end end |