Class: Google::Cloud::Compute::V1::BackendServiceLogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceLogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The available logging options for the load balancer traffic served by this backend service.
Defined Under Namespace
Modules: OptionalMode
Instance Attribute Summary collapse
-
#enable ⇒ ::Boolean
Denotes whether to enable logging for the load balancer traffic served by this backend service.
-
#optional_fields ⇒ ::Array<::String>
This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM.
-
#optional_mode ⇒ ::String
This field can only be specified if logging is enabled for this backend service.
-
#sample_rate ⇒ ::Float
This field can only be specified if logging is enabled for this backend service.
Instance Attribute Details
#enable ⇒ ::Boolean
Returns Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false.
12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12120 class BackendServiceLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field can only be specified if logging is enabled for this backend # service. Configures whether all, none or a subset of optional fields # should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, # EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. module OptionalMode # A value indicating that the enum field is not set. UNDEFINED_OPTIONAL_MODE = 0 # A subset of optional fields. CUSTOM = 388_595_569 # None optional fields. EXCLUDE_ALL_OPTIONAL = 168_636_099 # All optional fields. INCLUDE_ALL_OPTIONAL = 535_606_965 end end |
#optional_fields ⇒ ::Array<::String>
Returns This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM. Contains a list of optional fields you want to include in the logs. For example: serverInstance, serverGkeDetails.cluster, serverGkeDetails.pod.podNamespace.
12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12120 class BackendServiceLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field can only be specified if logging is enabled for this backend # service. Configures whether all, none or a subset of optional fields # should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, # EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. module OptionalMode # A value indicating that the enum field is not set. UNDEFINED_OPTIONAL_MODE = 0 # A subset of optional fields. CUSTOM = 388_595_569 # None optional fields. EXCLUDE_ALL_OPTIONAL = 168_636_099 # All optional fields. INCLUDE_ALL_OPTIONAL = 535_606_965 end end |
#optional_mode ⇒ ::String
Returns This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. Check the OptionalMode enum for the list of possible values.
12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12120 class BackendServiceLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field can only be specified if logging is enabled for this backend # service. Configures whether all, none or a subset of optional fields # should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, # EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. module OptionalMode # A value indicating that the enum field is not set. UNDEFINED_OPTIONAL_MODE = 0 # A subset of optional fields. CUSTOM = 388_595_569 # None optional fields. EXCLUDE_ALL_OPTIONAL = 168_636_099 # All optional fields. INCLUDE_ALL_OPTIONAL = 535_606_965 end end |
#sample_rate ⇒ ::Float
Returns This field can only be specified if logging is enabled for this backend service. The value of the field must be in [0, 1]. This configures the sampling rate of requests to the load balancer where 1.0 means all logged requests are reported and 0.0 means no logged requests are reported. The default value is 1.0.
12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12120 class BackendServiceLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field can only be specified if logging is enabled for this backend # service. Configures whether all, none or a subset of optional fields # should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, # EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. module OptionalMode # A value indicating that the enum field is not set. UNDEFINED_OPTIONAL_MODE = 0 # A subset of optional fields. CUSTOM = 388_595_569 # None optional fields. EXCLUDE_ALL_OPTIONAL = 168_636_099 # All optional fields. INCLUDE_ALL_OPTIONAL = 535_606_965 end end |