Class: Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Spillover
Instance Attribute Summary collapse
-
#spillover ⇒ ::String
This field indicates whether zonal affinity is enabled or not.
-
#spillover_ratio ⇒ ::Float
The value of the field must be in [0, 1].
Instance Attribute Details
#spillover ⇒ ::String
Returns This field indicates whether zonal affinity is enabled or not. The possible values are:
- ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity is disabled. The load balancer distributes new connections to all healthy backend endpoints across all zones.
- ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there are no healthy backend endpoints in the local zone, the load balancer distributes new connections to all backend endpoints in the local zone.
- ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there aren't enough healthy backend endpoints in the local zone, the load balancer distributes new connections to all healthy backend endpoints across all zones. Check the Spillover enum for the list of possible values.
12220 12221 12222 12223 12224 12225 12226 12227 12228 12229 12230 12231 12232 12233 12234 12235 12236 12237 12238 12239 12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12220 class BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field indicates whether zonal affinity is enabled or not. The # possible values are: # # - ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity # is disabled. The load balancer distributes new connections to all # healthy backend endpoints across all zones. # - ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there are no healthy # backend endpoints in the local zone, the load balancer distributes # new connections to all backend endpoints in the local zone. # - ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there aren't enough # healthy backend endpoints in the local zone, the load balancer # distributes new connections to all healthy backend endpoints across all # zones. module Spillover # A value indicating that the enum field is not set. UNDEFINED_SPILLOVER = 0 ZONAL_AFFINITY_DISABLED = 230_207_960 ZONAL_AFFINITY_SPILL_CROSS_ZONE = 251_048_410 ZONAL_AFFINITY_STAY_WITHIN_ZONE = 12_177_782 end end |
#spillover_ratio ⇒ ::Float
Returns The value of the field must be in [0, 1]. When the ratio of the count of healthy backend endpoints in a zone to the count of backend endpoints in that same zone is equal to or above this threshold, the load balancer distributes new connections to all healthy endpoints in the local zone only. When the ratio of the count of healthy backend endpoints in a zone to the count of backend endpoints in that same zone is below this threshold, the load balancer distributes all new connections to all healthy endpoints across all zones.
12220 12221 12222 12223 12224 12225 12226 12227 12228 12229 12230 12231 12232 12233 12234 12235 12236 12237 12238 12239 12240 12241 12242 12243 12244 12245 12246 12247 12248 12249 12250 12251 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12220 class BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field indicates whether zonal affinity is enabled or not. The # possible values are: # # - ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity # is disabled. The load balancer distributes new connections to all # healthy backend endpoints across all zones. # - ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there are no healthy # backend endpoints in the local zone, the load balancer distributes # new connections to all backend endpoints in the local zone. # - ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there aren't enough # healthy backend endpoints in the local zone, the load balancer # distributes new connections to all healthy backend endpoints across all # zones. module Spillover # A value indicating that the enum field is not set. UNDEFINED_SPILLOVER = 0 ZONAL_AFFINITY_DISABLED = 230_207_960 ZONAL_AFFINITY_SPILL_CROSS_ZONE = 251_048_410 ZONAL_AFFINITY_STAY_WITHIN_ZONE = 12_177_782 end end |