Class: Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Spillover
Instance Attribute Summary collapse
-
#spillover ⇒ ::String
This field indicates whether zonal affinity is enabled or not.
-
#spillover_ratio ⇒ ::Float
The value of the field must be in [0, 1].
Instance Attribute Details
#spillover ⇒ ::String
Returns This field indicates whether zonal affinity is enabled or not. The possible values are:
- ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity is disabled. The load balancer distributes new connections to all healthy backend endpoints across all zones.
- ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there are no healthy backend endpoints in the local zone, the load balancer distributes new connections to all backend endpoints in the local zone.
- ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is enabled. The load balancer distributes new connections to all healthy backend endpoints in the local zone only. If there aren't enough healthy backend endpoints in the local zone, the load balancer distributes new connections to all healthy backend endpoints across all zones. Check the Spillover enum for the list of possible values.
12182 12183 12184 12185 12186 12187 12188 12189 12190 12191 12192 12193 12194 12195 12196 12197 12198 12199 12200 12201 12202 12203 12204 12205 12206 12207 12208 12209 12210 12211 12212 12213 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12182 class BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field indicates whether zonal affinity is enabled or not. The # possible values are: # # - ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity # is disabled. The load balancer distributes new connections to all # healthy backend endpoints across all zones. # - ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there are no healthy # backend endpoints in the local zone, the load balancer distributes # new connections to all backend endpoints in the local zone. # - ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there aren't enough # healthy backend endpoints in the local zone, the load balancer # distributes new connections to all healthy backend endpoints across all # zones. module Spillover # A value indicating that the enum field is not set. UNDEFINED_SPILLOVER = 0 ZONAL_AFFINITY_DISABLED = 230_207_960 ZONAL_AFFINITY_SPILL_CROSS_ZONE = 251_048_410 ZONAL_AFFINITY_STAY_WITHIN_ZONE = 12_177_782 end end |
#spillover_ratio ⇒ ::Float
Returns The value of the field must be in [0, 1]. When the ratio of the count of healthy backend endpoints in a zone to the count of backend endpoints in that same zone is equal to or above this threshold, the load balancer distributes new connections to all healthy endpoints in the local zone only. When the ratio of the count of healthy backend endpoints in a zone to the count of backend endpoints in that same zone is below this threshold, the load balancer distributes all new connections to all healthy endpoints across all zones.
12182 12183 12184 12185 12186 12187 12188 12189 12190 12191 12192 12193 12194 12195 12196 12197 12198 12199 12200 12201 12202 12203 12204 12205 12206 12207 12208 12209 12210 12211 12212 12213 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12182 class BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field indicates whether zonal affinity is enabled or not. The # possible values are: # # - ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity # is disabled. The load balancer distributes new connections to all # healthy backend endpoints across all zones. # - ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there are no healthy # backend endpoints in the local zone, the load balancer distributes # new connections to all backend endpoints in the local zone. # - ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there aren't enough # healthy backend endpoints in the local zone, the load balancer # distributes new connections to all healthy backend endpoints across all # zones. module Spillover # A value indicating that the enum field is not set. UNDEFINED_SPILLOVER = 0 ZONAL_AFFINITY_DISABLED = 230_207_960 ZONAL_AFFINITY_SPILL_CROSS_ZONE = 251_048_410 ZONAL_AFFINITY_STAY_WITHIN_ZONE = 12_177_782 end end |