Class: Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Spillover
Instance Attribute Summary collapse
-
#spillover ⇒ ::String
This field indicates whether zonal affinity is enabled or not.
-
#spillover_ratio ⇒ ::Float
The value of the field must be in [0, 1].
Instance Attribute Details
#spillover ⇒ ::String
Returns This field indicates whether zonal affinity is enabled or not. The possible values are:
- ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity
is disabled. The load balancer distributes new connections to all
healthy backend endpoints across all zones.
- ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is
enabled. The load balancer distributes new connections to all healthy
backend endpoints in the local zone only. If there are no healthy
backend endpoints in the local zone, the load balancer distributes
new connections to all backend endpoints in the local zone.
- ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is
enabled. The load balancer distributes new connections to all healthy
backend endpoints in the local zone only. If there aren't enough
healthy backend endpoints in the local zone, the load balancer
distributes new connections to all healthy backend endpoints across all
zones.
Check the Spillover enum for the list of possible values.
12349 12350 12351 12352 12353 12354 12355 12356 12357 12358 12359 12360 12361 12362 12363 12364 12365 12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 12376 12377 12378 12379 12380 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12349 class BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field indicates whether zonal affinity is enabled or not. The # possible values are: # # - ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity # is disabled. The load balancer distributes new connections to all # healthy backend endpoints across all zones. # - ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there are no healthy # backend endpoints in the local zone, the load balancer distributes # new connections to all backend endpoints in the local zone. # - ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there aren't enough # healthy backend endpoints in the local zone, the load balancer # distributes new connections to all healthy backend endpoints across all # zones. module Spillover # A value indicating that the enum field is not set. UNDEFINED_SPILLOVER = 0 ZONAL_AFFINITY_DISABLED = 230_207_960 ZONAL_AFFINITY_SPILL_CROSS_ZONE = 251_048_410 ZONAL_AFFINITY_STAY_WITHIN_ZONE = 12_177_782 end end |
#spillover_ratio ⇒ ::Float
Returns The value of the field must be in [0, 1]. When the ratio of the count of healthy backend endpoints in a zone to the count of backend endpoints in that same zone is equal to or above this threshold, the load balancer distributes new connections to all healthy endpoints in the local zone only. When the ratio of the count of healthy backend endpoints in a zone to the count of backend endpoints in that same zone is below this threshold, the load balancer distributes all new connections to all healthy endpoints across all zones.
12349 12350 12351 12352 12353 12354 12355 12356 12357 12358 12359 12360 12361 12362 12363 12364 12365 12366 12367 12368 12369 12370 12371 12372 12373 12374 12375 12376 12377 12378 12379 12380 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12349 class BackendServiceNetworkPassThroughLbTrafficPolicyZonalAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field indicates whether zonal affinity is enabled or not. The # possible values are: # # - ZONAL_AFFINITY_DISABLED: Default Value. Zonal Affinity # is disabled. The load balancer distributes new connections to all # healthy backend endpoints across all zones. # - ZONAL_AFFINITY_STAY_WITHIN_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there are no healthy # backend endpoints in the local zone, the load balancer distributes # new connections to all backend endpoints in the local zone. # - ZONAL_AFFINITY_SPILL_CROSS_ZONE: Zonal Affinity is # enabled. The load balancer distributes new connections to all healthy # backend endpoints in the local zone only. If there aren't enough # healthy backend endpoints in the local zone, the load balancer # distributes new connections to all healthy backend endpoints across all # zones. module Spillover # A value indicating that the enum field is not set. UNDEFINED_SPILLOVER = 0 ZONAL_AFFINITY_DISABLED = 230_207_960 ZONAL_AFFINITY_SPILL_CROSS_ZONE = 251_048_410 ZONAL_AFFINITY_STAY_WITHIN_ZONE = 12_177_782 end end |