Class: Google::Cloud::Compute::V1::BackendServiceTlsSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BackendServiceTlsSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#authentication_config ⇒ ::String
Reference to the BackendAuthenticationConfig resource from the networksecurity.googleapis.com namespace.
-
#identity ⇒ ::String
Assigns the Managed Identity for the BackendService Workload.
-
#sni ⇒ ::String
Server Name Indication - see RFC3546 section 3.1.
-
#subject_alt_names ⇒ ::Array<::Google::Cloud::Compute::V1::BackendServiceTlsSettingsSubjectAltName>
A list of Subject Alternative Names (SANs) that the Load Balancer verifies during a TLS handshake with the backend.
Instance Attribute Details
#authentication_config ⇒ ::String
Returns Reference to the BackendAuthenticationConfig resource from the networksecurity.googleapis.com namespace. Can be used in authenticating TLS connections to the backend, as specified by the authenticationMode field. Can only be specified if authenticationMode is not NONE.
12495 12496 12497 12498 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12495 class BackendServiceTlsSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#identity ⇒ ::String
Returns Assigns the Managed Identity for the BackendService Workload.
Use this property to configure the load balancer back-end to use certificates and roots of trust provisioned by the Managed Workload Identity system.
The identity property is the
fully-specified SPIFFE ID to use in the SVID presented by the Load
Balancer Workload.
The SPIFFE ID must be a resource starting with the
trustDomain property value, followed by the path to the Managed
Workload Identity.
Supported SPIFFE ID format:
- //<trust_domain>/ns/<namespace>/sa/<subject>
The Trust Domain within the Managed Identity must refer to a valid Workload Identity Pool. The TrustConfig and CertificateIssuanceConfig will be inherited from the Workload Identity Pool.
Restrictions:
- If you set the `identity` property, you cannot manually set
the following fields:
- tlsSettings.sni
- tlsSettings.subjectAltNames
- tlsSettings.authenticationConfig
When defining a identity for a RegionBackendServices, the
corresponding Workload Identity Pool must have a ca_pool
configured in the same region.
The system will set up a read-onlytlsSettings.authenticationConfig for the Managed Identity.
12495 12496 12497 12498 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12495 class BackendServiceTlsSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sni ⇒ ::String
Returns Server Name Indication - see RFC3546 section 3.1. If set, the load balancer sends this string as the SNI hostname in the TLS connection to the backend, and requires that this string match a Subject Alternative Name (SAN) in the backend's server certificate. With a Regional Internet NEG backend, if the SNI is specified here, the load balancer uses it regardless of whether the Regional Internet NEG is specified with FQDN or IP address and port. When both sni and subjectAltNames are specified, the load balancer matches the backend certificate's SAN only to subjectAltNames.
12495 12496 12497 12498 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12495 class BackendServiceTlsSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subject_alt_names ⇒ ::Array<::Google::Cloud::Compute::V1::BackendServiceTlsSettingsSubjectAltName>
Returns A list of Subject Alternative Names (SANs) that the Load Balancer verifies during a TLS handshake with the backend. When the server presents its X.509 certificate to the Load Balancer, the Load Balancer inspects the certificate's SAN field, and requires that at least one SAN match one of the subjectAltNames in the list. This field is limited to 5 entries. When both sni and subjectAltNames are specified, the load balancer matches the backend certificate's SAN only to subjectAltNames.
12495 12496 12497 12498 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12495 class BackendServiceTlsSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |