Class: Google::Cloud::Compute::V1::BfdPacket
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BfdPacket
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Diagnostic, State
Instance Attribute Summary collapse
-
#authentication_present ⇒ ::Boolean
The Authentication Present bit of the BFD packet.
-
#control_plane_independent ⇒ ::Boolean
The Control Plane Independent bit of the BFD packet.
-
#demand ⇒ ::Boolean
The demand bit of the BFD packet.
-
#diagnostic ⇒ ::String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#final ⇒ ::Boolean
The Final bit of the BFD packet.
-
#length ⇒ ::Integer
The length of the BFD Control packet in bytes.
-
#min_echo_rx_interval_ms ⇒ ::Integer
The Required Min Echo RX Interval value in the BFD packet.
-
#min_rx_interval_ms ⇒ ::Integer
The Required Min RX Interval value in the BFD packet.
-
#min_tx_interval_ms ⇒ ::Integer
The Desired Min TX Interval value in the BFD packet.
-
#multiplier ⇒ ::Integer
The detection time multiplier of the BFD packet.
-
#multipoint ⇒ ::Boolean
The multipoint bit of the BFD packet.
-
#my_discriminator ⇒ ::Integer
The My Discriminator value in the BFD packet.
-
#poll ⇒ ::Boolean
The Poll bit of the BFD packet.
-
#state ⇒ ::String
The current BFD session state as seen by the transmitting system.
-
#version ⇒ ::Integer
The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
-
#your_discriminator ⇒ ::Integer
The Your Discriminator value in the BFD packet.
Instance Attribute Details
#authentication_present ⇒ ::Boolean
Returns The Authentication Present bit of the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#control_plane_independent ⇒ ::Boolean
Returns The Control Plane Independent bit of the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#demand ⇒ ::Boolean
Returns The demand bit of the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#diagnostic ⇒ ::String
Returns The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Check the Diagnostic enum for the list of possible values.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#final ⇒ ::Boolean
Returns The Final bit of the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#length ⇒ ::Integer
Returns The length of the BFD Control packet in bytes. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#min_echo_rx_interval_ms ⇒ ::Integer
Returns The Required Min Echo RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#min_rx_interval_ms ⇒ ::Integer
Returns The Required Min RX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#min_tx_interval_ms ⇒ ::Integer
Returns The Desired Min TX Interval value in the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#multiplier ⇒ ::Integer
Returns The detection time multiplier of the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#multipoint ⇒ ::Boolean
Returns The multipoint bit of the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#my_discriminator ⇒ ::Integer
Returns The My Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#poll ⇒ ::Boolean
Returns The Poll bit of the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#state ⇒ ::String
Returns The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Check the State enum for the list of possible values.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#version ⇒ ::Integer
Returns The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |
#your_discriminator ⇒ ::Integer
Returns The Your Discriminator value in the BFD packet. This is specified in section 4.1 ofRFC5880.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 12290 12291 12292 12293 12294 12295 12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 12311 12312 12313 12314 12315 12316 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12267 class BfdPacket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The diagnostic code specifies the local system's reason for the last change # in session state. This allows remote systems to determine the reason that # the previous session failed, for example. These diagnostic codes are # specified in section 4.1 ofRFC5880 module Diagnostic # A value indicating that the enum field is not set. UNDEFINED_DIAGNOSTIC = 0 ADMINISTRATIVELY_DOWN = 121_685_798 CONCATENATED_PATH_DOWN = 26_186_892 CONTROL_DETECTION_TIME_EXPIRED = 135_478_383 DIAGNOSTIC_UNSPECIFIED = 58_720_895 ECHO_FUNCTION_FAILED = 220_687_466 FORWARDING_PLANE_RESET = 19_715_882 NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742 NO_DIAGNOSTIC = 222_503_141 PATH_DOWN = 290_605_180 REVERSE_CONCATENATED_PATH_DOWN = 479_337_129 end # The current BFD session state as seen by the transmitting system. These # states are specified in section 4.1 ofRFC5880 module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ADMIN_DOWN = 128_544_690 DOWN = 2_104_482 INIT = 2_252_048 STATE_UNSPECIFIED = 470_755_401 UP = 2715 end end |