Class: Google::Cloud::Compute::V1::BfdStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Next free: 15

Defined Under Namespace

Modules: BfdSessionInitializationMode, LocalDiagnostic, LocalState

Instance Attribute Summary collapse

Instance Attribute Details

#bfd_session_initialization_mode::String

Returns The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. Check the BfdSessionInitializationMode enum for the list of possible values.

Returns:

  • (::String)

    The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. Check the BfdSessionInitializationMode enum for the list of possible values.



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end

#config_update_timestamp_micros::Integer

Returns Unix timestamp of the most recent config update.

Returns:

  • (::Integer)

    Unix timestamp of the most recent config update.



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end

#control_packet_counts::Google::Cloud::Compute::V1::BfdStatusPacketCounts

Returns Control packet counts for the current BFD session.

Returns:



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end

#control_packet_intervals::Array<::Google::Cloud::Compute::V1::PacketIntervals>

Returns Inter-packet time interval statistics for control packets.

Returns:



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end

#local_diagnostic::String

Returns The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Check the LocalDiagnostic enum for the list of possible values.

Returns:

  • (::String)

    The diagnostic code specifies the local system's reason for the last change in session state. This allows remote systems to determine the reason that the previous session failed, for example. These diagnostic codes are specified in section 4.1 ofRFC5880 Check the LocalDiagnostic enum for the list of possible values.



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end

#local_state::String

Returns The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Check the LocalState enum for the list of possible values.

Returns:

  • (::String)

    The current BFD session state as seen by the transmitting system. These states are specified in section 4.1 ofRFC5880 Check the LocalState enum for the list of possible values.



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end

#negotiated_local_control_tx_interval_ms::Integer

Returns Negotiated transmit interval for control packets.

Returns:

  • (::Integer)

    Negotiated transmit interval for control packets.



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end

#rx_packet::Google::Cloud::Compute::V1::BfdPacket

Returns The most recent Rx control packet for this BFD session.

Returns:



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end

#tx_packet::Google::Cloud::Compute::V1::BfdPacket

Returns The most recent Tx control packet for this BFD session.

Returns:



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end

#uptime_ms::Integer

Returns Session uptime in milliseconds. Value will be 0 if session is not up.

Returns:

  • (::Integer)

    Session uptime in milliseconds. Value will be 0 if session is not up.



12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
12371
12372
12373
12374
12375
12376
12377
12378
12379
12380
12381
12382
12383
12384
12385
12386
12387
12388
12389
12390
12391
12392
12393
12394
12395
12396
12397
12398
12399
12400
12401
12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
12417
12418
12419
12420
12421
12422
12423
12424
12425
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12360

class BfdStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The BFD session initialization mode for this BGP peer.
  # If set to ACTIVE, the Cloud Router will initiate the BFD session for
  # this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
  # peer router to initiate the BFD session for this BGP peer. If set to
  # DISABLED, BFD is disabled for this BGP peer.
  module BfdSessionInitializationMode
    # A value indicating that the enum field is not set.
    UNDEFINED_BFD_SESSION_INITIALIZATION_MODE = 0

    ACTIVE = 314_733_318

    DISABLED = 516_696_700

    PASSIVE = 462_813_959
  end

  # The diagnostic code specifies the local system's reason for the last change
  # in session state. This allows remote systems to determine the reason that
  # the previous session failed, for example. These diagnostic codes are
  # specified in section 4.1 ofRFC5880
  module LocalDiagnostic
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_DIAGNOSTIC = 0

    ADMINISTRATIVELY_DOWN = 121_685_798

    CONCATENATED_PATH_DOWN = 26_186_892

    CONTROL_DETECTION_TIME_EXPIRED = 135_478_383

    DIAGNOSTIC_UNSPECIFIED = 58_720_895

    ECHO_FUNCTION_FAILED = 220_687_466

    FORWARDING_PLANE_RESET = 19_715_882

    NEIGHBOR_SIGNALED_SESSION_DOWN = 374_226_742

    NO_DIAGNOSTIC = 222_503_141

    PATH_DOWN = 290_605_180

    REVERSE_CONCATENATED_PATH_DOWN = 479_337_129
  end

  # The current BFD session state as seen by the transmitting system. These
  # states are specified in section 4.1 ofRFC5880
  module LocalState
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCAL_STATE = 0

    ADMIN_DOWN = 128_544_690

    DOWN = 2_104_482

    INIT = 2_252_048

    STATE_UNSPECIFIED = 470_755_401

    UP = 2715
  end
end