Class: Google::Cloud::Compute::V1::BgpRoute
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BgpRoute
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Origin
Instance Attribute Summary collapse
-
#as_paths ⇒ ::Array<::Google::Cloud::Compute::V1::BgpRouteAsPath>
Output only.
-
#communities ⇒ ::Array<::String>
Output only.
-
#destination ⇒ ::Google::Cloud::Compute::V1::BgpRouteNetworkLayerReachabilityInformation
Output only.
-
#med ⇒ ::Integer
Output only.
-
#origin ⇒ ::String
Output only.
Instance Attribute Details
#as_paths ⇒ ::Array<::Google::Cloud::Compute::V1::BgpRouteAsPath>
Returns Output only. [Output only] AS-PATH for the route.
12628 12629 12630 12631 12632 12633 12634 12635 12636 12637 12638 12639 12640 12641 12642 12643 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12628 class BgpRoute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output only] BGP origin (EGP, IGP or INCOMPLETE) module Origin # A value indicating that the enum field is not set. UNDEFINED_ORIGIN = 0 BGP_ORIGIN_EGP = 378_906_473 BGP_ORIGIN_IGP = 378_910_317 BGP_ORIGIN_INCOMPLETE = 452_839_811 end end |
#communities ⇒ ::Array<::String>
Returns Output only. [Output only] BGP communities in human-readable A:B format.
12628 12629 12630 12631 12632 12633 12634 12635 12636 12637 12638 12639 12640 12641 12642 12643 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12628 class BgpRoute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output only] BGP origin (EGP, IGP or INCOMPLETE) module Origin # A value indicating that the enum field is not set. UNDEFINED_ORIGIN = 0 BGP_ORIGIN_EGP = 378_906_473 BGP_ORIGIN_IGP = 378_910_317 BGP_ORIGIN_INCOMPLETE = 452_839_811 end end |
#destination ⇒ ::Google::Cloud::Compute::V1::BgpRouteNetworkLayerReachabilityInformation
Returns Output only. [Output only] Destination IP range for the route, in human-readable CIDR format.
12628 12629 12630 12631 12632 12633 12634 12635 12636 12637 12638 12639 12640 12641 12642 12643 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12628 class BgpRoute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output only] BGP origin (EGP, IGP or INCOMPLETE) module Origin # A value indicating that the enum field is not set. UNDEFINED_ORIGIN = 0 BGP_ORIGIN_EGP = 378_906_473 BGP_ORIGIN_IGP = 378_910_317 BGP_ORIGIN_INCOMPLETE = 452_839_811 end end |
#med ⇒ ::Integer
Returns Output only. [Output only] BGP multi-exit discriminator.
12628 12629 12630 12631 12632 12633 12634 12635 12636 12637 12638 12639 12640 12641 12642 12643 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12628 class BgpRoute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output only] BGP origin (EGP, IGP or INCOMPLETE) module Origin # A value indicating that the enum field is not set. UNDEFINED_ORIGIN = 0 BGP_ORIGIN_EGP = 378_906_473 BGP_ORIGIN_IGP = 378_910_317 BGP_ORIGIN_INCOMPLETE = 452_839_811 end end |
#origin ⇒ ::String
Returns Output only. [Output only] BGP origin (EGP, IGP or INCOMPLETE) Check the Origin enum for the list of possible values.
12628 12629 12630 12631 12632 12633 12634 12635 12636 12637 12638 12639 12640 12641 12642 12643 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12628 class BgpRoute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output only] BGP origin (EGP, IGP or INCOMPLETE) module Origin # A value indicating that the enum field is not set. UNDEFINED_ORIGIN = 0 BGP_ORIGIN_EGP = 378_906_473 BGP_ORIGIN_IGP = 378_910_317 BGP_ORIGIN_INCOMPLETE = 452_839_811 end end |