Class: Google::Cloud::Compute::V1::BgpRouteAsPath

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#asns::Array<::Integer>

Returns Output only. [Output only] ASNs in the path segment. When type is SEQUENCE, these are ordered.

Returns:

  • (::Array<::Integer>)

    Output only. [Output only] ASNs in the path segment. When type is SEQUENCE, these are ordered.



12620
12621
12622
12623
12624
12625
12626
12627
12628
12629
12630
12631
12632
12633
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12620

class BgpRouteAsPath
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output only] Type of AS-PATH segment (SEQUENCE or SET)
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    AS_PATH_TYPE_SEQUENCE = 362_887_609

    AS_PATH_TYPE_SET = 302_584_650
  end
end

#asns32::Array<::Integer>

Returns Output only. [Output only] ASNs in the path segment. This field is for better support of 32 bit ASNs as the other asns field suffers from overflow when the ASN is larger. When type is SEQUENCE, these are ordered.

Returns:

  • (::Array<::Integer>)

    Output only. [Output only] ASNs in the path segment. This field is for better support of 32 bit ASNs as the other asns field suffers from overflow when the ASN is larger. When type is SEQUENCE, these are ordered.



12620
12621
12622
12623
12624
12625
12626
12627
12628
12629
12630
12631
12632
12633
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12620

class BgpRouteAsPath
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output only] Type of AS-PATH segment (SEQUENCE or SET)
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    AS_PATH_TYPE_SEQUENCE = 362_887_609

    AS_PATH_TYPE_SET = 302_584_650
  end
end

#type::String

Returns Output only. [Output only] Type of AS-PATH segment (SEQUENCE or SET) Check the Type enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output only] Type of AS-PATH segment (SEQUENCE or SET) Check the Type enum for the list of possible values.



12620
12621
12622
12623
12624
12625
12626
12627
12628
12629
12630
12631
12632
12633
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12620

class BgpRouteAsPath
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output only] Type of AS-PATH segment (SEQUENCE or SET)
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    AS_PATH_TYPE_SEQUENCE = 362_887_609

    AS_PATH_TYPE_SET = 302_584_650
  end
end