Class: Google::Cloud::Compute::V1::BulkInsertOperationStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#created_vm_count::Integer

Returns [Output Only] Count of VMs successfully created so far.

Returns:

  • (::Integer)

    [Output Only] Count of VMs successfully created so far.



12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
13011
13012
13013
13014
13015
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12994

class BulkInsertOperationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Creation status of BulkInsert operation - information
  # if the flow is rolling forward or rolling back.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Rolling forward - creating VMs.
    CREATING = 455_564_985

    # Done
    DONE = 2_104_194

    # Rolling back - cleaning up after an error.
    ROLLING_BACK = 259_411_649

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#deleted_vm_count::Integer

Returns [Output Only] Count of VMs that got deleted during rollback.

Returns:

  • (::Integer)

    [Output Only] Count of VMs that got deleted during rollback.



12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
13011
13012
13013
13014
13015
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12994

class BulkInsertOperationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Creation status of BulkInsert operation - information
  # if the flow is rolling forward or rolling back.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Rolling forward - creating VMs.
    CREATING = 455_564_985

    # Done
    DONE = 2_104_194

    # Rolling back - cleaning up after an error.
    ROLLING_BACK = 259_411_649

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#failed_to_create_vm_count::Integer

Returns [Output Only] Count of VMs that started creating but encountered an error.

Returns:

  • (::Integer)

    [Output Only] Count of VMs that started creating but encountered an error.



12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
13011
13012
13013
13014
13015
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12994

class BulkInsertOperationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Creation status of BulkInsert operation - information
  # if the flow is rolling forward or rolling back.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Rolling forward - creating VMs.
    CREATING = 455_564_985

    # Done
    DONE = 2_104_194

    # Rolling back - cleaning up after an error.
    ROLLING_BACK = 259_411_649

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#status::String

Returns [Output Only] Creation status of BulkInsert operation - information if the flow is rolling forward or rolling back. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] Creation status of BulkInsert operation - information if the flow is rolling forward or rolling back. Check the Status enum for the list of possible values.



12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
13011
13012
13013
13014
13015
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12994

class BulkInsertOperationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Creation status of BulkInsert operation - information
  # if the flow is rolling forward or rolling back.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Rolling forward - creating VMs.
    CREATING = 455_564_985

    # Done
    DONE = 2_104_194

    # Rolling back - cleaning up after an error.
    ROLLING_BACK = 259_411_649

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#target_vm_count::Integer

Returns [Output Only] Count of VMs originally planned to be created.

Returns:

  • (::Integer)

    [Output Only] Count of VMs originally planned to be created.



12994
12995
12996
12997
12998
12999
13000
13001
13002
13003
13004
13005
13006
13007
13008
13009
13010
13011
13012
13013
13014
13015
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12994

class BulkInsertOperationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Creation status of BulkInsert operation - information
  # if the flow is rolling forward or rolling back.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Rolling forward - creating VMs.
    CREATING = 455_564_985

    # Done
    DONE = 2_104_194

    # Rolling back - cleaning up after an error.
    ROLLING_BACK = 259_411_649

    STATUS_UNSPECIFIED = 42_133_066
  end
end