Class: Google::Cloud::Compute::V1::BulkInsertOperationStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::BulkInsertOperationStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#created_vm_count ⇒ ::Integer
[Output Only] Count of VMs successfully created so far.
-
#deleted_vm_count ⇒ ::Integer
[Output Only] Count of VMs that got deleted during rollback.
-
#failed_to_create_vm_count ⇒ ::Integer
[Output Only] Count of VMs that started creating but encountered an error.
-
#status ⇒ ::String
[Output Only] Creation status of BulkInsert operation - information if the flow is rolling forward or rolling back.
-
#target_vm_count ⇒ ::Integer
[Output Only] Count of VMs originally planned to be created.
Instance Attribute Details
#created_vm_count ⇒ ::Integer
Returns [Output Only] Count of VMs successfully created so far.
12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 12841 12842 12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12831 class BulkInsertOperationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Creation status of BulkInsert operation - information # if the flow is rolling forward or rolling back. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Rolling forward - creating VMs. CREATING = 455_564_985 # Done DONE = 2_104_194 # Rolling back - cleaning up after an error. ROLLING_BACK = 259_411_649 STATUS_UNSPECIFIED = 42_133_066 end end |
#deleted_vm_count ⇒ ::Integer
Returns [Output Only] Count of VMs that got deleted during rollback.
12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 12841 12842 12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12831 class BulkInsertOperationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Creation status of BulkInsert operation - information # if the flow is rolling forward or rolling back. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Rolling forward - creating VMs. CREATING = 455_564_985 # Done DONE = 2_104_194 # Rolling back - cleaning up after an error. ROLLING_BACK = 259_411_649 STATUS_UNSPECIFIED = 42_133_066 end end |
#failed_to_create_vm_count ⇒ ::Integer
Returns [Output Only] Count of VMs that started creating but encountered an error.
12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 12841 12842 12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12831 class BulkInsertOperationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Creation status of BulkInsert operation - information # if the flow is rolling forward or rolling back. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Rolling forward - creating VMs. CREATING = 455_564_985 # Done DONE = 2_104_194 # Rolling back - cleaning up after an error. ROLLING_BACK = 259_411_649 STATUS_UNSPECIFIED = 42_133_066 end end |
#status ⇒ ::String
Returns [Output Only] Creation status of BulkInsert operation - information if the flow is rolling forward or rolling back. Check the Status enum for the list of possible values.
12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 12841 12842 12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12831 class BulkInsertOperationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Creation status of BulkInsert operation - information # if the flow is rolling forward or rolling back. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Rolling forward - creating VMs. CREATING = 455_564_985 # Done DONE = 2_104_194 # Rolling back - cleaning up after an error. ROLLING_BACK = 259_411_649 STATUS_UNSPECIFIED = 42_133_066 end end |
#target_vm_count ⇒ ::Integer
Returns [Output Only] Count of VMs originally planned to be created.
12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 12841 12842 12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12831 class BulkInsertOperationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Creation status of BulkInsert operation - information # if the flow is rolling forward or rolling back. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Rolling forward - creating VMs. CREATING = 455_564_985 # Done DONE = 2_104_194 # Rolling back - cleaning up after an error. ROLLING_BACK = 259_411_649 STATUS_UNSPECIFIED = 42_133_066 end end |