Class: Google::Cloud::Compute::V1::CacheInvalidationRule
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CacheInvalidationRule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#cache_tags ⇒ ::Array<::String>
A list of cache tags used to identify cached objects.
-
#host ⇒ ::String
If set, this invalidation rule will only apply to requests with a Host header matching host.
- #path ⇒ ::String
Instance Attribute Details
#cache_tags ⇒ ::Array<::String>
Returns A list of cache tags used to identify cached objects.
- Cache tags are specified when the response is first cached, by setting
the
Cache-Tagresponse header at the origin. - Multiple cache tags in the same invalidation request are treated as
Boolean
OR- for example,tag1 OR tag2 OR tag3. - If other fields are also specified, these are treated as Boolean
ANDwith any tags.
Up to 10 tags can be specified in a single invalidation request.
13010 13011 13012 13013 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13010 class CacheInvalidationRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#host ⇒ ::String
Returns If set, this invalidation rule will only apply to requests with a Host header matching host.
13010 13011 13012 13013 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13010 class CacheInvalidationRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#path ⇒ ::String
13010 13011 13012 13013 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13010 class CacheInvalidationRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |