Class: Google::Cloud::Compute::V1::CachePolicyCacheKeyPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CachePolicyCacheKeyPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Message containing what to include in the cache key for a request for Cache Policy defined on Route Action.
Instance Attribute Summary collapse
-
#excluded_query_parameters ⇒ ::Array<::String>
Names of query string parameters to exclude in cache keys.
-
#include_host ⇒ ::Boolean
If true, requests to different hosts will be cached separately.
-
#include_protocol ⇒ ::Boolean
If true, http and https requests will be cached separately.
-
#include_query_string ⇒ ::Boolean
If true, include query string parameters in the cache key according to
includedQueryParametersandexcludedQueryParameters. -
#included_cookie_names ⇒ ::Array<::String>
Allows HTTP cookies (by name) to be used in the cache key.
-
#included_header_names ⇒ ::Array<::String>
Allows HTTP request headers (by name) to be used in the cache key.
-
#included_query_parameters ⇒ ::Array<::String>
Names of query string parameters to include in cache keys.
Instance Attribute Details
#excluded_query_parameters ⇒ ::Array<::String>
Returns Names of query string parameters to exclude in cache keys. All other
parameters will be included. Either specify excludedQueryParameters
or includedQueryParameters, not both. '&' and '=' will be percent
encoded and not treated as delimiters.
Note: This field applies to routes that use backend services. Attempting
to set it on a route that points exclusively to Backend Buckets will
result in a configuration error. For routes that point to a Backend
Bucket, use includedQueryParameters to define which parameters should
be part of the cache key.
13249 13250 13251 13252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13249 class CachePolicyCacheKeyPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#include_host ⇒ ::Boolean
Returns If true, requests to different hosts will be cached separately.
Note: This setting is only applicable to routes that use a Backend Service. It does not affect requests served by a Backend Bucket, as the host is never included in a Backend Bucket's cache key. Attempting to set it on a route that points exclusively to Backend Buckets will result in a configuration error.
13249 13250 13251 13252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13249 class CachePolicyCacheKeyPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#include_protocol ⇒ ::Boolean
Returns If true, http and https requests will be cached separately.
Note: This setting is only applicable to routes that use a Backend Service. It does not affect requests served by a Backend Bucket, as the protocol is never included in a Backend Bucket's cache key. Attempting to set on a route that points exclusively to Backend Buckets will result in a configuration error.
13249 13250 13251 13252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13249 class CachePolicyCacheKeyPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#include_query_string ⇒ ::Boolean
Returns If true, include query string parameters in the cache key according to
includedQueryParameters and excludedQueryParameters. If neither
is set, the entire query string will be included. If false, the query
string will be excluded from the cache key entirely.
Note: This field applies to routes that use backend services. Attempting
to set it on a route that points exclusively to Backend Buckets will
result in a configuration error. For routes that point to a Backend
Bucket, use includedQueryParameters to define which parameters should
be part of the cache key.
13249 13250 13251 13252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13249 class CachePolicyCacheKeyPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#included_cookie_names ⇒ ::Array<::String>
Returns Allows HTTP cookies (by name) to be used in the cache key. The name=value pair will be used in the cache key Cloud CDN generates.
Note: This setting is only applicable to routes that use a Backend Service. It does not affect requests served by a Backend Bucket. Attempting to set it on a route that points exclusively to Backend Buckets will result in a configuration error. Up to 5 cookie names can be specified.
13249 13250 13251 13252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13249 class CachePolicyCacheKeyPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#included_header_names ⇒ ::Array<::String>
Returns Allows HTTP request headers (by name) to be used in the cache key.
13249 13250 13251 13252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13249 class CachePolicyCacheKeyPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#included_query_parameters ⇒ ::Array<::String>
Returns Names of query string parameters to include in cache keys. All other
parameters will be excluded. Either specify includedQueryParameters
or excludedQueryParameters, not both. '&' and '=' will be percent
encoded and not treated as delimiters.
13249 13250 13251 13252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13249 class CachePolicyCacheKeyPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |