Class: Google::Cloud::Compute::V1::CalendarModeAdviceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CalendarModeAdviceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request to recommend the best way to consume the specified resources in the future.
Defined Under Namespace
Classes: FutureResourcesSpecsEntry
Instance Attribute Summary collapse
-
#future_resources_specs ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::FutureResourcesSpec}
Specification of resources to create in the future.
Instance Attribute Details
#future_resources_specs ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::FutureResourcesSpec}
Returns Specification of resources to create in the future. The key of the map is an arbitrary string specified by the caller. Value of the map is a specification of required resources and their constraints. Currently only one value is allowed in this map.
13280 13281 13282 13283 13284 13285 13286 13287 13288 13289 13290 13291 13292 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 13280 class CalendarModeAdviceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FutureResourcesSpec] class FutureResourcesSpecsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |