Module: Google::Cloud::Compute::V1::CapacityAdviceRequestDistributionPolicy::TargetShape
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Target distribution shape. You can specify the following values:ANY, ANY_SINGLE_ZONE, or BALANCED.
Constant Summary collapse
- UNDEFINED_TARGET_SHAPE =
A value indicating that the enum field is not set.
0- ANY =
Picks zones for creating VM instances to fulfill the requested number of VMs within present resource constraints.
64_972- ANY_SINGLE_ZONE =
Creates all VM instances within a single zone. The zone is selected based on the present resource constraints.
61_100_880- BALANCED =
Prioritizes acquisition of resources, scheduling VMs in zones where resources are available while distributing VMs as evenly as possible across selected zones to minimize the impact of zonal failure.
468_409_608- TARGET_SHAPE_UNSPECIFIED =
Default value, unused.
449_316_907