Class: Google::Cloud::Compute::V1::CapacityAdviceResponseRecommendationScores
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CapacityAdviceResponseRecommendationScores
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Groups information about a shard of capacity.
Instance Attribute Summary collapse
-
#estimated_uptime ⇒ ::String
The estimated run time of the majority of Spot VMs in the request before preemption.
-
#obtainability ⇒ ::Float
The obtainability score indicates the likelihood of successfully obtaining (provisioning) the requested number of VMs.
Instance Attribute Details
#estimated_uptime ⇒ ::String
Returns The estimated run time of the majority of Spot VMs in the request before preemption. The estimate is best-effort only. It is based on historical data and current conditions.
14038 14039 14040 14041 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14038 class CapacityAdviceResponseRecommendationScores include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#obtainability ⇒ ::Float
Returns The obtainability score indicates the likelihood of successfully obtaining (provisioning) the requested number of VMs. The score range is 0.0 through 1.0. Higher is better.
14038 14039 14040 14041 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14038 class CapacityAdviceResponseRecommendationScores include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |