Class: Google::Cloud::Compute::V1::CapacityAdviceResponseRecommendationShard
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CapacityAdviceResponseRecommendationShard
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Shards represent blocks of uniform capacity in recommendations. Each shard is for a single zone and a single machine shape. Each shard defines a size expressed as the number of VMs.
Defined Under Namespace
Modules: ProvisioningModel
Instance Attribute Summary collapse
-
#instance_count ⇒ ::Integer
The number of instances.
-
#machine_type ⇒ ::String
The machine type corresponds to the instance selection in the request.
-
#provisioning_model ⇒ ::String
The provisioning model that you want to view recommendations for.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#instance_count ⇒ ::Integer
Returns The number of instances.
14059 14060 14061 14062 14063 14064 14065 14066 14067 14068 14069 14070 14071 14072 14073 14074 14075 14076 14077 14078 14079 14080 14081 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14059 class CapacityAdviceResponseRecommendationShard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The provisioning model that you want to view recommendations for. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#machine_type ⇒ ::String
Returns The machine type corresponds to the instance selection in the request.
14059 14060 14061 14062 14063 14064 14065 14066 14067 14068 14069 14070 14071 14072 14073 14074 14075 14076 14077 14078 14079 14080 14081 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14059 class CapacityAdviceResponseRecommendationShard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The provisioning model that you want to view recommendations for. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#provisioning_model ⇒ ::String
Returns The provisioning model that you want to view recommendations for. Check the ProvisioningModel enum for the list of possible values.
14059 14060 14061 14062 14063 14064 14065 14066 14067 14068 14069 14070 14071 14072 14073 14074 14075 14076 14077 14078 14079 14080 14081 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14059 class CapacityAdviceResponseRecommendationShard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The provisioning model that you want to view recommendations for. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#zone ⇒ ::String
Returns Output only. The zone name for this shard.
14059 14060 14061 14062 14063 14064 14065 14066 14067 14068 14069 14070 14071 14072 14073 14074 14075 14076 14077 14078 14079 14080 14081 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14059 class CapacityAdviceResponseRecommendationShard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The provisioning model that you want to view recommendations for. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |