Class: Google::Cloud::Compute::V1::CapacityHistoryRequestInstancePropertiesScheduling
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CapacityHistoryRequestInstancePropertiesScheduling
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Scheduling options.
Defined Under Namespace
Modules: ProvisioningModel
Instance Attribute Summary collapse
-
#provisioning_model ⇒ ::String
The provisioning model to get capacity history for.
Instance Attribute Details
#provisioning_model ⇒ ::String
Returns The provisioning model to get capacity history for. This field must be set to SPOT.
For more information, see Compute Engine instances provisioning models. Check the ProvisioningModel enum for the list of possible values.
14165 14166 14167 14168 14169 14170 14171 14172 14173 14174 14175 14176 14177 14178 14179 14180 14181 14182 14183 14184 14185 14186 14187 14188 14189 14190 14191 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14165 class CapacityHistoryRequestInstancePropertiesScheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The provisioning model to get capacity history for. # This field must be set to SPOT. # # For more information, see # Compute Engine instances provisioning models. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |