Class: Google::Cloud::Compute::V1::CapacityHistoryRequestLocationPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CapacityHistoryRequestLocationPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Location policy for this request.
Instance Attribute Summary collapse
-
#location ⇒ ::String
The region or zone to get capacity history for.
Instance Attribute Details
#location ⇒ ::String
Returns The region or zone to get capacity history for.
It can be a partial or full URL. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone
- projects/project/zones/zone
- zones/zone
This field is optional.
14209 14210 14211 14212 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14209 class CapacityHistoryRequestLocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |