Class: Google::Cloud::Compute::V1::CapacityHistoryResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CapacityHistoryResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Contains the capacity history.
Instance Attribute Summary collapse
-
#location ⇒ ::String
Output only.
-
#machine_type ⇒ ::String
The machine type for which the capacity history is returned.
-
#preemption_history ⇒ ::Array<::Google::Cloud::Compute::V1::CapacityHistoryResponsePreemptionRecord>
The preemption history for the requested machine type and location.
-
#price_history ⇒ ::Array<::Google::Cloud::Compute::V1::CapacityHistoryResponsePriceRecord>
The price history for the requested machine type and location.
Instance Attribute Details
#location ⇒ ::String
Returns Output only. The location (region or zone) for which the capacity history is returned. It is returned as a URL - For example,https://www.googleapis.com/compute/v1/projects/project/zones/zone.
14228 14229 14230 14231 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14228 class CapacityHistoryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#machine_type ⇒ ::String
Returns The machine type for which the capacity history is returned.
14228 14229 14230 14231 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14228 class CapacityHistoryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#preemption_history ⇒ ::Array<::Google::Cloud::Compute::V1::CapacityHistoryResponsePreemptionRecord>
Returns The preemption history for the requested machine type and location.
14228 14229 14230 14231 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14228 class CapacityHistoryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#price_history ⇒ ::Array<::Google::Cloud::Compute::V1::CapacityHistoryResponsePriceRecord>
Returns The price history for the requested machine type and location.
14228 14229 14230 14231 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14228 class CapacityHistoryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |