Class: Google::Cloud::Compute::V1::CapacityHistoryResponsePreemptionRecord
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CapacityHistoryResponsePreemptionRecord
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A record of Spot VM preemption history.
Instance Attribute Summary collapse
-
#interval ⇒ ::Google::Cloud::Compute::V1::Interval
The time interval for this preemption record.
-
#preemption_rate ⇒ ::Float
The preemption rate during the interval, representing the fraction of Spot VMs that were preempted.
Instance Attribute Details
#interval ⇒ ::Google::Cloud::Compute::V1::Interval
Returns The time interval for this preemption record.
14243 14244 14245 14246 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14243 class CapacityHistoryResponsePreemptionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#preemption_rate ⇒ ::Float
Returns The preemption rate during the interval, representing the fraction of Spot VMs that were preempted. Range: 0.0 to 1.0. Preemption rate is calculated as (total preempted Spots) / (total Spots that stopped running).
14243 14244 14245 14246 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14243 class CapacityHistoryResponsePreemptionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |