Class: Google::Cloud::Compute::V1::CompositeHealthCheck
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CompositeHealthCheck
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a composite health check.
A composite health check resource specifies the health source resources and the health destination resource to which the aggregated health result from the health source resources is delivered.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#health_destination ⇒ ::String
URL to the destination resource.
-
#health_sources ⇒ ::Array<::String>
URLs to the HealthSource resources whose results are AND'ed.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fingerprint ⇒ ::String
Returns Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a CompositeHealthCheck. An up-to-date fingerprint must be provided in order to patch the CompositeHealthCheck; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the CompositeHealthCheck.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#health_destination ⇒ ::String
Returns URL to the destination resource. Must be set. Must be aForwardingRule. The ForwardingRule must have load balancing scheme INTERNAL orINTERNAL_MANAGED and must be regional and in the same region as the CompositeHealthCheck (cross-region deployment forINTERNAL_MANAGED is not supported). Can be mutated.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#health_sources ⇒ ::Array<::String>
Returns URLs to the HealthSource resources whose results are AND'ed. I.e. he aggregated result is is HEALTHY only if all sources are HEALTHY. Must have at least 1. Must not have more than 10. Must be regional and in the same region as theCompositeHealthCheck. Can be mutated.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
Returns Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#compositeHealthCheck for composite health checks.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the composite health check resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL with id for the resource.
14058 14059 14060 14061 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14058 class CompositeHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |