Class: Google::Cloud::Compute::V1::CompositeHealthCheckAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CompositeHealthCheckAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Contains a list of CompositeHealthChecksScopedList.
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList}
A list of CompositeHealthChecksScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14317 class CompositeHealthCheckAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList}
Returns A list of CompositeHealthChecksScopedList resources.
14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14317 class CompositeHealthCheckAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. Type of resource.
14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14317 class CompositeHealthCheckAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14317 class CompositeHealthCheckAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14317 class CompositeHealthCheckAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14317 class CompositeHealthCheckAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14317 class CompositeHealthCheckAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |