Class: Google::Cloud::Compute::V1::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#id::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    [Output Only] Unique identifier for the resource; defined by the server.



14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14089

class CompositeHealthCheckAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList}

Returns A list of CompositeHealthChecksScopedList resources.

Returns:



14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14089

class CompositeHealthCheckAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns Output only. Type of resource.

Returns:

  • (::String)

    Output only. Type of resource.



14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14089

class CompositeHealthCheckAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14089

class CompositeHealthCheckAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource.



14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14089

class CompositeHealthCheckAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Unreachable resources.



14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14089

class CompositeHealthCheckAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



14089
14090
14091
14092
14093
14094
14095
14096
14097
14098
14099
14100
14101
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14089

class CompositeHealthCheckAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::CompositeHealthChecksScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end