Class: Google::Cloud::Compute::V1::CompositeHealthCheckHealth

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Response message for RegionCompositeHealthChecks.GetHealth

Defined Under Namespace

Modules: HealthState

Instance Attribute Summary collapse

Instance Attribute Details

#health_sources::Array<::Google::Cloud::Compute::V1::CompositeHealthChecksGetHealthResponseHealthSourceHealth>

Returns Health sources and their corresponding health states.

Returns:



14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
14316
14317
14318
14319
14320
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14305

class CompositeHealthCheckHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the CompositeHealthCheck.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end

#health_state::String

Returns Health state of the CompositeHealthCheck. Check the HealthState enum for the list of possible values.

Returns:

  • (::String)

    Health state of the CompositeHealthCheck. Check the HealthState enum for the list of possible values.



14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
14316
14317
14318
14319
14320
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14305

class CompositeHealthCheckHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the CompositeHealthCheck.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end

#kind::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#compositeHealthCheckHealth for the health of composite health checks.

Returns:

  • (::String)

    Output only. [Output Only] Type of resource. Alwayscompute#compositeHealthCheckHealth for the health of composite health checks.



14305
14306
14307
14308
14309
14310
14311
14312
14313
14314
14315
14316
14317
14318
14319
14320
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14305

class CompositeHealthCheckHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the CompositeHealthCheck.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end