Class: Google::Cloud::Compute::V1::CompositeHealthChecksGetHealthResponseHealthSourceHealth
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CompositeHealthChecksGetHealthResponseHealthSourceHealth
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: HealthState
Instance Attribute Summary collapse
-
#health_state ⇒ ::String
Health state of the associated HealthSource resource.
-
#source ⇒ ::String
Fully qualified URL of the associated HealthSource resource.
Instance Attribute Details
#health_state ⇒ ::String
Returns Health state of the associated HealthSource resource. Check the HealthState enum for the list of possible values.
14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 14404 14405 14406 14407 14408 14409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14394 class CompositeHealthChecksGetHealthResponseHealthSourceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the associated HealthSource resource. module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end end |
#source ⇒ ::String
Returns Fully qualified URL of the associated HealthSource resource.
14394 14395 14396 14397 14398 14399 14400 14401 14402 14403 14404 14405 14406 14407 14408 14409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14394 class CompositeHealthChecksGetHealthResponseHealthSourceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the associated HealthSource resource. module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end end |