Class: Google::Cloud::Compute::V1::CompositeHealthChecksGetHealthResponseHealthSourceHealth
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CompositeHealthChecksGetHealthResponseHealthSourceHealth
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: HealthState
Instance Attribute Summary collapse
-
#health_state ⇒ ::String
Health state of the associated HealthSource resource.
-
#source ⇒ ::String
Fully qualified URL of the associated HealthSource resource.
Instance Attribute Details
#health_state ⇒ ::String
Returns Health state of the associated HealthSource resource. Check the HealthState enum for the list of possible values.
14356 14357 14358 14359 14360 14361 14362 14363 14364 14365 14366 14367 14368 14369 14370 14371 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14356 class CompositeHealthChecksGetHealthResponseHealthSourceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the associated HealthSource resource. module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end end |
#source ⇒ ::String
Returns Fully qualified URL of the associated HealthSource resource.
14356 14357 14358 14359 14360 14361 14362 14363 14364 14365 14366 14367 14368 14369 14370 14371 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14356 class CompositeHealthChecksGetHealthResponseHealthSourceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the associated HealthSource resource. module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end end |