Class: Google::Cloud::Compute::V1::ConfidentialInstanceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ConfidentialInstanceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A set of Confidential Instance options.
Defined Under Namespace
Modules: ConfidentialInstanceType
Instance Attribute Summary collapse
-
#confidential_instance_type ⇒ ::String
Defines the type of technology used by the confidential instance.
-
#enable_confidential_compute ⇒ ::Boolean
Defines whether the instance should have confidential compute enabled.
Instance Attribute Details
#confidential_instance_type ⇒ ::String
Returns Defines the type of technology used by the confidential instance. Check the ConfidentialInstanceType enum for the list of possible values.
14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 14449 14450 14451 14452 14453 14454 14455 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14431 class ConfidentialInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the type of technology used by the confidential instance. module ConfidentialInstanceType # A value indicating that the enum field is not set. UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE = 0 # Arm Confidential Compute Architecture. CCA = 66_529 # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 115_021_829 # AMD Secure Encrypted Virtualization. SEV = 81_988 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 21_753_562 # Intel Trust Domain eXtension. TDX = 82_920 end end |
#enable_confidential_compute ⇒ ::Boolean
Returns Defines whether the instance should have confidential compute enabled.
14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 14449 14450 14451 14452 14453 14454 14455 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14431 class ConfidentialInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the type of technology used by the confidential instance. module ConfidentialInstanceType # A value indicating that the enum field is not set. UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE = 0 # Arm Confidential Compute Architecture. CCA = 66_529 # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 115_021_829 # AMD Secure Encrypted Virtualization. SEV = 81_988 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 21_753_562 # Intel Trust Domain eXtension. TDX = 82_920 end end |