Class: Google::Cloud::Compute::V1::ConfidentialInstanceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A set of Confidential Instance options.

Defined Under Namespace

Modules: ConfidentialInstanceType

Instance Attribute Summary collapse

Instance Attribute Details

#confidential_instance_type::String

Returns Defines the type of technology used by the confidential instance. Check the ConfidentialInstanceType enum for the list of possible values.

Returns:

  • (::String)

    Defines the type of technology used by the confidential instance. Check the ConfidentialInstanceType enum for the list of possible values.



14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
14403
14404
14405
14406
14407
14408
14409
14410
14411
14412
14413
14414
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14393

class ConfidentialInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the type of technology used by the confidential instance.
  module ConfidentialInstanceType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE = 0

    # No type specified. Do not use this value.
    CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 115_021_829

    # AMD Secure Encrypted Virtualization.
    SEV = 81_988

    # AMD Secure Encrypted Virtualization - Secure Nested Paging.
    SEV_SNP = 21_753_562

    # Intel Trust Domain eXtension.
    TDX = 82_920
  end
end

#enable_confidential_compute::Boolean

Returns Defines whether the instance should have confidential compute enabled.

Returns:

  • (::Boolean)

    Defines whether the instance should have confidential compute enabled.



14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
14403
14404
14405
14406
14407
14408
14409
14410
14411
14412
14413
14414
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14393

class ConfidentialInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the type of technology used by the confidential instance.
  module ConfidentialInstanceType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE = 0

    # No type specified. Do not use this value.
    CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 115_021_829

    # AMD Secure Encrypted Virtualization.
    SEV = 81_988

    # AMD Secure Encrypted Virtualization - Secure Nested Paging.
    SEV_SNP = 21_753_562

    # Intel Trust Domain eXtension.
    TDX = 82_920
  end
end