Class: Google::Cloud::Compute::V1::ConfidentialInstanceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A set of Confidential Instance options.

Defined Under Namespace

Modules: ConfidentialInstanceType

Instance Attribute Summary collapse

Instance Attribute Details

#confidential_instance_type::String

Returns Defines the type of technology used by the confidential instance. Check the ConfidentialInstanceType enum for the list of possible values.

Returns:

  • (::String)

    Defines the type of technology used by the confidential instance. Check the ConfidentialInstanceType enum for the list of possible values.



14203
14204
14205
14206
14207
14208
14209
14210
14211
14212
14213
14214
14215
14216
14217
14218
14219
14220
14221
14222
14223
14224
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14203

class ConfidentialInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the type of technology used by the confidential instance.
  module ConfidentialInstanceType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE = 0

    # No type specified. Do not use this value.
    CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 115_021_829

    # AMD Secure Encrypted Virtualization.
    SEV = 81_988

    # AMD Secure Encrypted Virtualization - Secure Nested Paging.
    SEV_SNP = 21_753_562

    # Intel Trust Domain eXtension.
    TDX = 82_920
  end
end

#enable_confidential_compute::Boolean

Returns Defines whether the instance should have confidential compute enabled.

Returns:

  • (::Boolean)

    Defines whether the instance should have confidential compute enabled.



14203
14204
14205
14206
14207
14208
14209
14210
14211
14212
14213
14214
14215
14216
14217
14218
14219
14220
14221
14222
14223
14224
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14203

class ConfidentialInstanceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the type of technology used by the confidential instance.
  module ConfidentialInstanceType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE = 0

    # No type specified. Do not use this value.
    CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 115_021_829

    # AMD Secure Encrypted Virtualization.
    SEV = 81_988

    # AMD Secure Encrypted Virtualization - Secure Nested Paging.
    SEV_SNP = 21_753_562

    # Intel Trust Domain eXtension.
    TDX = 82_920
  end
end