Class: Google::Cloud::Compute::V1::CustomErrorResponsePolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CustomErrorResponsePolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.
Instance Attribute Summary collapse
-
#error_response_rules ⇒ ::Array<::Google::Cloud::Compute::V1::CustomErrorResponsePolicyCustomErrorResponseRule>
Specifies rules for returning error responses.
-
#error_service ⇒ ::String
The full or partial URL to the BackendBucket resource that contains the custom error content.
Instance Attribute Details
#error_response_rules ⇒ ::Array<::Google::Cloud::Compute::V1::CustomErrorResponsePolicyCustomErrorResponseRule>
Returns Specifies rules for returning error responses.
In a given policy, if you specify rules for both a range of error codes as well as rules for specific error codes then rules with specific error codes have a higher priority. For example, assume that you configure a rule for 401 (Un-authorized) code, and another for all 4 series error codes (4XX). If the backend service returns a401, then the rule for 401 will be applied. However if the backend service returns a 403, the rule for4xx takes effect.
14612 14613 14614 14615 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14612 class CustomErrorResponsePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error_service ⇒ ::String
Returns The full or partial URL to the BackendBucket resource that contains the custom error content. Examples are:
- https://www.googleapis.com/compute/v1/projects/project/global/backendBuckets/myBackendBucket
- compute/v1/projects/project/global/backendBuckets/myBackendBucket
- global/backendBuckets/myBackendBucket
If errorService is not specified at lower levels likepathMatcher, pathRule and routeRule, an errorService specified at a higher level in theUrlMap will be used. IfUrlMap.defaultCustomErrorResponsePolicy contains one or moreerrorResponseRules[], it must specifyerrorService.
If load balancer cannot reach the backendBucket, a simple Not Found Error will be returned, with the original response code (oroverrideResponseCode if configured).
errorService is not supported for internal or regionalHTTP/HTTPS load balancers.
14612 14613 14614 14615 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14612 class CustomErrorResponsePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |