Class: Google::Cloud::Compute::V1::CustomErrorResponsePolicyCustomErrorResponseRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specifies the mapping between the response code that will be returned along with the custom error content and the response code returned by the backend service.

Instance Attribute Summary collapse

Instance Attribute Details

#match_response_codes::Array<::String>



5432
5433
5434
5435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 5432

class CustomErrorResponsePolicyCustomErrorResponseRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#override_response_code::Integer



5432
5433
5434
5435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 5432

class CustomErrorResponsePolicyCustomErrorResponseRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path::String



5432
5433
5434
5435
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 5432

class CustomErrorResponsePolicyCustomErrorResponseRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end