Class: Google::Cloud::Compute::V1::CustomerEncryptionKey
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::CustomerEncryptionKey
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#kms_key_name ⇒ ::String
The name of the encryption key that is stored in Google Cloud KMS.
-
#kms_key_service_account ⇒ ::String
The service account being used for the encryption request for the given KMS key.
-
#raw_key ⇒ ::String
[DEPRECATED] CSEK is no longer supported.
-
#rsa_encrypted_key ⇒ ::String
[DEPRECATED] CSEK is no longer supported.
-
#sha256 ⇒ ::String
[DEPRECATED] CSEK is no longer supported.
Instance Attribute Details
#kms_key_name ⇒ ::String
Returns The name of the encryption key that is stored in Google Cloud KMS. For example:
"kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key
The fully-qualifed key name may be returned for resource GET requests. For example:
"kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key /cryptoKeyVersions/1.
15567 15568 15569 15570 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15567 class CustomerEncryptionKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kms_key_service_account ⇒ ::String
Returns The service account being used for the encryption request for the given KMS key. If absent, the Compute Engine default service account is used. For example:
"kmsKeyServiceAccount": "name@project_id.iam.gserviceaccount.com/.
15567 15568 15569 15570 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15567 class CustomerEncryptionKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#raw_key ⇒ ::String
Returns [DEPRECATED] CSEK is no longer supported. Use CMEK instead. Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource. You can provide either the rawKey or thersaEncryptedKey. For example:
"rawKey": "SGVsbG8gZnJvbSBHb29nbGUgQ2xvdWQgUGxhdGZvcm0=".
15567 15568 15569 15570 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15567 class CustomerEncryptionKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rsa_encrypted_key ⇒ ::String
Returns [DEPRECATED] CSEK is no longer supported. Use CMEK instead. Specifies an RFC 4648 base64 encoded, RSA-wrapped 2048-bit customer-supplied encryption key to either encrypt or decrypt this resource. You can provide either the rawKey or thersaEncryptedKey. For example:
"rsaEncryptedKey": "ieCx/NcW06PcT7Ep1X6LUTc/hLvUDYyzSZPPVCVPTVEohpeHASqC8uw5TzyO9U+Fka9JFH z0mBibXUInrC/jEk014kCK/NPjYgEMOyssZ4ZINPKxlUh2zn1bV+MCaTICrdmuSBTWlUUiFoD D6PYznLwh8ZNdaheCeZ8ewEXgFQ8V+sDroLaN3Xs3MDTXQEMMoNUXMCZEIpg9Vtp9x2oe=="
The key must meet the following requirements before you can provide it to Compute Engine:
1. The key is wrapped using a RSA public key certificate provided by
Google.
2. After being wrapped, the key must be encoded in RFC 4648 base64
encoding.
Gets the RSA public key certificate provided by Google at:
https://cloud-certs.storage.googleapis.com/google-cloud-csek-ingress.pem.
15567 15568 15569 15570 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15567 class CustomerEncryptionKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sha256 ⇒ ::String
Returns [DEPRECATED] CSEK is no longer supported. Use CMEK instead. [Output only] TheRFC 4648 base64 encoded SHA-256 hash of the customer-supplied encryption key that protects this resource.
15567 15568 15569 15570 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15567 class CustomerEncryptionKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |