Class: Google::Cloud::Compute::V1::Denied
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Denied
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#I_p_protocol ⇒ ::String
The IP protocol to which this rule applies.
-
#ports ⇒ ::Array<::String>
An optional list of ports to which this rule applies.
Instance Attribute Details
#I_p_protocol ⇒ ::String
Returns The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp,icmp, esp, ah, ipip,sctp) or the IP protocol number.
17805 17806 17807 17808 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17805 class Denied include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ports ⇒ ::Array<::String>
Returns An optional list of ports to which this rule applies. This field is only applicable for the UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port.
Example inputs include: ["22"], ["80","443"], and ["12345-12349"].
17805 17806 17807 17808 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17805 class Denied include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |