Class: Google::Cloud::Compute::V1::DeprecationStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::DeprecationStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Deprecation status for a public resource.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#deleted ⇒ ::String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED.
-
#deprecated ⇒ ::String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED.
-
#obsolete ⇒ ::String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE.
-
#replacement ⇒ ::String
The URL of the suggested replacement for a deprecated resource.
-
#state ⇒ ::String
The deprecation state of this resource.
Instance Attribute Details
#deleted ⇒ ::String
Returns An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED. This is only informational and the status will not change unless the client explicitly changes it.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 18317 18318 18319 18320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18300 class DeprecationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a # warning indicating the deprecated resource and recommending its # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ACTIVE = 314_733_318 DELETED = 120_962_041 DEPRECATED = 463_360_435 OBSOLETE = 66_532_761 end end |
#deprecated ⇒ ::String
Returns An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED. This is only informational and the status will not change unless the client explicitly changes it.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 18317 18318 18319 18320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18300 class DeprecationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a # warning indicating the deprecated resource and recommending its # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ACTIVE = 314_733_318 DELETED = 120_962_041 DEPRECATED = 463_360_435 OBSOLETE = 66_532_761 end end |
#obsolete ⇒ ::String
Returns An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE. This is only informational and the status will not change unless the client explicitly changes it.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 18317 18318 18319 18320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18300 class DeprecationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a # warning indicating the deprecated resource and recommending its # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ACTIVE = 314_733_318 DELETED = 120_962_041 DEPRECATED = 463_360_435 OBSOLETE = 66_532_761 end end |
#replacement ⇒ ::String
Returns The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 18317 18318 18319 18320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18300 class DeprecationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a # warning indicating the deprecated resource and recommending its # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ACTIVE = 314_733_318 DELETED = 120_962_041 DEPRECATED = 463_360_435 OBSOLETE = 66_532_761 end end |
#state ⇒ ::String
Returns The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. Check the State enum for the list of possible values.
18300 18301 18302 18303 18304 18305 18306 18307 18308 18309 18310 18311 18312 18313 18314 18315 18316 18317 18318 18319 18320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18300 class DeprecationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a # warning indicating the deprecated resource and recommending its # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 ACTIVE = 314_733_318 DELETED = 120_962_041 DEPRECATED = 463_360_435 OBSOLETE = 66_532_761 end end |