Class: Google::Cloud::Compute::V1::DeprecationStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Deprecation status for a public resource.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#deleted::String

Returns An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED. This is only informational and the status will not change unless the client explicitly changes it.

Returns:

  • (::String)

    An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED. This is only informational and the status will not change unless the client explicitly changes it.



18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
18157
18158
18159
18160
18161
18162
18163
18164
18165
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18145

class DeprecationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED.
  # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a
  # warning indicating the deprecated resource and recommending its
  # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    ACTIVE = 314_733_318

    DELETED = 120_962_041

    DEPRECATED = 463_360_435

    OBSOLETE = 66_532_761
  end
end

#deprecated::String

Returns An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED. This is only informational and the status will not change unless the client explicitly changes it.

Returns:

  • (::String)

    An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED. This is only informational and the status will not change unless the client explicitly changes it.



18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
18157
18158
18159
18160
18161
18162
18163
18164
18165
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18145

class DeprecationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED.
  # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a
  # warning indicating the deprecated resource and recommending its
  # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    ACTIVE = 314_733_318

    DELETED = 120_962_041

    DEPRECATED = 463_360_435

    OBSOLETE = 66_532_761
  end
end

#obsolete::String

Returns An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE. This is only informational and the status will not change unless the client explicitly changes it.

Returns:

  • (::String)

    An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE. This is only informational and the status will not change unless the client explicitly changes it.



18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
18157
18158
18159
18160
18161
18162
18163
18164
18165
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18145

class DeprecationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED.
  # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a
  # warning indicating the deprecated resource and recommending its
  # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    ACTIVE = 314_733_318

    DELETED = 120_962_041

    DEPRECATED = 463_360_435

    OBSOLETE = 66_532_761
  end
end

#replacement::String

Returns The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource.

Returns:

  • (::String)

    The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource.



18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
18157
18158
18159
18160
18161
18162
18163
18164
18165
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18145

class DeprecationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED.
  # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a
  # warning indicating the deprecated resource and recommending its
  # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    ACTIVE = 314_733_318

    DELETED = 120_962_041

    DEPRECATED = 463_360_435

    OBSOLETE = 66_532_761
  end
end

#state::String

Returns The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. Check the State enum for the list of possible values.

Returns:

  • (::String)

    The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. Check the State enum for the list of possible values.



18145
18146
18147
18148
18149
18150
18151
18152
18153
18154
18155
18156
18157
18158
18159
18160
18161
18162
18163
18164
18165
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18145

class DeprecationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED.
  # Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a
  # warning indicating the deprecated resource and recommending its
  # replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    ACTIVE = 314_733_318

    DELETED = 120_962_041

    DEPRECATED = 463_360_435

    OBSOLETE = 66_532_761
  end
end