Module: Google::Cloud::Compute::V1::DeprecationStatus::State
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error.
Constant Summary collapse
- UNDEFINED_STATE =
A value indicating that the enum field is not set.
0- ACTIVE =
314_733_318- DELETED =
120_962_041- DEPRECATED =
463_360_435- OBSOLETE =
66_532_761