Class: Google::Cloud::Compute::V1::DiskInstantiationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A specification of the desired way to instantiate a disk in the instance template when its created from a source instance.

Defined Under Namespace

Modules: InstantiateFrom

Instance Attribute Summary collapse

Instance Attribute Details

#auto_delete::Boolean

Returns Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).

Returns:

  • (::Boolean)

    Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).



19083
19084
19085
19086
19087
19088
19089
19090
19091
19092
19093
19094
19095
19096
19097
19098
19099
19100
19101
19102
19103
19104
19105
19106
19107
19108
19109
19110
19111
19112
19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
19136
19137
19138
19139
19140
19141
19142
19143
19144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19083

class DiskInstantiationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether to include the disk and what image to use. Possible
  # values are:
  #
  #
  #      - source-image: to use the same image that was used to
  #      create the source instance's corresponding disk. Applicable to the boot
  #      disk and additional read-write disks.
  #      - source-image-family: to use the same image family that
  #      was used to create the source instance's corresponding disk. Applicable
  #      to the boot disk and additional read-write disks.
  #      - custom-image: to use a user-provided image url for disk
  #      creation. Applicable to the boot disk and additional read-write
  #      disks.
  #    - attach-read-only: to attach a read-only
  #      disk. Applicable to read-only disks.
  #      - do-not-include: to exclude a disk from the template.
  #      Applicable to additional read-write disks, local SSDs, and read-only
  #      disks.
  module InstantiateFrom
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANTIATE_FROM = 0

    # Attach the existing disk in read-only mode. The request will fail if the
    # disk was attached in read-write mode on the source instance. Applicable
    # to: read-only disks.
    ATTACH_READ_ONLY = 513_775_419

    # Create a blank disk. The disk will be created unformatted. Applicable to:
    # additional read-write disks, local SSDs.
    BLANK = 63_281_460

    # Use the custom image specified in the custom_image field. Applicable to:
    # boot disk, additional read-write disks.
    CUSTOM_IMAGE = 196_311_789

    # Use the default instantiation option for the corresponding type of disk.
    # For boot disk and any other R/W disks, new custom images will be created
    # from each disk. For read-only disks, they will be attached in read-only
    # mode. Local SSD disks will be created as blank volumes.
    DEFAULT = 115_302_945

    # Do not include the disk in the instance template. Applicable to:
    # additional read-write disks, local SSDs, read-only disks.
    DO_NOT_INCLUDE = 104_218_952

    # Use the same source image used for creation of the source instance's
    # corresponding disk. The request will fail if the source VM's disk was
    # created from a snapshot. Applicable to: boot disk, additional read-write
    # disks.
    SOURCE_IMAGE = 62_631_959

    # Use the same source image family used for creation of the source
    # instance's corresponding disk. The request will fail if the source image
    # of the source disk does not belong to any image family. Applicable to:
    # boot disk, additional read-write disks.
    SOURCE_IMAGE_FAMILY = 76_850_316
  end
end

#custom_image::String

Returns The custom source image to be used to restore this disk when instantiating this instance template.

Returns:

  • (::String)

    The custom source image to be used to restore this disk when instantiating this instance template.



19083
19084
19085
19086
19087
19088
19089
19090
19091
19092
19093
19094
19095
19096
19097
19098
19099
19100
19101
19102
19103
19104
19105
19106
19107
19108
19109
19110
19111
19112
19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
19136
19137
19138
19139
19140
19141
19142
19143
19144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19083

class DiskInstantiationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether to include the disk and what image to use. Possible
  # values are:
  #
  #
  #      - source-image: to use the same image that was used to
  #      create the source instance's corresponding disk. Applicable to the boot
  #      disk and additional read-write disks.
  #      - source-image-family: to use the same image family that
  #      was used to create the source instance's corresponding disk. Applicable
  #      to the boot disk and additional read-write disks.
  #      - custom-image: to use a user-provided image url for disk
  #      creation. Applicable to the boot disk and additional read-write
  #      disks.
  #    - attach-read-only: to attach a read-only
  #      disk. Applicable to read-only disks.
  #      - do-not-include: to exclude a disk from the template.
  #      Applicable to additional read-write disks, local SSDs, and read-only
  #      disks.
  module InstantiateFrom
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANTIATE_FROM = 0

    # Attach the existing disk in read-only mode. The request will fail if the
    # disk was attached in read-write mode on the source instance. Applicable
    # to: read-only disks.
    ATTACH_READ_ONLY = 513_775_419

    # Create a blank disk. The disk will be created unformatted. Applicable to:
    # additional read-write disks, local SSDs.
    BLANK = 63_281_460

    # Use the custom image specified in the custom_image field. Applicable to:
    # boot disk, additional read-write disks.
    CUSTOM_IMAGE = 196_311_789

    # Use the default instantiation option for the corresponding type of disk.
    # For boot disk and any other R/W disks, new custom images will be created
    # from each disk. For read-only disks, they will be attached in read-only
    # mode. Local SSD disks will be created as blank volumes.
    DEFAULT = 115_302_945

    # Do not include the disk in the instance template. Applicable to:
    # additional read-write disks, local SSDs, read-only disks.
    DO_NOT_INCLUDE = 104_218_952

    # Use the same source image used for creation of the source instance's
    # corresponding disk. The request will fail if the source VM's disk was
    # created from a snapshot. Applicable to: boot disk, additional read-write
    # disks.
    SOURCE_IMAGE = 62_631_959

    # Use the same source image family used for creation of the source
    # instance's corresponding disk. The request will fail if the source image
    # of the source disk does not belong to any image family. Applicable to:
    # boot disk, additional read-write disks.
    SOURCE_IMAGE_FAMILY = 76_850_316
  end
end

#device_name::String

Returns Specifies the device name of the disk to which the configurations apply to.

Returns:

  • (::String)

    Specifies the device name of the disk to which the configurations apply to.



19083
19084
19085
19086
19087
19088
19089
19090
19091
19092
19093
19094
19095
19096
19097
19098
19099
19100
19101
19102
19103
19104
19105
19106
19107
19108
19109
19110
19111
19112
19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
19136
19137
19138
19139
19140
19141
19142
19143
19144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19083

class DiskInstantiationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether to include the disk and what image to use. Possible
  # values are:
  #
  #
  #      - source-image: to use the same image that was used to
  #      create the source instance's corresponding disk. Applicable to the boot
  #      disk and additional read-write disks.
  #      - source-image-family: to use the same image family that
  #      was used to create the source instance's corresponding disk. Applicable
  #      to the boot disk and additional read-write disks.
  #      - custom-image: to use a user-provided image url for disk
  #      creation. Applicable to the boot disk and additional read-write
  #      disks.
  #    - attach-read-only: to attach a read-only
  #      disk. Applicable to read-only disks.
  #      - do-not-include: to exclude a disk from the template.
  #      Applicable to additional read-write disks, local SSDs, and read-only
  #      disks.
  module InstantiateFrom
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANTIATE_FROM = 0

    # Attach the existing disk in read-only mode. The request will fail if the
    # disk was attached in read-write mode on the source instance. Applicable
    # to: read-only disks.
    ATTACH_READ_ONLY = 513_775_419

    # Create a blank disk. The disk will be created unformatted. Applicable to:
    # additional read-write disks, local SSDs.
    BLANK = 63_281_460

    # Use the custom image specified in the custom_image field. Applicable to:
    # boot disk, additional read-write disks.
    CUSTOM_IMAGE = 196_311_789

    # Use the default instantiation option for the corresponding type of disk.
    # For boot disk and any other R/W disks, new custom images will be created
    # from each disk. For read-only disks, they will be attached in read-only
    # mode. Local SSD disks will be created as blank volumes.
    DEFAULT = 115_302_945

    # Do not include the disk in the instance template. Applicable to:
    # additional read-write disks, local SSDs, read-only disks.
    DO_NOT_INCLUDE = 104_218_952

    # Use the same source image used for creation of the source instance's
    # corresponding disk. The request will fail if the source VM's disk was
    # created from a snapshot. Applicable to: boot disk, additional read-write
    # disks.
    SOURCE_IMAGE = 62_631_959

    # Use the same source image family used for creation of the source
    # instance's corresponding disk. The request will fail if the source image
    # of the source disk does not belong to any image family. Applicable to:
    # boot disk, additional read-write disks.
    SOURCE_IMAGE_FAMILY = 76_850_316
  end
end

#instantiate_from::String

Returns Specifies whether to include the disk and what image to use. Possible values are:

 - source-image: to use the same image that was used to
 create the source instance's corresponding disk. Applicable to the boot
 disk and additional read-write disks.
 - source-image-family: to use the same image family that
 was used to create the source instance's corresponding disk. Applicable
 to the boot disk and additional read-write disks.
 - custom-image: to use a user-provided image url for disk
 creation. Applicable to the boot disk and additional read-write
 disks.
  • attach-read-only: to attach a read-only disk. Applicable to read-only disks.
    • do-not-include: to exclude a disk from the template. Applicable to additional read-write disks, local SSDs, and read-only disks. Check the InstantiateFrom enum for the list of possible values.

Returns:

  • (::String)

    Specifies whether to include the disk and what image to use. Possible values are:

     - source-image: to use the same image that was used to
     create the source instance's corresponding disk. Applicable to the boot
     disk and additional read-write disks.
     - source-image-family: to use the same image family that
     was used to create the source instance's corresponding disk. Applicable
     to the boot disk and additional read-write disks.
     - custom-image: to use a user-provided image url for disk
     creation. Applicable to the boot disk and additional read-write
     disks.
    
    • attach-read-only: to attach a read-only disk. Applicable to read-only disks.
      • do-not-include: to exclude a disk from the template. Applicable to additional read-write disks, local SSDs, and read-only disks. Check the InstantiateFrom enum for the list of possible values.


19083
19084
19085
19086
19087
19088
19089
19090
19091
19092
19093
19094
19095
19096
19097
19098
19099
19100
19101
19102
19103
19104
19105
19106
19107
19108
19109
19110
19111
19112
19113
19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
19136
19137
19138
19139
19140
19141
19142
19143
19144
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19083

class DiskInstantiationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether to include the disk and what image to use. Possible
  # values are:
  #
  #
  #      - source-image: to use the same image that was used to
  #      create the source instance's corresponding disk. Applicable to the boot
  #      disk and additional read-write disks.
  #      - source-image-family: to use the same image family that
  #      was used to create the source instance's corresponding disk. Applicable
  #      to the boot disk and additional read-write disks.
  #      - custom-image: to use a user-provided image url for disk
  #      creation. Applicable to the boot disk and additional read-write
  #      disks.
  #    - attach-read-only: to attach a read-only
  #      disk. Applicable to read-only disks.
  #      - do-not-include: to exclude a disk from the template.
  #      Applicable to additional read-write disks, local SSDs, and read-only
  #      disks.
  module InstantiateFrom
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANTIATE_FROM = 0

    # Attach the existing disk in read-only mode. The request will fail if the
    # disk was attached in read-write mode on the source instance. Applicable
    # to: read-only disks.
    ATTACH_READ_ONLY = 513_775_419

    # Create a blank disk. The disk will be created unformatted. Applicable to:
    # additional read-write disks, local SSDs.
    BLANK = 63_281_460

    # Use the custom image specified in the custom_image field. Applicable to:
    # boot disk, additional read-write disks.
    CUSTOM_IMAGE = 196_311_789

    # Use the default instantiation option for the corresponding type of disk.
    # For boot disk and any other R/W disks, new custom images will be created
    # from each disk. For read-only disks, they will be attached in read-only
    # mode. Local SSD disks will be created as blank volumes.
    DEFAULT = 115_302_945

    # Do not include the disk in the instance template. Applicable to:
    # additional read-write disks, local SSDs, read-only disks.
    DO_NOT_INCLUDE = 104_218_952

    # Use the same source image used for creation of the source instance's
    # corresponding disk. The request will fail if the source VM's disk was
    # created from a snapshot. Applicable to: boot disk, additional read-write
    # disks.
    SOURCE_IMAGE = 62_631_959

    # Use the same source image family used for creation of the source
    # instance's corresponding disk. The request will fail if the source image
    # of the source disk does not belong to any image family. Applicable to:
    # boot disk, additional read-write disks.
    SOURCE_IMAGE_FAMILY = 76_850_316
  end
end