Class: Google::Cloud::Compute::V1::DiskInstantiationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A specification of the desired way to instantiate a disk in the instance template when its created from a source instance.

Defined Under Namespace

Modules: InstantiateFrom

Instance Attribute Summary collapse

Instance Attribute Details

#auto_delete::Boolean

Returns Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).

Returns:

  • (::Boolean)

    Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).



18654
18655
18656
18657
18658
18659
18660
18661
18662
18663
18664
18665
18666
18667
18668
18669
18670
18671
18672
18673
18674
18675
18676
18677
18678
18679
18680
18681
18682
18683
18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
18695
18696
18697
18698
18699
18700
18701
18702
18703
18704
18705
18706
18707
18708
18709
18710
18711
18712
18713
18714
18715
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18654

class DiskInstantiationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether to include the disk and what image to use. Possible
  # values are:
  #
  #
  #      - source-image: to use the same image that was used to
  #      create the source instance's corresponding disk. Applicable to the boot
  #      disk and additional read-write disks.
  #      - source-image-family: to use the same image family that
  #      was used to create the source instance's corresponding disk. Applicable
  #      to the boot disk and additional read-write disks.
  #      - custom-image: to use a user-provided image url for disk
  #      creation. Applicable to the boot disk and additional read-write
  #      disks.
  #    - attach-read-only: to attach a read-only
  #      disk. Applicable to read-only disks.
  #      - do-not-include: to exclude a disk from the template.
  #      Applicable to additional read-write disks, local SSDs, and read-only
  #      disks.
  module InstantiateFrom
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANTIATE_FROM = 0

    # Attach the existing disk in read-only mode. The request will fail if the
    # disk was attached in read-write mode on the source instance. Applicable
    # to: read-only disks.
    ATTACH_READ_ONLY = 513_775_419

    # Create a blank disk. The disk will be created unformatted. Applicable to:
    # additional read-write disks, local SSDs.
    BLANK = 63_281_460

    # Use the custom image specified in the custom_image field. Applicable to:
    # boot disk, additional read-write disks.
    CUSTOM_IMAGE = 196_311_789

    # Use the default instantiation option for the corresponding type of disk.
    # For boot disk and any other R/W disks, new custom images will be created
    # from each disk. For read-only disks, they will be attached in read-only
    # mode. Local SSD disks will be created as blank volumes.
    DEFAULT = 115_302_945

    # Do not include the disk in the instance template. Applicable to:
    # additional read-write disks, local SSDs, read-only disks.
    DO_NOT_INCLUDE = 104_218_952

    # Use the same source image used for creation of the source instance's
    # corresponding disk. The request will fail if the source VM's disk was
    # created from a snapshot. Applicable to: boot disk, additional read-write
    # disks.
    SOURCE_IMAGE = 62_631_959

    # Use the same source image family used for creation of the source
    # instance's corresponding disk. The request will fail if the source image
    # of the source disk does not belong to any image family. Applicable to:
    # boot disk, additional read-write disks.
    SOURCE_IMAGE_FAMILY = 76_850_316
  end
end

#custom_image::String

Returns The custom source image to be used to restore this disk when instantiating this instance template.

Returns:

  • (::String)

    The custom source image to be used to restore this disk when instantiating this instance template.



18654
18655
18656
18657
18658
18659
18660
18661
18662
18663
18664
18665
18666
18667
18668
18669
18670
18671
18672
18673
18674
18675
18676
18677
18678
18679
18680
18681
18682
18683
18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
18695
18696
18697
18698
18699
18700
18701
18702
18703
18704
18705
18706
18707
18708
18709
18710
18711
18712
18713
18714
18715
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18654

class DiskInstantiationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether to include the disk and what image to use. Possible
  # values are:
  #
  #
  #      - source-image: to use the same image that was used to
  #      create the source instance's corresponding disk. Applicable to the boot
  #      disk and additional read-write disks.
  #      - source-image-family: to use the same image family that
  #      was used to create the source instance's corresponding disk. Applicable
  #      to the boot disk and additional read-write disks.
  #      - custom-image: to use a user-provided image url for disk
  #      creation. Applicable to the boot disk and additional read-write
  #      disks.
  #    - attach-read-only: to attach a read-only
  #      disk. Applicable to read-only disks.
  #      - do-not-include: to exclude a disk from the template.
  #      Applicable to additional read-write disks, local SSDs, and read-only
  #      disks.
  module InstantiateFrom
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANTIATE_FROM = 0

    # Attach the existing disk in read-only mode. The request will fail if the
    # disk was attached in read-write mode on the source instance. Applicable
    # to: read-only disks.
    ATTACH_READ_ONLY = 513_775_419

    # Create a blank disk. The disk will be created unformatted. Applicable to:
    # additional read-write disks, local SSDs.
    BLANK = 63_281_460

    # Use the custom image specified in the custom_image field. Applicable to:
    # boot disk, additional read-write disks.
    CUSTOM_IMAGE = 196_311_789

    # Use the default instantiation option for the corresponding type of disk.
    # For boot disk and any other R/W disks, new custom images will be created
    # from each disk. For read-only disks, they will be attached in read-only
    # mode. Local SSD disks will be created as blank volumes.
    DEFAULT = 115_302_945

    # Do not include the disk in the instance template. Applicable to:
    # additional read-write disks, local SSDs, read-only disks.
    DO_NOT_INCLUDE = 104_218_952

    # Use the same source image used for creation of the source instance's
    # corresponding disk. The request will fail if the source VM's disk was
    # created from a snapshot. Applicable to: boot disk, additional read-write
    # disks.
    SOURCE_IMAGE = 62_631_959

    # Use the same source image family used for creation of the source
    # instance's corresponding disk. The request will fail if the source image
    # of the source disk does not belong to any image family. Applicable to:
    # boot disk, additional read-write disks.
    SOURCE_IMAGE_FAMILY = 76_850_316
  end
end

#device_name::String

Returns Specifies the device name of the disk to which the configurations apply to.

Returns:

  • (::String)

    Specifies the device name of the disk to which the configurations apply to.



18654
18655
18656
18657
18658
18659
18660
18661
18662
18663
18664
18665
18666
18667
18668
18669
18670
18671
18672
18673
18674
18675
18676
18677
18678
18679
18680
18681
18682
18683
18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
18695
18696
18697
18698
18699
18700
18701
18702
18703
18704
18705
18706
18707
18708
18709
18710
18711
18712
18713
18714
18715
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18654

class DiskInstantiationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether to include the disk and what image to use. Possible
  # values are:
  #
  #
  #      - source-image: to use the same image that was used to
  #      create the source instance's corresponding disk. Applicable to the boot
  #      disk and additional read-write disks.
  #      - source-image-family: to use the same image family that
  #      was used to create the source instance's corresponding disk. Applicable
  #      to the boot disk and additional read-write disks.
  #      - custom-image: to use a user-provided image url for disk
  #      creation. Applicable to the boot disk and additional read-write
  #      disks.
  #    - attach-read-only: to attach a read-only
  #      disk. Applicable to read-only disks.
  #      - do-not-include: to exclude a disk from the template.
  #      Applicable to additional read-write disks, local SSDs, and read-only
  #      disks.
  module InstantiateFrom
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANTIATE_FROM = 0

    # Attach the existing disk in read-only mode. The request will fail if the
    # disk was attached in read-write mode on the source instance. Applicable
    # to: read-only disks.
    ATTACH_READ_ONLY = 513_775_419

    # Create a blank disk. The disk will be created unformatted. Applicable to:
    # additional read-write disks, local SSDs.
    BLANK = 63_281_460

    # Use the custom image specified in the custom_image field. Applicable to:
    # boot disk, additional read-write disks.
    CUSTOM_IMAGE = 196_311_789

    # Use the default instantiation option for the corresponding type of disk.
    # For boot disk and any other R/W disks, new custom images will be created
    # from each disk. For read-only disks, they will be attached in read-only
    # mode. Local SSD disks will be created as blank volumes.
    DEFAULT = 115_302_945

    # Do not include the disk in the instance template. Applicable to:
    # additional read-write disks, local SSDs, read-only disks.
    DO_NOT_INCLUDE = 104_218_952

    # Use the same source image used for creation of the source instance's
    # corresponding disk. The request will fail if the source VM's disk was
    # created from a snapshot. Applicable to: boot disk, additional read-write
    # disks.
    SOURCE_IMAGE = 62_631_959

    # Use the same source image family used for creation of the source
    # instance's corresponding disk. The request will fail if the source image
    # of the source disk does not belong to any image family. Applicable to:
    # boot disk, additional read-write disks.
    SOURCE_IMAGE_FAMILY = 76_850_316
  end
end

#instantiate_from::String

Returns Specifies whether to include the disk and what image to use. Possible values are:

 - source-image: to use the same image that was used to
 create the source instance's corresponding disk. Applicable to the boot
 disk and additional read-write disks.
 - source-image-family: to use the same image family that
 was used to create the source instance's corresponding disk. Applicable
 to the boot disk and additional read-write disks.
 - custom-image: to use a user-provided image url for disk
 creation. Applicable to the boot disk and additional read-write
 disks.
  • attach-read-only: to attach a read-only disk. Applicable to read-only disks.
    • do-not-include: to exclude a disk from the template. Applicable to additional read-write disks, local SSDs, and read-only disks. Check the InstantiateFrom enum for the list of possible values.

Returns:

  • (::String)

    Specifies whether to include the disk and what image to use. Possible values are:

     - source-image: to use the same image that was used to
     create the source instance's corresponding disk. Applicable to the boot
     disk and additional read-write disks.
     - source-image-family: to use the same image family that
     was used to create the source instance's corresponding disk. Applicable
     to the boot disk and additional read-write disks.
     - custom-image: to use a user-provided image url for disk
     creation. Applicable to the boot disk and additional read-write
     disks.
    
    • attach-read-only: to attach a read-only disk. Applicable to read-only disks.
      • do-not-include: to exclude a disk from the template. Applicable to additional read-write disks, local SSDs, and read-only disks. Check the InstantiateFrom enum for the list of possible values.


18654
18655
18656
18657
18658
18659
18660
18661
18662
18663
18664
18665
18666
18667
18668
18669
18670
18671
18672
18673
18674
18675
18676
18677
18678
18679
18680
18681
18682
18683
18684
18685
18686
18687
18688
18689
18690
18691
18692
18693
18694
18695
18696
18697
18698
18699
18700
18701
18702
18703
18704
18705
18706
18707
18708
18709
18710
18711
18712
18713
18714
18715
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18654

class DiskInstantiationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether to include the disk and what image to use. Possible
  # values are:
  #
  #
  #      - source-image: to use the same image that was used to
  #      create the source instance's corresponding disk. Applicable to the boot
  #      disk and additional read-write disks.
  #      - source-image-family: to use the same image family that
  #      was used to create the source instance's corresponding disk. Applicable
  #      to the boot disk and additional read-write disks.
  #      - custom-image: to use a user-provided image url for disk
  #      creation. Applicable to the boot disk and additional read-write
  #      disks.
  #    - attach-read-only: to attach a read-only
  #      disk. Applicable to read-only disks.
  #      - do-not-include: to exclude a disk from the template.
  #      Applicable to additional read-write disks, local SSDs, and read-only
  #      disks.
  module InstantiateFrom
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANTIATE_FROM = 0

    # Attach the existing disk in read-only mode. The request will fail if the
    # disk was attached in read-write mode on the source instance. Applicable
    # to: read-only disks.
    ATTACH_READ_ONLY = 513_775_419

    # Create a blank disk. The disk will be created unformatted. Applicable to:
    # additional read-write disks, local SSDs.
    BLANK = 63_281_460

    # Use the custom image specified in the custom_image field. Applicable to:
    # boot disk, additional read-write disks.
    CUSTOM_IMAGE = 196_311_789

    # Use the default instantiation option for the corresponding type of disk.
    # For boot disk and any other R/W disks, new custom images will be created
    # from each disk. For read-only disks, they will be attached in read-only
    # mode. Local SSD disks will be created as blank volumes.
    DEFAULT = 115_302_945

    # Do not include the disk in the instance template. Applicable to:
    # additional read-write disks, local SSDs, read-only disks.
    DO_NOT_INCLUDE = 104_218_952

    # Use the same source image used for creation of the source instance's
    # corresponding disk. The request will fail if the source VM's disk was
    # created from a snapshot. Applicable to: boot disk, additional read-write
    # disks.
    SOURCE_IMAGE = 62_631_959

    # Use the same source image family used for creation of the source
    # instance's corresponding disk. The request will fail if the source image
    # of the source disk does not belong to any image family. Applicable to:
    # boot disk, additional read-write disks.
    SOURCE_IMAGE_FAMILY = 76_850_316
  end
end