Class: Google::Cloud::Compute::V1::DiskResourceStatusAsyncReplicationStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::DiskResourceStatusAsyncReplicationStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::String
Check the State enum for the list of possible values.
Instance Attribute Details
#state ⇒ ::String
Returns Check the State enum for the list of possible values.
19242 19243 19244 19245 19246 19247 19248 19249 19250 19251 19252 19253 19254 19255 19256 19257 19258 19259 19260 19261 19262 19263 19264 19265 19266 19267 19268 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19242 class DiskResourceStatusAsyncReplicationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Replication is active. ACTIVE = 314_733_318 # Secondary disk is created and is waiting for replication to start. CREATED = 135_924_424 # Replication is starting. STARTING = 488_820_800 STATE_UNSPECIFIED = 470_755_401 # Replication is stopped. STOPPED = 444_276_141 # Replication is stopping. STOPPING = 350_791_796 end end |