Class: Google::Cloud::Compute::V1::DiskResourceStatusAsyncReplicationStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#state::String

Returns Check the State enum for the list of possible values.

Returns:

  • (::String)

    Check the State enum for the list of possible values.



19087
19088
19089
19090
19091
19092
19093
19094
19095
19096
19097
19098
19099
19100
19101
19102
19103
19104
19105
19106
19107
19108
19109
19110
19111
19112
19113
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19087

class DiskResourceStatusAsyncReplicationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Replication is active.
    ACTIVE = 314_733_318

    # Secondary disk is created and is waiting for replication to start.
    CREATED = 135_924_424

    # Replication is starting.
    STARTING = 488_820_800

    STATE_UNSPECIFIED = 470_755_401

    # Replication is stopped.
    STOPPED = 444_276_141

    # Replication is stopping.
    STOPPING = 350_791_796
  end
end