Class: Google::Cloud::Compute::V1::DiskResourceStatusAsyncReplicationStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::DiskResourceStatusAsyncReplicationStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::String
Check the State enum for the list of possible values.
Instance Attribute Details
#state ⇒ ::String
Returns Check the State enum for the list of possible values.
7638 7639 7640 7641 7642 7643 7644 7645 7646 7647 7648 7649 7650 7651 7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7638 class DiskResourceStatusAsyncReplicationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Replication is active. ACTIVE = 314_733_318 # Secondary disk is created and is waiting for replication to start. CREATED = 135_924_424 # Replication is starting. STARTING = 488_820_800 STATE_UNSPECIFIED = 470_755_401 # Replication is stopped. STOPPED = 444_276_141 # Replication is stopping. STOPPING = 350_791_796 end end |