Class: Google::Cloud::Compute::V1::DiskResourceStatusAsyncReplicationStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#state::String

Returns Check the State enum for the list of possible values.

Returns:

  • (::String)

    Check the State enum for the list of possible values.



7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
7622
7623
7624
7625
7626
7627
7628
7629
7630
7631
7632
7633
7634
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7608

class DiskResourceStatusAsyncReplicationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Replication is active.
    ACTIVE = 314_733_318

    # Secondary disk is created and is waiting for replication to start.
    CREATED = 135_924_424

    # Replication is starting.
    STARTING = 488_820_800

    STATE_UNSPECIFIED = 470_755_401

    # Replication is stopped.
    STOPPED = 444_276_141

    # Replication is stopping.
    STOPPING = 350_791_796
  end
end