Class: Google::Cloud::Compute::V1::DiskResourceStatusAsyncReplicationStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#state::String



7584
7585
7586
7587
7588
7589
7590
7591
7592
7593
7594
7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 7584

class DiskResourceStatusAsyncReplicationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Replication is active.
    ACTIVE = 314_733_318

    # Secondary disk is created and is waiting for replication to start.
    CREATED = 135_924_424

    # Replication is starting.
    STARTING = 488_820_800

    STATE_UNSPECIFIED = 470_755_401

    # Replication is stopped.
    STOPPED = 444_276_141

    # Replication is stopping.
    STOPPING = 350_791_796
  end
end