Class: Google::Cloud::Compute::V1::DiskResourceStatusAsyncReplicationStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::DiskResourceStatusAsyncReplicationStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::String
Check the State enum for the list of possible values.
Instance Attribute Details
#state ⇒ ::String
Returns Check the State enum for the list of possible values.
19861 19862 19863 19864 19865 19866 19867 19868 19869 19870 19871 19872 19873 19874 19875 19876 19877 19878 19879 19880 19881 19882 19883 19884 19885 19886 19887 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19861 class DiskResourceStatusAsyncReplicationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Replication is active. ACTIVE = 314_733_318 # Secondary disk is created and is waiting for replication to start. CREATED = 135_924_424 # Replication is starting. STARTING = 488_820_800 STATE_UNSPECIFIED = 470_755_401 # Replication is stopped. STOPPED = 444_276_141 # Replication is stopping. STOPPING = 350_791_796 end end |