Class: Google::Cloud::Compute::V1::DistributionPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: TargetShape

Instance Attribute Summary collapse

Instance Attribute Details

#target_shape::String

Returns The distribution shape to which the group converges either proactively or on resize events (depending on the value set inupdatePolicy.instanceRedistributionType). Check the TargetShape enum for the list of possible values.

Returns:

  • (::String)

    The distribution shape to which the group converges either proactively or on resize events (depending on the value set inupdatePolicy.instanceRedistributionType). Check the TargetShape enum for the list of possible values.



19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
19136
19137
19138
19139
19140
19141
19142
19143
19144
19145
19146
19147
19148
19149
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19114

class DistributionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The distribution shape to which the group converges either proactively or
  # on resize events (depending on the value set inupdatePolicy.instanceRedistributionType).
  module TargetShape
    # A value indicating that the enum field is not set.
    UNDEFINED_TARGET_SHAPE = 0

    # The group picks zones for creating VM instances to fulfill the requested
    # number of VMs within present resource constraints and to maximize
    # utilization of unused zonal reservations. Recommended for batch workloads
    # that do not require high availability.
    ANY = 64_972

    # The group creates all VM instances within a single zone. The zone is
    # selected based on the present resource constraints and to maximize
    # utilization of unused zonal reservations.
    # Recommended for batch workloads with heavy interprocess communication.
    ANY_SINGLE_ZONE = 61_100_880

    # The group prioritizes acquisition of resources, scheduling VMs in zones
    # where resources are available while distributing VMs as evenly as
    # possible across selected zones to minimize the impact of zonal failure.
    # Recommended for highly available serving workloads.
    BALANCED = 468_409_608

    # The group schedules VM instance creation and deletion to achieve and
    # maintain an even number of managed instances across the selected zones.
    # The distribution is even when the number of managed instances does not
    # differ by more than 1 between any two zones. Recommended for highly
    # available serving workloads.
    EVEN = 2_140_442
  end
end

#zones::Array<::Google::Cloud::Compute::V1::DistributionPolicyZoneConfiguration>

Returns Zones where the regional managed instance group will create and manage its instances. By default, a regional MIG doesn't automatically select an AI zone to create instances, even if an AI zone is available in the specified region. To create instances in an AI zone in the selected region, you must explicitly specify it in the distribution policy together with the other preferred zones.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::DistributionPolicyZoneConfiguration>)

    Zones where the regional managed instance group will create and manage its instances. By default, a regional MIG doesn't automatically select an AI zone to create instances, even if an AI zone is available in the specified region. To create instances in an AI zone in the selected region, you must explicitly specify it in the distribution policy together with the other preferred zones.



19114
19115
19116
19117
19118
19119
19120
19121
19122
19123
19124
19125
19126
19127
19128
19129
19130
19131
19132
19133
19134
19135
19136
19137
19138
19139
19140
19141
19142
19143
19144
19145
19146
19147
19148
19149
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19114

class DistributionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The distribution shape to which the group converges either proactively or
  # on resize events (depending on the value set inupdatePolicy.instanceRedistributionType).
  module TargetShape
    # A value indicating that the enum field is not set.
    UNDEFINED_TARGET_SHAPE = 0

    # The group picks zones for creating VM instances to fulfill the requested
    # number of VMs within present resource constraints and to maximize
    # utilization of unused zonal reservations. Recommended for batch workloads
    # that do not require high availability.
    ANY = 64_972

    # The group creates all VM instances within a single zone. The zone is
    # selected based on the present resource constraints and to maximize
    # utilization of unused zonal reservations.
    # Recommended for batch workloads with heavy interprocess communication.
    ANY_SINGLE_ZONE = 61_100_880

    # The group prioritizes acquisition of resources, scheduling VMs in zones
    # where resources are available while distributing VMs as evenly as
    # possible across selected zones to minimize the impact of zonal failure.
    # Recommended for highly available serving workloads.
    BALANCED = 468_409_608

    # The group schedules VM instance creation and deletion to achieve and
    # maintain an even number of managed instances across the selected zones.
    # The distribution is even when the number of managed instances does not
    # differ by more than 1 between any two zones. Recommended for highly
    # available serving workloads.
    EVEN = 2_140_442
  end
end