Class: Google::Cloud::Compute::V1::ExchangedPeeringRoute

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#dest_range::String

Returns The destination range of the route.

Returns:

  • (::String)

    The destination range of the route.



19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
19372
19373
19374
19375
19376
19377
19378
19379
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19361

class ExchangedPeeringRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the peering route.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # For routes exported from local network.
    DYNAMIC_PEERING_ROUTE = 469_794_858

    # The peering route.
    STATIC_PEERING_ROUTE = 473_407_545

    # The peering route corresponding to subnetwork range.
    SUBNET_PEERING_ROUTE = 465_782_504
  end
end

#imported::Boolean

Returns True if the peering route has been imported from a peer. The actual import happens if the field networkPeering.importCustomRoutes is true for this network, and networkPeering.exportCustomRoutes is true for the peer network, and the import does not result in a route conflict.

Returns:

  • (::Boolean)

    True if the peering route has been imported from a peer. The actual import happens if the field networkPeering.importCustomRoutes is true for this network, and networkPeering.exportCustomRoutes is true for the peer network, and the import does not result in a route conflict.



19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
19372
19373
19374
19375
19376
19377
19378
19379
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19361

class ExchangedPeeringRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the peering route.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # For routes exported from local network.
    DYNAMIC_PEERING_ROUTE = 469_794_858

    # The peering route.
    STATIC_PEERING_ROUTE = 473_407_545

    # The peering route corresponding to subnetwork range.
    SUBNET_PEERING_ROUTE = 465_782_504
  end
end

#next_hop_region::String

Returns The region of peering route next hop, only applies to dynamic routes.

Returns:

  • (::String)

    The region of peering route next hop, only applies to dynamic routes.



19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
19372
19373
19374
19375
19376
19377
19378
19379
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19361

class ExchangedPeeringRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the peering route.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # For routes exported from local network.
    DYNAMIC_PEERING_ROUTE = 469_794_858

    # The peering route.
    STATIC_PEERING_ROUTE = 473_407_545

    # The peering route corresponding to subnetwork range.
    SUBNET_PEERING_ROUTE = 465_782_504
  end
end

#priority::Integer

Returns The priority of the peering route.

Returns:

  • (::Integer)

    The priority of the peering route.



19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
19372
19373
19374
19375
19376
19377
19378
19379
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19361

class ExchangedPeeringRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the peering route.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # For routes exported from local network.
    DYNAMIC_PEERING_ROUTE = 469_794_858

    # The peering route.
    STATIC_PEERING_ROUTE = 473_407_545

    # The peering route corresponding to subnetwork range.
    SUBNET_PEERING_ROUTE = 465_782_504
  end
end

#type::String

Returns The type of the peering route. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    The type of the peering route. Check the Type enum for the list of possible values.



19361
19362
19363
19364
19365
19366
19367
19368
19369
19370
19371
19372
19373
19374
19375
19376
19377
19378
19379
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19361

class ExchangedPeeringRoute
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the peering route.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # For routes exported from local network.
    DYNAMIC_PEERING_ROUTE = 469_794_858

    # The peering route.
    STATIC_PEERING_ROUTE = 473_407_545

    # The peering route corresponding to subnetwork range.
    SUBNET_PEERING_ROUTE = 465_782_504
  end
end