Class: Google::Cloud::Compute::V1::ExternalVpnGateway

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents an external VPN gateway.

External VPN gateway is the on-premises VPN gateway(s) or another cloud provider's VPN gateway that connects to your Google Cloud VPN gateway.

To create a highly available VPN from Google Cloud Platform to your VPN gateway or another cloud provider's VPN gateway, you must create a external VPN gateway resource with information about the other gateway.

For more information about using external VPN gateways, see Creating an HA VPN gateway and tunnel pair to a peer VPN.

Defined Under Namespace

Modules: RedundancyType Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

#interfaces::Array<::Google::Cloud::Compute::V1::ExternalVpnGatewayInterface>

Returns A list of interfaces for this external VPN gateway.

If your peer-side gateway is an on-premises gateway and non-AWS cloud providers' gateway, at most two interfaces can be provided for an external VPN gateway. If your peer side is an AWS virtual private gateway, four interfaces should be provided for an external VPN gateway.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::ExternalVpnGatewayInterface>)

    A list of interfaces for this external VPN gateway.

    If your peer-side gateway is an on-premises gateway and non-AWS cloud providers' gateway, at most two interfaces can be provided for an external VPN gateway. If your peer side is an AWS virtual private gateway, four interfaces should be provided for an external VPN gateway.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#externalVpnGateway for externalVpnGateways.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Alwayscompute#externalVpnGateway for externalVpnGateways.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

#label_fingerprint::String

Returns A fingerprint for the labels being applied to this ExternalVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.

To see the latest fingerprint, make a get() request to retrieve an ExternalVpnGateway.

Returns:

  • (::String)

    A fingerprint for the labels being applied to this ExternalVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.

    To see the latest fingerprint, make a get() request to retrieve an ExternalVpnGateway.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

#name::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

#params::Google::Cloud::Compute::V1::ExternalVpnGatewayParams

Returns Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.

Returns:



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

#redundancy_type::String

Returns Indicates the user-supplied redundancy type of this external VPN gateway. Check the RedundancyType enum for the list of possible values.

Returns:

  • (::String)

    Indicates the user-supplied redundancy type of this external VPN gateway. Check the RedundancyType enum for the list of possible values.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for the resource.



19838
19839
19840
19841
19842
19843
19844
19845
19846
19847
19848
19849
19850
19851
19852
19853
19854
19855
19856
19857
19858
19859
19860
19861
19862
19863
19864
19865
19866
19867
19868
19869
19870
19871
19872
19873
19874
19875
19876
19877
19878
19879
19880
19881
19882
19883
19884
19885
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19838

class ExternalVpnGateway
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the user-supplied redundancy type of this external VPN gateway.
  module RedundancyType
    # A value indicating that the enum field is not set.
    UNDEFINED_REDUNDANCY_TYPE = 0

    # The external VPN gateway has four public IP addresses; at the time of
    # writing this API, the AWS virtual private gateway is an example which has
    # four public IP addresses for high availability connections; there should
    # be two VPN connections in the AWS virtual private gateway , each AWS VPN
    # connection has two public IP addresses;  please make sure to put two
    # public IP addresses from one AWS VPN connection into interfaces 0 and 1
    # of this external VPN gateway, and put the other two public IP addresses
    # from another AWS VPN connection into interfaces 2 and 3 of this external
    # VPN gateway. When displaying highly available configuration status
    # for the VPN tunnels connected to FOUR_IPS_REDUNDANCY external VPN
    # gateway, Google will always detect whether interfaces 0 and 1 are
    # connected on one interface of HA Cloud VPN gateway, and detect whether
    # interfaces 2 and 3 are connected to another interface of the HA Cloud VPN
    # gateway.
    FOUR_IPS_REDUNDANCY = 520_087_913

    # The external VPN gateway has only one public IP address which internally
    # provide redundancy or failover.
    SINGLE_IP_INTERNALLY_REDUNDANT = 133_914_873

    # The external VPN gateway has two public IP addresses which are redundant
    # with each other, the following two types of setup on your on-premises
    # side would have this type of redundancy:
    # (1) Two separate on-premises gateways, each with one public IP address,
    #     the two on-premises gateways are redundant with each other.
    # (2) A single on-premise gateway with two public IP addresses that are
    #     redundant with eatch other.
    TWO_IPS_REDUNDANCY = 367_049_635
  end
end