Class: Google::Cloud::Compute::V1::FileContentBuffer
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FileContentBuffer
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: FileType
Instance Attribute Summary collapse
-
#content ⇒ ::String
The raw content in the secure keys file.
-
#file_type ⇒ ::String
The file type of source file.
Instance Attribute Details
#content ⇒ ::String
Returns The raw content in the secure keys file.
20138 20139 20140 20141 20142 20143 20144 20145 20146 20147 20148 20149 20150 20151 20152 20153 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20138 class FileContentBuffer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The file type of source file. module FileType # A value indicating that the enum field is not set. UNDEFINED_FILE_TYPE = 0 BIN = 65_767 UNDEFINED = 137_851_184 X509 = 2_674_086 end end |
#file_type ⇒ ::String
Returns The file type of source file. Check the FileType enum for the list of possible values.
20138 20139 20140 20141 20142 20143 20144 20145 20146 20147 20148 20149 20150 20151 20152 20153 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20138 class FileContentBuffer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The file type of source file. module FileType # A value indicating that the enum field is not set. UNDEFINED_FILE_TYPE = 0 BIN = 65_767 UNDEFINED = 137_851_184 X509 = 2_674_086 end end |