Class: Google::Cloud::Compute::V1::FileContentBuffer

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: FileType

Instance Attribute Summary collapse

Instance Attribute Details

#content::String

Returns The raw content in the secure keys file.

Returns:

  • (::String)

    The raw content in the secure keys file.



8153
8154
8155
8156
8157
8158
8159
8160
8161
8162
8163
8164
8165
8166
8167
8168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8153

class FileContentBuffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The file type of source file.
  module FileType
    # A value indicating that the enum field is not set.
    UNDEFINED_FILE_TYPE = 0

    BIN = 65_767

    UNDEFINED = 137_851_184

    X509 = 2_674_086
  end
end

#file_type::String

Returns The file type of source file. Check the FileType enum for the list of possible values.

Returns:

  • (::String)

    The file type of source file. Check the FileType enum for the list of possible values.



8153
8154
8155
8156
8157
8158
8159
8160
8161
8162
8163
8164
8165
8166
8167
8168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8153

class FileContentBuffer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The file type of source file.
  module FileType
    # A value indicating that the enum field is not set.
    UNDEFINED_FILE_TYPE = 0

    BIN = 65_767

    UNDEFINED = 137_851_184

    X509 = 2_674_086
  end
end