Class: Google::Cloud::Compute::V1::FileContentBuffer
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FileContentBuffer
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: FileType
Instance Attribute Summary collapse
-
#content ⇒ ::String
The raw content in the secure keys file.
-
#file_type ⇒ ::String
The file type of source file.
Instance Attribute Details
#content ⇒ ::String
Returns The raw content in the secure keys file.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 6913 class FileContentBuffer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The file type of source file. module FileType # A value indicating that the enum field is not set. UNDEFINED_FILE_TYPE = 0 BIN = 65767 UNDEFINED = 137851184 X509 = 2674086 end end |
#file_type ⇒ ::String
Returns The file type of source file. Check the FileType enum for the list of possible values.
6913 6914 6915 6916 6917 6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 6913 class FileContentBuffer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The file type of source file. module FileType # A value indicating that the enum field is not set. UNDEFINED_FILE_TYPE = 0 BIN = 65767 UNDEFINED = 137851184 X509 = 2674086 end end |