Class: Google::Cloud::Compute::V1::Firewall
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Firewall
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Firewall Rule resource. Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, read Firewall rules.
Defined Under Namespace
Modules: Direction
Instance Attribute Summary collapse
-
#allowed ⇒ ::Array<::Google::Cloud::Compute::V1::Allowed>
The list of ALLOW rules specified by this firewall.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#denied ⇒ ::Array<::Google::Cloud::Compute::V1::Denied>
The list of DENY rules specified by this firewall.
-
#description ⇒ ::String
An optional description of this resource.
-
#destination_ranges ⇒ ::Array<::String>
If destination ranges are specified, the firewall rule applies only to traffic that has destination IP address in these ranges.
-
#direction ⇒ ::String
Direction of traffic to which this firewall applies, either
INGRESSorEGRESS. -
#disabled ⇒ ::Boolean
Denotes whether the firewall rule is disabled.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
[Output Only] Type of the resource.
-
#log_config ⇒ ::Google::Cloud::Compute::V1::FirewallLogConfig
This field denotes the logging options for a particular firewall rule.
-
#name ⇒ ::String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ ::String
URL of the network resource for this firewall rule.
-
#params ⇒ ::Google::Cloud::Compute::V1::FirewallParams
Input only.
-
#priority ⇒ ::Integer
Priority for this rule.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#source_ranges ⇒ ::Array<::String>
If source ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges.
-
#source_service_accounts ⇒ ::Array<::String>
If source service accounts are specified, the firewall rules apply only to traffic originating from an instance with a service account in this list.
-
#source_tags ⇒ ::Array<::String>
If source tags are specified, the firewall rule applies only to traffic with source IPs that match the primary network interfaces of VM instances that have the tag and are in the same VPC network.
-
#target_service_accounts ⇒ ::Array<::String>
A list of service accounts indicating sets of instances located in the network that may make network connections as specified in allowed[].
-
#target_tags ⇒ ::Array<::String>
A list of tags that controls which instances the firewall rule applies to.
Instance Attribute Details
#allowed ⇒ ::Array<::Google::Cloud::Compute::V1::Allowed>
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#creation_timestamp ⇒ ::String
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#denied ⇒ ::Array<::Google::Cloud::Compute::V1::Denied>
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#description ⇒ ::String
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#destination_ranges ⇒ ::Array<::String>
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#direction ⇒ ::String
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#disabled ⇒ ::Boolean
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#id ⇒ ::Integer
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#kind ⇒ ::String
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#log_config ⇒ ::Google::Cloud::Compute::V1::FirewallLogConfig
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#name ⇒ ::String
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#network ⇒ ::String
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#params ⇒ ::Google::Cloud::Compute::V1::FirewallParams
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#priority ⇒ ::Integer
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#self_link ⇒ ::String
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#source_ranges ⇒ ::Array<::String>
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#source_service_accounts ⇒ ::Array<::String>
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#source_tags ⇒ ::Array<::String>
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#target_service_accounts ⇒ ::Array<::String>
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |
#target_tags ⇒ ::Array<::String>
8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8552 class Firewall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to which this firewall applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify the sourceTags fields. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Indicates that firewall should apply to outgoing traffic. EGRESS = 432_880_501 # Indicates that firewall should apply to incoming traffic. INGRESS = 516_931_221 end end |