Class: Google::Cloud::Compute::V1::FirewallLogConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The available logging options for a firewall rule.

Defined Under Namespace

Modules: Metadata

Instance Attribute Summary collapse

Instance Attribute Details

#enable::Boolean

Returns This field denotes whether to enable logging for a particular firewall rule.

Returns:

  • (::Boolean)

    This field denotes whether to enable logging for a particular firewall rule.



20355
20356
20357
20358
20359
20360
20361
20362
20363
20364
20365
20366
20367
20368
20369
20370
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20355

class FirewallLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field can only be specified for a particular firewall rule if
  # logging is enabled for that rule. This field denotes whether to include
  # or exclude metadata for firewall logs.
  module Metadata
    # A value indicating that the enum field is not set.
    UNDEFINED_METADATA = 0

    EXCLUDE_ALL_METADATA = 334_519_954

    INCLUDE_ALL_METADATA = 164_619_908
  end
end

#metadata::String

Returns This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs. Check the Metadata enum for the list of possible values.

Returns:

  • (::String)

    This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs. Check the Metadata enum for the list of possible values.



20355
20356
20357
20358
20359
20360
20361
20362
20363
20364
20365
20366
20367
20368
20369
20370
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20355

class FirewallLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field can only be specified for a particular firewall rule if
  # logging is enabled for that rule. This field denotes whether to include
  # or exclude metadata for firewall logs.
  module Metadata
    # A value indicating that the enum field is not set.
    UNDEFINED_METADATA = 0

    EXCLUDE_ALL_METADATA = 334_519_954

    INCLUDE_ALL_METADATA = 164_619_908
  end
end