Class: Google::Cloud::Compute::V1::FirewallLogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FirewallLogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The available logging options for a firewall rule.
Defined Under Namespace
Modules: Metadata
Instance Attribute Summary collapse
-
#enable ⇒ ::Boolean
This field denotes whether to enable logging for a particular firewall rule.
-
#metadata ⇒ ::String
This field can only be specified for a particular firewall rule if logging is enabled for that rule.
Instance Attribute Details
#enable ⇒ ::Boolean
Returns This field denotes whether to enable logging for a particular firewall rule.
8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8278 class FirewallLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#metadata ⇒ ::String
Returns This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs. Check the Metadata enum for the list of possible values.
8278 8279 8280 8281 8282 8283 8284 8285 8286 8287 8288 8289 8290 8291 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8278 class FirewallLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |