Class: Google::Cloud::Compute::V1::FirewallLogConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The available logging options for a firewall rule.

Defined Under Namespace

Modules: Metadata

Instance Attribute Summary collapse

Instance Attribute Details

#enable::Boolean

Returns This field denotes whether to enable logging for a particular firewall rule.

Returns:

  • (::Boolean)

    This field denotes whether to enable logging for a particular firewall rule.



8254
8255
8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8254

class FirewallLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs.
  module 
    # A value indicating that the enum field is not set.
     = 0

     = 334_519_954

     = 164_619_908
  end
end

#metadata::String

Returns This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs. Check the Metadata enum for the list of possible values.

Returns:

  • (::String)

    This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs. Check the Metadata enum for the list of possible values.



8254
8255
8256
8257
8258
8259
8260
8261
8262
8263
8264
8265
8266
8267
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8254

class FirewallLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # This field can only be specified for a particular firewall rule if logging is enabled for that rule. This field denotes whether to include or exclude metadata for firewall logs.
  module 
    # A value indicating that the enum field is not set.
     = 0

     = 334_519_954

     = 164_619_908
  end
end