Class: Google::Cloud::Compute::V1::FirewallPolicyRule
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FirewallPolicyRule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).
Defined Under Namespace
Modules: Direction, TargetType
Instance Attribute Summary collapse
-
#action ⇒ ::String
The Action to perform when the client connection triggers the rule.
-
#description ⇒ ::String
An optional description for this resource.
-
#direction ⇒ ::String
The direction in which this rule applies.
-
#disabled ⇒ ::Boolean
Denotes whether the firewall policy rule is disabled.
-
#enable_logging ⇒ ::Boolean
Denotes whether to enable logging for a particular rule.
-
#kind ⇒ ::String
Output only.
-
#match ⇒ ::Google::Cloud::Compute::V1::FirewallPolicyRuleMatcher
A match condition that incoming traffic is evaluated against.
-
#priority ⇒ ::Integer
An integer indicating the priority of a rule in the list.
-
#rule_name ⇒ ::String
An optional name for the rule.
-
#rule_tuple_count ⇒ ::Integer
Output only.
-
#security_profile_group ⇒ ::String
A fully-qualified URL of a SecurityProfileGroup resource instance.
-
#target_forwarding_rules ⇒ ::Array<::String>
A list of forwarding rules to which this rule applies.
-
#target_resources ⇒ ::Array<::String>
A list of network resource URLs to which this rule applies.
-
#target_secure_tags ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag>
A list of secure tags that controls which instances the firewall rule applies to.
-
#target_service_accounts ⇒ ::Array<::String>
A list of service accounts indicating the sets of instances that are applied with this rule.
-
#target_type ⇒ ::String
Target types of the firewall policy rule.
-
#tls_inspect ⇒ ::Boolean
Boolean flag indicating if the traffic should be TLS decrypted.
Instance Attribute Details
#action ⇒ ::String
Returns The Action to perform when the client connection triggers the rule. Valid actions for firewall rules are: "allow", "deny", "apply_security_profile_group" and "goto_next" ( "apply_security_profile_group" can be specified only for global network firewall policies or hierarchical firewall policies). Valid actions for packet mirroring rules are: "mirror", "do_not_mirror" and "goto_next".
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#description ⇒ ::String
Returns An optional description for this resource.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#direction ⇒ ::String
Returns The direction in which this rule applies. Check the Direction enum for the list of possible values.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#disabled ⇒ ::Boolean
Returns Denotes whether the firewall policy rule is disabled. When set to true, the firewall policy rule is not enforced and traffic behaves as if it did not exist. If this is unspecified, the firewall policy rule will be enabled.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#enable_logging ⇒ ::Boolean
Returns Denotes whether to enable logging for a particular rule. If logging is enabled, logs will be exported to the configured export destination in Stackdriver. Logs may be exported to BigQuery or Pub/Sub. Note: you cannot enable logging on "goto_next" rules.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#kind ⇒ ::String
Returns Output only. [Output only] Type of the resource. Returnscompute#firewallPolicyRule for firewall rules andcompute#packetMirroringRule for packet mirroring rules.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#match ⇒ ::Google::Cloud::Compute::V1::FirewallPolicyRuleMatcher
Returns A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding 'action' is enforced.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#priority ⇒ ::Integer
Returns An integer indicating the priority of a rule in the list. The priority must be a positive value between 0 and 2147483647. Rules are evaluated from highest to lowest priority where 0 is the highest priority and 2147483647 is the lowest priority.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#rule_name ⇒ ::String
Returns An optional name for the rule. This field is not a unique identifier and can be updated.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#rule_tuple_count ⇒ ::Integer
Returns Output only. [Output Only] Calculation of the complexity of a single firewall policy rule.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#security_profile_group ⇒ ::String
Returns A fully-qualified URL of a SecurityProfileGroup resource instance. Example: https://networksecurity.googleapis.com/v1/projects/\{project}/locations/\{location}/securityProfileGroups/my-security-profile-group Must be specified if action is one of 'apply_security_profile_group' or 'mirror'. Cannot be specified for other actions. Can be specified only for global network firewall policies or hierarchical firewall policies.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#target_forwarding_rules ⇒ ::Array<::String>
Returns A list of forwarding rules to which this rule applies. This field allows you to control which load balancers get this rule. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/global/forwardingRules/forwardingRule
- https://www.googleapis.com/compute/v1/projects/project/regions/region/forwardingRules/forwardingRule
- projects/project/global/
forwardingRules/forwardingRule
- projects/project/regions/region/forwardingRules/
forwardingRule.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#target_resources ⇒ ::Array<::String>
Returns A list of network resource URLs to which this rule applies. This field allows you to control which network's VMs get this rule. If this field is left blank, all VMs within the organization will receive the rule.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#target_secure_tags ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag>
Returns A list of secure tags that controls which instances the firewall rule applies to. If targetSecureTag are specified, then the firewall rule applies only to instances in the VPC network that have one of those EFFECTIVE secure tags, if all the target_secure_tag are in INEFFECTIVE state, then this rule will be ignored.targetSecureTag may not be set at the same time astargetServiceAccounts. If neither targetServiceAccounts nortargetSecureTag are specified, the firewall rule applies to all instances on the specified network. Maximum number of target label tags allowed is 256.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#target_service_accounts ⇒ ::Array<::String>
Returns A list of service accounts indicating the sets of instances that are applied with this rule.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#target_type ⇒ ::String
Returns Target types of the firewall policy rule. Default value is INSTANCES. Check the TargetType enum for the list of possible values.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |
#tls_inspect ⇒ ::Boolean
Returns Boolean flag indicating if the traffic should be TLS decrypted. Can be set only if action = 'apply_security_profile_group' and cannot be set for other actions.
20687 20688 20689 20690 20691 20692 20693 20694 20695 20696 20697 20698 20699 20700 20701 20702 20703 20704 20705 20706 20707 20708 20709 20710 20711 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20687 class FirewallPolicyRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The direction in which this rule applies. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 EGRESS = 432_880_501 INGRESS = 516_931_221 end # Target types of the firewall policy rule. # Default value is INSTANCES. module TargetType # A value indicating that the enum field is not set. UNDEFINED_TARGET_TYPE = 0 INSTANCES = 131_337_822 INTERNAL_MANAGED_LB = 309_241_080 end end |