Class: Google::Cloud::Compute::V1::FirewallPolicyRuleMatcher
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FirewallPolicyRuleMatcher
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
Defined Under Namespace
Modules: DestNetworkContext, DestNetworkType, SrcNetworkContext, SrcNetworkType
Instance Attribute Summary collapse
-
#dest_address_groups ⇒ ::Array<::String>
Address groups which should be matched against the traffic destination.
-
#dest_fqdns ⇒ ::Array<::String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic destination.
-
#dest_ip_ranges ⇒ ::Array<::String>
CIDR IP address range.
-
#dest_network_context ⇒ ::String
Network context of the traffic destination.
-
#dest_network_type ⇒ ::String
Network type of the traffic destination.
-
#dest_region_codes ⇒ ::Array<::String>
Region codes whose IP addresses will be used to match for destination of traffic.
-
#dest_threat_intelligences ⇒ ::Array<::String>
Names of Network Threat Intelligence lists.
-
#layer4_configs ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
-
#src_address_groups ⇒ ::Array<::String>
Address groups which should be matched against the traffic source.
-
#src_fqdns ⇒ ::Array<::String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic source.
-
#src_ip_ranges ⇒ ::Array<::String>
CIDR IP address range.
-
#src_network_context ⇒ ::String
Network context of the traffic source.
-
#src_network_type ⇒ ::String
Network type of the traffic source.
-
#src_networks ⇒ ::Array<::String>
Networks of the traffic source.
-
#src_region_codes ⇒ ::Array<::String>
Region codes whose IP addresses will be used to match for source of traffic.
-
#src_secure_tags ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag>
List of secure tag values, which should be matched at the source of the traffic.
-
#src_threat_intelligences ⇒ ::Array<::String>
Names of Network Threat Intelligence lists.
Instance Attribute Details
#dest_address_groups ⇒ ::Array<::String>
Returns Address groups which should be matched against the traffic destination. Maximum number of destination address groups is 10.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_fqdns ⇒ ::Array<::String>
Returns Fully Qualified Domain Name (FQDN) which should be matched against traffic destination. Maximum number of destination fqdn allowed is 100.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_ip_ranges ⇒ ::Array<::String>
Returns CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_network_context ⇒ ::String
Returns Network context of the traffic destination. Allowed values are:
- UNSPECIFIED
- INTERNET
- NON_INTERNET
Check the DestNetworkContext enum for the list of possible values.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_network_type ⇒ ::String
Returns Network type of the traffic destination. Allowed values are:
- UNSPECIFIED
- INTERNET
- NON_INTERNET
Check the DestNetworkType enum for the list of possible values.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_region_codes ⇒ ::Array<::String>
Returns Region codes whose IP addresses will be used to match for destination of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of dest region codes allowed is 5000.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_threat_intelligences ⇒ ::Array<::String>
Returns Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic destination.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#layer4_configs ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleMatcherLayer4Config>
Returns Pairs of IP protocols and ports that the rule should match.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_address_groups ⇒ ::Array<::String>
Returns Address groups which should be matched against the traffic source. Maximum number of source address groups is 10.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_fqdns ⇒ ::Array<::String>
Returns Fully Qualified Domain Name (FQDN) which should be matched against traffic source. Maximum number of source fqdn allowed is 100.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_ip_ranges ⇒ ::Array<::String>
Returns CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_network_context ⇒ ::String
Returns Network context of the traffic source. Allowed values are:
- UNSPECIFIED
- INTERNET
- INTRA_VPC
- NON_INTERNET
- VPC_NETWORKS
Check the SrcNetworkContext enum for the list of possible values.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_network_type ⇒ ::String
Returns Network type of the traffic source. Allowed values are:
- UNSPECIFIED
- INTERNET
- INTRA_VPC
- NON_INTERNET
- VPC_NETWORKS
Check the SrcNetworkType enum for the list of possible values.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_networks ⇒ ::Array<::String>
Returns Networks of the traffic source. It can be either a full or partial url.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_region_codes ⇒ ::Array<::String>
Returns Region codes whose IP addresses will be used to match for source of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of source region codes allowed is 5000.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_secure_tags ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag>
Returns List of secure tag values, which should be matched at the source of the traffic. For INGRESS rule, if all the srcSecureTag are INEFFECTIVE, and there is no srcIpRange, this rule will be ignored. Maximum number of source tag values allowed is 256.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_threat_intelligences ⇒ ::Array<::String>
Returns Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic source.
20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 20833 20834 20835 20836 20837 20838 20839 20840 20841 20842 20843 20844 20845 20846 20847 20848 20849 20850 20851 20852 20853 20854 20855 20856 20857 20858 20859 20860 20861 20862 20863 20864 20865 20866 20867 20868 20869 20870 20871 20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 20882 20883 20884 20885 20886 20887 20888 20889 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20814 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |