Class: Google::Cloud::Compute::V1::FirewallPolicyRuleMatcher

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.

Defined Under Namespace

Modules: DestNetworkContext, DestNetworkType, SrcNetworkContext, SrcNetworkType

Instance Attribute Summary collapse

Instance Attribute Details

#dest_address_groups::Array<::String>

Returns Address groups which should be matched against the traffic destination. Maximum number of destination address groups is 10.

Returns:

  • (::Array<::String>)

    Address groups which should be matched against the traffic destination. Maximum number of destination address groups is 10.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#dest_fqdns::Array<::String>

Returns Fully Qualified Domain Name (FQDN) which should be matched against traffic destination. Maximum number of destination fqdn allowed is 100.

Returns:

  • (::Array<::String>)

    Fully Qualified Domain Name (FQDN) which should be matched against traffic destination. Maximum number of destination fqdn allowed is 100.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#dest_ip_ranges::Array<::String>

Returns CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000.

Returns:

  • (::Array<::String>)

    CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#dest_network_context::String

Returns Network context of the traffic destination. Allowed values are:

 - UNSPECIFIED
 - INTERNET
 - NON_INTERNET

Check the DestNetworkContext enum for the list of possible values.

Returns:

  • (::String)

    Network context of the traffic destination. Allowed values are:

     - UNSPECIFIED
     - INTERNET
     - NON_INTERNET
    

    Check the DestNetworkContext enum for the list of possible values.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#dest_network_type::String

Returns Network type of the traffic destination. Allowed values are:

 - UNSPECIFIED
 - INTERNET
 - NON_INTERNET

Check the DestNetworkType enum for the list of possible values.

Returns:

  • (::String)

    Network type of the traffic destination. Allowed values are:

     - UNSPECIFIED
     - INTERNET
     - NON_INTERNET
    

    Check the DestNetworkType enum for the list of possible values.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#dest_region_codes::Array<::String>

Returns Region codes whose IP addresses will be used to match for destination of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of dest region codes allowed is 5000.

Returns:

  • (::Array<::String>)

    Region codes whose IP addresses will be used to match for destination of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of dest region codes allowed is 5000.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#dest_threat_intelligences::Array<::String>

Returns Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic destination.

Returns:

  • (::Array<::String>)

    Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic destination.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#layer4_configs::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleMatcherLayer4Config>

Returns Pairs of IP protocols and ports that the rule should match.

Returns:



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#src_address_groups::Array<::String>

Returns Address groups which should be matched against the traffic source. Maximum number of source address groups is 10.

Returns:

  • (::Array<::String>)

    Address groups which should be matched against the traffic source. Maximum number of source address groups is 10.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#src_fqdns::Array<::String>

Returns Fully Qualified Domain Name (FQDN) which should be matched against traffic source. Maximum number of source fqdn allowed is 100.

Returns:

  • (::Array<::String>)

    Fully Qualified Domain Name (FQDN) which should be matched against traffic source. Maximum number of source fqdn allowed is 100.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#src_ip_ranges::Array<::String>

Returns CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.

Returns:

  • (::Array<::String>)

    CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#src_network_context::String

Returns Network context of the traffic source. Allowed values are:

 - UNSPECIFIED
 - INTERNET
 - INTRA_VPC
 - NON_INTERNET
 - VPC_NETWORKS

Check the SrcNetworkContext enum for the list of possible values.

Returns:

  • (::String)

    Network context of the traffic source. Allowed values are:

     - UNSPECIFIED
     - INTERNET
     - INTRA_VPC
     - NON_INTERNET
     - VPC_NETWORKS
    

    Check the SrcNetworkContext enum for the list of possible values.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#src_network_type::String

Returns Network type of the traffic source. Allowed values are:

 - UNSPECIFIED
 - INTERNET
 - INTRA_VPC
 - NON_INTERNET
 - VPC_NETWORKS

Check the SrcNetworkType enum for the list of possible values.

Returns:

  • (::String)

    Network type of the traffic source. Allowed values are:

     - UNSPECIFIED
     - INTERNET
     - INTRA_VPC
     - NON_INTERNET
     - VPC_NETWORKS
    

    Check the SrcNetworkType enum for the list of possible values.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#src_networks::Array<::String>

Returns Networks of the traffic source. It can be either a full or partial url.

Returns:

  • (::Array<::String>)

    Networks of the traffic source. It can be either a full or partial url.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#src_region_codes::Array<::String>

Returns Region codes whose IP addresses will be used to match for source of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of source region codes allowed is 5000.

Returns:

  • (::Array<::String>)

    Region codes whose IP addresses will be used to match for source of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of source region codes allowed is 5000.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#src_secure_tags::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag>

Returns List of secure tag values, which should be matched at the source of the traffic. For INGRESS rule, if all the srcSecureTag are INEFFECTIVE, and there is no srcIpRange, this rule will be ignored. Maximum number of source tag values allowed is 256.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag>)

    List of secure tag values, which should be matched at the source of the traffic. For INGRESS rule, if all the srcSecureTag are INEFFECTIVE, and there is no srcIpRange, this rule will be ignored. Maximum number of source tag values allowed is 256.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end

#src_threat_intelligences::Array<::String>

Returns Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic source.

Returns:

  • (::Array<::String>)

    Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic source.



20627
20628
20629
20630
20631
20632
20633
20634
20635
20636
20637
20638
20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
20660
20661
20662
20663
20664
20665
20666
20667
20668
20669
20670
20671
20672
20673
20674
20675
20676
20677
20678
20679
20680
20681
20682
20683
20684
20685
20686
20687
20688
20689
20690
20691
20692
20693
20694
20695
20696
20697
20698
20699
20700
20701
20702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20627

class FirewallPolicyRuleMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network context of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic destination. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - NON_INTERNET
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module DestNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEST_NETWORK_TYPE = 0
  end

  # Network context of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkContext
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_CONTEXT = 0
  end

  # Network type of the traffic source. Allowed values are:
  #
  #
  #      - UNSPECIFIED
  #      - INTERNET
  #      - INTRA_VPC
  #      - NON_INTERNET
  #      - VPC_NETWORKS
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INTERNET
  # INTRA_VPC
  # NON_INTERNET
  # UNSPECIFIED
  # VPC_NETWORKS
  module SrcNetworkType
    # A value indicating that the enum field is not set.
    UNDEFINED_SRC_NETWORK_TYPE = 0
  end
end