Class: Google::Cloud::Compute::V1::FirewallPolicyRuleMatcher
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FirewallPolicyRuleMatcher
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
Defined Under Namespace
Modules: DestNetworkContext, DestNetworkType, SrcNetworkContext, SrcNetworkType
Instance Attribute Summary collapse
-
#dest_address_groups ⇒ ::Array<::String>
Address groups which should be matched against the traffic destination.
-
#dest_fqdns ⇒ ::Array<::String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic destination.
-
#dest_ip_ranges ⇒ ::Array<::String>
CIDR IP address range.
-
#dest_network_context ⇒ ::String
Network context of the traffic destination.
-
#dest_network_type ⇒ ::String
Network type of the traffic destination.
-
#dest_region_codes ⇒ ::Array<::String>
Region codes whose IP addresses will be used to match for destination of traffic.
-
#dest_threat_intelligences ⇒ ::Array<::String>
Names of Network Threat Intelligence lists.
-
#layer4_configs ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
-
#src_address_groups ⇒ ::Array<::String>
Address groups which should be matched against the traffic source.
-
#src_fqdns ⇒ ::Array<::String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic source.
-
#src_ip_ranges ⇒ ::Array<::String>
CIDR IP address range.
-
#src_network_context ⇒ ::String
Network context of the traffic source.
-
#src_network_type ⇒ ::String
Network type of the traffic source.
-
#src_networks ⇒ ::Array<::String>
Networks of the traffic source.
-
#src_region_codes ⇒ ::Array<::String>
Region codes whose IP addresses will be used to match for source of traffic.
-
#src_secure_tags ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag>
List of secure tag values, which should be matched at the source of the traffic.
-
#src_threat_intelligences ⇒ ::Array<::String>
Names of Network Threat Intelligence lists.
Instance Attribute Details
#dest_address_groups ⇒ ::Array<::String>
Returns Address groups which should be matched against the traffic destination. Maximum number of destination address groups is 10.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_fqdns ⇒ ::Array<::String>
Returns Fully Qualified Domain Name (FQDN) which should be matched against traffic destination. Maximum number of destination fqdn allowed is 100.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_ip_ranges ⇒ ::Array<::String>
Returns CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_network_context ⇒ ::String
Returns Network context of the traffic destination. Allowed values are:
- UNSPECIFIED
- INTERNET
- NON_INTERNET
Check the DestNetworkContext enum for the list of possible values.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_network_type ⇒ ::String
Returns Network type of the traffic destination. Allowed values are:
- UNSPECIFIED
- INTERNET
- NON_INTERNET
Check the DestNetworkType enum for the list of possible values.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_region_codes ⇒ ::Array<::String>
Returns Region codes whose IP addresses will be used to match for destination of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of dest region codes allowed is 5000.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#dest_threat_intelligences ⇒ ::Array<::String>
Returns Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic destination.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#layer4_configs ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleMatcherLayer4Config>
Returns Pairs of IP protocols and ports that the rule should match.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_address_groups ⇒ ::Array<::String>
Returns Address groups which should be matched against the traffic source. Maximum number of source address groups is 10.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_fqdns ⇒ ::Array<::String>
Returns Fully Qualified Domain Name (FQDN) which should be matched against traffic source. Maximum number of source fqdn allowed is 100.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_ip_ranges ⇒ ::Array<::String>
Returns CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_network_context ⇒ ::String
Returns Network context of the traffic source. Allowed values are:
- UNSPECIFIED
- INTERNET
- INTRA_VPC
- NON_INTERNET
- VPC_NETWORKS
Check the SrcNetworkContext enum for the list of possible values.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_network_type ⇒ ::String
Returns Network type of the traffic source. Allowed values are:
- UNSPECIFIED
- INTERNET
- INTRA_VPC
- NON_INTERNET
- VPC_NETWORKS
Check the SrcNetworkType enum for the list of possible values.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_networks ⇒ ::Array<::String>
Returns Networks of the traffic source. It can be either a full or partial url.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_region_codes ⇒ ::Array<::String>
Returns Region codes whose IP addresses will be used to match for source of traffic. Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of source region codes allowed is 5000.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_secure_tags ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag>
Returns List of secure tag values, which should be matched at the source of the traffic. For INGRESS rule, if all the srcSecureTag are INEFFECTIVE, and there is no srcIpRange, this rule will be ignored. Maximum number of source tag values allowed is 256.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |
#src_threat_intelligences ⇒ ::Array<::String>
Returns Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic source.
21441 21442 21443 21444 21445 21446 21447 21448 21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 21479 21480 21481 21482 21483 21484 21485 21486 21487 21488 21489 21490 21491 21492 21493 21494 21495 21496 21497 21498 21499 21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21441 class FirewallPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network context of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkContext # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_CONTEXT = 0 end # Network type of the traffic destination. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - NON_INTERNET # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module DestNetworkType # A value indicating that the enum field is not set. UNDEFINED_DEST_NETWORK_TYPE = 0 end # Network context of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkContext # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_CONTEXT = 0 end # Network type of the traffic source. Allowed values are: # # # - UNSPECIFIED # - INTERNET # - INTRA_VPC # - NON_INTERNET # - VPC_NETWORKS # Additional supported values which may be not listed in the enum directly due to technical reasons: # INTERNET # INTRA_VPC # NON_INTERNET # UNSPECIFIED # VPC_NETWORKS module SrcNetworkType # A value indicating that the enum field is not set. UNDEFINED_SRC_NETWORK_TYPE = 0 end end |