Module: Google::Cloud::Compute::V1::FirewallPolicyRuleMatcher::SrcNetworkContext
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Network context of the traffic source. Allowed values are:
- UNSPECIFIED
- INTERNET
- INTRA_VPC
- NON_INTERNET
- VPC_NETWORKS
Additional supported values which may be not listed in the enum directly due to technical reasons: INTERNET INTRA_VPC NON_INTERNET UNSPECIFIED VPC_NETWORKS
Constant Summary collapse
- UNDEFINED_SRC_NETWORK_CONTEXT =
A value indicating that the enum field is not set.
0