Class: Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#name ⇒ ::String
Name of the secure tag, created with TagManager's TagValue API.
-
#state ⇒ ::String
Output only.
Instance Attribute Details
#name ⇒ ::String
Returns Name of the secure tag, created with TagManager's TagValue API.
20732 20733 20734 20735 20736 20737 20738 20739 20740 20741 20742 20743 20744 20745 20746 20747 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20732 class FirewallPolicyRuleSecureTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] State of the secure tag, either `EFFECTIVE` or # `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted # or its network is deleted. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 EFFECTIVE = 244_201_863 INEFFECTIVE = 304_458_242 end end |
#state ⇒ ::String
Returns Output only. [Output Only] State of the secure tag, either EFFECTIVE or
INEFFECTIVE. A secure tag is INEFFECTIVE when it is deleted
or its network is deleted.
Check the State enum for the list of possible values.
20732 20733 20734 20735 20736 20737 20738 20739 20740 20741 20742 20743 20744 20745 20746 20747 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20732 class FirewallPolicyRuleSecureTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] State of the secure tag, either `EFFECTIVE` or # `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted # or its network is deleted. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 EFFECTIVE = 244_201_863 INEFFECTIVE = 304_458_242 end end |