Class: Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#name ⇒ ::String
Name of the secure tag, created with TagManager's TagValue API.
-
#state ⇒ ::String
[Output Only] State of the secure tag, either
EFFECTIVEorINEFFECTIVE.
Instance Attribute Details
#name ⇒ ::String
8561 8562 8563 8564 8565 8566 8567 8568 8569 8570 8571 8572 8573 8574 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8561 class FirewallPolicyRuleSecureTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] State of the secure tag, either `EFFECTIVE` or `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted or its network is deleted. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 EFFECTIVE = 244_201_863 INEFFECTIVE = 304_458_242 end end |
#state ⇒ ::String
8561 8562 8563 8564 8565 8566 8567 8568 8569 8570 8571 8572 8573 8574 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8561 class FirewallPolicyRuleSecureTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] State of the secure tag, either `EFFECTIVE` or `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted or its network is deleted. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 EFFECTIVE = 244_201_863 INEFFECTIVE = 304_458_242 end end |