Class: Google::Cloud::Compute::V1::FirewallPolicyRuleSecureTag

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Name of the secure tag, created with TagManager's TagValue API.

Returns:

  • (::String)

    Name of the secure tag, created with TagManager's TagValue API.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8531

class FirewallPolicyRuleSecureTag
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] State of the secure tag, either `EFFECTIVE` or `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted or its network is deleted.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    EFFECTIVE = 244_201_863

    INEFFECTIVE = 304_458_242
  end
end

#state::String

Returns [Output Only] State of the secure tag, either EFFECTIVE or INEFFECTIVE. A secure tag is INEFFECTIVE when it is deleted or its network is deleted. Check the State enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] State of the secure tag, either EFFECTIVE or INEFFECTIVE. A secure tag is INEFFECTIVE when it is deleted or its network is deleted. Check the State enum for the list of possible values.



8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 8531

class FirewallPolicyRuleSecureTag
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] State of the secure tag, either `EFFECTIVE` or `INEFFECTIVE`. A secure tag is `INEFFECTIVE` when it is deleted or its network is deleted.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    EFFECTIVE = 244_201_863

    INEFFECTIVE = 304_458_242
  end
end