Class: Google::Cloud::Compute::V1::FlexibleTimeRange
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FlexibleTimeRange
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies a flexible time range with flexible start time and duration.
It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.
Instance Attribute Summary collapse
- #max_duration ⇒ ::String
- #min_duration ⇒ ::String
- #start_time_not_earlier_than ⇒ ::String
- #start_time_not_later_than ⇒ ::String
Instance Attribute Details
#max_duration ⇒ ::String
20511 20512 20513 20514 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20511 class FlexibleTimeRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_duration ⇒ ::String
20511 20512 20513 20514 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20511 class FlexibleTimeRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time_not_earlier_than ⇒ ::String
20511 20512 20513 20514 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20511 class FlexibleTimeRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time_not_later_than ⇒ ::String
20511 20512 20513 20514 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20511 class FlexibleTimeRange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |