Module: Google::Cloud::Compute::V1::FutureReservationCommitmentInfo::PreviousCommitmentTerms
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment.
Constant Summary collapse
- UNDEFINED_PREVIOUS_COMMITMENT_TERMS =
A value indicating that the enum field is not set.
0- EXTEND =
All associated parent Committed Used Discount(s) end-date/term will be extended to the end-time of this future reservation. Default is to extend previous commitment(s) time to the end_time of the reservation.
448_639_770- PREVIOUSCOMMITMENTTERM_UNSPECIFIED =
No changes to associated parents Committed Used Discount(s) terms.
98_482_448