Class: Google::Cloud::Compute::V1::FutureReservationParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Additional future reservation params.

Defined Under Namespace

Classes: ResourceManagerTagsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#resource_manager_tags::Google::Protobuf::Map{::String => ::String}

Returns Input only. Resource manager tags to be bound to the future reservation. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Input only. Resource manager tags to be bound to the future reservation. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in namespaced format such as {org_id|project_id}/{tag_key_short_name} and {tag_value_short_name}. The field is ignored (both PUT & PATCH) when empty.



21717
21718
21719
21720
21721
21722
21723
21724
21725
21726
21727
21728
21729
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21717

class FutureReservationParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceManagerTagsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end