Class: Google::Cloud::Compute::V1::FutureReservationSpecificSKUProperties
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureReservationSpecificSKUProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#instance_properties ⇒ ::Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationReservedInstanceProperties
Properties of the SKU instances being reserved.
-
#source_instance_template ⇒ ::String
The instance template that will be used to populate the ReservedInstanceProperties of the future reservation.
-
#total_count ⇒ ::Integer
Total number of instances for which capacity assurance is requested at a future time period.
Instance Attribute Details
#instance_properties ⇒ ::Google::Cloud::Compute::V1::AllocationSpecificSKUAllocationReservedInstanceProperties
Returns Properties of the SKU instances being reserved.
21465 21466 21467 21468 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21465 class FutureReservationSpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_instance_template ⇒ ::String
Returns The instance template that will be used to populate the ReservedInstanceProperties of the future reservation.
21465 21466 21467 21468 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21465 class FutureReservationSpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_count ⇒ ::Integer
Returns Total number of instances for which capacity assurance is requested at a future time period.
21465 21466 21467 21468 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21465 class FutureReservationSpecificSKUProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |