Class: Google::Cloud::Compute::V1::FutureReservationStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output only] Represents status related to the future reservation.

Defined Under Namespace

Modules: AmendmentStatus, ProcurementStatus

Instance Attribute Summary collapse

Instance Attribute Details

#amendment_status::String

Returns Output only. [Output Only] The current status of the requested amendment. Check the AmendmentStatus enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The current status of the requested amendment. Check the AmendmentStatus enum for the list of possible values.



21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
22017
22018
22019
22020
22021
22022
22023
22024
22025
22026
22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
22040
22041
22042
22043
22044
22045
22046
22047
22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
22059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21984

class FutureReservationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current status of the requested amendment.
  module AmendmentStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_AMENDMENT_STATUS = 0

    # The requested amendment to the Future Resevation has been approved and
    # applied by GCP.
    AMENDMENT_APPROVED = 150_573_001

    # The requested amendment to the Future Reservation has been declined by
    # GCP and the original state was restored.
    AMENDMENT_DECLINED = 70_395_200

    # The requested amendment to the Future Reservation is currently being
    # reviewd by GCP.
    AMENDMENT_IN_REVIEW = 25_830_624

    AMENDMENT_STATUS_UNSPECIFIED = 412_250_332
  end

  # Output only. Current state of this Future Reservation
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#auto_created_reservations::Array<::String>

Returns Output only. Fully qualified urls of the automatically created reservations at start_time.

Returns:

  • (::Array<::String>)

    Output only. Fully qualified urls of the automatically created reservations at start_time.



21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
22017
22018
22019
22020
22021
22022
22023
22024
22025
22026
22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
22040
22041
22042
22043
22044
22045
22046
22047
22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
22059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21984

class FutureReservationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current status of the requested amendment.
  module AmendmentStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_AMENDMENT_STATUS = 0

    # The requested amendment to the Future Resevation has been approved and
    # applied by GCP.
    AMENDMENT_APPROVED = 150_573_001

    # The requested amendment to the Future Reservation has been declined by
    # GCP and the original state was restored.
    AMENDMENT_DECLINED = 70_395_200

    # The requested amendment to the Future Reservation is currently being
    # reviewd by GCP.
    AMENDMENT_IN_REVIEW = 25_830_624

    AMENDMENT_STATUS_UNSPECIFIED = 412_250_332
  end

  # Output only. Current state of this Future Reservation
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#existing_matching_usage_info::Google::Cloud::Compute::V1::FutureReservationStatusExistingMatchingUsageInfo

Returns Output only. [Output Only] Represents the existing matching usage for the future reservation.

Returns:



21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
22017
22018
22019
22020
22021
22022
22023
22024
22025
22026
22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
22040
22041
22042
22043
22044
22045
22046
22047
22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
22059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21984

class FutureReservationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current status of the requested amendment.
  module AmendmentStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_AMENDMENT_STATUS = 0

    # The requested amendment to the Future Resevation has been approved and
    # applied by GCP.
    AMENDMENT_APPROVED = 150_573_001

    # The requested amendment to the Future Reservation has been declined by
    # GCP and the original state was restored.
    AMENDMENT_DECLINED = 70_395_200

    # The requested amendment to the Future Reservation is currently being
    # reviewd by GCP.
    AMENDMENT_IN_REVIEW = 25_830_624

    AMENDMENT_STATUS_UNSPECIFIED = 412_250_332
  end

  # Output only. Current state of this Future Reservation
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#fulfilled_count::Integer

Returns Output only. This count indicates the fulfilled capacity so far. This is set during "PROVISIONING" state. This count also includes capacity delivered as part of existing matching reservations.

Returns:

  • (::Integer)

    Output only. This count indicates the fulfilled capacity so far. This is set during "PROVISIONING" state. This count also includes capacity delivered as part of existing matching reservations.



21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
22017
22018
22019
22020
22021
22022
22023
22024
22025
22026
22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
22040
22041
22042
22043
22044
22045
22046
22047
22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
22059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21984

class FutureReservationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current status of the requested amendment.
  module AmendmentStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_AMENDMENT_STATUS = 0

    # The requested amendment to the Future Resevation has been approved and
    # applied by GCP.
    AMENDMENT_APPROVED = 150_573_001

    # The requested amendment to the Future Reservation has been declined by
    # GCP and the original state was restored.
    AMENDMENT_DECLINED = 70_395_200

    # The requested amendment to the Future Reservation is currently being
    # reviewd by GCP.
    AMENDMENT_IN_REVIEW = 25_830_624

    AMENDMENT_STATUS_UNSPECIFIED = 412_250_332
  end

  # Output only. Current state of this Future Reservation
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#last_known_good_state::Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodState

Returns Output only. [Output Only] This field represents the future reservation before an amendment was requested. If the amendment is declined, the Future Reservation will be reverted to the last known good state. The last known good state is not set when updating a future reservation whose Procurement Status is DRAFTING.

Returns:

  • (::Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodState)

    Output only. [Output Only] This field represents the future reservation before an amendment was requested. If the amendment is declined, the Future Reservation will be reverted to the last known good state. The last known good state is not set when updating a future reservation whose Procurement Status is DRAFTING.



21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
22017
22018
22019
22020
22021
22022
22023
22024
22025
22026
22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
22040
22041
22042
22043
22044
22045
22046
22047
22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
22059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21984

class FutureReservationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current status of the requested amendment.
  module AmendmentStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_AMENDMENT_STATUS = 0

    # The requested amendment to the Future Resevation has been approved and
    # applied by GCP.
    AMENDMENT_APPROVED = 150_573_001

    # The requested amendment to the Future Reservation has been declined by
    # GCP and the original state was restored.
    AMENDMENT_DECLINED = 70_395_200

    # The requested amendment to the Future Reservation is currently being
    # reviewd by GCP.
    AMENDMENT_IN_REVIEW = 25_830_624

    AMENDMENT_STATUS_UNSPECIFIED = 412_250_332
  end

  # Output only. Current state of this Future Reservation
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#lock_time::String

Returns Output only. Time when Future Reservation would become LOCKED, after which no modifications to Future Reservation will be allowed. Applicable only after the Future Reservation is in the APPROVED state. The lock_time is an RFC3339 string. The procurement_status will transition to PROCURING state at this time.

Returns:

  • (::String)

    Output only. Time when Future Reservation would become LOCKED, after which no modifications to Future Reservation will be allowed. Applicable only after the Future Reservation is in the APPROVED state. The lock_time is an RFC3339 string. The procurement_status will transition to PROCURING state at this time.



21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
22017
22018
22019
22020
22021
22022
22023
22024
22025
22026
22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
22040
22041
22042
22043
22044
22045
22046
22047
22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
22059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21984

class FutureReservationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current status of the requested amendment.
  module AmendmentStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_AMENDMENT_STATUS = 0

    # The requested amendment to the Future Resevation has been approved and
    # applied by GCP.
    AMENDMENT_APPROVED = 150_573_001

    # The requested amendment to the Future Reservation has been declined by
    # GCP and the original state was restored.
    AMENDMENT_DECLINED = 70_395_200

    # The requested amendment to the Future Reservation is currently being
    # reviewd by GCP.
    AMENDMENT_IN_REVIEW = 25_830_624

    AMENDMENT_STATUS_UNSPECIFIED = 412_250_332
  end

  # Output only. Current state of this Future Reservation
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#procurement_status::String

Returns Output only. Current state of this Future Reservation Check the ProcurementStatus enum for the list of possible values.

Returns:

  • (::String)

    Output only. Current state of this Future Reservation Check the ProcurementStatus enum for the list of possible values.



21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
22017
22018
22019
22020
22021
22022
22023
22024
22025
22026
22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
22040
22041
22042
22043
22044
22045
22046
22047
22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
22059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21984

class FutureReservationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current status of the requested amendment.
  module AmendmentStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_AMENDMENT_STATUS = 0

    # The requested amendment to the Future Resevation has been approved and
    # applied by GCP.
    AMENDMENT_APPROVED = 150_573_001

    # The requested amendment to the Future Reservation has been declined by
    # GCP and the original state was restored.
    AMENDMENT_DECLINED = 70_395_200

    # The requested amendment to the Future Reservation is currently being
    # reviewd by GCP.
    AMENDMENT_IN_REVIEW = 25_830_624

    AMENDMENT_STATUS_UNSPECIFIED = 412_250_332
  end

  # Output only. Current state of this Future Reservation
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#specific_sku_properties::Google::Cloud::Compute::V1::FutureReservationStatusSpecificSKUProperties



21984
21985
21986
21987
21988
21989
21990
21991
21992
21993
21994
21995
21996
21997
21998
21999
22000
22001
22002
22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
22017
22018
22019
22020
22021
22022
22023
22024
22025
22026
22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
22040
22041
22042
22043
22044
22045
22046
22047
22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
22059
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21984

class FutureReservationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current status of the requested amendment.
  module AmendmentStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_AMENDMENT_STATUS = 0

    # The requested amendment to the Future Resevation has been approved and
    # applied by GCP.
    AMENDMENT_APPROVED = 150_573_001

    # The requested amendment to the Future Reservation has been declined by
    # GCP and the original state was restored.
    AMENDMENT_DECLINED = 70_395_200

    # The requested amendment to the Future Reservation is currently being
    # reviewd by GCP.
    AMENDMENT_IN_REVIEW = 25_830_624

    AMENDMENT_STATUS_UNSPECIFIED = 412_250_332
  end

  # Output only. Current state of this Future Reservation
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end