Class: Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodState

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The state that the future reservation will be reverted to should the amendment be declined.

Defined Under Namespace

Modules: ProcurementStatus

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Output only. [Output Only] The description of the FutureReservation before an amendment was requested.

Returns:

  • (::String)

    Output only. [Output Only] The description of the FutureReservation before an amendment was requested.



21901
21902
21903
21904
21905
21906
21907
21908
21909
21910
21911
21912
21913
21914
21915
21916
21917
21918
21919
21920
21921
21922
21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
21939
21940
21941
21942
21943
21944
21945
21946
21947
21948
21949
21950
21951
21952
21953
21954
21955
21956
21957
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21901

class FutureReservationStatusLastKnownGoodState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the last known good state for the Future
  # Reservation.
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#existing_matching_usage_info::Google::Cloud::Compute::V1::FutureReservationStatusExistingMatchingUsageInfo

Returns Output only. [Output Only] Represents the matching usage for the future reservation before an amendment was requested.

Returns:



21901
21902
21903
21904
21905
21906
21907
21908
21909
21910
21911
21912
21913
21914
21915
21916
21917
21918
21919
21920
21921
21922
21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
21939
21940
21941
21942
21943
21944
21945
21946
21947
21948
21949
21950
21951
21952
21953
21954
21955
21956
21957
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21901

class FutureReservationStatusLastKnownGoodState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the last known good state for the Future
  # Reservation.
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#future_reservation_specs::Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs



21901
21902
21903
21904
21905
21906
21907
21908
21909
21910
21911
21912
21913
21914
21915
21916
21917
21918
21919
21920
21921
21922
21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
21939
21940
21941
21942
21943
21944
21945
21946
21947
21948
21949
21950
21951
21952
21953
21954
21955
21956
21957
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21901

class FutureReservationStatusLastKnownGoodState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the last known good state for the Future
  # Reservation.
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#lock_time::String

Returns Output only. [Output Only] The lock time of the FutureReservation before an amendment was requested.

Returns:

  • (::String)

    Output only. [Output Only] The lock time of the FutureReservation before an amendment was requested.



21901
21902
21903
21904
21905
21906
21907
21908
21909
21910
21911
21912
21913
21914
21915
21916
21917
21918
21919
21920
21921
21922
21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
21939
21940
21941
21942
21943
21944
21945
21946
21947
21948
21949
21950
21951
21952
21953
21954
21955
21956
21957
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21901

class FutureReservationStatusLastKnownGoodState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the last known good state for the Future
  # Reservation.
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#name_prefix::String

Returns Output only. [Output Only] The name prefix of the Future Reservation before an amendment was requested.

Returns:

  • (::String)

    Output only. [Output Only] The name prefix of the Future Reservation before an amendment was requested.



21901
21902
21903
21904
21905
21906
21907
21908
21909
21910
21911
21912
21913
21914
21915
21916
21917
21918
21919
21920
21921
21922
21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
21939
21940
21941
21942
21943
21944
21945
21946
21947
21948
21949
21950
21951
21952
21953
21954
21955
21956
21957
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21901

class FutureReservationStatusLastKnownGoodState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the last known good state for the Future
  # Reservation.
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end

#procurement_status::String

Returns Output only. [Output Only] The status of the last known good state for the Future Reservation. Check the ProcurementStatus enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The status of the last known good state for the Future Reservation. Check the ProcurementStatus enum for the list of possible values.



21901
21902
21903
21904
21905
21906
21907
21908
21909
21910
21911
21912
21913
21914
21915
21916
21917
21918
21919
21920
21921
21922
21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
21939
21940
21941
21942
21943
21944
21945
21946
21947
21948
21949
21950
21951
21952
21953
21954
21955
21956
21957
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21901

class FutureReservationStatusLastKnownGoodState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the last known good state for the Future
  # Reservation.
  module ProcurementStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PROCUREMENT_STATUS = 0

    # Future reservation is approved by GCP.
    APPROVED = 357_258_935

    # Future reservation is cancelled by the customer.
    CANCELLED = 41_957_681

    # Future reservation is committed by the customer.
    COMMITTED = 221_710_172

    # Future reservation is rejected by GCP.
    DECLINED = 277_081_134

    # Related status for PlanningStatus.Draft. Transitions to
    # PENDING_APPROVAL upon user submitting FR.
    DRAFTING = 477_863_585

    # Future reservation failed. No additional reservations were provided.
    FAILED = 455_706_685

    # Future reservation is partially fulfilled. Additional reservations were
    # provided but did not reach total_count reserved instance slots.
    FAILED_PARTIALLY_FULFILLED = 14_455_212

    # Future reservation is fulfilled completely.
    FULFILLED = 409_958_655

    # An Amendment to the Future Reservation has been requested. If the
    # Amendment is declined, the Future Reservation will be restored to the
    # last known good state.
    PENDING_AMENDMENT_APPROVAL = 510_150_429

    # Future reservation is pending approval by GCP.
    PENDING_APPROVAL = 209_692_683

    PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705

    # Future reservation is being procured by GCP. Beyond this point, Future
    # reservation is locked and no further modifications are allowed.
    PROCURING = 95_959_663

    # Future reservation capacity is being provisioned. This state will be
    # entered after start_time, while reservations are being created to
    # provide total_count reserved instance slots. This state will not
    # persist past start_time + 24h.
    PROVISIONING = 290_896_621
  end
end