Class: Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodState
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodState
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The state that the future reservation will be reverted to should the amendment be declined.
Defined Under Namespace
Modules: ProcurementStatus
Instance Attribute Summary collapse
-
#description ⇒ ::String
Output only.
-
#existing_matching_usage_info ⇒ ::Google::Cloud::Compute::V1::FutureReservationStatusExistingMatchingUsageInfo
Output only.
- #future_reservation_specs ⇒ ::Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
-
#lock_time ⇒ ::String
Output only.
-
#name_prefix ⇒ ::String
Output only.
-
#procurement_status ⇒ ::String
Output only.
Instance Attribute Details
#description ⇒ ::String
Returns Output only. [Output Only] The description of the FutureReservation before an amendment was requested.
22784 22785 22786 22787 22788 22789 22790 22791 22792 22793 22794 22795 22796 22797 22798 22799 22800 22801 22802 22803 22804 22805 22806 22807 22808 22809 22810 22811 22812 22813 22814 22815 22816 22817 22818 22819 22820 22821 22822 22823 22824 22825 22826 22827 22828 22829 22830 22831 22832 22833 22834 22835 22836 22837 22838 22839 22840 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22784 class FutureReservationStatusLastKnownGoodState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the last known good state for the Future # Reservation. module ProcurementStatus # A value indicating that the enum field is not set. UNDEFINED_PROCUREMENT_STATUS = 0 # Future reservation is approved by GCP. APPROVED = 357_258_935 # Future reservation is cancelled by the customer. CANCELLED = 41_957_681 # Future reservation is committed by the customer. COMMITTED = 221_710_172 # Future reservation is rejected by GCP. DECLINED = 277_081_134 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 477_863_585 # Future reservation failed. No additional reservations were provided. FAILED = 455_706_685 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 14_455_212 # Future reservation is fulfilled completely. FULFILLED = 409_958_655 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 510_150_429 # Future reservation is pending approval by GCP. PENDING_APPROVAL = 209_692_683 PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705 # Future reservation is being procured by GCP. Beyond this point, Future # reservation is locked and no further modifications are allowed. PROCURING = 95_959_663 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 290_896_621 end end |
#existing_matching_usage_info ⇒ ::Google::Cloud::Compute::V1::FutureReservationStatusExistingMatchingUsageInfo
Returns Output only. [Output Only] Represents the matching usage for the future reservation before an amendment was requested.
22784 22785 22786 22787 22788 22789 22790 22791 22792 22793 22794 22795 22796 22797 22798 22799 22800 22801 22802 22803 22804 22805 22806 22807 22808 22809 22810 22811 22812 22813 22814 22815 22816 22817 22818 22819 22820 22821 22822 22823 22824 22825 22826 22827 22828 22829 22830 22831 22832 22833 22834 22835 22836 22837 22838 22839 22840 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22784 class FutureReservationStatusLastKnownGoodState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the last known good state for the Future # Reservation. module ProcurementStatus # A value indicating that the enum field is not set. UNDEFINED_PROCUREMENT_STATUS = 0 # Future reservation is approved by GCP. APPROVED = 357_258_935 # Future reservation is cancelled by the customer. CANCELLED = 41_957_681 # Future reservation is committed by the customer. COMMITTED = 221_710_172 # Future reservation is rejected by GCP. DECLINED = 277_081_134 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 477_863_585 # Future reservation failed. No additional reservations were provided. FAILED = 455_706_685 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 14_455_212 # Future reservation is fulfilled completely. FULFILLED = 409_958_655 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 510_150_429 # Future reservation is pending approval by GCP. PENDING_APPROVAL = 209_692_683 PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705 # Future reservation is being procured by GCP. Beyond this point, Future # reservation is locked and no further modifications are allowed. PROCURING = 95_959_663 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 290_896_621 end end |
#future_reservation_specs ⇒ ::Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
22784 22785 22786 22787 22788 22789 22790 22791 22792 22793 22794 22795 22796 22797 22798 22799 22800 22801 22802 22803 22804 22805 22806 22807 22808 22809 22810 22811 22812 22813 22814 22815 22816 22817 22818 22819 22820 22821 22822 22823 22824 22825 22826 22827 22828 22829 22830 22831 22832 22833 22834 22835 22836 22837 22838 22839 22840 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22784 class FutureReservationStatusLastKnownGoodState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the last known good state for the Future # Reservation. module ProcurementStatus # A value indicating that the enum field is not set. UNDEFINED_PROCUREMENT_STATUS = 0 # Future reservation is approved by GCP. APPROVED = 357_258_935 # Future reservation is cancelled by the customer. CANCELLED = 41_957_681 # Future reservation is committed by the customer. COMMITTED = 221_710_172 # Future reservation is rejected by GCP. DECLINED = 277_081_134 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 477_863_585 # Future reservation failed. No additional reservations were provided. FAILED = 455_706_685 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 14_455_212 # Future reservation is fulfilled completely. FULFILLED = 409_958_655 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 510_150_429 # Future reservation is pending approval by GCP. PENDING_APPROVAL = 209_692_683 PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705 # Future reservation is being procured by GCP. Beyond this point, Future # reservation is locked and no further modifications are allowed. PROCURING = 95_959_663 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 290_896_621 end end |
#lock_time ⇒ ::String
Returns Output only. [Output Only] The lock time of the FutureReservation before an amendment was requested.
22784 22785 22786 22787 22788 22789 22790 22791 22792 22793 22794 22795 22796 22797 22798 22799 22800 22801 22802 22803 22804 22805 22806 22807 22808 22809 22810 22811 22812 22813 22814 22815 22816 22817 22818 22819 22820 22821 22822 22823 22824 22825 22826 22827 22828 22829 22830 22831 22832 22833 22834 22835 22836 22837 22838 22839 22840 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22784 class FutureReservationStatusLastKnownGoodState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the last known good state for the Future # Reservation. module ProcurementStatus # A value indicating that the enum field is not set. UNDEFINED_PROCUREMENT_STATUS = 0 # Future reservation is approved by GCP. APPROVED = 357_258_935 # Future reservation is cancelled by the customer. CANCELLED = 41_957_681 # Future reservation is committed by the customer. COMMITTED = 221_710_172 # Future reservation is rejected by GCP. DECLINED = 277_081_134 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 477_863_585 # Future reservation failed. No additional reservations were provided. FAILED = 455_706_685 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 14_455_212 # Future reservation is fulfilled completely. FULFILLED = 409_958_655 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 510_150_429 # Future reservation is pending approval by GCP. PENDING_APPROVAL = 209_692_683 PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705 # Future reservation is being procured by GCP. Beyond this point, Future # reservation is locked and no further modifications are allowed. PROCURING = 95_959_663 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 290_896_621 end end |
#name_prefix ⇒ ::String
Returns Output only. [Output Only] The name prefix of the Future Reservation before an amendment was requested.
22784 22785 22786 22787 22788 22789 22790 22791 22792 22793 22794 22795 22796 22797 22798 22799 22800 22801 22802 22803 22804 22805 22806 22807 22808 22809 22810 22811 22812 22813 22814 22815 22816 22817 22818 22819 22820 22821 22822 22823 22824 22825 22826 22827 22828 22829 22830 22831 22832 22833 22834 22835 22836 22837 22838 22839 22840 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22784 class FutureReservationStatusLastKnownGoodState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the last known good state for the Future # Reservation. module ProcurementStatus # A value indicating that the enum field is not set. UNDEFINED_PROCUREMENT_STATUS = 0 # Future reservation is approved by GCP. APPROVED = 357_258_935 # Future reservation is cancelled by the customer. CANCELLED = 41_957_681 # Future reservation is committed by the customer. COMMITTED = 221_710_172 # Future reservation is rejected by GCP. DECLINED = 277_081_134 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 477_863_585 # Future reservation failed. No additional reservations were provided. FAILED = 455_706_685 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 14_455_212 # Future reservation is fulfilled completely. FULFILLED = 409_958_655 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 510_150_429 # Future reservation is pending approval by GCP. PENDING_APPROVAL = 209_692_683 PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705 # Future reservation is being procured by GCP. Beyond this point, Future # reservation is locked and no further modifications are allowed. PROCURING = 95_959_663 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 290_896_621 end end |
#procurement_status ⇒ ::String
Returns Output only. [Output Only] The status of the last known good state for the Future Reservation. Check the ProcurementStatus enum for the list of possible values.
22784 22785 22786 22787 22788 22789 22790 22791 22792 22793 22794 22795 22796 22797 22798 22799 22800 22801 22802 22803 22804 22805 22806 22807 22808 22809 22810 22811 22812 22813 22814 22815 22816 22817 22818 22819 22820 22821 22822 22823 22824 22825 22826 22827 22828 22829 22830 22831 22832 22833 22834 22835 22836 22837 22838 22839 22840 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22784 class FutureReservationStatusLastKnownGoodState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the last known good state for the Future # Reservation. module ProcurementStatus # A value indicating that the enum field is not set. UNDEFINED_PROCUREMENT_STATUS = 0 # Future reservation is approved by GCP. APPROVED = 357_258_935 # Future reservation is cancelled by the customer. CANCELLED = 41_957_681 # Future reservation is committed by the customer. COMMITTED = 221_710_172 # Future reservation is rejected by GCP. DECLINED = 277_081_134 # Related status for PlanningStatus.Draft. Transitions to # PENDING_APPROVAL upon user submitting FR. DRAFTING = 477_863_585 # Future reservation failed. No additional reservations were provided. FAILED = 455_706_685 # Future reservation is partially fulfilled. Additional reservations were # provided but did not reach total_count reserved instance slots. FAILED_PARTIALLY_FULFILLED = 14_455_212 # Future reservation is fulfilled completely. FULFILLED = 409_958_655 # An Amendment to the Future Reservation has been requested. If the # Amendment is declined, the Future Reservation will be restored to the # last known good state. PENDING_AMENDMENT_APPROVAL = 510_150_429 # Future reservation is pending approval by GCP. PENDING_APPROVAL = 209_692_683 PROCUREMENT_STATUS_UNSPECIFIED = 45_807_705 # Future reservation is being procured by GCP. Beyond this point, Future # reservation is locked and no further modifications are allowed. PROCURING = 95_959_663 # Future reservation capacity is being provisioned. This state will be # entered after start_time, while reservations are being created to # provide total_count reserved instance slots. This state will not # persist past start_time + 24h. PROVISIONING = 290_896_621 end end |