Class: Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The properties of the last known good state for the Future Reservation.
Instance Attribute Summary collapse
-
#share_settings ⇒ ::Google::Cloud::Compute::V1::ShareSettings
Output only.
-
#specific_sku_properties ⇒ ::Google::Cloud::Compute::V1::FutureReservationSpecificSKUProperties
Output only.
-
#time_window ⇒ ::Google::Cloud::Compute::V1::FutureReservationTimeWindow
Output only.
Instance Attribute Details
#share_settings ⇒ ::Google::Cloud::Compute::V1::ShareSettings
Returns Output only. [Output Only] The previous share settings of the Future Reservation.
21693 21694 21695 21696 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class FutureReservationStatusLastKnownGoodStateFutureReservationSpecs include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#specific_sku_properties ⇒ ::Google::Cloud::Compute::V1::FutureReservationSpecificSKUProperties
Returns Output only. [Output Only] The previous instance related properties of the Future Reservation.
21693 21694 21695 21696 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class FutureReservationStatusLastKnownGoodStateFutureReservationSpecs include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#time_window ⇒ ::Google::Cloud::Compute::V1::FutureReservationTimeWindow
Returns Output only. [Output Only] The previous time window of the Future Reservation.
21693 21694 21695 21696 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class FutureReservationStatusLastKnownGoodStateFutureReservationSpecs include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |