Class: Google::Cloud::Compute::V1::FutureReservationStoragePoolProvisionedCapacity
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureReservationStoragePoolProvisionedCapacity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Storage pool provisioned capacities for each SKU type.
Instance Attribute Summary collapse
-
#pool_provisioned_capacity_gb ⇒ ::Integer
Size of the storage pool in GiB.
-
#pool_provisioned_iops ⇒ ::Integer
Provisioned IOPS of the storage pool.
-
#pool_provisioned_throughput ⇒ ::Integer
Provisioned throughput of the storage pool in MiB/s.
Instance Attribute Details
#pool_provisioned_capacity_gb ⇒ ::Integer
Returns Size of the storage pool in GiB.
22895 22896 22897 22898 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22895 class FutureReservationStoragePoolProvisionedCapacity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_provisioned_iops ⇒ ::Integer
Returns Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced.
22895 22896 22897 22898 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22895 class FutureReservationStoragePoolProvisionedCapacity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_provisioned_throughput ⇒ ::Integer
Returns Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput.
22895 22896 22897 22898 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22895 class FutureReservationStoragePoolProvisionedCapacity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |