Class: Google::Cloud::Compute::V1::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns:

  • (::String)


22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22027

class FutureReservationsAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    [Output Only] Unique identifier for the resource; defined by the server.



22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22027

class FutureReservationsAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::FutureReservationsScopedList}

Returns A list of Future reservation resources.

Returns:



22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22027

class FutureReservationsAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#futureReservationsAggregatedListResponse for future resevation aggregated list response.

Returns:

  • (::String)

    Output only. [Output Only] Type of resource. Alwayscompute#futureReservationsAggregatedListResponse for future resevation aggregated list response.



22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22027

class FutureReservationsAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22027

class FutureReservationsAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource.



22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22027

class FutureReservationsAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Unreachable resources.



22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22027

class FutureReservationsAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



22027
22028
22029
22030
22031
22032
22033
22034
22035
22036
22037
22038
22039
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22027

class FutureReservationsAggregatedListResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end