Class: Google::Cloud::Compute::V1::FutureResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesRecommendation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Recommendation for single resources specification, to be created in the future.
Defined Under Namespace
Modules: RecommendationType Classes: OtherLocationsEntry
Instance Attribute Summary collapse
- #end_time ⇒ ::String
-
#location ⇒ ::String
The advised location for resource usage.
-
#other_locations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation}
List of locations in the request scope that were not recommended.
-
#recommendation_id ⇒ ::String
Unique id of the recommendation, a UUID string generated by the API.
-
#recommendation_type ⇒ ::String
Type of recommendation.
- #start_time ⇒ ::String
Instance Attribute Details
#end_time ⇒ ::String
22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 22320 22321 22322 22323 22324 22325 22326 22327 22328 22329 22330 22331 22332 22333 22334 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22310 class FutureResourcesRecommendation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation] class OtherLocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of recommendation. Currently only FUTURE_RESERVATION is supported. module RecommendationType # A value indicating that the enum field is not set. UNDEFINED_RECOMMENDATION_TYPE = 0 # A Future Reservation is recommended. FUTURE_RESERVATION = 41_036_592 # Default value, unused. RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624 end end |
#location ⇒ ::String
Returns The advised location for resource usage. When a zone, in format 'zones/'. If not set, it means that no location is recommended - see other_locations for details.
22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 22320 22321 22322 22323 22324 22325 22326 22327 22328 22329 22330 22331 22332 22333 22334 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22310 class FutureResourcesRecommendation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation] class OtherLocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of recommendation. Currently only FUTURE_RESERVATION is supported. module RecommendationType # A value indicating that the enum field is not set. UNDEFINED_RECOMMENDATION_TYPE = 0 # A Future Reservation is recommended. FUTURE_RESERVATION = 41_036_592 # Default value, unused. RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624 end end |
#other_locations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation}
Returns List of locations in the request scope that were not recommended. Keys of the map are zones, in format 'zones/'. The values are status information indicating the recommendation status.
22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 22320 22321 22322 22323 22324 22325 22326 22327 22328 22329 22330 22331 22332 22333 22334 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22310 class FutureResourcesRecommendation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation] class OtherLocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of recommendation. Currently only FUTURE_RESERVATION is supported. module RecommendationType # A value indicating that the enum field is not set. UNDEFINED_RECOMMENDATION_TYPE = 0 # A Future Reservation is recommended. FUTURE_RESERVATION = 41_036_592 # Default value, unused. RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624 end end |
#recommendation_id ⇒ ::String
Returns Unique id of the recommendation, a UUID string generated by the API.
22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 22320 22321 22322 22323 22324 22325 22326 22327 22328 22329 22330 22331 22332 22333 22334 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22310 class FutureResourcesRecommendation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation] class OtherLocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of recommendation. Currently only FUTURE_RESERVATION is supported. module RecommendationType # A value indicating that the enum field is not set. UNDEFINED_RECOMMENDATION_TYPE = 0 # A Future Reservation is recommended. FUTURE_RESERVATION = 41_036_592 # Default value, unused. RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624 end end |
#recommendation_type ⇒ ::String
Returns Type of recommendation. Currently only FUTURE_RESERVATION is supported. Check the RecommendationType enum for the list of possible values.
22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 22320 22321 22322 22323 22324 22325 22326 22327 22328 22329 22330 22331 22332 22333 22334 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22310 class FutureResourcesRecommendation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation] class OtherLocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of recommendation. Currently only FUTURE_RESERVATION is supported. module RecommendationType # A value indicating that the enum field is not set. UNDEFINED_RECOMMENDATION_TYPE = 0 # A Future Reservation is recommended. FUTURE_RESERVATION = 41_036_592 # Default value, unused. RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624 end end |
#start_time ⇒ ::String
22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 22320 22321 22322 22323 22324 22325 22326 22327 22328 22329 22330 22331 22332 22333 22334 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22310 class FutureResourcesRecommendation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation] class OtherLocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of recommendation. Currently only FUTURE_RESERVATION is supported. module RecommendationType # A value indicating that the enum field is not set. UNDEFINED_RECOMMENDATION_TYPE = 0 # A Future Reservation is recommended. FUTURE_RESERVATION = 41_036_592 # Default value, unused. RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624 end end |