Class: Google::Cloud::Compute::V1::FutureResourcesRecommendation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Recommendation for single resources specification, to be created in the future.

Defined Under Namespace

Modules: RecommendationType Classes: OtherLocationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#end_time::String

Returns:

  • (::String)


21834
21835
21836
21837
21838
21839
21840
21841
21842
21843
21844
21845
21846
21847
21848
21849
21850
21851
21852
21853
21854
21855
21856
21857
21858
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21834

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#location::String

Returns The advised location for resource usage. When a zone, in format 'zones/'. If not set, it means that no location is recommended - see other_locations for details.

Returns:

  • (::String)

    The advised location for resource usage. When a zone, in format 'zones/'. If not set, it means that no location is recommended - see other_locations for details.



21834
21835
21836
21837
21838
21839
21840
21841
21842
21843
21844
21845
21846
21847
21848
21849
21850
21851
21852
21853
21854
21855
21856
21857
21858
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21834

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#other_locations::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation}

Returns List of locations in the request scope that were not recommended. Keys of the map are zones, in format 'zones/'. The values are status information indicating the recommendation status.

Returns:



21834
21835
21836
21837
21838
21839
21840
21841
21842
21843
21844
21845
21846
21847
21848
21849
21850
21851
21852
21853
21854
21855
21856
21857
21858
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21834

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#recommendation_id::String

Returns Unique id of the recommendation, a UUID string generated by the API.

Returns:

  • (::String)

    Unique id of the recommendation, a UUID string generated by the API.



21834
21835
21836
21837
21838
21839
21840
21841
21842
21843
21844
21845
21846
21847
21848
21849
21850
21851
21852
21853
21854
21855
21856
21857
21858
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21834

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#recommendation_type::String

Returns Type of recommendation. Currently only FUTURE_RESERVATION is supported. Check the RecommendationType enum for the list of possible values.

Returns:

  • (::String)

    Type of recommendation. Currently only FUTURE_RESERVATION is supported. Check the RecommendationType enum for the list of possible values.



21834
21835
21836
21837
21838
21839
21840
21841
21842
21843
21844
21845
21846
21847
21848
21849
21850
21851
21852
21853
21854
21855
21856
21857
21858
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21834

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end

#start_time::String

Returns:

  • (::String)


21834
21835
21836
21837
21838
21839
21840
21841
21842
21843
21844
21845
21846
21847
21848
21849
21850
21851
21852
21853
21854
21855
21856
21857
21858
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21834

class FutureResourcesRecommendation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation]
  class OtherLocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of recommendation. Currently only FUTURE_RESERVATION is supported.
  module RecommendationType
    # A value indicating that the enum field is not set.
    UNDEFINED_RECOMMENDATION_TYPE = 0

    # A Future Reservation is recommended.
    FUTURE_RESERVATION = 41_036_592

    # Default value, unused.
    RECOMMENDATION_TYPE_UNSPECIFIED = 140_641_624
  end
end