Class: Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Information about recommendation status for locations that were allowed but not used by the response.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#details ⇒ ::String
Details (human readable) describing the situation.
-
#status ⇒ ::String
Status of recommendation in this location.
Instance Attribute Details
#details ⇒ ::String
Returns Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions.
22348 22349 22350 22351 22352 22353 22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22348 class FutureResourcesRecommendationOtherLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of recommendation in this location. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The requested resources are offered in this location # but the requested time window is does not meet the required conditions. CONDITIONS_NOT_MET = 363_628_457 # The requested resources are not offered in this location. # Retrying the request will not change this status. NOT_SUPPORTED = 317_950_466 # The requested resources are offered in this location # and the requested time window is accepted # but there is no capacity within the requested time window. NO_CAPACITY = 274_240_888 # Default value, unused. OTHER_LOCATION_STATUS_UNDEFINED = 222_662_622 # The requested resources are offered in this location # and it is possible to request them. However, another location # was better and was recommended. RECOMMENDED = 369_652_283 end end |
#status ⇒ ::String
Returns Status of recommendation in this location. Check the Status enum for the list of possible values.
22348 22349 22350 22351 22352 22353 22354 22355 22356 22357 22358 22359 22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 22376 22377 22378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22348 class FutureResourcesRecommendationOtherLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of recommendation in this location. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The requested resources are offered in this location # but the requested time window is does not meet the required conditions. CONDITIONS_NOT_MET = 363_628_457 # The requested resources are not offered in this location. # Retrying the request will not change this status. NOT_SUPPORTED = 317_950_466 # The requested resources are offered in this location # and the requested time window is accepted # but there is no capacity within the requested time window. NO_CAPACITY = 274_240_888 # Default value, unused. OTHER_LOCATION_STATUS_UNDEFINED = 222_662_622 # The requested resources are offered in this location # and it is possible to request them. However, another location # was better and was recommended. RECOMMENDED = 369_652_283 end end |