Class: Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Information about recommendation status for locations that were allowed but not used by the response.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#details::String

Returns Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions.

Returns:

  • (::String)

    Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions.



22149
22150
22151
22152
22153
22154
22155
22156
22157
22158
22159
22160
22161
22162
22163
22164
22165
22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
22178
22179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22149

class FutureResourcesRecommendationOtherLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status of recommendation in this location.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The requested resources are offered in this location
    # but the requested time window is does not meet the required conditions.
    CONDITIONS_NOT_MET = 363_628_457

    # The requested resources are not offered in this location.
    # Retrying the request will not change this status.
    NOT_SUPPORTED = 317_950_466

    # The requested resources are offered in this location
    # and the requested time window is accepted
    # but there is no capacity within the requested time window.
    NO_CAPACITY = 274_240_888

    # Default value, unused.
    OTHER_LOCATION_STATUS_UNDEFINED = 222_662_622

    # The requested resources are offered in this location
    # and it is possible to request them. However, another location
    # was better and was recommended.
    RECOMMENDED = 369_652_283
  end
end

#status::String

Returns Status of recommendation in this location. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Status of recommendation in this location. Check the Status enum for the list of possible values.



22149
22150
22151
22152
22153
22154
22155
22156
22157
22158
22159
22160
22161
22162
22163
22164
22165
22166
22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
22177
22178
22179
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22149

class FutureResourcesRecommendationOtherLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status of recommendation in this location.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The requested resources are offered in this location
    # but the requested time window is does not meet the required conditions.
    CONDITIONS_NOT_MET = 363_628_457

    # The requested resources are not offered in this location.
    # Retrying the request will not change this status.
    NOT_SUPPORTED = 317_950_466

    # The requested resources are offered in this location
    # and the requested time window is accepted
    # but there is no capacity within the requested time window.
    NO_CAPACITY = 274_240_888

    # Default value, unused.
    OTHER_LOCATION_STATUS_UNDEFINED = 222_662_622

    # The requested resources are offered in this location
    # and it is possible to request them. However, another location
    # was better and was recommended.
    RECOMMENDED = 369_652_283
  end
end