Class: Google::Cloud::Compute::V1::FutureResourcesRecommendationOtherLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Information about recommendation status for locations that were allowed but not used by the response.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#details::String

Returns Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions.

Returns:

  • (::String)

    Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions.



21872
21873
21874
21875
21876
21877
21878
21879
21880
21881
21882
21883
21884
21885
21886
21887
21888
21889
21890
21891
21892
21893
21894
21895
21896
21897
21898
21899
21900
21901
21902
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21872

class FutureResourcesRecommendationOtherLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status of recommendation in this location.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The requested resources are offered in this location
    # but the requested time window is does not meet the required conditions.
    CONDITIONS_NOT_MET = 363_628_457

    # The requested resources are not offered in this location.
    # Retrying the request will not change this status.
    NOT_SUPPORTED = 317_950_466

    # The requested resources are offered in this location
    # and the requested time window is accepted
    # but there is no capacity within the requested time window.
    NO_CAPACITY = 274_240_888

    # Default value, unused.
    OTHER_LOCATION_STATUS_UNDEFINED = 222_662_622

    # The requested resources are offered in this location
    # and it is possible to request them. However, another location
    # was better and was recommended.
    RECOMMENDED = 369_652_283
  end
end

#status::String

Returns Status of recommendation in this location. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Status of recommendation in this location. Check the Status enum for the list of possible values.



21872
21873
21874
21875
21876
21877
21878
21879
21880
21881
21882
21883
21884
21885
21886
21887
21888
21889
21890
21891
21892
21893
21894
21895
21896
21897
21898
21899
21900
21901
21902
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21872

class FutureResourcesRecommendationOtherLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Status of recommendation in this location.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The requested resources are offered in this location
    # but the requested time window is does not meet the required conditions.
    CONDITIONS_NOT_MET = 363_628_457

    # The requested resources are not offered in this location.
    # Retrying the request will not change this status.
    NOT_SUPPORTED = 317_950_466

    # The requested resources are offered in this location
    # and the requested time window is accepted
    # but there is no capacity within the requested time window.
    NO_CAPACITY = 274_240_888

    # Default value, unused.
    OTHER_LOCATION_STATUS_UNDEFINED = 222_662_622

    # The requested resources are offered in this location
    # and it is possible to request them. However, another location
    # was better and was recommended.
    RECOMMENDED = 369_652_283
  end
end