Class: Google::Cloud::Compute::V1::FutureResourcesSpec
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specification of resources to be created at some time in the future within an optionally specified set of locations, and within the specified time range.
Defined Under Namespace
Modules: DeploymentType
Instance Attribute Summary collapse
-
#deployment_type ⇒ ::String
Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD).
-
#location_policy ⇒ ::Google::Cloud::Compute::V1::FutureResourcesSpecLocationPolicy
Optional location policy allowing to exclude some zone(s) in which the resources must not be created.
-
#target_resources ⇒ ::Google::Cloud::Compute::V1::FutureResourcesSpecTargetResources
Specification of the reserved resources.
-
#time_range_spec ⇒ ::Google::Cloud::Compute::V1::FlexibleTimeRange
Specification of a time range in which the resources may be created.
Instance Attribute Details
#deployment_type ⇒ ::String
Returns Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD). Defaults to DENSE. Check the DeploymentType enum for the list of possible values.
22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22200 class FutureResourcesSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates if the reservation allocation strategy is static (DENSE) or # dynamic (STANDARD). Defaults to DENSE. module DeploymentType # A value indicating that the enum field is not set. UNDEFINED_DEPLOYMENT_TYPE = 0 # The reserved capacity is made up of densely deployed reservation blocks. DENSE = 64_932_607 DEPLOYMENT_TYPE_UNSPECIFIED = 234_847_180 end end |
#location_policy ⇒ ::Google::Cloud::Compute::V1::FutureResourcesSpecLocationPolicy
Returns Optional location policy allowing to exclude some zone(s) in which the resources must not be created.
22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22200 class FutureResourcesSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates if the reservation allocation strategy is static (DENSE) or # dynamic (STANDARD). Defaults to DENSE. module DeploymentType # A value indicating that the enum field is not set. UNDEFINED_DEPLOYMENT_TYPE = 0 # The reserved capacity is made up of densely deployed reservation blocks. DENSE = 64_932_607 DEPLOYMENT_TYPE_UNSPECIFIED = 234_847_180 end end |
#target_resources ⇒ ::Google::Cloud::Compute::V1::FutureResourcesSpecTargetResources
Returns Specification of the reserved resources.
22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22200 class FutureResourcesSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates if the reservation allocation strategy is static (DENSE) or # dynamic (STANDARD). Defaults to DENSE. module DeploymentType # A value indicating that the enum field is not set. UNDEFINED_DEPLOYMENT_TYPE = 0 # The reserved capacity is made up of densely deployed reservation blocks. DENSE = 64_932_607 DEPLOYMENT_TYPE_UNSPECIFIED = 234_847_180 end end |
#time_range_spec ⇒ ::Google::Cloud::Compute::V1::FlexibleTimeRange
Returns Specification of a time range in which the resources may be created. The time range specifies start of resource use and planned end of resource use.
22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22200 class FutureResourcesSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates if the reservation allocation strategy is static (DENSE) or # dynamic (STANDARD). Defaults to DENSE. module DeploymentType # A value indicating that the enum field is not set. UNDEFINED_DEPLOYMENT_TYPE = 0 # The reserved capacity is made up of densely deployed reservation blocks. DENSE = 64_932_607 DEPLOYMENT_TYPE_UNSPECIFIED = 234_847_180 end end |