Class: Google::Cloud::Compute::V1::FutureResourcesSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specification of resources to be created at some time in the future within an optionally specified set of locations, and within the specified time range.

Defined Under Namespace

Modules: DeploymentType

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_type::String

Returns Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD). Defaults to DENSE. Check the DeploymentType enum for the list of possible values.

Returns:

  • (::String)

    Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD). Defaults to DENSE. Check the DeploymentType enum for the list of possible values.



21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21923

class FutureResourcesSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates if the reservation allocation strategy is static (DENSE) or
  # dynamic (STANDARD). Defaults to DENSE.
  module DeploymentType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEPLOYMENT_TYPE = 0

    # The reserved capacity is made up of densely deployed reservation blocks.
    DENSE = 64_932_607

    DEPLOYMENT_TYPE_UNSPECIFIED = 234_847_180
  end
end

#location_policy::Google::Cloud::Compute::V1::FutureResourcesSpecLocationPolicy

Returns Optional location policy allowing to exclude some zone(s) in which the resources must not be created.

Returns:



21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21923

class FutureResourcesSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates if the reservation allocation strategy is static (DENSE) or
  # dynamic (STANDARD). Defaults to DENSE.
  module DeploymentType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEPLOYMENT_TYPE = 0

    # The reserved capacity is made up of densely deployed reservation blocks.
    DENSE = 64_932_607

    DEPLOYMENT_TYPE_UNSPECIFIED = 234_847_180
  end
end

#target_resources::Google::Cloud::Compute::V1::FutureResourcesSpecTargetResources

Returns Specification of the reserved resources.

Returns:



21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21923

class FutureResourcesSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates if the reservation allocation strategy is static (DENSE) or
  # dynamic (STANDARD). Defaults to DENSE.
  module DeploymentType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEPLOYMENT_TYPE = 0

    # The reserved capacity is made up of densely deployed reservation blocks.
    DENSE = 64_932_607

    DEPLOYMENT_TYPE_UNSPECIFIED = 234_847_180
  end
end

#time_range_spec::Google::Cloud::Compute::V1::FlexibleTimeRange

Returns Specification of a time range in which the resources may be created. The time range specifies start of resource use and planned end of resource use.

Returns:



21923
21924
21925
21926
21927
21928
21929
21930
21931
21932
21933
21934
21935
21936
21937
21938
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21923

class FutureResourcesSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates if the reservation allocation strategy is static (DENSE) or
  # dynamic (STANDARD). Defaults to DENSE.
  module DeploymentType
    # A value indicating that the enum field is not set.
    UNDEFINED_DEPLOYMENT_TYPE = 0

    # The reserved capacity is made up of densely deployed reservation blocks.
    DENSE = 64_932_607

    DEPLOYMENT_TYPE_UNSPECIFIED = 234_847_180
  end
end