Class: Google::Cloud::Compute::V1::FutureResourcesSpecAggregateResources
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesSpecAggregateResources
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: VmFamily, WorkloadType
Instance Attribute Summary collapse
-
#accelerator_count ⇒ ::Integer
Size of the request, in accelerator (chip) count.
-
#vm_family ⇒ ::String
The VM family that all instances scheduled against this reservation must belong to.
-
#workload_type ⇒ ::String
Workload type.
Instance Attribute Details
#accelerator_count ⇒ ::Integer
Returns Size of the request, in accelerator (chip) count.
22428 22429 22430 22431 22432 22433 22434 22435 22436 22437 22438 22439 22440 22441 22442 22443 22444 22445 22446 22447 22448 22449 22450 22451 22452 22453 22454 22455 22456 22457 22458 22459 22460 22461 22462 22463 22464 22465 22466 22467 22468 22469 22470 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22428 class FutureResourcesSpecAggregateResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation # must belong to. Use for TPU reservations. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # Workload type. Use for TPU reservations. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |
#vm_family ⇒ ::String
Returns The VM family that all instances scheduled against this reservation must belong to. Use for TPU reservations. Check the VmFamily enum for the list of possible values.
22428 22429 22430 22431 22432 22433 22434 22435 22436 22437 22438 22439 22440 22441 22442 22443 22444 22445 22446 22447 22448 22449 22450 22451 22452 22453 22454 22455 22456 22457 22458 22459 22460 22461 22462 22463 22464 22465 22466 22467 22468 22469 22470 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22428 class FutureResourcesSpecAggregateResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation # must belong to. Use for TPU reservations. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # Workload type. Use for TPU reservations. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |
#workload_type ⇒ ::String
Returns Workload type. Use for TPU reservations. Check the WorkloadType enum for the list of possible values.
22428 22429 22430 22431 22432 22433 22434 22435 22436 22437 22438 22439 22440 22441 22442 22443 22444 22445 22446 22447 22448 22449 22450 22451 22452 22453 22454 22455 22456 22457 22458 22459 22460 22461 22462 22463 22464 22465 22466 22467 22468 22469 22470 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22428 class FutureResourcesSpecAggregateResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation # must belong to. Use for TPU reservations. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # Workload type. Use for TPU reservations. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |