Class: Google::Cloud::Compute::V1::FutureResourcesSpecAggregateResources
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesSpecAggregateResources
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: VmFamily, WorkloadType
Instance Attribute Summary collapse
-
#accelerator_count ⇒ ::Integer
Size of the request, in accelerator (chip) count.
-
#vm_family ⇒ ::String
The VM family that all instances scheduled against this reservation must belong to.
-
#workload_type ⇒ ::String
Workload type.
Instance Attribute Details
#accelerator_count ⇒ ::Integer
Returns Size of the request, in accelerator (chip) count.
22229 22230 22231 22232 22233 22234 22235 22236 22237 22238 22239 22240 22241 22242 22243 22244 22245 22246 22247 22248 22249 22250 22251 22252 22253 22254 22255 22256 22257 22258 22259 22260 22261 22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22229 class FutureResourcesSpecAggregateResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation # must belong to. Use for TPU reservations. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # Workload type. Use for TPU reservations. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |
#vm_family ⇒ ::String
Returns The VM family that all instances scheduled against this reservation must belong to. Use for TPU reservations. Check the VmFamily enum for the list of possible values.
22229 22230 22231 22232 22233 22234 22235 22236 22237 22238 22239 22240 22241 22242 22243 22244 22245 22246 22247 22248 22249 22250 22251 22252 22253 22254 22255 22256 22257 22258 22259 22260 22261 22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22229 class FutureResourcesSpecAggregateResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation # must belong to. Use for TPU reservations. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # Workload type. Use for TPU reservations. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |
#workload_type ⇒ ::String
Returns Workload type. Use for TPU reservations. Check the WorkloadType enum for the list of possible values.
22229 22230 22231 22232 22233 22234 22235 22236 22237 22238 22239 22240 22241 22242 22243 22244 22245 22246 22247 22248 22249 22250 22251 22252 22253 22254 22255 22256 22257 22258 22259 22260 22261 22262 22263 22264 22265 22266 22267 22268 22269 22270 22271 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22229 class FutureResourcesSpecAggregateResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The VM family that all instances scheduled against this reservation # must belong to. Use for TPU reservations. module VmFamily # A value indicating that the enum field is not set. UNDEFINED_VM_FAMILY = 0 VM_FAMILY_CLOUD_TPU_DEVICE_CT3 = 42_845_948 VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L = 108_020_067 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP = 18_705_267 VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT6E = 398_926_997 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P = 517_384_376 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P = 517_384_407 VM_FAMILY_CLOUD_TPU_POD_SLICE_CT5P = 517_384_438 VM_FAMILY_CLOUD_TPU_POD_SLICE_TPU7X = 485_271_888 end # Workload type. Use for TPU reservations. module WorkloadType # A value indicating that the enum field is not set. UNDEFINED_WORKLOAD_TYPE = 0 # Reserved resources will be optimized for BATCH workloads, such as ML # training. BATCH = 62_971_674 # Reserved resources will be optimized for SERVING workloads, such as ML # inference. SERVING = 17_781_740 UNSPECIFIED = 526_786_327 end end |