Class: Google::Cloud::Compute::V1::FutureResourcesSpecLocalSsdPartition
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesSpecLocalSsdPartition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: DiskInterface
Instance Attribute Summary collapse
-
#disk_interface ⇒ ::String
Disk interface.
-
#disk_size_gb ⇒ ::Integer
The size of the disk in GB.
Instance Attribute Details
#disk_interface ⇒ ::String
Returns Disk interface. Defaults to SCSI. Check the DiskInterface enum for the list of possible values.
22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 22490 22491 22492 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22479 class FutureResourcesSpecLocalSsdPartition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Disk interface. Defaults to SCSI. module DiskInterface # A value indicating that the enum field is not set. UNDEFINED_DISK_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end end |
#disk_size_gb ⇒ ::Integer
Returns The size of the disk in GB.
22479 22480 22481 22482 22483 22484 22485 22486 22487 22488 22489 22490 22491 22492 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22479 class FutureResourcesSpecLocalSsdPartition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Disk interface. Defaults to SCSI. module DiskInterface # A value indicating that the enum field is not set. UNDEFINED_DISK_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end end |