Class: Google::Cloud::Compute::V1::FutureResourcesSpecLocalSsdPartition
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesSpecLocalSsdPartition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: DiskInterface
Instance Attribute Summary collapse
-
#disk_interface ⇒ ::String
Disk interface.
-
#disk_size_gb ⇒ ::Integer
The size of the disk in GB.
Instance Attribute Details
#disk_interface ⇒ ::String
Returns Disk interface. Defaults to SCSI. Check the DiskInterface enum for the list of possible values.
22280 22281 22282 22283 22284 22285 22286 22287 22288 22289 22290 22291 22292 22293 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22280 class FutureResourcesSpecLocalSsdPartition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Disk interface. Defaults to SCSI. module DiskInterface # A value indicating that the enum field is not set. UNDEFINED_DISK_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end end |
#disk_size_gb ⇒ ::Integer
Returns The size of the disk in GB.
22280 22281 22282 22283 22284 22285 22286 22287 22288 22289 22290 22291 22292 22293 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22280 class FutureResourcesSpecLocalSsdPartition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Disk interface. Defaults to SCSI. module DiskInterface # A value indicating that the enum field is not set. UNDEFINED_DISK_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end end |