Class: Google::Cloud::Compute::V1::FutureResourcesSpecLocalSsdPartition

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DiskInterface

Instance Attribute Summary collapse

Instance Attribute Details

#disk_interface::String

Returns Disk interface. Defaults to SCSI. Check the DiskInterface enum for the list of possible values.

Returns:

  • (::String)

    Disk interface. Defaults to SCSI. Check the DiskInterface enum for the list of possible values.



22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22003

class FutureResourcesSpecLocalSsdPartition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Disk interface. Defaults to SCSI.
  module DiskInterface
    # A value indicating that the enum field is not set.
    UNDEFINED_DISK_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end

#disk_size_gb::Integer

Returns The size of the disk in GB.

Returns:

  • (::Integer)

    The size of the disk in GB.



22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
22014
22015
22016
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22003

class FutureResourcesSpecLocalSsdPartition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Disk interface. Defaults to SCSI.
  module DiskInterface
    # A value indicating that the enum field is not set.
    UNDEFINED_DISK_INTERFACE = 0

    NVME = 2_408_800

    SCSI = 2_539_686
  end
end