Class: Google::Cloud::Compute::V1::FutureResourcesSpecLocationPolicyLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Preference for a single specified location.

Defined Under Namespace

Modules: Preference

Instance Attribute Summary collapse

Instance Attribute Details

#preference::String

Returns Preference for this location. Check the Preference enum for the list of possible values.

Returns:

  • (::String)

    Preference for this location. Check the Preference enum for the list of possible values.



22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
22331
22332
22333
22334
22335
22336
22337
22338
22339
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22321

class FutureResourcesSpecLocationPolicyLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Preference for this location.
  module Preference
    # A value indicating that the enum field is not set.
    UNDEFINED_PREFERENCE = 0

    # Location is allowed for use.
    ALLOW = 62_368_553

    # Location is prohibited.
    DENY = 2_094_604

    # Default value, unused.
    PREFERENCE_UNSPECIFIED = 496_219_571
  end
end