Class: Google::Cloud::Compute::V1::FutureResourcesSpecLocationPolicyLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesSpecLocationPolicyLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Preference for a single specified location.
Defined Under Namespace
Modules: Preference
Instance Attribute Summary collapse
-
#preference ⇒ ::String
Preference for this location.
Instance Attribute Details
#preference ⇒ ::String
Returns Preference for this location. Check the Preference enum for the list of possible values.
22044 22045 22046 22047 22048 22049 22050 22051 22052 22053 22054 22055 22056 22057 22058 22059 22060 22061 22062 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22044 class FutureResourcesSpecLocationPolicyLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preference for this location. module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # Location is allowed for use. ALLOW = 62_368_553 # Location is prohibited. DENY = 2_094_604 # Default value, unused. PREFERENCE_UNSPECIFIED = 496_219_571 end end |