Class: Google::Cloud::Compute::V1::FutureResourcesSpecLocationPolicyLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesSpecLocationPolicyLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Preference for a single specified location.
Defined Under Namespace
Modules: Preference
Instance Attribute Summary collapse
-
#preference ⇒ ::String
Preference for this location.
Instance Attribute Details
#preference ⇒ ::String
Returns Preference for this location. Check the Preference enum for the list of possible values.
23236 23237 23238 23239 23240 23241 23242 23243 23244 23245 23246 23247 23248 23249 23250 23251 23252 23253 23254 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23236 class FutureResourcesSpecLocationPolicyLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preference for this location. module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # Location is allowed for use. ALLOW = 62_368_553 # Location is prohibited. DENY = 2_094_604 # Default value, unused. PREFERENCE_UNSPECIFIED = 496_219_571 end end |