Class: Google::Cloud::Compute::V1::FutureResourcesSpecSpecificSKUResources
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::FutureResourcesSpecSpecificSKUResources
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#instance_count ⇒ ::Integer
Size of the request, in instance count.
-
#local_ssd_partitions ⇒ ::Array<::Google::Cloud::Compute::V1::FutureResourcesSpecLocalSsdPartition>
Local SSD partitions.
-
#machine_type ⇒ ::String
The machine type to use for instances that will use the reservation.
Instance Attribute Details
#instance_count ⇒ ::Integer
Returns Size of the request, in instance count.
22078 22079 22080 22081 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22078 class FutureResourcesSpecSpecificSKUResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#local_ssd_partitions ⇒ ::Array<::Google::Cloud::Compute::V1::FutureResourcesSpecLocalSsdPartition>
Returns Local SSD partitions. You do not have to include SSD partitions that are built in the machine type.
22078 22079 22080 22081 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22078 class FutureResourcesSpecSpecificSKUResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#machine_type ⇒ ::String
Returns The machine type to use for instances that will use the reservation. This field only accepts machine type names. e.g. n2-standard-4 and does not accept machine type full or partial url. e.g. projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4. Use for GPU reservations.
22078 22079 22080 22081 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22078 class FutureResourcesSpecSpecificSKUResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |