Class: Google::Cloud::Compute::V1::GRPCHealthCheck
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GRPCHealthCheck
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: PortSpecification
Instance Attribute Summary collapse
-
#grpc_service_name ⇒ ::String
The gRPC service name for the health check.
-
#port ⇒ ::Integer
The TCP port number to which the health check prober sends packets.
-
#port_name ⇒ ::String
Not supported.
-
#port_specification ⇒ ::String
Specifies how a port is selected for health checking.
Instance Attribute Details
#grpc_service_name ⇒ ::String
Returns The gRPC service name for the health check. This field is optional. The value of grpc_service_name has the following meanings by convention:
Empty service_name means the overall status of all services at the backend.
Non-empty service_name means the health of that gRPC service, as defined by the owner of the service.
The grpc_service_name can only be ASCII.
22613 22614 22615 22616 22617 22618 22619 22620 22621 22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22613 class GRPCHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end end |
#port ⇒ ::Integer
Returns The TCP port number to which the health check prober sends packets. Valid values are 1 through 65535.
22613 22614 22615 22616 22617 22618 22619 22620 22621 22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22613 class GRPCHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end end |
#port_name ⇒ ::String
Returns Not supported.
22613 22614 22615 22616 22617 22618 22619 22620 22621 22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22613 class GRPCHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end end |
#port_specification ⇒ ::String
Returns Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends.
For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Check the PortSpecification enum for the list of possible values.
22613 22614 22615 22616 22617 22618 22619 22620 22621 22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22613 class GRPCHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end end |