Class: Google::Cloud::Compute::V1::GRPCTLSHealthCheck
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GRPCTLSHealthCheck
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: PortSpecification
Instance Attribute Summary collapse
-
#grpc_service_name ⇒ ::String
The gRPC service name for the health check.
-
#port ⇒ ::Integer
The TCP port number to which the health check prober sends packets.
-
#port_specification ⇒ ::String
Specifies how a port is selected for health checking.
Instance Attribute Details
#grpc_service_name ⇒ ::String
Returns The gRPC service name for the health check. This field is optional. The value of grpc_service_name has the following meanings by convention:
Empty service_name means the overall status of all services at the backend.
Non-empty service_name means the health of that gRPC service, as defined by the owner of the service.
The grpc_service_name can only be ASCII.
22500 22501 22502 22503 22504 22505 22506 22507 22508 22509 22510 22511 22512 22513 22514 22515 22516 22517 22518 22519 22520 22521 22522 22523 22524 22525 22526 22527 22528 22529 22530 22531 22532 22533 22534 22535 22536 22537 22538 22539 22540 22541 22542 22543 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22500 class GRPCTLSHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end end |
#port ⇒ ::Integer
Returns The TCP port number to which the health check prober sends packets. Valid values are 1 through 65535.
22500 22501 22502 22503 22504 22505 22506 22507 22508 22509 22510 22511 22512 22513 22514 22515 22516 22517 22518 22519 22520 22521 22522 22523 22524 22525 22526 22527 22528 22529 22530 22531 22532 22533 22534 22535 22536 22537 22538 22539 22540 22541 22542 22543 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22500 class GRPCTLSHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end end |
#port_specification ⇒ ::String
Returns Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends.
For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Check the PortSpecification enum for the list of possible values.
22500 22501 22502 22503 22504 22505 22506 22507 22508 22509 22510 22511 22512 22513 22514 22515 22516 22517 22518 22519 22520 22521 22522 22523 22524 22525 22526 22527 22528 22529 22530 22531 22532 22533 22534 22535 22536 22537 22538 22539 22540 22541 22542 22543 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22500 class GRPCTLSHealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end end |