Class: Google::Cloud::Compute::V1::GetForwardingRuleRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GetForwardingRuleRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for ForwardingRules.Get. See the method description for details.
Defined Under Namespace
Modules: View
Instance Attribute Summary collapse
-
#forwarding_rule ⇒ ::String
Name of the ForwardingRule resource to return.
-
#project ⇒ ::String
Project ID for this request.
-
#region ⇒ ::String
Name of the region scoping this request.
-
#view ⇒ ::String
Check the View enum for the list of possible values.
Instance Attribute Details
#forwarding_rule ⇒ ::String
Returns Name of the ForwardingRule resource to return.
23033 23034 23035 23036 23037 23038 23039 23040 23041 23042 23043 23044 23045 23046 23047 23048 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23033 class GetForwardingRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module View # A value indicating that the enum field is not set. UNDEFINED_VIEW = 0 # The default view of a ForwardingRule, which includes the basic fields. BASIC = 62_970_894 # The full view, including the ForwardingRule.`attached_extensions` field. FULL = 2_169_487 end end |
#project ⇒ ::String
Returns Project ID for this request.
23033 23034 23035 23036 23037 23038 23039 23040 23041 23042 23043 23044 23045 23046 23047 23048 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23033 class GetForwardingRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module View # A value indicating that the enum field is not set. UNDEFINED_VIEW = 0 # The default view of a ForwardingRule, which includes the basic fields. BASIC = 62_970_894 # The full view, including the ForwardingRule.`attached_extensions` field. FULL = 2_169_487 end end |
#region ⇒ ::String
Returns Name of the region scoping this request.
23033 23034 23035 23036 23037 23038 23039 23040 23041 23042 23043 23044 23045 23046 23047 23048 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23033 class GetForwardingRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module View # A value indicating that the enum field is not set. UNDEFINED_VIEW = 0 # The default view of a ForwardingRule, which includes the basic fields. BASIC = 62_970_894 # The full view, including the ForwardingRule.`attached_extensions` field. FULL = 2_169_487 end end |
#view ⇒ ::String
Returns Check the View enum for the list of possible values.
23033 23034 23035 23036 23037 23038 23039 23040 23041 23042 23043 23044 23045 23046 23047 23048 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23033 class GetForwardingRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module View # A value indicating that the enum field is not set. UNDEFINED_VIEW = 0 # The default view of a ForwardingRule, which includes the basic fields. BASIC = 62_970_894 # The full view, including the ForwardingRule.`attached_extensions` field. FULL = 2_169_487 end end |