Class: Google::Cloud::Compute::V1::GetGlobalForwardingRuleRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GetGlobalForwardingRuleRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for GlobalForwardingRules.Get. See the method description for details.
Defined Under Namespace
Modules: View
Instance Attribute Summary collapse
-
#forwarding_rule ⇒ ::String
Name of the ForwardingRule resource to return.
-
#project ⇒ ::String
Project ID for this request.
-
#view ⇒ ::String
Check the View enum for the list of possible values.
Instance Attribute Details
#forwarding_rule ⇒ ::String
Returns Name of the ForwardingRule resource to return.
23100 23101 23102 23103 23104 23105 23106 23107 23108 23109 23110 23111 23112 23113 23114 23115 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23100 class GetGlobalForwardingRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module View # A value indicating that the enum field is not set. UNDEFINED_VIEW = 0 # The default view of a ForwardingRule, which includes the basic fields. BASIC = 62_970_894 # The full view, including the ForwardingRule.`attached_extensions` field. FULL = 2_169_487 end end |
#project ⇒ ::String
Returns Project ID for this request.
23100 23101 23102 23103 23104 23105 23106 23107 23108 23109 23110 23111 23112 23113 23114 23115 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23100 class GetGlobalForwardingRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module View # A value indicating that the enum field is not set. UNDEFINED_VIEW = 0 # The default view of a ForwardingRule, which includes the basic fields. BASIC = 62_970_894 # The full view, including the ForwardingRule.`attached_extensions` field. FULL = 2_169_487 end end |
#view ⇒ ::String
Returns Check the View enum for the list of possible values.
23100 23101 23102 23103 23104 23105 23106 23107 23108 23109 23110 23111 23112 23113 23114 23115 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23100 class GetGlobalForwardingRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module View # A value indicating that the enum field is not set. UNDEFINED_VIEW = 0 # The default view of a ForwardingRule, which includes the basic fields. BASIC = 62_970_894 # The full view, including the ForwardingRule.`attached_extensions` field. FULL = 2_169_487 end end |