Class: Google::Cloud::Compute::V1::GetHealthOperationMetadataHealthInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GetHealthOperationMetadataHealthInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Health information.
Defined Under Namespace
Modules: AvailabilitySloStatus, HealthStatus, RepairCategory, UnhealthyReason
Instance Attribute Summary collapse
-
#availability_slo_status ⇒ ::String
Output only.
-
#health_status ⇒ ::String
Output only.
-
#repair_category ⇒ ::String
Output only.
-
#unhealthy_reason ⇒ ::String
Output only.
-
#update_time ⇒ ::String
Output only.
Instance Attribute Details
#availability_slo_status ⇒ ::String
Returns Output only. The availability SLO status. Check the AvailabilitySloStatus enum for the list of possible values.
23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 23986 23987 23988 23989 23990 23991 23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 24014 24015 24016 24017 24018 24019 24020 24021 24022 24023 24024 24025 24026 24027 24028 24029 24030 24031 24032 24033 24034 24035 24036 24037 24038 24039 24040 24041 24042 24043 24044 24045 24046 24047 24048 24049 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23971 class GetHealthOperationMetadataHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The availability SLO status. module AvailabilitySloStatus # A value indicating that the enum field is not set. UNDEFINED_AVAILABILITY_SLO_STATUS = 0 # The slot availability is in SLO. AVAILABILITY_SLO_STATUS_IN_SLO = 142_966_428 # The slot availability is out of SLO. AVAILABILITY_SLO_STATUS_OUT_OF_SLO = 112_099_455 # The slot availability is unknown. AVAILABILITY_SLO_STATUS_SLO_UNKNOWN = 280_579_681 # Unspecified availability SLO status. AVAILABILITY_SLO_STATUS_UNSPECIFIED = 481_084_279 end # Output only. The health status. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation slot is healthy. HEALTH_STATUS_HEALTHY = 281_715_315 # The reservation slot is unhealthy. HEALTH_STATUS_UNHEALTHY = 476_038_202 # Unspecified health status. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end # Output only. The repair category. module RepairCategory # A value indicating that the enum field is not set. UNDEFINED_REPAIR_CATEGORY = 0 # The repair is because of critical failures, that are scoped outside # emergent maintenance REPAIR_CATEGORY_CRITICAL_FAILURE = 58_241_977 # The repair is because of an emergent maintenance REPAIR_CATEGORY_EMERGENT_MAINTENANCE = 400_869_148 # The repair is because of a planned maintenance REPAIR_CATEGORY_PLANNED_MAINTENANCE = 489_286_537 # Unspecified repair category. REPAIR_CATEGORY_UNSPECIFIED = 287_264_456 # The repair is because of a user reported fault REPAIR_CATEGORY_USER_REPORTED_FAULT = 227_760_443 end # Output only. The reason for unhealthy status. module UnhealthyReason # A value indicating that the enum field is not set. UNDEFINED_UNHEALTHY_REASON = 0 # The slot is unhealthy because there is a pending repair, waiting for # customer approval UNHEALTHY_REASON_PENDING_USER_APPROVAL = 315_397_455 # The slot is unhealthy because repair is in progress UNHEALTHY_REASON_REPAIRING = 199_320_309 # The slot is unhealthy because a vm cannot be scheduled on it, and no # repairs are running on the slot UNHEALTHY_REASON_UNSCHEDULABLE = 118_083_439 # Unspecified unhealthy reason. UNHEALTHY_REASON_UNSPECIFIED = 337_725_687 end end |
#health_status ⇒ ::String
Returns Output only. The health status. Check the HealthStatus enum for the list of possible values.
23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 23986 23987 23988 23989 23990 23991 23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 24014 24015 24016 24017 24018 24019 24020 24021 24022 24023 24024 24025 24026 24027 24028 24029 24030 24031 24032 24033 24034 24035 24036 24037 24038 24039 24040 24041 24042 24043 24044 24045 24046 24047 24048 24049 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23971 class GetHealthOperationMetadataHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The availability SLO status. module AvailabilitySloStatus # A value indicating that the enum field is not set. UNDEFINED_AVAILABILITY_SLO_STATUS = 0 # The slot availability is in SLO. AVAILABILITY_SLO_STATUS_IN_SLO = 142_966_428 # The slot availability is out of SLO. AVAILABILITY_SLO_STATUS_OUT_OF_SLO = 112_099_455 # The slot availability is unknown. AVAILABILITY_SLO_STATUS_SLO_UNKNOWN = 280_579_681 # Unspecified availability SLO status. AVAILABILITY_SLO_STATUS_UNSPECIFIED = 481_084_279 end # Output only. The health status. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation slot is healthy. HEALTH_STATUS_HEALTHY = 281_715_315 # The reservation slot is unhealthy. HEALTH_STATUS_UNHEALTHY = 476_038_202 # Unspecified health status. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end # Output only. The repair category. module RepairCategory # A value indicating that the enum field is not set. UNDEFINED_REPAIR_CATEGORY = 0 # The repair is because of critical failures, that are scoped outside # emergent maintenance REPAIR_CATEGORY_CRITICAL_FAILURE = 58_241_977 # The repair is because of an emergent maintenance REPAIR_CATEGORY_EMERGENT_MAINTENANCE = 400_869_148 # The repair is because of a planned maintenance REPAIR_CATEGORY_PLANNED_MAINTENANCE = 489_286_537 # Unspecified repair category. REPAIR_CATEGORY_UNSPECIFIED = 287_264_456 # The repair is because of a user reported fault REPAIR_CATEGORY_USER_REPORTED_FAULT = 227_760_443 end # Output only. The reason for unhealthy status. module UnhealthyReason # A value indicating that the enum field is not set. UNDEFINED_UNHEALTHY_REASON = 0 # The slot is unhealthy because there is a pending repair, waiting for # customer approval UNHEALTHY_REASON_PENDING_USER_APPROVAL = 315_397_455 # The slot is unhealthy because repair is in progress UNHEALTHY_REASON_REPAIRING = 199_320_309 # The slot is unhealthy because a vm cannot be scheduled on it, and no # repairs are running on the slot UNHEALTHY_REASON_UNSCHEDULABLE = 118_083_439 # Unspecified unhealthy reason. UNHEALTHY_REASON_UNSPECIFIED = 337_725_687 end end |
#repair_category ⇒ ::String
Returns Output only. The repair category. Check the RepairCategory enum for the list of possible values.
23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 23986 23987 23988 23989 23990 23991 23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 24014 24015 24016 24017 24018 24019 24020 24021 24022 24023 24024 24025 24026 24027 24028 24029 24030 24031 24032 24033 24034 24035 24036 24037 24038 24039 24040 24041 24042 24043 24044 24045 24046 24047 24048 24049 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23971 class GetHealthOperationMetadataHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The availability SLO status. module AvailabilitySloStatus # A value indicating that the enum field is not set. UNDEFINED_AVAILABILITY_SLO_STATUS = 0 # The slot availability is in SLO. AVAILABILITY_SLO_STATUS_IN_SLO = 142_966_428 # The slot availability is out of SLO. AVAILABILITY_SLO_STATUS_OUT_OF_SLO = 112_099_455 # The slot availability is unknown. AVAILABILITY_SLO_STATUS_SLO_UNKNOWN = 280_579_681 # Unspecified availability SLO status. AVAILABILITY_SLO_STATUS_UNSPECIFIED = 481_084_279 end # Output only. The health status. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation slot is healthy. HEALTH_STATUS_HEALTHY = 281_715_315 # The reservation slot is unhealthy. HEALTH_STATUS_UNHEALTHY = 476_038_202 # Unspecified health status. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end # Output only. The repair category. module RepairCategory # A value indicating that the enum field is not set. UNDEFINED_REPAIR_CATEGORY = 0 # The repair is because of critical failures, that are scoped outside # emergent maintenance REPAIR_CATEGORY_CRITICAL_FAILURE = 58_241_977 # The repair is because of an emergent maintenance REPAIR_CATEGORY_EMERGENT_MAINTENANCE = 400_869_148 # The repair is because of a planned maintenance REPAIR_CATEGORY_PLANNED_MAINTENANCE = 489_286_537 # Unspecified repair category. REPAIR_CATEGORY_UNSPECIFIED = 287_264_456 # The repair is because of a user reported fault REPAIR_CATEGORY_USER_REPORTED_FAULT = 227_760_443 end # Output only. The reason for unhealthy status. module UnhealthyReason # A value indicating that the enum field is not set. UNDEFINED_UNHEALTHY_REASON = 0 # The slot is unhealthy because there is a pending repair, waiting for # customer approval UNHEALTHY_REASON_PENDING_USER_APPROVAL = 315_397_455 # The slot is unhealthy because repair is in progress UNHEALTHY_REASON_REPAIRING = 199_320_309 # The slot is unhealthy because a vm cannot be scheduled on it, and no # repairs are running on the slot UNHEALTHY_REASON_UNSCHEDULABLE = 118_083_439 # Unspecified unhealthy reason. UNHEALTHY_REASON_UNSPECIFIED = 337_725_687 end end |
#unhealthy_reason ⇒ ::String
Returns Output only. The reason for unhealthy status. Check the UnhealthyReason enum for the list of possible values.
23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 23986 23987 23988 23989 23990 23991 23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 24014 24015 24016 24017 24018 24019 24020 24021 24022 24023 24024 24025 24026 24027 24028 24029 24030 24031 24032 24033 24034 24035 24036 24037 24038 24039 24040 24041 24042 24043 24044 24045 24046 24047 24048 24049 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23971 class GetHealthOperationMetadataHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The availability SLO status. module AvailabilitySloStatus # A value indicating that the enum field is not set. UNDEFINED_AVAILABILITY_SLO_STATUS = 0 # The slot availability is in SLO. AVAILABILITY_SLO_STATUS_IN_SLO = 142_966_428 # The slot availability is out of SLO. AVAILABILITY_SLO_STATUS_OUT_OF_SLO = 112_099_455 # The slot availability is unknown. AVAILABILITY_SLO_STATUS_SLO_UNKNOWN = 280_579_681 # Unspecified availability SLO status. AVAILABILITY_SLO_STATUS_UNSPECIFIED = 481_084_279 end # Output only. The health status. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation slot is healthy. HEALTH_STATUS_HEALTHY = 281_715_315 # The reservation slot is unhealthy. HEALTH_STATUS_UNHEALTHY = 476_038_202 # Unspecified health status. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end # Output only. The repair category. module RepairCategory # A value indicating that the enum field is not set. UNDEFINED_REPAIR_CATEGORY = 0 # The repair is because of critical failures, that are scoped outside # emergent maintenance REPAIR_CATEGORY_CRITICAL_FAILURE = 58_241_977 # The repair is because of an emergent maintenance REPAIR_CATEGORY_EMERGENT_MAINTENANCE = 400_869_148 # The repair is because of a planned maintenance REPAIR_CATEGORY_PLANNED_MAINTENANCE = 489_286_537 # Unspecified repair category. REPAIR_CATEGORY_UNSPECIFIED = 287_264_456 # The repair is because of a user reported fault REPAIR_CATEGORY_USER_REPORTED_FAULT = 227_760_443 end # Output only. The reason for unhealthy status. module UnhealthyReason # A value indicating that the enum field is not set. UNDEFINED_UNHEALTHY_REASON = 0 # The slot is unhealthy because there is a pending repair, waiting for # customer approval UNHEALTHY_REASON_PENDING_USER_APPROVAL = 315_397_455 # The slot is unhealthy because repair is in progress UNHEALTHY_REASON_REPAIRING = 199_320_309 # The slot is unhealthy because a vm cannot be scheduled on it, and no # repairs are running on the slot UNHEALTHY_REASON_UNSCHEDULABLE = 118_083_439 # Unspecified unhealthy reason. UNHEALTHY_REASON_UNSPECIFIED = 337_725_687 end end |
#update_time ⇒ ::String
Returns Output only. The time when health info was updated.
23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 23986 23987 23988 23989 23990 23991 23992 23993 23994 23995 23996 23997 23998 23999 24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 24014 24015 24016 24017 24018 24019 24020 24021 24022 24023 24024 24025 24026 24027 24028 24029 24030 24031 24032 24033 24034 24035 24036 24037 24038 24039 24040 24041 24042 24043 24044 24045 24046 24047 24048 24049 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23971 class GetHealthOperationMetadataHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The availability SLO status. module AvailabilitySloStatus # A value indicating that the enum field is not set. UNDEFINED_AVAILABILITY_SLO_STATUS = 0 # The slot availability is in SLO. AVAILABILITY_SLO_STATUS_IN_SLO = 142_966_428 # The slot availability is out of SLO. AVAILABILITY_SLO_STATUS_OUT_OF_SLO = 112_099_455 # The slot availability is unknown. AVAILABILITY_SLO_STATUS_SLO_UNKNOWN = 280_579_681 # Unspecified availability SLO status. AVAILABILITY_SLO_STATUS_UNSPECIFIED = 481_084_279 end # Output only. The health status. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation slot is healthy. HEALTH_STATUS_HEALTHY = 281_715_315 # The reservation slot is unhealthy. HEALTH_STATUS_UNHEALTHY = 476_038_202 # Unspecified health status. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end # Output only. The repair category. module RepairCategory # A value indicating that the enum field is not set. UNDEFINED_REPAIR_CATEGORY = 0 # The repair is because of critical failures, that are scoped outside # emergent maintenance REPAIR_CATEGORY_CRITICAL_FAILURE = 58_241_977 # The repair is because of an emergent maintenance REPAIR_CATEGORY_EMERGENT_MAINTENANCE = 400_869_148 # The repair is because of a planned maintenance REPAIR_CATEGORY_PLANNED_MAINTENANCE = 489_286_537 # Unspecified repair category. REPAIR_CATEGORY_UNSPECIFIED = 287_264_456 # The repair is because of a user reported fault REPAIR_CATEGORY_USER_REPORTED_FAULT = 227_760_443 end # Output only. The reason for unhealthy status. module UnhealthyReason # A value indicating that the enum field is not set. UNDEFINED_UNHEALTHY_REASON = 0 # The slot is unhealthy because there is a pending repair, waiting for # customer approval UNHEALTHY_REASON_PENDING_USER_APPROVAL = 315_397_455 # The slot is unhealthy because repair is in progress UNHEALTHY_REASON_REPAIRING = 199_320_309 # The slot is unhealthy because a vm cannot be scheduled on it, and no # repairs are running on the slot UNHEALTHY_REASON_UNSCHEDULABLE = 118_083_439 # Unspecified unhealthy reason. UNHEALTHY_REASON_UNSPECIFIED = 337_725_687 end end |