Module: Google::Cloud::Compute::V1::GetHealthOperationMetadataHealthInfo::RepairCategory
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Output only. The repair category.
Constant Summary collapse
- UNDEFINED_REPAIR_CATEGORY =
A value indicating that the enum field is not set.
0- REPAIR_CATEGORY_CRITICAL_FAILURE =
The repair is because of critical failures, that are scoped outside emergent maintenance
58_241_977- REPAIR_CATEGORY_EMERGENT_MAINTENANCE =
The repair is because of an emergent maintenance
400_869_148- REPAIR_CATEGORY_PLANNED_MAINTENANCE =
The repair is because of a planned maintenance
489_286_537- REPAIR_CATEGORY_UNSPECIFIED =
Unspecified repair category.
287_264_456- REPAIR_CATEGORY_USER_REPORTED_FAULT =
The repair is because of a user reported fault
227_760_443