Module: Google::Cloud::Compute::V1::GetHealthOperationMetadataHealthInfo::UnhealthyReason
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Output only. The reason for unhealthy status.
Constant Summary collapse
- UNDEFINED_UNHEALTHY_REASON =
A value indicating that the enum field is not set.
0- UNHEALTHY_REASON_PENDING_USER_APPROVAL =
The slot is unhealthy because there is a pending repair, waiting for customer approval
315_397_455- UNHEALTHY_REASON_REPAIRING =
The slot is unhealthy because repair is in progress
199_320_309- UNHEALTHY_REASON_UNSCHEDULABLE =
The slot is unhealthy because a vm cannot be scheduled on it, and no repairs are running on the slot
118_083_439- UNHEALTHY_REASON_UNSPECIFIED =
Unspecified unhealthy reason.
337_725_687