Class: Google::Cloud::Compute::V1::GetReservationBlockRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for ReservationBlocks.Get. See the method description for details.

Defined Under Namespace

Modules: View

Instance Attribute Summary collapse

Instance Attribute Details

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



24771
24772
24773
24774
24775
24776
24777
24778
24779
24780
24781
24782
24783
24784
24785
24786
24787
24788
24789
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24771

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end

#reservation::String

Returns The name of the reservation. Name should conform to RFC1035 or be a resource ID.

Returns:

  • (::String)

    The name of the reservation. Name should conform to RFC1035 or be a resource ID.



24771
24772
24773
24774
24775
24776
24777
24778
24779
24780
24781
24782
24783
24784
24785
24786
24787
24788
24789
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24771

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end

#reservation_block::String

Returns The name of the reservation block. Name should conform to RFC1035 or be a resource ID.

Returns:

  • (::String)

    The name of the reservation block. Name should conform to RFC1035 or be a resource ID.



24771
24772
24773
24774
24775
24776
24777
24778
24779
24780
24781
24782
24783
24784
24785
24786
24787
24788
24789
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24771

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end

#view::String

Returns View of the Block. Check the View enum for the list of possible values.

Returns:

  • (::String)

    View of the Block. Check the View enum for the list of possible values.



24771
24772
24773
24774
24775
24776
24777
24778
24779
24780
24781
24782
24783
24784
24785
24786
24787
24788
24789
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24771

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end

#zone::String

Returns Name of the zone for this request. Zone name should conform to RFC1035.

Returns:

  • (::String)

    Name of the zone for this request. Zone name should conform to RFC1035.



24771
24772
24773
24774
24775
24776
24777
24778
24779
24780
24781
24782
24783
24784
24785
24786
24787
24788
24789
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24771

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end