Class: Google::Cloud::Compute::V1::GetReservationBlockRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for ReservationBlocks.Get. See the method description for details.

Defined Under Namespace

Modules: View

Instance Attribute Summary collapse

Instance Attribute Details

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



24467
24468
24469
24470
24471
24472
24473
24474
24475
24476
24477
24478
24479
24480
24481
24482
24483
24484
24485
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24467

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end

#reservation::String

Returns The name of the reservation. Name should conform to RFC1035 or be a resource ID.

Returns:

  • (::String)

    The name of the reservation. Name should conform to RFC1035 or be a resource ID.



24467
24468
24469
24470
24471
24472
24473
24474
24475
24476
24477
24478
24479
24480
24481
24482
24483
24484
24485
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24467

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end

#reservation_block::String

Returns The name of the reservation block. Name should conform to RFC1035 or be a resource ID.

Returns:

  • (::String)

    The name of the reservation block. Name should conform to RFC1035 or be a resource ID.



24467
24468
24469
24470
24471
24472
24473
24474
24475
24476
24477
24478
24479
24480
24481
24482
24483
24484
24485
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24467

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end

#view::String

Returns View of the Block. Check the View enum for the list of possible values.

Returns:

  • (::String)

    View of the Block. Check the View enum for the list of possible values.



24467
24468
24469
24470
24471
24472
24473
24474
24475
24476
24477
24478
24479
24480
24481
24482
24483
24484
24485
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24467

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end

#zone::String

Returns Name of the zone for this request. Zone name should conform to RFC1035.

Returns:

  • (::String)

    Name of the zone for this request. Zone name should conform to RFC1035.



24467
24468
24469
24470
24471
24472
24473
24474
24475
24476
24477
24478
24479
24480
24481
24482
24483
24484
24485
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24467

class GetReservationBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the Block.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation block
    BASIC = 62_970_894

    # The default / unset value. The API will default to the BASIC view.
    BLOCK_VIEW_UNSPECIFIED = 275_070_479

    # Includes detailed topology view.
    FULL = 2_169_487
  end
end