Class: Google::Cloud::Compute::V1::GetReservationSubBlockRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for ReservationSubBlocks.Get. See the method description for details.

Defined Under Namespace

Modules: View

Instance Attribute Summary collapse

Instance Attribute Details

#parent_name::String

Returns The name of the parent reservation and parent block. In the format of reservations/{reservation_name}/reservationBlocks/{reservation_block_name}.

Returns:

  • (::String)

    The name of the parent reservation and parent block. In the format of reservations/{reservation_name}/reservationBlocks/{reservation_block_name}



24541
24542
24543
24544
24545
24546
24547
24548
24549
24550
24551
24552
24553
24554
24555
24556
24557
24558
24559
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24541

class GetReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the subBlock.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation sub block
    SUB_BLOCK_VIEW_BASIC = 236_009_797

    # Includes detailed topology view.
    SUB_BLOCK_VIEW_FULL = 440_711_800

    # The default / unset value. The API will default to the BASIC view.
    SUB_BLOCK_VIEW_UNSPECIFIED = 246_642_446
  end
end

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



24541
24542
24543
24544
24545
24546
24547
24548
24549
24550
24551
24552
24553
24554
24555
24556
24557
24558
24559
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24541

class GetReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the subBlock.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation sub block
    SUB_BLOCK_VIEW_BASIC = 236_009_797

    # Includes detailed topology view.
    SUB_BLOCK_VIEW_FULL = 440_711_800

    # The default / unset value. The API will default to the BASIC view.
    SUB_BLOCK_VIEW_UNSPECIFIED = 246_642_446
  end
end

#reservation_sub_block::String

Returns The name of the reservation subBlock. Name should conform to RFC1035 or be a resource ID.

Returns:

  • (::String)

    The name of the reservation subBlock. Name should conform to RFC1035 or be a resource ID.



24541
24542
24543
24544
24545
24546
24547
24548
24549
24550
24551
24552
24553
24554
24555
24556
24557
24558
24559
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24541

class GetReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the subBlock.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation sub block
    SUB_BLOCK_VIEW_BASIC = 236_009_797

    # Includes detailed topology view.
    SUB_BLOCK_VIEW_FULL = 440_711_800

    # The default / unset value. The API will default to the BASIC view.
    SUB_BLOCK_VIEW_UNSPECIFIED = 246_642_446
  end
end

#view::String

Returns View of the subBlock. Check the View enum for the list of possible values.

Returns:

  • (::String)

    View of the subBlock. Check the View enum for the list of possible values.



24541
24542
24543
24544
24545
24546
24547
24548
24549
24550
24551
24552
24553
24554
24555
24556
24557
24558
24559
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24541

class GetReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the subBlock.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation sub block
    SUB_BLOCK_VIEW_BASIC = 236_009_797

    # Includes detailed topology view.
    SUB_BLOCK_VIEW_FULL = 440_711_800

    # The default / unset value. The API will default to the BASIC view.
    SUB_BLOCK_VIEW_UNSPECIFIED = 246_642_446
  end
end

#zone::String

Returns Name of the zone for this request. Zone name should conform to RFC1035.

Returns:

  • (::String)

    Name of the zone for this request. Zone name should conform to RFC1035.



24541
24542
24543
24544
24545
24546
24547
24548
24549
24550
24551
24552
24553
24554
24555
24556
24557
24558
24559
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24541

class GetReservationSubBlockRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # View of the subBlock.
  module View
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEW = 0

    # This view includes basic information about the reservation sub block
    SUB_BLOCK_VIEW_BASIC = 236_009_797

    # Includes detailed topology view.
    SUB_BLOCK_VIEW_FULL = 440_711_800

    # The default / unset value. The API will default to the BASIC view.
    SUB_BLOCK_VIEW_UNSPECIFIED = 246_642_446
  end
end