Module: Google::Cloud::Compute::V1::GetReservationSubBlockRequest::View
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
View of the subBlock.
Constant Summary collapse
- UNDEFINED_VIEW =
A value indicating that the enum field is not set.
0- SUB_BLOCK_VIEW_BASIC =
This view includes basic information about the reservation sub block
236_009_797- SUB_BLOCK_VIEW_FULL =
Includes detailed topology view.
440_711_800- SUB_BLOCK_VIEW_UNSPECIFIED =
The default / unset value. The API will default to the BASIC view.
246_642_446