Class: Google::Cloud::Compute::V1::GetSubnetworkRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GetSubnetworkRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for Subnetworks.Get. See the method description for details.
Defined Under Namespace
Modules: Views
Instance Attribute Summary collapse
-
#project ⇒ ::String
Project ID for this request.
-
#region ⇒ ::String
Name of the region scoping this request.
-
#subnetwork ⇒ ::String
Name of the Subnetwork resource to return.
-
#views ⇒ ::String
Defines the extra views returned back in the subnetwork resource.
Instance Attribute Details
#project ⇒ ::String
Returns Project ID for this request.
25509 25510 25511 25512 25513 25514 25515 25516 25517 25518 25519 25520 25521 25522 25523 25524 25525 25526 25527 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25509 class GetSubnetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the extra views returned back in the subnetwork resource. # Supported values: # # - WITH_UTILIZATION: Utilization data is included in the # response. module Views # A value indicating that the enum field is not set. UNDEFINED_VIEWS = 0 DEFAULT = 115_302_945 # Utilization data is included in the response. WITH_UTILIZATION = 504_090_633 end end |
#region ⇒ ::String
Returns Name of the region scoping this request.
25509 25510 25511 25512 25513 25514 25515 25516 25517 25518 25519 25520 25521 25522 25523 25524 25525 25526 25527 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25509 class GetSubnetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the extra views returned back in the subnetwork resource. # Supported values: # # - WITH_UTILIZATION: Utilization data is included in the # response. module Views # A value indicating that the enum field is not set. UNDEFINED_VIEWS = 0 DEFAULT = 115_302_945 # Utilization data is included in the response. WITH_UTILIZATION = 504_090_633 end end |
#subnetwork ⇒ ::String
Returns Name of the Subnetwork resource to return.
25509 25510 25511 25512 25513 25514 25515 25516 25517 25518 25519 25520 25521 25522 25523 25524 25525 25526 25527 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25509 class GetSubnetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the extra views returned back in the subnetwork resource. # Supported values: # # - WITH_UTILIZATION: Utilization data is included in the # response. module Views # A value indicating that the enum field is not set. UNDEFINED_VIEWS = 0 DEFAULT = 115_302_945 # Utilization data is included in the response. WITH_UTILIZATION = 504_090_633 end end |
#views ⇒ ::String
Returns Defines the extra views returned back in the subnetwork resource. Supported values:
- WITH_UTILIZATION: Utilization data is included in the response. Check the Views enum for the list of possible values.
25509 25510 25511 25512 25513 25514 25515 25516 25517 25518 25519 25520 25521 25522 25523 25524 25525 25526 25527 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25509 class GetSubnetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the extra views returned back in the subnetwork resource. # Supported values: # # - WITH_UTILIZATION: Utilization data is included in the # response. module Views # A value indicating that the enum field is not set. UNDEFINED_VIEWS = 0 DEFAULT = 115_302_945 # Utilization data is included in the response. WITH_UTILIZATION = 504_090_633 end end |