Class: Google::Cloud::Compute::V1::GetSubnetworkRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for Subnetworks.Get. See the method description for details.

Defined Under Namespace

Modules: Views

Instance Attribute Summary collapse

Instance Attribute Details

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



25261
25262
25263
25264
25265
25266
25267
25268
25269
25270
25271
25272
25273
25274
25275
25276
25277
25278
25279
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25261

class GetSubnetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the extra views returned back in the subnetwork resource.
  # Supported values:
  #
  #    - WITH_UTILIZATION: Utilization data is included in the
  #    response.
  module Views
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEWS = 0

    DEFAULT = 115_302_945

    # Utilization data is included in the response.
    WITH_UTILIZATION = 504_090_633
  end
end

#region::String

Returns Name of the region scoping this request.

Returns:

  • (::String)

    Name of the region scoping this request.



25261
25262
25263
25264
25265
25266
25267
25268
25269
25270
25271
25272
25273
25274
25275
25276
25277
25278
25279
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25261

class GetSubnetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the extra views returned back in the subnetwork resource.
  # Supported values:
  #
  #    - WITH_UTILIZATION: Utilization data is included in the
  #    response.
  module Views
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEWS = 0

    DEFAULT = 115_302_945

    # Utilization data is included in the response.
    WITH_UTILIZATION = 504_090_633
  end
end

#subnetwork::String

Returns Name of the Subnetwork resource to return.

Returns:

  • (::String)

    Name of the Subnetwork resource to return.



25261
25262
25263
25264
25265
25266
25267
25268
25269
25270
25271
25272
25273
25274
25275
25276
25277
25278
25279
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25261

class GetSubnetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the extra views returned back in the subnetwork resource.
  # Supported values:
  #
  #    - WITH_UTILIZATION: Utilization data is included in the
  #    response.
  module Views
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEWS = 0

    DEFAULT = 115_302_945

    # Utilization data is included in the response.
    WITH_UTILIZATION = 504_090_633
  end
end

#views::String

Returns Defines the extra views returned back in the subnetwork resource. Supported values:

  • WITH_UTILIZATION: Utilization data is included in the response. Check the Views enum for the list of possible values.

Returns:

  • (::String)

    Defines the extra views returned back in the subnetwork resource. Supported values:

    • WITH_UTILIZATION: Utilization data is included in the response. Check the Views enum for the list of possible values.


25261
25262
25263
25264
25265
25266
25267
25268
25269
25270
25271
25272
25273
25274
25275
25276
25277
25278
25279
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25261

class GetSubnetworkRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the extra views returned back in the subnetwork resource.
  # Supported values:
  #
  #    - WITH_UTILIZATION: Utilization data is included in the
  #    response.
  module Views
    # A value indicating that the enum field is not set.
    UNDEFINED_VIEWS = 0

    DEFAULT = 115_302_945

    # Utilization data is included in the response.
    WITH_UTILIZATION = 504_090_633
  end
end