Class: Google::Cloud::Compute::V1::GetSubnetworkRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GetSubnetworkRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for Subnetworks.Get. See the method description for details.
Defined Under Namespace
Modules: Views
Instance Attribute Summary collapse
-
#project ⇒ ::String
Project ID for this request.
-
#region ⇒ ::String
Name of the region scoping this request.
-
#subnetwork ⇒ ::String
Name of the Subnetwork resource to return.
-
#views ⇒ ::String
Defines the extra views returned back in the subnetwork resource.
Instance Attribute Details
#project ⇒ ::String
Returns Project ID for this request.
24933 24934 24935 24936 24937 24938 24939 24940 24941 24942 24943 24944 24945 24946 24947 24948 24949 24950 24951 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24933 class GetSubnetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the extra views returned back in the subnetwork resource. # Supported values: # # - WITH_UTILIZATION: Utilization data is included in the # response. module Views # A value indicating that the enum field is not set. UNDEFINED_VIEWS = 0 DEFAULT = 115_302_945 # Utilization data is included in the response. WITH_UTILIZATION = 504_090_633 end end |
#region ⇒ ::String
Returns Name of the region scoping this request.
24933 24934 24935 24936 24937 24938 24939 24940 24941 24942 24943 24944 24945 24946 24947 24948 24949 24950 24951 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24933 class GetSubnetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the extra views returned back in the subnetwork resource. # Supported values: # # - WITH_UTILIZATION: Utilization data is included in the # response. module Views # A value indicating that the enum field is not set. UNDEFINED_VIEWS = 0 DEFAULT = 115_302_945 # Utilization data is included in the response. WITH_UTILIZATION = 504_090_633 end end |
#subnetwork ⇒ ::String
Returns Name of the Subnetwork resource to return.
24933 24934 24935 24936 24937 24938 24939 24940 24941 24942 24943 24944 24945 24946 24947 24948 24949 24950 24951 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24933 class GetSubnetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the extra views returned back in the subnetwork resource. # Supported values: # # - WITH_UTILIZATION: Utilization data is included in the # response. module Views # A value indicating that the enum field is not set. UNDEFINED_VIEWS = 0 DEFAULT = 115_302_945 # Utilization data is included in the response. WITH_UTILIZATION = 504_090_633 end end |
#views ⇒ ::String
Returns Defines the extra views returned back in the subnetwork resource. Supported values:
- WITH_UTILIZATION: Utilization data is included in the response. Check the Views enum for the list of possible values.
24933 24934 24935 24936 24937 24938 24939 24940 24941 24942 24943 24944 24945 24946 24947 24948 24949 24950 24951 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24933 class GetSubnetworkRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the extra views returned back in the subnetwork resource. # Supported values: # # - WITH_UTILIZATION: Utilization data is included in the # response. module Views # A value indicating that the enum field is not set. UNDEFINED_VIEWS = 0 DEFAULT = 115_302_945 # Utilization data is included in the response. WITH_UTILIZATION = 504_090_633 end end |