Class: Google::Cloud::Compute::V1::GetVersionOperationMetadataSbomInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: CurrentComponentVersionsEntry, TargetComponentVersionsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#current_component_versions::Google::Protobuf::Map{::String => ::String}

Returns A mapping of components to their currently-applied versions or other appropriate identifiers.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    A mapping of components to their currently-applied versions or other appropriate identifiers.



25661
25662
25663
25664
25665
25666
25667
25668
25669
25670
25671
25672
25673
25674
25675
25676
25677
25678
25679
25680
25681
25682
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25661

class GetVersionOperationMetadataSbomInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class CurrentComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#target_component_versions::Google::Protobuf::Map{::String => ::String}

Returns A mapping of components to their target versions or other appropriate identifiers.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    A mapping of components to their target versions or other appropriate identifiers.



25661
25662
25663
25664
25665
25666
25667
25668
25669
25670
25671
25672
25673
25674
25675
25676
25677
25678
25679
25680
25681
25682
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25661

class GetVersionOperationMetadataSbomInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class CurrentComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end