Class: Google::Cloud::Compute::V1::GetVersionOperationMetadataSbomInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: CurrentComponentVersionsEntry, TargetComponentVersionsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#current_component_versions::Google::Protobuf::Map{::String => ::String}

Returns A mapping of components to their currently-applied versions or other appropriate identifiers.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    A mapping of components to their currently-applied versions or other appropriate identifiers.



25413
25414
25415
25416
25417
25418
25419
25420
25421
25422
25423
25424
25425
25426
25427
25428
25429
25430
25431
25432
25433
25434
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25413

class GetVersionOperationMetadataSbomInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class CurrentComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#target_component_versions::Google::Protobuf::Map{::String => ::String}

Returns A mapping of components to their target versions or other appropriate identifiers.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    A mapping of components to their target versions or other appropriate identifiers.



25413
25414
25415
25416
25417
25418
25419
25420
25421
25422
25423
25424
25425
25426
25427
25428
25429
25430
25431
25432
25433
25434
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25413

class GetVersionOperationMetadataSbomInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class CurrentComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetComponentVersionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end