Class: Google::Cloud::Compute::V1::GetVersionOperationMetadataSbomInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GetVersionOperationMetadataSbomInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: CurrentComponentVersionsEntry, TargetComponentVersionsEntry
Instance Attribute Summary collapse
-
#current_component_versions ⇒ ::Google::Protobuf::Map{::String => ::String}
SBOM versions currently applied to the resource.
-
#target_component_versions ⇒ ::Google::Protobuf::Map{::String => ::String}
SBOM versions scheduled for the next maintenance.
Instance Attribute Details
#current_component_versions ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns SBOM versions currently applied to the resource. The key is the component name and the value is the version.
25085 25086 25087 25088 25089 25090 25091 25092 25093 25094 25095 25096 25097 25098 25099 25100 25101 25102 25103 25104 25105 25106 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25085 class GetVersionOperationMetadataSbomInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CurrentComponentVersionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TargetComponentVersionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#target_component_versions ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns SBOM versions scheduled for the next maintenance. The key is the component name and the value is the version.
25085 25086 25087 25088 25089 25090 25091 25092 25093 25094 25095 25096 25097 25098 25099 25100 25101 25102 25103 25104 25105 25106 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25085 class GetVersionOperationMetadataSbomInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CurrentComponentVersionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TargetComponentVersionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |