Class: Google::Cloud::Compute::V1::GlobalSetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GlobalSetLabelsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#label_fingerprint ⇒ ::String
The fingerprint of the previous set of labels for this resource, used to detect conflicts.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
A list of labels to apply for this resource.
Instance Attribute Details
#label_fingerprint ⇒ ::String
Returns The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash when updating or changing labels, otherwise the request will fail with error412 conditionNotMet. Make a get() request to the resource to get the latest fingerprint.
26025 26026 26027 26028 26029 26030 26031 26032 26033 26034 26035 26036 26037 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26025 class GlobalSetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns A list of labels to apply for this resource. Each label must comply with the requirements for labels. For example,"webserver-frontend": "images". A label value can also be empty (e.g. "my-label": "").
26025 26026 26027 26028 26029 26030 26031 26032 26033 26034 26035 26036 26037 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26025 class GlobalSetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |