Class: Google::Cloud::Compute::V1::GlobalSetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GlobalSetLabelsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#label_fingerprint ⇒ ::String
The fingerprint of the previous set of labels for this resource, used to detect conflicts.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
A list of labels to apply for this resource.
Instance Attribute Details
#label_fingerprint ⇒ ::String
11126 11127 11128 11129 11130 11131 11132 11133 11134 11135 11136 11137 11138 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11126 class GlobalSetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
11126 11127 11128 11129 11130 11131 11132 11133 11134 11135 11136 11137 11138 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11126 class GlobalSetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |