Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GlobalVmExtensionPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Message describing GlobalVmExtensionPolicy object.
Defined Under Namespace
Modules: ScopedResourceStatus Classes: ExtensionPoliciesEntry
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#extension_policies ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy}
Required.
-
#id ⇒ ::Integer
Output only.
-
#instance_selectors ⇒ ::Array<::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyInstanceSelector>
Optional.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#priority ⇒ ::Integer
Optional.
-
#rollout_operation ⇒ ::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperation
Required.
-
#scoped_resource_status ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#update_timestamp ⇒ ::String
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#extension_policies ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy}
Returns Required. Map from extension (eg: "cloudops") to its policy configuration. The key is the name of the extension.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#instance_selectors ⇒ ::Array<::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyInstanceSelector>
Returns Optional. Selector to target VMs for a policy. There is a logical "AND" between instance_selectors.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#globalVmExtensionPolicy for globalVmExtensionPolicies.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#priority ⇒ ::Integer
Returns Optional. Used to resolve conflicts when multiple policies are active for the same extension. Defaults to 0.
Larger the number, higher the priority. When the priority is the same, the policy with the newer create time has higher priority.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#rollout_operation ⇒ ::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperation
Returns Required. The rollout strategy and status.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#scoped_resource_status ⇒ ::String
Returns Output only. [Output Only] The scoped resource status. It's only for tracking the purging status of the policy. Check the ScopedResourceStatus enum for the list of possible values.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource's resource id.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |
#update_timestamp ⇒ ::String
Returns Output only. [Output Only] Update timestamp inRFC3339 text format.
25867 25868 25869 25870 25871 25872 25873 25874 25875 25876 25877 25878 25879 25880 25881 25882 25883 25884 25885 25886 25887 25888 25889 25890 25891 25892 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25867 class GlobalVmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output Only] The scoped resource status. It's only for tracking the # purging status of the policy. module ScopedResourceStatus # A value indicating that the enum field is not set. UNDEFINED_SCOPED_RESOURCE_STATUS = 0 # The zonal policies are being deleted. SCOPED_RESOURCE_STATUS_DELETING = 404_198_387 # Default value. This value is unused. SCOPED_RESOURCE_STATUS_UNSPECIFIED = 437_941_996 end end |