Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyLabelSelector
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GlobalVmExtensionPolicyLabelSelector
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A LabelSelector is applicable for a VM only if it matches all labels in the LabelSelector.
Defined Under Namespace
Classes: InclusionLabelsEntry
Instance Attribute Summary collapse
Instance Attribute Details
#inclusion_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels as key value pairs. A VM should contain all the pairs specified in this map to be selected; Labels within the LabelSelector are OR'ed.
26173 26174 26175 26176 26177 26178 26179 26180 26181 26182 26183 26184 26185 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26173 class GlobalVmExtensionPolicyLabelSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class InclusionLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |