Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutInput
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutInput
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: PredefinedRolloutPlan
Instance Attribute Summary collapse
-
#conflict_behavior ⇒ ::String
Optional.
-
#name ⇒ ::String
Optional.
-
#predefined_rollout_plan ⇒ ::String
Optional.
-
#retry_uuid ⇒ ::String
Optional.
Instance Attribute Details
#conflict_behavior ⇒ ::String
Returns Optional. Specifies the behavior of the rollout if a conflict is detected in a
project during a rollout. This only applies to insert and update
methods.
A conflict occurs in the following cases:
insertmethod: If the zonal policy already exists when the insert happens.updatemethod: If the zonal policy was modified by a zonal API call outside of this rollout.
Possible values are the following:
""(empty string): If a conflict occurs, the local value is not overwritten. This is the default behavior."overwrite": If a conflict occurs, the local value is overwritten with the rollout value.
26275 26276 26277 26278 26279 26280 26281 26282 26283 26284 26285 26286 26287 26288 26289 26290 26291 26292 26293 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26275 class GlobalVmExtensionPolicyRolloutOperationRolloutInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Specifies the predefined rollout plan for the policy. Valid values # are `SLOW_ROLLOUT` and `FAST_ROLLOUT`. The recommended value is # `SLOW_ROLLOUT` for progressive rollout. For more information, see Rollout # plans for global policies. module PredefinedRolloutPlan # A value indicating that the enum field is not set. UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0 FAST_ROLLOUT = 207_153_326 ROLLOUT_PLAN_UNSPECIFIED = 144_511_983 SLOW_ROLLOUT = 31_032_659 end end |
#name ⇒ ::String
Returns Optional. The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.
26275 26276 26277 26278 26279 26280 26281 26282 26283 26284 26285 26286 26287 26288 26289 26290 26291 26292 26293 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26275 class GlobalVmExtensionPolicyRolloutOperationRolloutInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Specifies the predefined rollout plan for the policy. Valid values # are `SLOW_ROLLOUT` and `FAST_ROLLOUT`. The recommended value is # `SLOW_ROLLOUT` for progressive rollout. For more information, see Rollout # plans for global policies. module PredefinedRolloutPlan # A value indicating that the enum field is not set. UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0 FAST_ROLLOUT = 207_153_326 ROLLOUT_PLAN_UNSPECIFIED = 144_511_983 SLOW_ROLLOUT = 31_032_659 end end |
#predefined_rollout_plan ⇒ ::String
Returns Optional. Specifies the predefined rollout plan for the policy. Valid values
are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is
SLOW_ROLLOUT for progressive rollout. For more information, see Rollout
plans for global policies.
Check the PredefinedRolloutPlan enum for the list of possible values.
26275 26276 26277 26278 26279 26280 26281 26282 26283 26284 26285 26286 26287 26288 26289 26290 26291 26292 26293 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26275 class GlobalVmExtensionPolicyRolloutOperationRolloutInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Specifies the predefined rollout plan for the policy. Valid values # are `SLOW_ROLLOUT` and `FAST_ROLLOUT`. The recommended value is # `SLOW_ROLLOUT` for progressive rollout. For more information, see Rollout # plans for global policies. module PredefinedRolloutPlan # A value indicating that the enum field is not set. UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0 FAST_ROLLOUT = 207_153_326 ROLLOUT_PLAN_UNSPECIFIED = 144_511_983 SLOW_ROLLOUT = 31_032_659 end end |
#retry_uuid ⇒ ::String
Returns Optional. The UUID that identifies a policy rollout retry attempt for update and delete operations. Set this field only when retrying a rollout for an existing extension policy.
updatemethod: Lets you retry policy rollout without changes. An error occurs if you set retry_uuid but the policy is modified.deletemethod: Lets you retry policy deletion rollout if the previous deletion rollout is not finished and the policy is in the DELETING state. If you set this field when the policy is not in the DELETING state, an error occurs.
26275 26276 26277 26278 26279 26280 26281 26282 26283 26284 26285 26286 26287 26288 26289 26290 26291 26292 26293 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26275 class GlobalVmExtensionPolicyRolloutOperationRolloutInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Specifies the predefined rollout plan for the policy. Valid values # are `SLOW_ROLLOUT` and `FAST_ROLLOUT`. The recommended value is # `SLOW_ROLLOUT` for progressive rollout. For more information, see Rollout # plans for global policies. module PredefinedRolloutPlan # A value indicating that the enum field is not set. UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0 FAST_ROLLOUT = 207_153_326 ROLLOUT_PLAN_UNSPECIFIED = 144_511_983 SLOW_ROLLOUT = 31_032_659 end end |