Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutInput

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: PredefinedRolloutPlan

Instance Attribute Summary collapse

Instance Attribute Details

#conflict_behavior::String

Returns Optional. Specifies the behavior of the rollout if a conflict is detected in a project during a rollout. This only applies to insert and update methods.

A conflict occurs in the following cases:

  • insert method: If the zonal policy already exists when the insert happens.
  • update method: If the zonal policy was modified by a zonal API call outside of this rollout.

Possible values are the following:

  • "" (empty string): If a conflict occurs, the local value is not overwritten. This is the default behavior.
  • "overwrite": If a conflict occurs, the local value is overwritten with the rollout value.

Returns:

  • (::String)

    Optional. Specifies the behavior of the rollout if a conflict is detected in a project during a rollout. This only applies to insert and update methods.

    A conflict occurs in the following cases:

    • insert method: If the zonal policy already exists when the insert happens.
    • update method: If the zonal policy was modified by a zonal API call outside of this rollout.

    Possible values are the following:

    • "" (empty string): If a conflict occurs, the local value is not overwritten. This is the default behavior.
    • "overwrite": If a conflict occurs, the local value is overwritten with the rollout value.


26027
26028
26029
26030
26031
26032
26033
26034
26035
26036
26037
26038
26039
26040
26041
26042
26043
26044
26045
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26027

class GlobalVmExtensionPolicyRolloutOperationRolloutInput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Specifies the predefined rollout plan for the policy. Valid values
  # are `SLOW_ROLLOUT` and `FAST_ROLLOUT`. The recommended value is
  # `SLOW_ROLLOUT` for progressive rollout. For more information, see Rollout
  # plans for global policies.
  module PredefinedRolloutPlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0

    FAST_ROLLOUT = 207_153_326

    ROLLOUT_PLAN_UNSPECIFIED = 144_511_983

    SLOW_ROLLOUT = 31_032_659
  end
end

#name::String

Returns Optional. The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.

Returns:

  • (::String)

    Optional. The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.



26027
26028
26029
26030
26031
26032
26033
26034
26035
26036
26037
26038
26039
26040
26041
26042
26043
26044
26045
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26027

class GlobalVmExtensionPolicyRolloutOperationRolloutInput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Specifies the predefined rollout plan for the policy. Valid values
  # are `SLOW_ROLLOUT` and `FAST_ROLLOUT`. The recommended value is
  # `SLOW_ROLLOUT` for progressive rollout. For more information, see Rollout
  # plans for global policies.
  module PredefinedRolloutPlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0

    FAST_ROLLOUT = 207_153_326

    ROLLOUT_PLAN_UNSPECIFIED = 144_511_983

    SLOW_ROLLOUT = 31_032_659
  end
end

#predefined_rollout_plan::String

Returns Optional. Specifies the predefined rollout plan for the policy. Valid values are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is SLOW_ROLLOUT for progressive rollout. For more information, see Rollout plans for global policies. Check the PredefinedRolloutPlan enum for the list of possible values.

Returns:

  • (::String)

    Optional. Specifies the predefined rollout plan for the policy. Valid values are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is SLOW_ROLLOUT for progressive rollout. For more information, see Rollout plans for global policies. Check the PredefinedRolloutPlan enum for the list of possible values.



26027
26028
26029
26030
26031
26032
26033
26034
26035
26036
26037
26038
26039
26040
26041
26042
26043
26044
26045
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26027

class GlobalVmExtensionPolicyRolloutOperationRolloutInput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Specifies the predefined rollout plan for the policy. Valid values
  # are `SLOW_ROLLOUT` and `FAST_ROLLOUT`. The recommended value is
  # `SLOW_ROLLOUT` for progressive rollout. For more information, see Rollout
  # plans for global policies.
  module PredefinedRolloutPlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0

    FAST_ROLLOUT = 207_153_326

    ROLLOUT_PLAN_UNSPECIFIED = 144_511_983

    SLOW_ROLLOUT = 31_032_659
  end
end

#retry_uuid::String

Returns Optional. The UUID that identifies a policy rollout retry attempt for update and delete operations. Set this field only when retrying a rollout for an existing extension policy.

  • update method: Lets you retry policy rollout without changes. An error occurs if you set retry_uuid but the policy is modified.
  • delete method: Lets you retry policy deletion rollout if the previous deletion rollout is not finished and the policy is in the DELETING state. If you set this field when the policy is not in the DELETING state, an error occurs.

Returns:

  • (::String)

    Optional. The UUID that identifies a policy rollout retry attempt for update and delete operations. Set this field only when retrying a rollout for an existing extension policy.

    • update method: Lets you retry policy rollout without changes. An error occurs if you set retry_uuid but the policy is modified.
    • delete method: Lets you retry policy deletion rollout if the previous deletion rollout is not finished and the policy is in the DELETING state. If you set this field when the policy is not in the DELETING state, an error occurs.


26027
26028
26029
26030
26031
26032
26033
26034
26035
26036
26037
26038
26039
26040
26041
26042
26043
26044
26045
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26027

class GlobalVmExtensionPolicyRolloutOperationRolloutInput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Specifies the predefined rollout plan for the policy. Valid values
  # are `SLOW_ROLLOUT` and `FAST_ROLLOUT`. The recommended value is
  # `SLOW_ROLLOUT` for progressive rollout. For more information, see Rollout
  # plans for global policies.
  module PredefinedRolloutPlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0

    FAST_ROLLOUT = 207_153_326

    ROLLOUT_PLAN_UNSPECIFIED = 144_511_983

    SLOW_ROLLOUT = 31_032_659
  end
end