Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State Classes: LocationRolloutStatusEntry

Instance Attribute Summary collapse

Instance Attribute Details

#location_rollout_status::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus}

Returns Output only. [Output Only] The rollout status for each location. The list of the locations is the same as the list of locations in the rollout plan.

Returns:



26326
26327
26328
26329
26330
26331
26332
26333
26334
26335
26336
26337
26338
26339
26340
26341
26342
26343
26344
26345
26346
26347
26348
26349
26350
26351
26352
26353
26354
26355
26356
26357
26358
26359
26360
26361
26362
26363
26364
26365
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26326

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end

#rollout::String

Returns Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/.

Returns:

  • (::String)

    Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/.



26326
26327
26328
26329
26330
26331
26332
26333
26334
26335
26336
26337
26338
26339
26340
26341
26342
26343
26344
26345
26346
26347
26348
26349
26350
26351
26352
26353
26354
26355
26356
26357
26358
26359
26360
26361
26362
26363
26364
26365
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26326

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end

#rollout_plan::String

Returns Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.

Returns:

  • (::String)

    Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.



26326
26327
26328
26329
26330
26331
26332
26333
26334
26335
26336
26337
26338
26339
26340
26341
26342
26343
26344
26345
26346
26347
26348
26349
26350
26351
26352
26353
26354
26355
26356
26357
26358
26359
26360
26361
26362
26363
26364
26365
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26326

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end

#state::String

Returns Output only. [Output Only] The overall state of the rollout. Check the State enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The overall state of the rollout. Check the State enum for the list of possible values.



26326
26327
26328
26329
26330
26331
26332
26333
26334
26335
26336
26337
26338
26339
26340
26341
26342
26343
26344
26345
26346
26347
26348
26349
26350
26351
26352
26353
26354
26355
26356
26357
26358
26359
26360
26361
26362
26363
26364
26365
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26326

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end