Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State Classes: LocationRolloutStatusEntry

Instance Attribute Summary collapse

Instance Attribute Details

#location_rollout_status::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus}

Returns Output only. [Output Only] The rollout status for each location. The list of the locations is the same as the list of locations in the rollout plan.

Returns:



26078
26079
26080
26081
26082
26083
26084
26085
26086
26087
26088
26089
26090
26091
26092
26093
26094
26095
26096
26097
26098
26099
26100
26101
26102
26103
26104
26105
26106
26107
26108
26109
26110
26111
26112
26113
26114
26115
26116
26117
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26078

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end

#rollout::String

Returns Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/.

Returns:

  • (::String)

    Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/.



26078
26079
26080
26081
26082
26083
26084
26085
26086
26087
26088
26089
26090
26091
26092
26093
26094
26095
26096
26097
26098
26099
26100
26101
26102
26103
26104
26105
26106
26107
26108
26109
26110
26111
26112
26113
26114
26115
26116
26117
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26078

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end

#rollout_plan::String

Returns Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.

Returns:

  • (::String)

    Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/.



26078
26079
26080
26081
26082
26083
26084
26085
26086
26087
26088
26089
26090
26091
26092
26093
26094
26095
26096
26097
26098
26099
26100
26101
26102
26103
26104
26105
26106
26107
26108
26109
26110
26111
26112
26113
26114
26115
26116
26117
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26078

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end

#state::String

Returns Output only. [Output Only] The overall state of the rollout. Check the State enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The overall state of the rollout. Check the State enum for the list of possible values.



26078
26079
26080
26081
26082
26083
26084
26085
26086
26087
26088
26089
26090
26091
26092
26093
26094
26095
26096
26097
26098
26099
26100
26101
26102
26103
26104
26105
26106
26107
26108
26109
26110
26111
26112
26113
26114
26115
26116
26117
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26078

class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus]
  class LocationRolloutStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The overall state of the rollout.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Iteration was explicitly cancelled.
    STATE_CANCELLED = 534_636_259

    # Iteration completed, with all actions being successful.
    STATE_COMPLETED = 265_728_989

    # Iteration completed, with failures.
    STATE_FAILED = 50_857_931

    # The rollout is paused.
    STATE_PAUSED = 337_513_660

    # Iteration is in progress.
    STATE_PROCESSING = 74_195_873

    # Impossible to determine current state of the iteration.
    STATE_UNKNOWN = 230_861_404

    # Default value. This value is unused.
    STATE_UNSPECIFIED = 470_755_401
  end
end