Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::String
Output only.
Instance Attribute Details
#state ⇒ ::String
Returns Output only. [Output Only] The state of the location rollout. Check the State enum for the list of possible values.
26371 26372 26373 26374 26375 26376 26377 26378 26379 26380 26381 26382 26383 26384 26385 26386 26387 26388 26389 26390 26391 26392 26393 26394 26395 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26371 class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The state of the location rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The location rollout is completed. LOCATION_ROLLOUT_STATE_COMPLETED = 134_765_221 # The location rollout has failed. LOCATION_ROLLOUT_STATE_FAILED = 53_286_403 # The location rollout has not started. LOCATION_ROLLOUT_STATE_NOT_STARTED = 471_817_423 # The location rollout is skipped. LOCATION_ROLLOUT_STATE_SKIPPED = 54_074_890 # Default value. This value is unused. LOCATION_ROLLOUT_STATE_UNSPECIFIED = 242_367_761 end end |