Class: Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::String
Output only.
Instance Attribute Details
#state ⇒ ::String
Returns Output only. [Output Only] The state of the location rollout. Check the State enum for the list of possible values.
27296 27297 27298 27299 27300 27301 27302 27303 27304 27305 27306 27307 27308 27309 27310 27311 27312 27313 27314 27315 27316 27317 27318 27319 27320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27296 class GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The state of the location rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The location rollout is completed. LOCATION_ROLLOUT_STATE_COMPLETED = 134_765_221 # The location rollout has failed. LOCATION_ROLLOUT_STATE_FAILED = 53_286_403 # The location rollout has not started. LOCATION_ROLLOUT_STATE_NOT_STARTED = 471_817_423 # The location rollout is skipped. LOCATION_ROLLOUT_STATE_SKIPPED = 54_074_890 # Default value. This value is unused. LOCATION_ROLLOUT_STATE_UNSPECIFIED = 242_367_761 end end |