Class: Google::Cloud::Compute::V1::GroupMaintenanceInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Maintenance Info for ReservationBlocks.

Defined Under Namespace

Modules: SchedulingType

Instance Attribute Summary collapse

Instance Attribute Details

#instance_maintenance_ongoing_count::Integer

Returns Describes number of instances that have ongoing maintenance.

Returns:

  • (::Integer)

    Describes number of instances that have ongoing maintenance.



25515
25516
25517
25518
25519
25520
25521
25522
25523
25524
25525
25526
25527
25528
25529
25530
25531
25532
25533
25534
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25515

class GroupMaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of maintenance for the reservation.
  module SchedulingType
    # A value indicating that the enum field is not set.
    UNDEFINED_SCHEDULING_TYPE = 0

    # Maintenance on all reserved instances in the reservation is synchronized.
    GROUPED = 474_540_862

    # Unknown maintenance type.
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 447_183_678

    # Maintenance is not synchronized for this reservation. Instead, each
    # instance has its own maintenance window.
    INDEPENDENT = 127_011_674
  end
end

#instance_maintenance_pending_count::Integer

Returns Describes number of instances that have pending maintenance.

Returns:

  • (::Integer)

    Describes number of instances that have pending maintenance.



25515
25516
25517
25518
25519
25520
25521
25522
25523
25524
25525
25526
25527
25528
25529
25530
25531
25532
25533
25534
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25515

class GroupMaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of maintenance for the reservation.
  module SchedulingType
    # A value indicating that the enum field is not set.
    UNDEFINED_SCHEDULING_TYPE = 0

    # Maintenance on all reserved instances in the reservation is synchronized.
    GROUPED = 474_540_862

    # Unknown maintenance type.
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 447_183_678

    # Maintenance is not synchronized for this reservation. Instead, each
    # instance has its own maintenance window.
    INDEPENDENT = 127_011_674
  end
end

#maintenance_ongoing_count::Integer

Returns Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have ongoing maintenance.

Returns:

  • (::Integer)

    Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have ongoing maintenance.



25515
25516
25517
25518
25519
25520
25521
25522
25523
25524
25525
25526
25527
25528
25529
25530
25531
25532
25533
25534
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25515

class GroupMaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of maintenance for the reservation.
  module SchedulingType
    # A value indicating that the enum field is not set.
    UNDEFINED_SCHEDULING_TYPE = 0

    # Maintenance on all reserved instances in the reservation is synchronized.
    GROUPED = 474_540_862

    # Unknown maintenance type.
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 447_183_678

    # Maintenance is not synchronized for this reservation. Instead, each
    # instance has its own maintenance window.
    INDEPENDENT = 127_011_674
  end
end

#maintenance_pending_count::Integer

Returns Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have pending maintenance.

Returns:

  • (::Integer)

    Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have pending maintenance.



25515
25516
25517
25518
25519
25520
25521
25522
25523
25524
25525
25526
25527
25528
25529
25530
25531
25532
25533
25534
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25515

class GroupMaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of maintenance for the reservation.
  module SchedulingType
    # A value indicating that the enum field is not set.
    UNDEFINED_SCHEDULING_TYPE = 0

    # Maintenance on all reserved instances in the reservation is synchronized.
    GROUPED = 474_540_862

    # Unknown maintenance type.
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 447_183_678

    # Maintenance is not synchronized for this reservation. Instead, each
    # instance has its own maintenance window.
    INDEPENDENT = 127_011_674
  end
end

#scheduling_type::String

Returns The type of maintenance for the reservation. Check the SchedulingType enum for the list of possible values.

Returns:

  • (::String)

    The type of maintenance for the reservation. Check the SchedulingType enum for the list of possible values.



25515
25516
25517
25518
25519
25520
25521
25522
25523
25524
25525
25526
25527
25528
25529
25530
25531
25532
25533
25534
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25515

class GroupMaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of maintenance for the reservation.
  module SchedulingType
    # A value indicating that the enum field is not set.
    UNDEFINED_SCHEDULING_TYPE = 0

    # Maintenance on all reserved instances in the reservation is synchronized.
    GROUPED = 474_540_862

    # Unknown maintenance type.
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 447_183_678

    # Maintenance is not synchronized for this reservation. Instead, each
    # instance has its own maintenance window.
    INDEPENDENT = 127_011_674
  end
end

#subblock_infra_maintenance_ongoing_count::Integer

Returns Describes number of subblock Infrastructure that has ongoing maintenance. Here, Subblock Infrastructure Maintenance pertains to upstream hardware contained in the Subblock that is necessary for a VM Family(e.g. NVLink Domains). Not all VM Families will support this field.

Returns:

  • (::Integer)

    Describes number of subblock Infrastructure that has ongoing maintenance. Here, Subblock Infrastructure Maintenance pertains to upstream hardware contained in the Subblock that is necessary for a VM Family(e.g. NVLink Domains). Not all VM Families will support this field.



25515
25516
25517
25518
25519
25520
25521
25522
25523
25524
25525
25526
25527
25528
25529
25530
25531
25532
25533
25534
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25515

class GroupMaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of maintenance for the reservation.
  module SchedulingType
    # A value indicating that the enum field is not set.
    UNDEFINED_SCHEDULING_TYPE = 0

    # Maintenance on all reserved instances in the reservation is synchronized.
    GROUPED = 474_540_862

    # Unknown maintenance type.
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 447_183_678

    # Maintenance is not synchronized for this reservation. Instead, each
    # instance has its own maintenance window.
    INDEPENDENT = 127_011_674
  end
end

#subblock_infra_maintenance_pending_count::Integer

Returns Describes number of subblock Infrastructure that has pending maintenance. Here, Subblock Infrastructure Maintenance pertains to upstream hardware contained in the Subblock that is necessary for a VM Family (e.g. NVLink Domains). Not all VM Families will support this field.

Returns:

  • (::Integer)

    Describes number of subblock Infrastructure that has pending maintenance. Here, Subblock Infrastructure Maintenance pertains to upstream hardware contained in the Subblock that is necessary for a VM Family (e.g. NVLink Domains). Not all VM Families will support this field.



25515
25516
25517
25518
25519
25520
25521
25522
25523
25524
25525
25526
25527
25528
25529
25530
25531
25532
25533
25534
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25515

class GroupMaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of maintenance for the reservation.
  module SchedulingType
    # A value indicating that the enum field is not set.
    UNDEFINED_SCHEDULING_TYPE = 0

    # Maintenance on all reserved instances in the reservation is synchronized.
    GROUPED = 474_540_862

    # Unknown maintenance type.
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 447_183_678

    # Maintenance is not synchronized for this reservation. Instead, each
    # instance has its own maintenance window.
    INDEPENDENT = 127_011_674
  end
end

#upcoming_group_maintenance::Google::Cloud::Compute::V1::UpcomingMaintenance

Returns Maintenance information on this group of VMs.

Returns:



25515
25516
25517
25518
25519
25520
25521
25522
25523
25524
25525
25526
25527
25528
25529
25530
25531
25532
25533
25534
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25515

class GroupMaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of maintenance for the reservation.
  module SchedulingType
    # A value indicating that the enum field is not set.
    UNDEFINED_SCHEDULING_TYPE = 0

    # Maintenance on all reserved instances in the reservation is synchronized.
    GROUPED = 474_540_862

    # Unknown maintenance type.
    GROUP_MAINTENANCE_TYPE_UNSPECIFIED = 447_183_678

    # Maintenance is not synchronized for this reservation. Instead, each
    # instance has its own maintenance window.
    INDEPENDENT = 127_011_674
  end
end