Class: Google::Cloud::Compute::V1::GuestOsFeature
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GuestOsFeature
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Guest OS features.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#type ⇒ ::String
The ID of a supported feature.
Instance Attribute Details
#type ⇒ ::String
Returns The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values:
- VIRTIO_SCSI_MULTIQUEUE
- WINDOWS
- MULTI_IP_SUBNET
- UEFI_COMPATIBLE
- GVNIC
- SEV_CAPABLE
- SUSPEND_RESUME_COMPATIBLE
- SEV_LIVE_MIGRATABLE_V2
- SEV_SNP_CAPABLE
- TDX_CAPABLE
- IDPF
- SNP_SVSM_CAPABLE
- CCA_CAPABLE
For more information, see Enabling guest operating system features. Check the Type enum for the list of possible values.
26525 26526 26527 26528 26529 26530 26531 26532 26533 26534 26535 26536 26537 26538 26539 26540 26541 26542 26543 26544 26545 26546 26547 26548 26549 26550 26551 26552 26553 26554 26555 26556 26557 26558 26559 26560 26561 26562 26563 26564 26565 26566 26567 26568 26569 26570 26571 26572 26573 26574 26575 26576 26577 26578 26579 26580 26581 26582 26583 26584 26585 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26525 class GuestOsFeature include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The ID of a supported feature. To add multiple values, use commas to # separate values. Set to one or more of the following values: # # - VIRTIO_SCSI_MULTIQUEUE # - WINDOWS # - MULTI_IP_SUBNET # - UEFI_COMPATIBLE # - GVNIC # - SEV_CAPABLE # - SUSPEND_RESUME_COMPATIBLE # - SEV_LIVE_MIGRATABLE_V2 # - SEV_SNP_CAPABLE # - TDX_CAPABLE # - IDPF # - SNP_SVSM_CAPABLE # - CCA_CAPABLE # # # For more information, see # Enabling guest operating system features. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 BARE_METAL_LINUX_COMPATIBLE = 354_232_740 CCA_CAPABLE = 79_012_270 FEATURE_TYPE_UNSPECIFIED = 531_767_259 GVNIC = 68_209_305 IDPF = 2_242_641 MULTI_IP_SUBNET = 151_776_719 SECURE_BOOT = 376_811_194 SEV_CAPABLE = 87_083_793 SEV_LIVE_MIGRATABLE = 392_039_820 SEV_LIVE_MIGRATABLE_V2 = 168_551_983 SEV_SNP_CAPABLE = 426_919 SNP_SVSM_CAPABLE = 52_921_460 TDX_CAPABLE = 240_446_133 UEFI_COMPATIBLE = 195_865_408 VIRTIO_SCSI_MULTIQUEUE = 201_597_069 WINDOWS = 456_863_331 end end |