Class: Google::Cloud::Compute::V1::GuestOsFeature
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GuestOsFeature
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Guest OS features.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#type ⇒ ::String
The ID of a supported feature.
Instance Attribute Details
#type ⇒ ::String
Returns The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values:
- VIRTIO_SCSI_MULTIQUEUE
- WINDOWS
- MULTI_IP_SUBNET
- UEFI_COMPATIBLE
- GVNIC
- SEV_CAPABLE
- SUSPEND_RESUME_COMPATIBLE
- SEV_LIVE_MIGRATABLE_V2
- SEV_SNP_CAPABLE
- TDX_CAPABLE
- IDPF
- SNP_SVSM_CAPABLE
- CCA_CAPABLE
For more information, see Enabling guest operating system features. Check the Type enum for the list of possible values.
26277 26278 26279 26280 26281 26282 26283 26284 26285 26286 26287 26288 26289 26290 26291 26292 26293 26294 26295 26296 26297 26298 26299 26300 26301 26302 26303 26304 26305 26306 26307 26308 26309 26310 26311 26312 26313 26314 26315 26316 26317 26318 26319 26320 26321 26322 26323 26324 26325 26326 26327 26328 26329 26330 26331 26332 26333 26334 26335 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26277 class GuestOsFeature include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The ID of a supported feature. To add multiple values, use commas to # separate values. Set to one or more of the following values: # # - VIRTIO_SCSI_MULTIQUEUE # - WINDOWS # - MULTI_IP_SUBNET # - UEFI_COMPATIBLE # - GVNIC # - SEV_CAPABLE # - SUSPEND_RESUME_COMPATIBLE # - SEV_LIVE_MIGRATABLE_V2 # - SEV_SNP_CAPABLE # - TDX_CAPABLE # - IDPF # - SNP_SVSM_CAPABLE # - CCA_CAPABLE # # # For more information, see # Enabling guest operating system features. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 BARE_METAL_LINUX_COMPATIBLE = 354_232_740 FEATURE_TYPE_UNSPECIFIED = 531_767_259 GVNIC = 68_209_305 IDPF = 2_242_641 MULTI_IP_SUBNET = 151_776_719 SECURE_BOOT = 376_811_194 SEV_CAPABLE = 87_083_793 SEV_LIVE_MIGRATABLE = 392_039_820 SEV_LIVE_MIGRATABLE_V2 = 168_551_983 SEV_SNP_CAPABLE = 426_919 SNP_SVSM_CAPABLE = 52_921_460 TDX_CAPABLE = 240_446_133 UEFI_COMPATIBLE = 195_865_408 VIRTIO_SCSI_MULTIQUEUE = 201_597_069 WINDOWS = 456_863_331 end end |