Class: Google::Cloud::Compute::V1::GuestOsFeature

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Guest OS features.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#type::String

Returns The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values:

  • VIRTIO_SCSI_MULTIQUEUE
  • WINDOWS
  • MULTI_IP_SUBNET
  • UEFI_COMPATIBLE
  • GVNIC
  • SEV_CAPABLE
  • SUSPEND_RESUME_COMPATIBLE
  • SEV_LIVE_MIGRATABLE_V2
  • SEV_SNP_CAPABLE
  • TDX_CAPABLE
  • IDPF
  • SNP_SVSM_CAPABLE
  • CCA_CAPABLE

For more information, see Enabling guest operating system features. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values:

    • VIRTIO_SCSI_MULTIQUEUE
    • WINDOWS
    • MULTI_IP_SUBNET
    • UEFI_COMPATIBLE
    • GVNIC
    • SEV_CAPABLE
    • SUSPEND_RESUME_COMPATIBLE
    • SEV_LIVE_MIGRATABLE_V2
    • SEV_SNP_CAPABLE
    • TDX_CAPABLE
    • IDPF
    • SNP_SVSM_CAPABLE
    • CCA_CAPABLE

    For more information, see Enabling guest operating system features. Check the Type enum for the list of possible values.



25609
25610
25611
25612
25613
25614
25615
25616
25617
25618
25619
25620
25621
25622
25623
25624
25625
25626
25627
25628
25629
25630
25631
25632
25633
25634
25635
25636
25637
25638
25639
25640
25641
25642
25643
25644
25645
25646
25647
25648
25649
25650
25651
25652
25653
25654
25655
25656
25657
25658
25659
25660
25661
25662
25663
25664
25665
25666
25667
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25609

class GuestOsFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The ID of a supported feature. To add multiple values, use commas to
  # separate values. Set to one or more of the following values:
  #
  #    - VIRTIO_SCSI_MULTIQUEUE
  #    - WINDOWS
  #    - MULTI_IP_SUBNET
  #    - UEFI_COMPATIBLE
  #    - GVNIC
  #    - SEV_CAPABLE
  #    - SUSPEND_RESUME_COMPATIBLE
  #    - SEV_LIVE_MIGRATABLE_V2
  #    - SEV_SNP_CAPABLE
  #    - TDX_CAPABLE
  #    - IDPF
  #    - SNP_SVSM_CAPABLE
  #    - CCA_CAPABLE
  #
  #
  # For more information, see
  # Enabling guest operating system features.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    BARE_METAL_LINUX_COMPATIBLE = 354_232_740

    FEATURE_TYPE_UNSPECIFIED = 531_767_259

    GVNIC = 68_209_305

    IDPF = 2_242_641

    MULTI_IP_SUBNET = 151_776_719

    SECURE_BOOT = 376_811_194

    SEV_CAPABLE = 87_083_793

    SEV_LIVE_MIGRATABLE = 392_039_820

    SEV_LIVE_MIGRATABLE_V2 = 168_551_983

    SEV_SNP_CAPABLE = 426_919

    SNP_SVSM_CAPABLE = 52_921_460

    TDX_CAPABLE = 240_446_133

    UEFI_COMPATIBLE = 195_865_408

    VIRTIO_SCSI_MULTIQUEUE = 201_597_069

    WINDOWS = 456_863_331
  end
end