Class: Google::Cloud::Compute::V1::GuestOsFeature
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::GuestOsFeature
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Guest OS features.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#type ⇒ ::String
The ID of a supported feature.
Instance Attribute Details
#type ⇒ ::String
Returns The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values:
- VIRTIO_SCSI_MULTIQUEUE
- WINDOWS
- MULTI_IP_SUBNET
- UEFI_COMPATIBLE
- GVNIC
- SEV_CAPABLE
- SUSPEND_RESUME_COMPATIBLE
- SEV_LIVE_MIGRATABLE_V2
- SEV_SNP_CAPABLE
- TDX_CAPABLE
- IDPF
- SNP_SVSM_CAPABLE
- CCA_CAPABLE
- SUSPEND_SAFE_FPR
For more information, see Enabling guest operating system features. Check the Type enum for the list of possible values.
27451 27452 27453 27454 27455 27456 27457 27458 27459 27460 27461 27462 27463 27464 27465 27466 27467 27468 27469 27470 27471 27472 27473 27474 27475 27476 27477 27478 27479 27480 27481 27482 27483 27484 27485 27486 27487 27488 27489 27490 27491 27492 27493 27494 27495 27496 27497 27498 27499 27500 27501 27502 27503 27504 27505 27506 27507 27508 27509 27510 27511 27512 27513 27514 27515 27516 27517 27518 27519 27520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27451 class GuestOsFeature include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The ID of a supported feature. To add multiple values, use commas to # separate values. Set to one or more of the following values: # # - VIRTIO_SCSI_MULTIQUEUE # - WINDOWS # - MULTI_IP_SUBNET # - UEFI_COMPATIBLE # - GVNIC # - SEV_CAPABLE # - SUSPEND_RESUME_COMPATIBLE # - SEV_LIVE_MIGRATABLE_V2 # - SEV_SNP_CAPABLE # - TDX_CAPABLE # - IDPF # - SNP_SVSM_CAPABLE # - CCA_CAPABLE # - SUSPEND_SAFE_FPR # # # For more information, see # Enabling guest operating system features. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 BARE_METAL_LINUX_COMPATIBLE = 354_232_740 # Indicates the guest OS is capable of Bare Metal Secure AI (BMSAI) # confidential computing. BMSAI_CAPABLE = 449_302_109 CCA_CAPABLE = 79_012_270 FEATURE_TYPE_UNSPECIFIED = 531_767_259 GVNIC = 68_209_305 IDPF = 2_242_641 MULTI_IP_SUBNET = 151_776_719 SECURE_BOOT = 376_811_194 SEV_CAPABLE = 87_083_793 SEV_LIVE_MIGRATABLE = 392_039_820 SEV_LIVE_MIGRATABLE_V2 = 168_551_983 SEV_SNP_CAPABLE = 426_919 SNP_SVSM_CAPABLE = 52_921_460 # Indicates the guest OS is safe for free page reporting (FPR) during # suspend. SUSPEND_SAFE_FPR = 223_956_441 TDX_CAPABLE = 240_446_133 UEFI_COMPATIBLE = 195_865_408 VIRTIO_SCSI_MULTIQUEUE = 201_597_069 WINDOWS = 456_863_331 end end |