Class: Google::Cloud::Compute::V1::HTTP2HealthCheck

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: PortSpecification, ProxyHeader

Instance Attribute Summary collapse

Instance Attribute Details

#host::String

Returns The value of the host header in the HTTP/2 health check request. If left empty (default value), the host header is set to the destination IP address to which health check packets are sent. The destination IP address depends on the type of load balancer. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet-dest.

Returns:



26392
26393
26394
26395
26396
26397
26398
26399
26400
26401
26402
26403
26404
26405
26406
26407
26408
26409
26410
26411
26412
26413
26414
26415
26416
26417
26418
26419
26420
26421
26422
26423
26424
26425
26426
26427
26428
26429
26430
26431
26432
26433
26434
26435
26436
26437
26438
26439
26440
26441
26442
26443
26444
26445
26446
26447
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26392

class HTTP2HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#port::Integer

Returns The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535.

Returns:

  • (::Integer)

    The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535.



26392
26393
26394
26395
26396
26397
26398
26399
26400
26401
26402
26403
26404
26405
26406
26407
26408
26409
26410
26411
26412
26413
26414
26415
26416
26417
26418
26419
26420
26421
26422
26423
26424
26425
26426
26427
26428
26429
26430
26431
26432
26433
26434
26435
26436
26437
26438
26439
26440
26441
26442
26443
26444
26445
26446
26447
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26392

class HTTP2HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#port_name::String

Returns Not supported.

Returns:

  • (::String)

    Not supported.



26392
26393
26394
26395
26396
26397
26398
26399
26400
26401
26402
26403
26404
26405
26406
26407
26408
26409
26410
26411
26412
26413
26414
26415
26416
26417
26418
26419
26420
26421
26422
26423
26424
26425
26426
26427
26428
26429
26430
26431
26432
26433
26434
26435
26436
26437
26438
26439
26440
26441
26442
26443
26444
26445
26446
26447
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26392

class HTTP2HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#port_specification::String

Returns Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends.

For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Check the PortSpecification enum for the list of possible values.

Returns:

  • (::String)

    Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends.

    For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Check the PortSpecification enum for the list of possible values.



26392
26393
26394
26395
26396
26397
26398
26399
26400
26401
26402
26403
26404
26405
26406
26407
26408
26409
26410
26411
26412
26413
26414
26415
26416
26417
26418
26419
26420
26421
26422
26423
26424
26425
26426
26427
26428
26429
26430
26431
26432
26433
26434
26435
26436
26437
26438
26439
26440
26441
26442
26443
26444
26445
26446
26447
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26392

class HTTP2HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#proxy_header::String

Returns Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Check the ProxyHeader enum for the list of possible values.

Returns:

  • (::String)

    Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Check the ProxyHeader enum for the list of possible values.



26392
26393
26394
26395
26396
26397
26398
26399
26400
26401
26402
26403
26404
26405
26406
26407
26408
26409
26410
26411
26412
26413
26414
26415
26416
26417
26418
26419
26420
26421
26422
26423
26424
26425
26426
26427
26428
26429
26430
26431
26432
26433
26434
26435
26436
26437
26438
26439
26440
26441
26442
26443
26444
26445
26446
26447
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26392

class HTTP2HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#request_path::String

Returns The request path of the HTTP/2 health check request. The default value is/. Must comply withRFC3986.

Returns:

  • (::String)

    The request path of the HTTP/2 health check request. The default value is/. Must comply withRFC3986.



26392
26393
26394
26395
26396
26397
26398
26399
26400
26401
26402
26403
26404
26405
26406
26407
26408
26409
26410
26411
26412
26413
26414
26415
26416
26417
26418
26419
26420
26421
26422
26423
26424
26425
26426
26427
26428
26429
26430
26431
26432
26433
26434
26435
26436
26437
26438
26439
26440
26441
26442
26443
26444
26445
26446
26447
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26392

class HTTP2HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end

#response::String

Returns Creates a content-based HTTP/2 health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-http.

Returns:



26392
26393
26394
26395
26396
26397
26398
26399
26400
26401
26402
26403
26404
26405
26406
26407
26408
26409
26410
26411
26412
26413
26414
26415
26416
26417
26418
26419
26420
26421
26422
26423
26424
26425
26426
26427
26428
26429
26430
26431
26432
26433
26434
26435
26436
26437
26438
26439
26440
26441
26442
26443
26444
26445
26446
26447
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26392

class HTTP2HealthCheck
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how a port is selected for health checking. Can be one of the
  # following values:
  # USE_FIXED_PORT: Specifies a port number explicitly using theport field  in the health check. Supported by backend services
  # for passthrough load balancers and backend services for proxy load
  # balancers. Not supported by target pools. The health check supports all
  # backends supported by the backend service provided the backend can be
  # health checked. For example, GCE_VM_IP network endpoint
  # groups, GCE_VM_IP_PORT network endpoint groups, and instance
  # group backends.
  #  USE_NAMED_PORT: Not supported.
  # USE_SERVING_PORT: Provides an indirect method of specifying
  # the health check port by referring to the backend service. Only supported
  # by backend services for proxy load balancers. Not supported by target
  # pools.  Not supported by backend services for passthrough load balancers.
  # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group
  # backends.
  #
  # For GCE_VM_IP_PORT network endpoint group backends, the health
  # check uses the port number specified for each endpoint in the network
  # endpoint group.  For instance group backends, the health check uses the
  # port number determined by looking up the backend service's named port in
  # the instance group's list of named ports.
  module PortSpecification
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_SPECIFICATION = 0

    # The port number in the health check's port is used for health
    # checking. Applies to network endpoint group and instance group backends.
    USE_FIXED_PORT = 190_235_748

    # Not supported.
    USE_NAMED_PORT = 349_300_671

    # For network endpoint group backends, the health check uses the port number
    # specified on each endpoint in the network endpoint group. For instance
    # group backends, the health check uses the port number specified for the
    # backend service's named port defined in the instance group's named ports.
    USE_SERVING_PORT = 362_637_516
  end

  # Specifies the type of proxy header to append before sending data to the
  # backend, either NONE or PROXY_V1. The default
  # is NONE.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end