Class: Google::Cloud::Compute::V1::HTTP2HealthCheck
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HTTP2HealthCheck
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: PortSpecification, ProxyHeader
Instance Attribute Summary collapse
-
#host ⇒ ::String
The value of the host header in the HTTP/2 health check request.
-
#port ⇒ ::Integer
The TCP port number to which the health check prober sends packets.
-
#port_name ⇒ ::String
Not supported.
-
#port_specification ⇒ ::String
Specifies how a port is selected for health checking.
-
#proxy_header ⇒ ::String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#request_path ⇒ ::String
The request path of the HTTP/2 health check request.
-
#response ⇒ ::String
Creates a content-based HTTP/2 health check.
Instance Attribute Details
#host ⇒ ::String
Returns The value of the host header in the HTTP/2 health check request. If left empty (default value), the host header is set to the destination IP address to which health check packets are sent. The destination IP address depends on the type of load balancer. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet-dest.
25724 25725 25726 25727 25728 25729 25730 25731 25732 25733 25734 25735 25736 25737 25738 25739 25740 25741 25742 25743 25744 25745 25746 25747 25748 25749 25750 25751 25752 25753 25754 25755 25756 25757 25758 25759 25760 25761 25762 25763 25764 25765 25766 25767 25768 25769 25770 25771 25772 25773 25774 25775 25776 25777 25778 25779 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25724 class HTTP2HealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#port ⇒ ::Integer
Returns The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535.
25724 25725 25726 25727 25728 25729 25730 25731 25732 25733 25734 25735 25736 25737 25738 25739 25740 25741 25742 25743 25744 25745 25746 25747 25748 25749 25750 25751 25752 25753 25754 25755 25756 25757 25758 25759 25760 25761 25762 25763 25764 25765 25766 25767 25768 25769 25770 25771 25772 25773 25774 25775 25776 25777 25778 25779 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25724 class HTTP2HealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#port_name ⇒ ::String
Returns Not supported.
25724 25725 25726 25727 25728 25729 25730 25731 25732 25733 25734 25735 25736 25737 25738 25739 25740 25741 25742 25743 25744 25745 25746 25747 25748 25749 25750 25751 25752 25753 25754 25755 25756 25757 25758 25759 25760 25761 25762 25763 25764 25765 25766 25767 25768 25769 25770 25771 25772 25773 25774 25775 25776 25777 25778 25779 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25724 class HTTP2HealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#port_specification ⇒ ::String
Returns Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends.
For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Check the PortSpecification enum for the list of possible values.
25724 25725 25726 25727 25728 25729 25730 25731 25732 25733 25734 25735 25736 25737 25738 25739 25740 25741 25742 25743 25744 25745 25746 25747 25748 25749 25750 25751 25752 25753 25754 25755 25756 25757 25758 25759 25760 25761 25762 25763 25764 25765 25766 25767 25768 25769 25770 25771 25772 25773 25774 25775 25776 25777 25778 25779 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25724 class HTTP2HealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#proxy_header ⇒ ::String
Returns Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Check the ProxyHeader enum for the list of possible values.
25724 25725 25726 25727 25728 25729 25730 25731 25732 25733 25734 25735 25736 25737 25738 25739 25740 25741 25742 25743 25744 25745 25746 25747 25748 25749 25750 25751 25752 25753 25754 25755 25756 25757 25758 25759 25760 25761 25762 25763 25764 25765 25766 25767 25768 25769 25770 25771 25772 25773 25774 25775 25776 25777 25778 25779 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25724 class HTTP2HealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#request_path ⇒ ::String
Returns The request path of the HTTP/2 health check request. The default value is/. Must comply withRFC3986.
25724 25725 25726 25727 25728 25729 25730 25731 25732 25733 25734 25735 25736 25737 25738 25739 25740 25741 25742 25743 25744 25745 25746 25747 25748 25749 25750 25751 25752 25753 25754 25755 25756 25757 25758 25759 25760 25761 25762 25763 25764 25765 25766 25767 25768 25769 25770 25771 25772 25773 25774 25775 25776 25777 25778 25779 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25724 class HTTP2HealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |
#response ⇒ ::String
Returns Creates a content-based HTTP/2 health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-protocol-http.
25724 25725 25726 25727 25728 25729 25730 25731 25732 25733 25734 25735 25736 25737 25738 25739 25740 25741 25742 25743 25744 25745 25746 25747 25748 25749 25750 25751 25752 25753 25754 25755 25756 25757 25758 25759 25760 25761 25762 25763 25764 25765 25766 25767 25768 25769 25770 25771 25772 25773 25774 25775 25776 25777 25778 25779 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25724 class HTTP2HealthCheck include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies how a port is selected for health checking. Can be one of the # following values: # USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services # for passthrough load balancers and backend services for proxy load # balancers. Not supported by target pools. The health check supports all # backends supported by the backend service provided the backend can be # health checked. For example, GCE_VM_IP network endpoint # groups, GCE_VM_IP_PORT network endpoint groups, and instance # group backends. # USE_NAMED_PORT: Not supported. # USE_SERVING_PORT: Provides an indirect method of specifying # the health check port by referring to the backend service. Only supported # by backend services for proxy load balancers. Not supported by target # pools. Not supported by backend services for passthrough load balancers. # Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group # backends. # # For GCE_VM_IP_PORT network endpoint group backends, the health # check uses the port number specified for each endpoint in the network # endpoint group. For instance group backends, the health check uses the # port number determined by looking up the backend service's named port in # the instance group's list of named ports. module PortSpecification # A value indicating that the enum field is not set. UNDEFINED_PORT_SPECIFICATION = 0 # The port number in the health check's port is used for health # checking. Applies to network endpoint group and instance group backends. USE_FIXED_PORT = 190_235_748 # Not supported. USE_NAMED_PORT = 349_300_671 # For network endpoint group backends, the health check uses the port number # specified on each endpoint in the network endpoint group. For instance # group backends, the health check uses the port number specified for the # backend service's named port defined in the instance group's named ports. USE_SERVING_PORT = 362_637_516 end # Specifies the type of proxy header to append before sending data to the # backend, either NONE or PROXY_V1. The default # is NONE. module ProxyHeader # A value indicating that the enum field is not set. UNDEFINED_PROXY_HEADER = 0 NONE = 2_402_104 PROXY_V1 = 334_352_940 end end |