Class: Google::Cloud::Compute::V1::HealthAggregationPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HealthAggregationPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a health aggregation policy.
A health aggregation policy resource defines a policy to aggregate health.
For more information, see Health checks overview.
Defined Under Namespace
Modules: PolicyType
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#healthy_percent_threshold ⇒ ::Integer
Can only be set if the policyType field isBACKEND_SERVICE_POLICY.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#min_healthy_threshold ⇒ ::Integer
Can only be set if the policyType field isBACKEND_SERVICE_POLICY.
-
#name ⇒ ::String
Name of the resource.
-
#policy_type ⇒ ::String
Specifies the type of the healthAggregationPolicy.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#fingerprint ⇒ ::String
Returns Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a HealthAggregationPolicy. An up-to-date fingerprint must be provided in order to patch the HealthAggregationPolicy; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the HealthAggregationPolicy.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#healthy_percent_threshold ⇒ ::Integer
Returns Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies the threshold (as a percentage) of healthy endpoints required in order to consider the aggregated health result HEALTHY. Defaults to 60. Must be in range [0, 100]. Not applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated. This field is optional, and will be set to the default if unspecified. Note that both this threshold and minHealthyThreshold must be satisfied in order for HEALTHY to be the aggregated result. "Endpoints" refers to network endpoints within a Network Endpoint Group or instances within an Instance Group.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#healthAggregationPolicy for health aggregation policies.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#min_healthy_threshold ⇒ ::Integer
Returns Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies the minimum number of healthy endpoints required in order to consider the aggregated health result HEALTHY. Defaults to 1. Must be positive. Not applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated. This field is optional, and will be set to the default if unspecified. Note that both this threshold and healthyPercentThreshold must be satisfied in order for HEALTHY to be the aggregated result. "Endpoints" refers to network endpoints within a Network Endpoint Group or instances within an Instance Group.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#policy_type ⇒ ::String
Returns Specifies the type of the healthAggregationPolicy. The only allowed value for global resources is DNS_PUBLIC_IP_POLICY. The only allowed value for regional resources is BACKEND_SERVICE_POLICY. Must be specified when the healthAggregationPolicy is created, and cannot be mutated. Check the PolicyType enum for the list of possible values.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the health aggregation policy resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL with id for the resource.
26097 26098 26099 26100 26101 26102 26103 26104 26105 26106 26107 26108 26109 26110 26111 26112 26113 26114 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26097 class HealthAggregationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of the healthAggregationPolicy. The only allowed value # for global resources is DNS_PUBLIC_IP_POLICY. The only allowed # value for regional resources is BACKEND_SERVICE_POLICY. Must # be specified when the healthAggregationPolicy is created, and cannot be # mutated. module PolicyType # A value indicating that the enum field is not set. UNDEFINED_POLICY_TYPE = 0 BACKEND_SERVICE_POLICY = 415_582_023 DNS_PUBLIC_IP_POLICY = 366_354_794 end end |