Class: Google::Cloud::Compute::V1::HealthCheckService

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Health-Check as a Service resource.

Defined Under Namespace

Modules: HealthStatusAggregationPolicy

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#description::String



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#fingerprint::String



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#health_checks::Array<::String>



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#health_status_aggregation_policy::String



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#id::Integer



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#kind::String



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#name::String



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#network_endpoint_groups::Array<::String>



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#notification_endpoints::Array<::String>



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end

#region::String



11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end


11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
11598
11599
11600
11601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586

class HealthCheckService
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService.
  module HealthStatusAggregationPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0

    # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY.
    AND = 64_951

    # An EndpointHealth message is returned for each backend in the health check service.
    NO_AGGREGATION = 426_445_124
  end
end