Class: Google::Cloud::Compute::V1::HealthCheckService
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HealthCheckService
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Health-Check as a Service resource.
Defined Under Namespace
Modules: HealthStatusAggregationPolicy
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ ::String
An optional description of this resource.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#health_checks ⇒ ::Array<::String>
A list of URLs to the HealthCheck resources.
-
#health_status_aggregation_policy ⇒ ::String
Optional.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
[Output only] Type of the resource.
-
#name ⇒ ::String
Name of the resource.
-
#network_endpoint_groups ⇒ ::Array<::String>
A list of URLs to the NetworkEndpointGroup resources.
-
#notification_endpoints ⇒ ::Array<::String>
A list of URLs to the NotificationEndpoint resources.
-
#region ⇒ ::String
[Output Only] URL of the region where the health check service resides.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
Instance Attribute Details
#creation_timestamp ⇒ ::String
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#description ⇒ ::String
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#fingerprint ⇒ ::String
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#health_checks ⇒ ::Array<::String>
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#health_status_aggregation_policy ⇒ ::String
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#id ⇒ ::Integer
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#kind ⇒ ::String
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#name ⇒ ::String
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#network_endpoint_groups ⇒ ::Array<::String>
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#notification_endpoints ⇒ ::Array<::String>
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#region ⇒ ::String
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |
#self_link ⇒ ::String
11586 11587 11588 11589 11590 11591 11592 11593 11594 11595 11596 11597 11598 11599 11600 11601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11586 class HealthCheckService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. - NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service. - AND. If any health check of an endpoint reports UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is only allowed with regional HealthCheckService. module HealthStatusAggregationPolicy # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY = 0 # If any backend's health check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire health check service. If all backend's are healthy, the HealthState of the health check service is HEALTHY. AND = 64_951 # An EndpointHealth message is returned for each backend in the health check service. NO_AGGREGATION = 426_445_124 end end |