Class: Google::Cloud::Compute::V1::HealthSourceHealth

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Response message for RegionHealthSources.GetHealth

Defined Under Namespace

Modules: HealthState

Instance Attribute Summary collapse

Instance Attribute Details

#health_state::String

Returns Health state of the HealthSource. Check the HealthState enum for the list of possible values.

Returns:

  • (::String)

    Health state of the HealthSource. Check the HealthState enum for the list of possible values.



27680
27681
27682
27683
27684
27685
27686
27687
27688
27689
27690
27691
27692
27693
27694
27695
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27680

class HealthSourceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the HealthSource.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end

#kind::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#healthSourceHealth for the health of health sources.

Returns:

  • (::String)

    Output only. [Output Only] Type of resource. Alwayscompute#healthSourceHealth for the health of health sources.



27680
27681
27682
27683
27684
27685
27686
27687
27688
27689
27690
27691
27692
27693
27694
27695
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27680

class HealthSourceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the HealthSource.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end

#sources::Array<::Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfo>

Returns Health state details of the sources.

Returns:



27680
27681
27682
27683
27684
27685
27686
27687
27688
27689
27690
27691
27692
27693
27694
27695
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27680

class HealthSourceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the HealthSource.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end