Class: Google::Cloud::Compute::V1::HealthSourceHealth
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HealthSourceHealth
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Response message for RegionHealthSources.GetHealth
Defined Under Namespace
Modules: HealthState
Instance Attribute Summary collapse
-
#health_state ⇒ ::String
Health state of the HealthSource.
-
#kind ⇒ ::String
Output only.
-
#sources ⇒ ::Array<::Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfo>
Health state details of the sources.
Instance Attribute Details
#health_state ⇒ ::String
Returns Health state of the HealthSource. Check the HealthState enum for the list of possible values.
27430 27431 27432 27433 27434 27435 27436 27437 27438 27439 27440 27441 27442 27443 27444 27445 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27430 class HealthSourceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the HealthSource. module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Alwayscompute#healthSourceHealth for the health of health sources.
27430 27431 27432 27433 27434 27435 27436 27437 27438 27439 27440 27441 27442 27443 27444 27445 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27430 class HealthSourceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the HealthSource. module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end end |
#sources ⇒ ::Array<::Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfo>
Returns Health state details of the sources.
27430 27431 27432 27433 27434 27435 27436 27437 27438 27439 27440 27441 27442 27443 27444 27445 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27430 class HealthSourceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the HealthSource. module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end end |