Class: Google::Cloud::Compute::V1::HealthSourceHealth

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Response message for RegionHealthSources.GetHealth

Defined Under Namespace

Modules: HealthState

Instance Attribute Summary collapse

Instance Attribute Details

#health_state::String

Returns Health state of the HealthSource. Check the HealthState enum for the list of possible values.

Returns:

  • (::String)

    Health state of the HealthSource. Check the HealthState enum for the list of possible values.



26762
26763
26764
26765
26766
26767
26768
26769
26770
26771
26772
26773
26774
26775
26776
26777
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26762

class HealthSourceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the HealthSource.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end

#kind::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#healthSourceHealth for the health of health sources.

Returns:

  • (::String)

    Output only. [Output Only] Type of resource. Alwayscompute#healthSourceHealth for the health of health sources.



26762
26763
26764
26765
26766
26767
26768
26769
26770
26771
26772
26773
26774
26775
26776
26777
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26762

class HealthSourceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the HealthSource.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end

#sources::Array<::Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfo>

Returns Health state details of the sources.

Returns:



26762
26763
26764
26765
26766
26767
26768
26769
26770
26771
26772
26773
26774
26775
26776
26777
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26762

class HealthSourceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the HealthSource.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end
end