Class: Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#backends::Array<::Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfoBackendInfo>

Returns Represents an instance group or network endpoint group behind the source backend service. Only used if the sourceType of the regionHealthSource is BACKEND_SERVICE.

Returns:



27487
27488
27489
27490
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27487

class HealthSourcesGetHealthResponseSourceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#forwarding_rule::String

Returns Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.

Returns:

  • (::String)

    Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.



27487
27488
27489
27490
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27487

class HealthSourcesGetHealthResponseSourceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source::String

Returns Fully qualified URL of the associated source resource. This is always a backend service URL.

Returns:

  • (::String)

    Fully qualified URL of the associated source resource. This is always a backend service URL.



27487
27488
27489
27490
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27487

class HealthSourcesGetHealthResponseSourceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end