Class: Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#backends ⇒ ::Array<::Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfoBackendInfo>
Represents an instance group or network endpoint group behind the source backend service.
-
#forwarding_rule ⇒ ::String
Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.
-
#source ⇒ ::String
Fully qualified URL of the associated source resource.
Instance Attribute Details
#backends ⇒ ::Array<::Google::Cloud::Compute::V1::HealthSourcesGetHealthResponseSourceInfoBackendInfo>
Returns Represents an instance group or network endpoint group behind the source backend service. Only used if the sourceType of the regionHealthSource is BACKEND_SERVICE.
26819 26820 26821 26822 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26819 class HealthSourcesGetHealthResponseSourceInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#forwarding_rule ⇒ ::String
Returns Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.
26819 26820 26821 26822 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26819 class HealthSourcesGetHealthResponseSourceInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source ⇒ ::String
Returns Fully qualified URL of the associated source resource. This is always a backend service URL.
26819 26820 26821 26822 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 26819 class HealthSourcesGetHealthResponseSourceInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |