Class: Google::Cloud::Compute::V1::HealthStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: HealthState, Ipv6HealthState, WeightError Classes: AnnotationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Metadata defined as annotations for network endpoint.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Metadata defined as annotations for network endpoint.



27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#forwarding_rule::String

Returns URL of the forwarding rule associated with the health status of the instance.

Returns:

  • (::String)

    URL of the forwarding rule associated with the health status of the instance.



27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#forwarding_rule_ip::String

Returns A forwarding rule IP address assigned to this instance.

Returns:

  • (::String)

    A forwarding rule IP address assigned to this instance.



27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#health_state::String

Returns Health state of the IPv4 address of the instance. Check the HealthState enum for the list of possible values.

Returns:

  • (::String)

    Health state of the IPv4 address of the instance. Check the HealthState enum for the list of possible values.



27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#instance::String

Returns URL of the instance resource.

Returns:

  • (::String)

    URL of the instance resource.



27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#ip_address::String

Returns For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip.

Returns:

  • (::String)

    For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip.



27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#ipv6_address::String

Returns:

  • (::String)


27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#ipv6_health_state::String

Returns Health state of the IPv6 address of the instance. Check the Ipv6HealthState enum for the list of possible values.

Returns:

  • (::String)

    Health state of the IPv6 address of the instance. Check the Ipv6HealthState enum for the list of possible values.



27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#port::Integer

Returns The named port of the instance group, not necessarily the port that is health-checked.

Returns:

  • (::Integer)

    The named port of the instance group, not necessarily the port that is health-checked.



27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#weight::String

Returns:

  • (::String)


27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end

#weight_error::String

Returns Check the WeightError enum for the list of possible values.

Returns:

  • (::String)

    Check the WeightError enum for the list of possible values.



27558
27559
27560
27561
27562
27563
27564
27565
27566
27567
27568
27569
27570
27571
27572
27573
27574
27575
27576
27577
27578
27579
27580
27581
27582
27583
27584
27585
27586
27587
27588
27589
27590
27591
27592
27593
27594
27595
27596
27597
27598
27599
27600
27601
27602
27603
27604
27605
27606
27607
27608
27609
27610
27611
27612
27613
27614
27615
27616
27617
27618
27619
27620
27621
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27558

class HealthStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Health state of the IPv4 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084
  end

  # Health state of the IPv6 address of the instance.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # HEALTHY
  # UNHEALTHY
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end

  module WeightError
    # A value indicating that the enum field is not set.
    UNDEFINED_WEIGHT_ERROR = 0

    # The response to a Health Check probe had the HTTP response header field
    # X-Load-Balancing-Endpoint-Weight, but its content was invalid (i.e., not
    # a non-negative single-precision floating-point number in decimal string
    # representation).
    INVALID_WEIGHT = 383_698_400

    # The response to a Health Check probe did not have the HTTP response
    # header field X-Load-Balancing-Endpoint-Weight.
    MISSING_WEIGHT = 384_027_537

    # This is the value when the accompanied health status is either TIMEOUT
    # (i.e.,the Health Check probe was not able to get a response in time) or
    # UNKNOWN. For the latter, it should be typically because there has not
    # been sufficient time to parse and report the weight for a new backend
    # (which is with 0.0.0.0 ip address). However, it can be also due to an
    # outage case for which the health status is explicitly reset to UNKNOWN.
    UNAVAILABLE_WEIGHT = 439_464_295

    # This is the default value when WeightReportMode is DISABLE,
    # and is also the initial value when WeightReportMode has just updated to
    # ENABLE or DRY_RUN and there has not been
    # sufficient time to parse and report the backend weight.
    WEIGHT_NONE = 502_428_831
  end
end