Class: Google::Cloud::Compute::V1::HealthStatusForNetworkEndpoint
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HealthStatusForNetworkEndpoint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: HealthState, Ipv6HealthState
Instance Attribute Summary collapse
-
#backend_service ⇒ ::Google::Cloud::Compute::V1::BackendServiceReference
URL of the backend service associated with the health state of the network endpoint.
-
#forwarding_rule ⇒ ::Google::Cloud::Compute::V1::ForwardingRuleReference
URL of the forwarding rule associated with the health state of the network endpoint.
-
#health_check ⇒ ::Google::Cloud::Compute::V1::HealthCheckReference
URL of the health check associated with the health state of the network endpoint.
-
#health_check_service ⇒ ::Google::Cloud::Compute::V1::HealthCheckServiceReference
URL of the health check service associated with the health state of the network endpoint.
-
#health_state ⇒ ::String
Health state of the network endpoint determined based on the health checks configured.
-
#ipv6_health_state ⇒ ::String
Health state of the ipv6 network endpoint determined based on the health checks configured.
Instance Attribute Details
#backend_service ⇒ ::Google::Cloud::Compute::V1::BackendServiceReference
Returns URL of the backend service associated with the health state of the network endpoint.
27899 27900 27901 27902 27903 27904 27905 27906 27907 27908 27909 27910 27911 27912 27913 27914 27915 27916 27917 27918 27919 27920 27921 27922 27923 27924 27925 27926 27927 27928 27929 27930 27931 27932 27933 27934 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27899 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks # configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health # checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#forwarding_rule ⇒ ::Google::Cloud::Compute::V1::ForwardingRuleReference
Returns URL of the forwarding rule associated with the health state of the network endpoint.
27899 27900 27901 27902 27903 27904 27905 27906 27907 27908 27909 27910 27911 27912 27913 27914 27915 27916 27917 27918 27919 27920 27921 27922 27923 27924 27925 27926 27927 27928 27929 27930 27931 27932 27933 27934 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27899 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks # configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health # checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#health_check ⇒ ::Google::Cloud::Compute::V1::HealthCheckReference
Returns URL of the health check associated with the health state of the network endpoint.
27899 27900 27901 27902 27903 27904 27905 27906 27907 27908 27909 27910 27911 27912 27913 27914 27915 27916 27917 27918 27919 27920 27921 27922 27923 27924 27925 27926 27927 27928 27929 27930 27931 27932 27933 27934 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27899 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks # configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health # checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#health_check_service ⇒ ::Google::Cloud::Compute::V1::HealthCheckServiceReference
Returns URL of the health check service associated with the health state of the network endpoint.
27899 27900 27901 27902 27903 27904 27905 27906 27907 27908 27909 27910 27911 27912 27913 27914 27915 27916 27917 27918 27919 27920 27921 27922 27923 27924 27925 27926 27927 27928 27929 27930 27931 27932 27933 27934 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27899 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks # configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health # checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#health_state ⇒ ::String
Returns Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.
27899 27900 27901 27902 27903 27904 27905 27906 27907 27908 27909 27910 27911 27912 27913 27914 27915 27916 27917 27918 27919 27920 27921 27922 27923 27924 27925 27926 27927 27928 27929 27930 27931 27932 27933 27934 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27899 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks # configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health # checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#ipv6_health_state ⇒ ::String
Returns Health state of the ipv6 network endpoint determined based on the health checks configured. Check the Ipv6HealthState enum for the list of possible values.
27899 27900 27901 27902 27903 27904 27905 27906 27907 27908 27909 27910 27911 27912 27913 27914 27915 27916 27917 27918 27919 27920 27921 27922 27923 27924 27925 27926 27927 27928 27929 27930 27931 27932 27933 27934 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27899 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks # configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health # checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |