Class: Google::Cloud::Compute::V1::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: HealthState, Ipv6HealthState

Instance Attribute Summary collapse

Instance Attribute Details

#backend_service::Google::Cloud::Compute::V1::BackendServiceReference

Returns URL of the backend service associated with the health state of the network endpoint.

Returns:



27649
27650
27651
27652
27653
27654
27655
27656
27657
27658
27659
27660
27661
27662
27663
27664
27665
27666
27667
27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
27679
27680
27681
27682
27683
27684
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27649

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480_455_402

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#forwarding_rule::Google::Cloud::Compute::V1::ForwardingRuleReference

Returns URL of the forwarding rule associated with the health state of the network endpoint.

Returns:



27649
27650
27651
27652
27653
27654
27655
27656
27657
27658
27659
27660
27661
27662
27663
27664
27665
27666
27667
27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
27679
27680
27681
27682
27683
27684
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27649

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480_455_402

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#health_check::Google::Cloud::Compute::V1::HealthCheckReference

Returns URL of the health check associated with the health state of the network endpoint.

Returns:



27649
27650
27651
27652
27653
27654
27655
27656
27657
27658
27659
27660
27661
27662
27663
27664
27665
27666
27667
27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
27679
27680
27681
27682
27683
27684
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27649

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480_455_402

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#health_check_service::Google::Cloud::Compute::V1::HealthCheckServiceReference

Returns URL of the health check service associated with the health state of the network endpoint.

Returns:



27649
27650
27651
27652
27653
27654
27655
27656
27657
27658
27659
27660
27661
27662
27663
27664
27665
27666
27667
27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
27679
27680
27681
27682
27683
27684
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27649

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480_455_402

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#health_state::String

Returns Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.

Returns:

  • (::String)

    Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.



27649
27650
27651
27652
27653
27654
27655
27656
27657
27658
27659
27660
27661
27662
27663
27664
27665
27666
27667
27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
27679
27680
27681
27682
27683
27684
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27649

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480_455_402

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end

#ipv6_health_state::String

Returns Health state of the ipv6 network endpoint determined based on the health checks configured. Check the Ipv6HealthState enum for the list of possible values.

Returns:

  • (::String)

    Health state of the ipv6 network endpoint determined based on the health checks configured. Check the Ipv6HealthState enum for the list of possible values.



27649
27650
27651
27652
27653
27654
27655
27656
27657
27658
27659
27660
27661
27662
27663
27664
27665
27666
27667
27668
27669
27670
27671
27672
27673
27674
27675
27676
27677
27678
27679
27680
27681
27682
27683
27684
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27649

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks
  # configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480_455_402

    HEALTHY = 439_801_213

    UNHEALTHY = 462_118_084

    UNKNOWN = 433_141_802
  end

  # Health state of the ipv6 network endpoint determined based on the health
  # checks configured.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DRAINING
  # HEALTHY
  # UNHEALTHY
  # UNKNOWN
  module Ipv6HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_HEALTH_STATE = 0
  end
end