Class: Google::Cloud::Compute::V1::HealthStatusForNetworkEndpoint
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HealthStatusForNetworkEndpoint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: HealthState, Ipv6HealthState
Instance Attribute Summary collapse
-
#backend_service ⇒ ::Google::Cloud::Compute::V1::BackendServiceReference
URL of the backend service associated with the health state of the network endpoint.
-
#forwarding_rule ⇒ ::Google::Cloud::Compute::V1::ForwardingRuleReference
URL of the forwarding rule associated with the health state of the network endpoint.
-
#health_check ⇒ ::Google::Cloud::Compute::V1::HealthCheckReference
URL of the health check associated with the health state of the network endpoint.
-
#health_check_service ⇒ ::Google::Cloud::Compute::V1::HealthCheckServiceReference
URL of the health check service associated with the health state of the network endpoint.
-
#health_state ⇒ ::String
Health state of the network endpoint determined based on the health checks configured.
-
#ipv6_health_state ⇒ ::String
Health state of the ipv6 network endpoint determined based on the health checks configured.
Instance Attribute Details
#backend_service ⇒ ::Google::Cloud::Compute::V1::BackendServiceReference
Returns URL of the backend service associated with the health state of the network endpoint.
11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11786 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#forwarding_rule ⇒ ::Google::Cloud::Compute::V1::ForwardingRuleReference
Returns URL of the forwarding rule associated with the health state of the network endpoint.
11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11786 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#health_check ⇒ ::Google::Cloud::Compute::V1::HealthCheckReference
Returns URL of the health check associated with the health state of the network endpoint.
11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11786 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#health_check_service ⇒ ::Google::Cloud::Compute::V1::HealthCheckServiceReference
Returns URL of the health check service associated with the health state of the network endpoint.
11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11786 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#health_state ⇒ ::String
Returns Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.
11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11786 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |
#ipv6_health_state ⇒ ::String
Returns Health state of the ipv6 network endpoint determined based on the health checks configured. Check the Ipv6HealthState enum for the list of possible values.
11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 11786 class HealthStatusForNetworkEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Health state of the network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module HealthState # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATE = 0 DRAINING = 480_455_402 HEALTHY = 439_801_213 UNHEALTHY = 462_118_084 UNKNOWN = 433_141_802 end # Health state of the ipv6 network endpoint determined based on the health checks configured. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DRAINING # HEALTHY # UNHEALTHY # UNKNOWN module Ipv6HealthState # A value indicating that the enum field is not set. UNDEFINED_IPV6_HEALTH_STATE = 0 end end |