Class: Google::Cloud::Compute::V1::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: HealthState

Instance Attribute Summary collapse

Instance Attribute Details

#backend_service::Google::Cloud::Compute::V1::BackendServiceReference

Returns URL of the backend service associated with the health state of the network endpoint.

Returns:



10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 10153

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480455402

    HEALTHY = 439801213

    UNHEALTHY = 462118084

    UNKNOWN = 433141802
  end
end

#forwarding_rule::Google::Cloud::Compute::V1::ForwardingRuleReference

Returns URL of the forwarding rule associated with the health state of the network endpoint.

Returns:



10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 10153

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480455402

    HEALTHY = 439801213

    UNHEALTHY = 462118084

    UNKNOWN = 433141802
  end
end

#health_check::Google::Cloud::Compute::V1::HealthCheckReference

Returns URL of the health check associated with the health state of the network endpoint.

Returns:



10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 10153

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480455402

    HEALTHY = 439801213

    UNHEALTHY = 462118084

    UNKNOWN = 433141802
  end
end

#health_check_service::Google::Cloud::Compute::V1::HealthCheckServiceReference

Returns URL of the health check service associated with the health state of the network endpoint.

Returns:



10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 10153

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480455402

    HEALTHY = 439801213

    UNHEALTHY = 462118084

    UNKNOWN = 433141802
  end
end

#health_state::String

Returns Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.

Returns:

  • (::String)

    Health state of the network endpoint determined based on the health checks configured. Check the HealthState enum for the list of possible values.



10153
10154
10155
10156
10157
10158
10159
10160
10161
10162
10163
10164
10165
10166
10167
10168
10169
10170
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 10153

class HealthStatusForNetworkEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Health state of the network endpoint determined based on the health checks configured.
  module HealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATE = 0

    DRAINING = 480455402

    HEALTHY = 439801213

    UNHEALTHY = 462118084

    UNKNOWN = 433141802
  end
end