Class: Google::Cloud::Compute::V1::HostsListResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HostsListResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
- #etag ⇒ ::String
-
#id ⇒ ::String
The unique identifier for the resource; defined by the server.
-
#items ⇒ ::Array<::Google::Cloud::Compute::V1::Host>
A list of host resources.
-
#kind ⇒ ::String
The type of resource.
-
#next_page_token ⇒ ::String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
The server-defined URL for this resource.
-
#unreachables ⇒ ::Array<::String>
Unreachable resources.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
An informational warning message.
Instance Attribute Details
#etag ⇒ ::String
29062 29063 29064 29065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29062 class HostsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String
Returns The unique identifier for the resource; defined by the server.
29062 29063 29064 29065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29062 class HostsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#items ⇒ ::Array<::Google::Cloud::Compute::V1::Host>
Returns A list of host resources.
29062 29063 29064 29065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29062 class HostsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns The type of resource. Always compute#host for a list of hosts.
29062 29063 29064 29065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29062 class HostsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
29062 29063 29064 29065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29062 class HostsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns The server-defined URL for this resource.
29062 29063 29064 29065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29062 class HostsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachables ⇒ ::Array<::String>
Returns Unreachable resources. end_interface: MixerListResponseWithEtagBuilder.
29062 29063 29064 29065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29062 class HostsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns An informational warning message.
29062 29063 29064 29065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29062 class HostsListResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |