Class: Google::Cloud::Compute::V1::HttpQueryParameterMatch
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::HttpQueryParameterMatch
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
HttpRouteRuleMatch criteria for a request's query parameter.
Instance Attribute Summary collapse
-
#exact_match ⇒ ::String
The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch.
-
#name ⇒ ::String
The name of the query parameter to match.
-
#present_match ⇒ ::Boolean
Specifies that the queryParameterMatch matches if the request contains the query parameter, irrespective of whether the parameter has a value or not.
-
#regex_match ⇒ ::String
The queryParameterMatch matches if the value of the parameter matches the regular expression specified byregexMatch.
Instance Attribute Details
#exact_match ⇒ ::String
Returns The queryParameterMatch matches if the value of the parameter exactly matches the contents of exactMatch.
Only one of presentMatch, exactMatch, orregexMatch must be set.
27287 27288 27289 27290 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27287 class HttpQueryParameterMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns The name of the query parameter to match. The query parameter must exist in the request, in the absence of which the request match fails.
27287 27288 27289 27290 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27287 class HttpQueryParameterMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#present_match ⇒ ::Boolean
Returns Specifies that the queryParameterMatch matches if the request contains the query parameter, irrespective of whether the parameter has a value or not.
Only one of presentMatch, exactMatch, orregexMatch must be set.
27287 27288 27289 27290 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27287 class HttpQueryParameterMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#regex_match ⇒ ::String
Returns The queryParameterMatch matches if the value of the parameter matches the regular expression specified byregexMatch. For more information about regular expression syntax, see Syntax.
Only one of presentMatch, exactMatch, orregexMatch must be set.
Regular expressions can only be used when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED, EXTERNAL_MANAGED (regional scope) or INTERNAL_MANAGED.
27287 27288 27289 27290 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 27287 class HttpQueryParameterMatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |