Class: Google::Cloud::Compute::V1::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#id ⇒ ::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String) —

    [Output Only] Unique identifier for the resource; defined by the server.



33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33275

class InstanceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstancesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstancesScopedList}

Returns An object that contains a list of instances scoped by zone.

Returns:



33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33275

class InstanceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstancesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind ⇒ ::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#instanceAggregatedList for aggregated lists of Instance resources.

Returns:

  • (::String) —

    Output only. [Output Only] Type of resource. Alwayscompute#instanceAggregatedList for aggregated lists of Instance resources.



33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33275

class InstanceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstancesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token ⇒ ::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String) —

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33275

class InstanceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstancesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String) —

    Output only. [Output Only] Server-defined URL for this resource.



33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33275

class InstanceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstancesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables ⇒ ::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>) —

    Output only. [Output Only] Unreachable resources.



33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33275

class InstanceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstancesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning ⇒ ::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33275

class InstanceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::InstancesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end