Class: Google::Cloud::Compute::V1::InstanceFlexibilityPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceFlexibilityPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A flexible specification of machine types for instances to create.
Defined Under Namespace
Classes: InstanceSelectionsEntry
Instance Attribute Summary collapse
-
#instance_selections ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceFlexibilityPolicyInstanceSelection}
Specification of alternative, flexible instance subsets.
Instance Attribute Details
#instance_selections ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceFlexibilityPolicyInstanceSelection}
Returns Specification of alternative, flexible instance subsets. One of them will be selected to create the instances based on various criteria, like:
- ranks,
- location policy,
- current capacity,
- available reservations (you can specify affinity in InstanceProperties),
- SWAN/GOOSE limitations. Key is an arbitrary, unique RFC1035 string that identifies the instance selection.
31249 31250 31251 31252 31253 31254 31255 31256 31257 31258 31259 31260 31261 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31249 class InstanceFlexibilityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceFlexibilityPolicyInstanceSelection] class InstanceSelectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |