Class: Google::Cloud::Compute::V1::InstanceFlexibilityPolicyInstanceSelection
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceFlexibilityPolicyInstanceSelection
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specification of machine type to use. Every position inside this message is an alternative. The count specified in the shape flexibility must not exceed the number of entries in per_instance_properties or the capacity of the name_pattern, if used.
Instance Attribute Summary collapse
-
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::AttachedDisk>
Disks to be attached to the instances created from in this selection.
-
#machine_types ⇒ ::Array<::String>
Alternative machine types to use for instances that are created from these properties.
-
#rank ⇒ ::Integer
Rank when prioritizing the shape flexibilities.
Instance Attribute Details
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::AttachedDisk>
Returns Disks to be attached to the instances created from in this selection. They override the disks specified in the instance properties.
31283 31284 31285 31286 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31283 class InstanceFlexibilityPolicyInstanceSelection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#machine_types ⇒ ::Array<::String>
Returns Alternative machine types to use for instances that are created from
these properties. This field only accepts a machine type names, for
example n2-standard-4 and not URLs or partial URLs.
31283 31284 31285 31286 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31283 class InstanceFlexibilityPolicyInstanceSelection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rank ⇒ ::Integer
Returns Rank when prioritizing the shape flexibilities. The instance selections with rank are considered first, in the ascending order of the rank. If not set, defaults to 0.
31283 31284 31285 31286 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31283 class InstanceFlexibilityPolicyInstanceSelection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |