Class: Google::Cloud::Compute::V1::InstanceGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
Output only.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceGroupsScopedList}
A list of InstanceGroupsScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Output only.
Instance Attribute Details
#id ⇒ ::String
Returns Output only. [Output Only] Unique identifier for the resource; defined by the server.
32119 32120 32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32119 class InstanceGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceGroupsScopedList}
Returns A list of InstanceGroupsScopedList resources.
32119 32120 32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32119 class InstanceGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] The resource type, which is alwayscompute#instanceGroupAggregatedList for aggregated lists of instance groups.
32119 32120 32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32119 class InstanceGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
32119 32120 32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32119 class InstanceGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
32119 32120 32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32119 class InstanceGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
32119 32120 32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32119 class InstanceGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Output only. [Output Only] Informational warning message.
32119 32120 32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32119 class InstanceGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |