Class: Google::Cloud::Compute::V1::InstanceGroupManager

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, read Instance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use the regionInstanceGroupManagers resource.

Defined Under Namespace

Modules: ListManagedInstancesResults

Instance Attribute Summary collapse

Instance Attribute Details

#all_instances_config::Google::Cloud::Compute::V1::InstanceGroupManagerAllInstancesConfig



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#auto_healing_policies::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerAutoHealingPolicy>



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#base_instance_name::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#creation_timestamp::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#current_actions::Google::Cloud::Compute::V1::InstanceGroupManagerActionsSummary



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#description::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#distribution_policy::Google::Cloud::Compute::V1::DistributionPolicy



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#fingerprint::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#id::Integer



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#instance_flexibility_policy::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceFlexibilityPolicy



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#instance_group::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#instance_lifecycle_policy::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#instance_template::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#kind::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#list_managed_instances_results::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#name::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#named_ports::Array<::Google::Cloud::Compute::V1::NamedPort>



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#region::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#resource_policies::Google::Cloud::Compute::V1::InstanceGroupManagerResourcePolicies



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#satisfies_pzi::Boolean



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#satisfies_pzs::Boolean



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end


14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#standby_policy::Google::Cloud::Compute::V1::InstanceGroupManagerStandbyPolicy



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#stateful_policy::Google::Cloud::Compute::V1::StatefulPolicy



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#status::Google::Cloud::Compute::V1::InstanceGroupManagerStatus



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#target_pools::Array<::String>



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#target_size::Integer



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#target_stopped_size::Integer



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#target_suspended_size::Integer



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#update_policy::Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#versions::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerVersion>



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end

#zone::String



14111
14112
14113
14114
14115
14116
14117
14118
14119
14120
14121
14122
14123
14124
14125
14126
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111

class InstanceGroupManager
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pagination behavior of the listManagedInstances API method for this managed instance group.
  module ListManagedInstancesResults
    # A value indicating that the enum field is not set.
    UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0

    # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response.
    PAGELESS = 32_183_464

    # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected.
    PAGINATED = 40_190_637
  end
end