Class: Google::Cloud::Compute::V1::InstanceGroupManager
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManager
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, read Instance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use the regionInstanceGroupManagers resource.
Defined Under Namespace
Modules: ListManagedInstancesResults
Instance Attribute Summary collapse
-
#all_instances_config ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerAllInstancesConfig
Specifies configuration that overrides the instance template configuration for the group.
-
#auto_healing_policies ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerAutoHealingPolicy>
The autohealing policy for this managed instance group.
-
#base_instance_name ⇒ ::String
The base instance name is a prefix that you want to attach to the names of all VMs in a MIG.
-
#creation_timestamp ⇒ ::String
[Output Only] The creation timestamp for this managed instance group in RFC3339 text format.
-
#current_actions ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerActionsSummary
[Output Only] The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions.
-
#description ⇒ ::String
An optional description of this resource.
-
#distribution_policy ⇒ ::Google::Cloud::Compute::V1::DistributionPolicy
Policy specifying the intended distribution of managed instances across zones in a regional managed instance group.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#id ⇒ ::Integer
[Output Only] A unique identifier for this resource type.
-
#instance_flexibility_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceFlexibilityPolicy
Instance flexibility allowing MIG to create VMs from multiple types of machines.
-
#instance_group ⇒ ::String
[Output Only] The URL of the Instance Group resource.
-
#instance_lifecycle_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy
The repair policy for this managed instance group.
-
#instance_template ⇒ ::String
The URL of the instance template that is specified for this managed instance group.
-
#kind ⇒ ::String
[Output Only] The resource type, which is always compute#instanceGroupManager for managed instance groups.
-
#list_managed_instances_results ⇒ ::String
Pagination behavior of the listManagedInstances API method for this managed instance group.
-
#name ⇒ ::String
The name of the managed instance group.
-
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager.
-
#region ⇒ ::String
[Output Only] The URL of the region where the managed instance group resides (for regional resources).
-
#resource_policies ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResourcePolicies
Resource policies for this managed instance group.
-
#satisfies_pzi ⇒ ::Boolean
[Output Only] Reserved for future use.
-
#satisfies_pzs ⇒ ::Boolean
[Output Only] Reserved for future use.
-
#self_link ⇒ ::String
[Output Only] The URL for this managed instance group.
-
#standby_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStandbyPolicy
Standby policy for stopped and suspended instances.
-
#stateful_policy ⇒ ::Google::Cloud::Compute::V1::StatefulPolicy
Stateful configuration for this Instanced Group Manager.
-
#status ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStatus
[Output Only] The status of this managed instance group.
-
#target_pools ⇒ ::Array<::String>
The URLs for all TargetPool resources to which instances in the instanceGroup field are added.
-
#target_size ⇒ ::Integer
The target number of running instances for this managed instance group.
-
#target_stopped_size ⇒ ::Integer
The target number of stopped instances for this managed instance group.
-
#target_suspended_size ⇒ ::Integer
The target number of suspended instances for this managed instance group.
-
#update_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy
The update policy for this managed instance group.
-
#versions ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerVersion>
Specifies the instance templates used by this managed instance group to create instances.
-
#zone ⇒ ::String
[Output Only] The URL of a zone where the managed instance group is located (for zonal resources).
Instance Attribute Details
#all_instances_config ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerAllInstancesConfig
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#auto_healing_policies ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerAutoHealingPolicy>
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#base_instance_name ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#creation_timestamp ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#current_actions ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerActionsSummary
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#description ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#distribution_policy ⇒ ::Google::Cloud::Compute::V1::DistributionPolicy
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#fingerprint ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#id ⇒ ::Integer
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#instance_flexibility_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceFlexibilityPolicy
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#instance_group ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#instance_lifecycle_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#instance_template ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#kind ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#list_managed_instances_results ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#name ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#region ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#resource_policies ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResourcePolicies
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#satisfies_pzi ⇒ ::Boolean
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#satisfies_pzs ⇒ ::Boolean
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#self_link ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#standby_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStandbyPolicy
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#stateful_policy ⇒ ::Google::Cloud::Compute::V1::StatefulPolicy
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#status ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStatus
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#target_pools ⇒ ::Array<::String>
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#target_size ⇒ ::Integer
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#target_stopped_size ⇒ ::Integer
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#target_suspended_size ⇒ ::Integer
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#update_policy ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#versions ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceGroupManagerVersion>
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |
#zone ⇒ ::String
14111 14112 14113 14114 14115 14116 14117 14118 14119 14120 14121 14122 14123 14124 14125 14126 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14111 class InstanceGroupManager include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Pagination behavior of the listManagedInstances API method for this managed instance group. module ListManagedInstancesResults # A value indicating that the enum field is not set. UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS = 0 # (Default) Pagination is disabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are ignored and all instances are returned in a single response. PAGELESS = 32_183_464 # Pagination is enabled for the group's listManagedInstances API method. maxResults and pageToken query parameters are respected. PAGINATED = 40_190_637 end end |