Class: Google::Cloud::Compute::V1::InstanceGroupManagerAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
Output only.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList}
A list of InstanceGroupManagersScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Output only.
Instance Attribute Details
#id ⇒ ::String
Returns Output only. Unique identifier for the resource; defined by the server.
32730 32731 32732 32733 32734 32735 32736 32737 32738 32739 32740 32741 32742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList}
Returns A list of InstanceGroupManagersScopedList resources.
32730 32731 32732 32733 32734 32735 32736 32737 32738 32739 32740 32741 32742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. The resource type, which is alwayscompute#instanceGroupManagerAggregatedList for an aggregated list of managed instance groups.
32730 32731 32732 32733 32734 32735 32736 32737 32738 32739 32740 32741 32742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
32730 32731 32732 32733 32734 32735 32736 32737 32738 32739 32740 32741 32742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. Server-defined URL for this resource.
32730 32731 32732 32733 32734 32735 32736 32737 32738 32739 32740 32741 32742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. Unreachable resources.
32730 32731 32732 32733 32734 32735 32736 32737 32738 32739 32740 32741 32742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Output only. Informational warning message.
32730 32731 32732 32733 32734 32735 32736 32737 32738 32739 32740 32741 32742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |