Class: Google::Cloud::Compute::V1::InstanceGroupManagerAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
Output only.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList}
A list of InstanceGroupManagersScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Output only.
Instance Attribute Details
#id ⇒ ::String
Returns Output only. [Output Only] Unique identifier for the resource; defined by the server.
31730 31731 31732 31733 31734 31735 31736 31737 31738 31739 31740 31741 31742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList}
Returns A list of InstanceGroupManagersScopedList resources.
31730 31731 31732 31733 31734 31735 31736 31737 31738 31739 31740 31741 31742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] The resource type, which is alwayscompute#instanceGroupManagerAggregatedList for an aggregated list of managed instance groups.
31730 31731 31732 31733 31734 31735 31736 31737 31738 31739 31740 31741 31742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
31730 31731 31732 31733 31734 31735 31736 31737 31738 31739 31740 31741 31742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
31730 31731 31732 31733 31734 31735 31736 31737 31738 31739 31740 31741 31742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
31730 31731 31732 31733 31734 31735 31736 31737 31738 31739 31740 31741 31742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Output only. [Output Only] Informational warning message.
31730 31731 31732 31733 31734 31735 31736 31737 31738 31739 31740 31741 31742 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31730 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |