Class: Google::Cloud::Compute::V1::InstanceGroupManagerAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
Output only.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList}
A list of InstanceGroupManagersScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Output only.
Instance Attribute Details
#id ⇒ ::String
Returns Output only. Unique identifier for the resource; defined by the server.
33818 33819 33820 33821 33822 33823 33824 33825 33826 33827 33828 33829 33830 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33818 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList}
Returns A list of InstanceGroupManagersScopedList resources.
33818 33819 33820 33821 33822 33823 33824 33825 33826 33827 33828 33829 33830 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33818 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. The resource type, which is alwayscompute#instanceGroupManagerAggregatedList for an aggregated list of managed instance groups.
33818 33819 33820 33821 33822 33823 33824 33825 33826 33827 33828 33829 33830 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33818 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
33818 33819 33820 33821 33822 33823 33824 33825 33826 33827 33828 33829 33830 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33818 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. Server-defined URL for this resource.
33818 33819 33820 33821 33822 33823 33824 33825 33826 33827 33828 33829 33830 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33818 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. Unreachable resources.
33818 33819 33820 33821 33822 33823 33824 33825 33826 33827 33828 33829 33830 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33818 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns Output only. Informational warning message.
33818 33819 33820 33821 33822 33823 33824 33825 33826 33827 33828 33829 33830 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33818 class InstanceGroupManagerAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InstanceGroupManagersScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |