Class: Google::Cloud::Compute::V1::InstanceGroupManagerAllInstancesConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerAllInstancesConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#properties ⇒ ::Google::Cloud::Compute::V1::InstancePropertiesPatch
Properties to set on all instances in the group.
Instance Attribute Details
#properties ⇒ ::Google::Cloud::Compute::V1::InstancePropertiesPatch
Returns Properties to set on all instances in the group.
You can add or modify properties using theinstanceGroupManagers.patch orregionInstanceGroupManagers.patch. After settingallInstancesConfig on the group, you must update the group's instances to apply the configuration. To apply the configuration, set the group's updatePolicy.type field to use proactive updates or use the applyUpdatesToInstances method.
32474 32475 32476 32477 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32474 class InstanceGroupManagerAllInstancesConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |