Class: Google::Cloud::Compute::V1::InstanceGroupManagerAllInstancesConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#properties::Google::Cloud::Compute::V1::InstancePropertiesPatch

Returns Properties to set on all instances in the group.

You can add or modify properties using theinstanceGroupManagers.patch orregionInstanceGroupManagers.patch. After settingallInstancesConfig on the group, you must update the group's instances to apply the configuration. To apply the configuration, set the group's updatePolicy.type field to use proactive updates or use the applyUpdatesToInstances method.

Returns:

  • (::Google::Cloud::Compute::V1::InstancePropertiesPatch)

    Properties to set on all instances in the group.

    You can add or modify properties using theinstanceGroupManagers.patch orregionInstanceGroupManagers.patch. After settingallInstancesConfig on the group, you must update the group's instances to apply the configuration. To apply the configuration, set the group's updatePolicy.type field to use proactive updates or use the applyUpdatesToInstances method.



31752
31753
31754
31755
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31752

class InstanceGroupManagerAllInstancesConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end