Class: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DefaultActionOnFailure, ForceUpdateOnRepair, OnFailedHealthCheck

Instance Attribute Summary collapse

Instance Attribute Details

#default_action_on_failure::String

Returns The action that a MIG performs on a failed VM. If the value of the onFailedHealthCheck field is DEFAULT_ACTION, then the same action also applies to the VMs on which your application fails a health check. Valid values are

  • REPAIR (default): MIG automatically repairs a failed VM by recreating it. For more information, see About repairing VMs in a MIG.
  • DO_NOTHING: MIG does not repair a failed VM. Check the DefaultActionOnFailure enum for the list of possible values.

Returns:

  • (::String)

    The action that a MIG performs on a failed VM. If the value of the onFailedHealthCheck field is DEFAULT_ACTION, then the same action also applies to the VMs on which your application fails a health check. Valid values are

    • REPAIR (default): MIG automatically repairs a failed VM by recreating it. For more information, see About repairing VMs in a MIG.
    • DO_NOTHING: MIG does not repair a failed VM. Check the DefaultActionOnFailure enum for the list of possible values.


32851
32852
32853
32854
32855
32856
32857
32858
32859
32860
32861
32862
32863
32864
32865
32866
32867
32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
32883
32884
32885
32886
32887
32888
32889
32890
32891
32892
32893
32894
32895
32896
32897
32898
32899
32900
32901
32902
32903
32904
32905
32906
32907
32908
32909
32910
32911
32912
32913
32914
32915
32916
32917
32918
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32851

class InstanceGroupManagerInstanceLifecyclePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The action that a MIG performs on a failed VM. If the value of the
  # onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action also
  # applies to the VMs on which your application fails a health check.
  # Valid values are
  #
  #    - REPAIR (default): MIG automatically repairs a failed VM
  #    by recreating it. For more information, see About
  #    repairing VMs in a MIG.
  #    - DO_NOTHING: MIG does not repair a failed VM.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module DefaultActionOnFailure
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0

    DO_NOTHING = 451_307_513

    REPAIR = 266_277_773
  end

  # A bit indicating whether to forcefully apply the group's latest
  # configuration when repairing a VM. Valid options are:
  #
  #
  #
  #      -  NO (default): If configuration updates are available, they are not
  #      forcefully applied during repair. Instead, configuration updates are
  #      applied according to the group's update policy.
  #
  #      -  YES: If configuration updates are available, they are applied
  #      during repair.
  module ForceUpdateOnRepair
    # A value indicating that the enum field is not set.
    UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0

    NO = 2497

    YES = 87_751
  end

  # The action that a MIG performs on an unhealthy VM. A VM is marked as
  # unhealthy when the application running on that VM fails a health check.
  # Valid values are:
  #
  #    - DEFAULT_ACTION (default): MIG uses the same action
  #    configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  #    - REPAIR: MIG automatically repairs an unhealthy VM by
  #    recreating it.
  #    - DO_NOTHING: MIG doesn't repair an unhealthy VM.
  #    For more information, see
  #    About repairing VMs in a MIG.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module OnFailedHealthCheck
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_FAILED_HEALTH_CHECK = 0

    # (Default) MIG uses the same action configured for
    # instanceLifecyclePolicy.defaultActionOnFailure field.
    DEFAULT_ACTION = 463_967_764
  end
end

#force_update_on_repair::String

Returns A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:

 -  NO (default): If configuration updates are available, they are not
 forcefully applied during repair. Instead, configuration updates are
 applied according to the group's update policy.

 -  YES: If configuration updates are available, they are applied
 during repair.

Check the ForceUpdateOnRepair enum for the list of possible values.

Returns:

  • (::String)

    A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:

     -  NO (default): If configuration updates are available, they are not
     forcefully applied during repair. Instead, configuration updates are
     applied according to the group's update policy.
    
     -  YES: If configuration updates are available, they are applied
     during repair.
    

    Check the ForceUpdateOnRepair enum for the list of possible values.



32851
32852
32853
32854
32855
32856
32857
32858
32859
32860
32861
32862
32863
32864
32865
32866
32867
32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
32883
32884
32885
32886
32887
32888
32889
32890
32891
32892
32893
32894
32895
32896
32897
32898
32899
32900
32901
32902
32903
32904
32905
32906
32907
32908
32909
32910
32911
32912
32913
32914
32915
32916
32917
32918
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32851

class InstanceGroupManagerInstanceLifecyclePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The action that a MIG performs on a failed VM. If the value of the
  # onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action also
  # applies to the VMs on which your application fails a health check.
  # Valid values are
  #
  #    - REPAIR (default): MIG automatically repairs a failed VM
  #    by recreating it. For more information, see About
  #    repairing VMs in a MIG.
  #    - DO_NOTHING: MIG does not repair a failed VM.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module DefaultActionOnFailure
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0

    DO_NOTHING = 451_307_513

    REPAIR = 266_277_773
  end

  # A bit indicating whether to forcefully apply the group's latest
  # configuration when repairing a VM. Valid options are:
  #
  #
  #
  #      -  NO (default): If configuration updates are available, they are not
  #      forcefully applied during repair. Instead, configuration updates are
  #      applied according to the group's update policy.
  #
  #      -  YES: If configuration updates are available, they are applied
  #      during repair.
  module ForceUpdateOnRepair
    # A value indicating that the enum field is not set.
    UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0

    NO = 2497

    YES = 87_751
  end

  # The action that a MIG performs on an unhealthy VM. A VM is marked as
  # unhealthy when the application running on that VM fails a health check.
  # Valid values are:
  #
  #    - DEFAULT_ACTION (default): MIG uses the same action
  #    configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  #    - REPAIR: MIG automatically repairs an unhealthy VM by
  #    recreating it.
  #    - DO_NOTHING: MIG doesn't repair an unhealthy VM.
  #    For more information, see
  #    About repairing VMs in a MIG.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module OnFailedHealthCheck
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_FAILED_HEALTH_CHECK = 0

    # (Default) MIG uses the same action configured for
    # instanceLifecyclePolicy.defaultActionOnFailure field.
    DEFAULT_ACTION = 463_967_764
  end
end

#on_failed_health_check::String

Returns The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:

  • DEFAULT_ACTION (default): MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  • REPAIR: MIG automatically repairs an unhealthy VM by recreating it.
  • DO_NOTHING: MIG doesn't repair an unhealthy VM. For more information, see About repairing VMs in a MIG. Check the OnFailedHealthCheck enum for the list of possible values.

Returns:

  • (::String)

    The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:

    • DEFAULT_ACTION (default): MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.
    • REPAIR: MIG automatically repairs an unhealthy VM by recreating it.
    • DO_NOTHING: MIG doesn't repair an unhealthy VM. For more information, see About repairing VMs in a MIG. Check the OnFailedHealthCheck enum for the list of possible values.


32851
32852
32853
32854
32855
32856
32857
32858
32859
32860
32861
32862
32863
32864
32865
32866
32867
32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
32883
32884
32885
32886
32887
32888
32889
32890
32891
32892
32893
32894
32895
32896
32897
32898
32899
32900
32901
32902
32903
32904
32905
32906
32907
32908
32909
32910
32911
32912
32913
32914
32915
32916
32917
32918
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32851

class InstanceGroupManagerInstanceLifecyclePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The action that a MIG performs on a failed VM. If the value of the
  # onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action also
  # applies to the VMs on which your application fails a health check.
  # Valid values are
  #
  #    - REPAIR (default): MIG automatically repairs a failed VM
  #    by recreating it. For more information, see About
  #    repairing VMs in a MIG.
  #    - DO_NOTHING: MIG does not repair a failed VM.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module DefaultActionOnFailure
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0

    DO_NOTHING = 451_307_513

    REPAIR = 266_277_773
  end

  # A bit indicating whether to forcefully apply the group's latest
  # configuration when repairing a VM. Valid options are:
  #
  #
  #
  #      -  NO (default): If configuration updates are available, they are not
  #      forcefully applied during repair. Instead, configuration updates are
  #      applied according to the group's update policy.
  #
  #      -  YES: If configuration updates are available, they are applied
  #      during repair.
  module ForceUpdateOnRepair
    # A value indicating that the enum field is not set.
    UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0

    NO = 2497

    YES = 87_751
  end

  # The action that a MIG performs on an unhealthy VM. A VM is marked as
  # unhealthy when the application running on that VM fails a health check.
  # Valid values are:
  #
  #    - DEFAULT_ACTION (default): MIG uses the same action
  #    configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  #    - REPAIR: MIG automatically repairs an unhealthy VM by
  #    recreating it.
  #    - DO_NOTHING: MIG doesn't repair an unhealthy VM.
  #    For more information, see
  #    About repairing VMs in a MIG.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module OnFailedHealthCheck
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_FAILED_HEALTH_CHECK = 0

    # (Default) MIG uses the same action configured for
    # instanceLifecyclePolicy.defaultActionOnFailure field.
    DEFAULT_ACTION = 463_967_764
  end
end

#on_repair::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicyOnRepair

Returns Configuration for VM repairs in the MIG.

Returns:



32851
32852
32853
32854
32855
32856
32857
32858
32859
32860
32861
32862
32863
32864
32865
32866
32867
32868
32869
32870
32871
32872
32873
32874
32875
32876
32877
32878
32879
32880
32881
32882
32883
32884
32885
32886
32887
32888
32889
32890
32891
32892
32893
32894
32895
32896
32897
32898
32899
32900
32901
32902
32903
32904
32905
32906
32907
32908
32909
32910
32911
32912
32913
32914
32915
32916
32917
32918
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32851

class InstanceGroupManagerInstanceLifecyclePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The action that a MIG performs on a failed VM. If the value of the
  # onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action also
  # applies to the VMs on which your application fails a health check.
  # Valid values are
  #
  #    - REPAIR (default): MIG automatically repairs a failed VM
  #    by recreating it. For more information, see About
  #    repairing VMs in a MIG.
  #    - DO_NOTHING: MIG does not repair a failed VM.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module DefaultActionOnFailure
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0

    DO_NOTHING = 451_307_513

    REPAIR = 266_277_773
  end

  # A bit indicating whether to forcefully apply the group's latest
  # configuration when repairing a VM. Valid options are:
  #
  #
  #
  #      -  NO (default): If configuration updates are available, they are not
  #      forcefully applied during repair. Instead, configuration updates are
  #      applied according to the group's update policy.
  #
  #      -  YES: If configuration updates are available, they are applied
  #      during repair.
  module ForceUpdateOnRepair
    # A value indicating that the enum field is not set.
    UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0

    NO = 2497

    YES = 87_751
  end

  # The action that a MIG performs on an unhealthy VM. A VM is marked as
  # unhealthy when the application running on that VM fails a health check.
  # Valid values are:
  #
  #    - DEFAULT_ACTION (default): MIG uses the same action
  #    configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  #    - REPAIR: MIG automatically repairs an unhealthy VM by
  #    recreating it.
  #    - DO_NOTHING: MIG doesn't repair an unhealthy VM.
  #    For more information, see
  #    About repairing VMs in a MIG.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module OnFailedHealthCheck
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_FAILED_HEALTH_CHECK = 0

    # (Default) MIG uses the same action configured for
    # instanceLifecyclePolicy.defaultActionOnFailure field.
    DEFAULT_ACTION = 463_967_764
  end
end