Class: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: DefaultActionOnFailure, ForceUpdateOnRepair, OnFailedHealthCheck
Instance Attribute Summary collapse
-
#default_action_on_failure ⇒ ::String
The action that a MIG performs on a failed or an unhealthy VM.
-
#force_update_on_repair ⇒ ::String
A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM.
-
#on_failed_health_check ⇒ ::String
The action that a MIG performs on an unhealthy VM.
Instance Attribute Details
#default_action_on_failure ⇒ ::String
Returns The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are
- REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG.
- DO_NOTHING: MIG does not repair a failed or an unhealthy VM. Check the DefaultActionOnFailure enum for the list of possible values.
32571 32572 32573 32574 32575 32576 32577 32578 32579 32580 32581 32582 32583 32584 32585 32586 32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 32599 32600 32601 32602 32603 32604 32605 32606 32607 32608 32609 32610 32611 32612 32613 32614 32615 32616 32617 32618 32619 32620 32621 32622 32623 32624 32625 32626 32627 32628 32629 32630 32631 32632 32633 32634 32635 32636 32637 32638 32639 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32571 class InstanceGroupManagerInstanceLifecyclePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The action that a MIG performs on a failed or an unhealthy VM. # A VM is marked as unhealthy when the application running on that # VM fails a health check. # Valid values are # # - REPAIR (default): MIG automatically repairs a failed or # an unhealthy VM by recreating it. For more information, see About # repairing VMs in a MIG. # - DO_NOTHING: MIG does not repair a failed or an unhealthy # VM. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module DefaultActionOnFailure # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0 DO_NOTHING = 451_307_513 REPAIR = 266_277_773 end # A bit indicating whether to forcefully apply the group's latest # configuration when repairing a VM. Valid options are: # # # # - NO (default): If configuration updates are available, they are not # forcefully applied during repair. Instead, configuration updates are # applied according to the group's update policy. # # - YES: If configuration updates are available, they are applied # during repair. module ForceUpdateOnRepair # A value indicating that the enum field is not set. UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0 NO = 2497 YES = 87_751 end # The action that a MIG performs on an unhealthy VM. A VM is marked as # unhealthy when the application running on that VM fails a health check. # Valid values are: # # - DEFAULT_ACTION (default): MIG uses the same action # configured for instanceLifecyclePolicy.defaultActionOnFailure field. # - REPAIR: MIG automatically repairs an unhealthy VM by # recreating it. # - DO_NOTHING: MIG doesn't repair an unhealthy VM. # For more information, see # About repairing VMs in a MIG. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module OnFailedHealthCheck # A value indicating that the enum field is not set. UNDEFINED_ON_FAILED_HEALTH_CHECK = 0 # (Default) MIG uses the same action configured for # instanceLifecyclePolicy.defaultActionOnFailure field. DEFAULT_ACTION = 463_967_764 end end |
#force_update_on_repair ⇒ ::String
Returns A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:
- NO (default): If configuration updates are available, they are not
forcefully applied during repair. Instead, configuration updates are
applied according to the group's update policy.
- YES: If configuration updates are available, they are applied
during repair.
Check the ForceUpdateOnRepair enum for the list of possible values.
32571 32572 32573 32574 32575 32576 32577 32578 32579 32580 32581 32582 32583 32584 32585 32586 32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 32599 32600 32601 32602 32603 32604 32605 32606 32607 32608 32609 32610 32611 32612 32613 32614 32615 32616 32617 32618 32619 32620 32621 32622 32623 32624 32625 32626 32627 32628 32629 32630 32631 32632 32633 32634 32635 32636 32637 32638 32639 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32571 class InstanceGroupManagerInstanceLifecyclePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The action that a MIG performs on a failed or an unhealthy VM. # A VM is marked as unhealthy when the application running on that # VM fails a health check. # Valid values are # # - REPAIR (default): MIG automatically repairs a failed or # an unhealthy VM by recreating it. For more information, see About # repairing VMs in a MIG. # - DO_NOTHING: MIG does not repair a failed or an unhealthy # VM. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module DefaultActionOnFailure # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0 DO_NOTHING = 451_307_513 REPAIR = 266_277_773 end # A bit indicating whether to forcefully apply the group's latest # configuration when repairing a VM. Valid options are: # # # # - NO (default): If configuration updates are available, they are not # forcefully applied during repair. Instead, configuration updates are # applied according to the group's update policy. # # - YES: If configuration updates are available, they are applied # during repair. module ForceUpdateOnRepair # A value indicating that the enum field is not set. UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0 NO = 2497 YES = 87_751 end # The action that a MIG performs on an unhealthy VM. A VM is marked as # unhealthy when the application running on that VM fails a health check. # Valid values are: # # - DEFAULT_ACTION (default): MIG uses the same action # configured for instanceLifecyclePolicy.defaultActionOnFailure field. # - REPAIR: MIG automatically repairs an unhealthy VM by # recreating it. # - DO_NOTHING: MIG doesn't repair an unhealthy VM. # For more information, see # About repairing VMs in a MIG. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module OnFailedHealthCheck # A value indicating that the enum field is not set. UNDEFINED_ON_FAILED_HEALTH_CHECK = 0 # (Default) MIG uses the same action configured for # instanceLifecyclePolicy.defaultActionOnFailure field. DEFAULT_ACTION = 463_967_764 end end |
#on_failed_health_check ⇒ ::String
Returns The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:
- DEFAULT_ACTION (default): MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.
- REPAIR: MIG automatically repairs an unhealthy VM by recreating it.
- DO_NOTHING: MIG doesn't repair an unhealthy VM. For more information, see About repairing VMs in a MIG. Check the OnFailedHealthCheck enum for the list of possible values.
32571 32572 32573 32574 32575 32576 32577 32578 32579 32580 32581 32582 32583 32584 32585 32586 32587 32588 32589 32590 32591 32592 32593 32594 32595 32596 32597 32598 32599 32600 32601 32602 32603 32604 32605 32606 32607 32608 32609 32610 32611 32612 32613 32614 32615 32616 32617 32618 32619 32620 32621 32622 32623 32624 32625 32626 32627 32628 32629 32630 32631 32632 32633 32634 32635 32636 32637 32638 32639 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32571 class InstanceGroupManagerInstanceLifecyclePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The action that a MIG performs on a failed or an unhealthy VM. # A VM is marked as unhealthy when the application running on that # VM fails a health check. # Valid values are # # - REPAIR (default): MIG automatically repairs a failed or # an unhealthy VM by recreating it. For more information, see About # repairing VMs in a MIG. # - DO_NOTHING: MIG does not repair a failed or an unhealthy # VM. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module DefaultActionOnFailure # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0 DO_NOTHING = 451_307_513 REPAIR = 266_277_773 end # A bit indicating whether to forcefully apply the group's latest # configuration when repairing a VM. Valid options are: # # # # - NO (default): If configuration updates are available, they are not # forcefully applied during repair. Instead, configuration updates are # applied according to the group's update policy. # # - YES: If configuration updates are available, they are applied # during repair. module ForceUpdateOnRepair # A value indicating that the enum field is not set. UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0 NO = 2497 YES = 87_751 end # The action that a MIG performs on an unhealthy VM. A VM is marked as # unhealthy when the application running on that VM fails a health check. # Valid values are: # # - DEFAULT_ACTION (default): MIG uses the same action # configured for instanceLifecyclePolicy.defaultActionOnFailure field. # - REPAIR: MIG automatically repairs an unhealthy VM by # recreating it. # - DO_NOTHING: MIG doesn't repair an unhealthy VM. # For more information, see # About repairing VMs in a MIG. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module OnFailedHealthCheck # A value indicating that the enum field is not set. UNDEFINED_ON_FAILED_HEALTH_CHECK = 0 # (Default) MIG uses the same action configured for # instanceLifecyclePolicy.defaultActionOnFailure field. DEFAULT_ACTION = 463_967_764 end end |