Class: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DefaultActionOnFailure, ForceUpdateOnRepair, OnFailedHealthCheck

Instance Attribute Summary collapse

Instance Attribute Details

#default_action_on_failure::String

Returns The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are

  • REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG.
  • DO_NOTHING: MIG does not repair a failed or an unhealthy VM. Check the DefaultActionOnFailure enum for the list of possible values.

Returns:

  • (::String)

    The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are

    • REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG.
    • DO_NOTHING: MIG does not repair a failed or an unhealthy VM. Check the DefaultActionOnFailure enum for the list of possible values.


31849
31850
31851
31852
31853
31854
31855
31856
31857
31858
31859
31860
31861
31862
31863
31864
31865
31866
31867
31868
31869
31870
31871
31872
31873
31874
31875
31876
31877
31878
31879
31880
31881
31882
31883
31884
31885
31886
31887
31888
31889
31890
31891
31892
31893
31894
31895
31896
31897
31898
31899
31900
31901
31902
31903
31904
31905
31906
31907
31908
31909
31910
31911
31912
31913
31914
31915
31916
31917
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31849

class InstanceGroupManagerInstanceLifecyclePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The action that a MIG performs on a failed or an unhealthy VM.
  # A VM is marked as unhealthy when the application running on that
  # VM fails a health check.
  # Valid values are
  #
  #    - REPAIR (default): MIG automatically repairs a failed or
  #    an unhealthy VM by recreating it. For more information, see About
  #    repairing VMs in a MIG.
  #    - DO_NOTHING: MIG does not repair a failed or an unhealthy
  #    VM.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module DefaultActionOnFailure
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0

    DO_NOTHING = 451_307_513

    REPAIR = 266_277_773
  end

  # A bit indicating whether to forcefully apply the group's latest
  # configuration when repairing a VM. Valid options are:
  #
  #
  #
  #      -  NO (default): If configuration updates are available, they are not
  #      forcefully applied during repair. Instead, configuration updates are
  #      applied according to the group's update policy.
  #
  #      -  YES: If configuration updates are available, they are applied
  #      during repair.
  module ForceUpdateOnRepair
    # A value indicating that the enum field is not set.
    UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0

    NO = 2497

    YES = 87_751
  end

  # The action that a MIG performs on an unhealthy VM. A VM is marked as
  # unhealthy when the application running on that VM fails a health check.
  # Valid values are:
  #
  #    - DEFAULT_ACTION (default): MIG uses the same action
  #    configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  #    - REPAIR: MIG automatically repairs an unhealthy VM by
  #    recreating it.
  #    - DO_NOTHING: MIG doesn't repair an unhealthy VM.
  #    For more information, see
  #    About repairing VMs in a MIG.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module OnFailedHealthCheck
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_FAILED_HEALTH_CHECK = 0

    # (Default) MIG uses the same action configured for
    # instanceLifecyclePolicy.defaultActionOnFailure field.
    DEFAULT_ACTION = 463_967_764
  end
end

#force_update_on_repair::String

Returns A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:

 -  NO (default): If configuration updates are available, they are not
 forcefully applied during repair. Instead, configuration updates are
 applied according to the group's update policy.

 -  YES: If configuration updates are available, they are applied
 during repair.

Check the ForceUpdateOnRepair enum for the list of possible values.

Returns:

  • (::String)

    A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:

     -  NO (default): If configuration updates are available, they are not
     forcefully applied during repair. Instead, configuration updates are
     applied according to the group's update policy.
    
     -  YES: If configuration updates are available, they are applied
     during repair.
    

    Check the ForceUpdateOnRepair enum for the list of possible values.



31849
31850
31851
31852
31853
31854
31855
31856
31857
31858
31859
31860
31861
31862
31863
31864
31865
31866
31867
31868
31869
31870
31871
31872
31873
31874
31875
31876
31877
31878
31879
31880
31881
31882
31883
31884
31885
31886
31887
31888
31889
31890
31891
31892
31893
31894
31895
31896
31897
31898
31899
31900
31901
31902
31903
31904
31905
31906
31907
31908
31909
31910
31911
31912
31913
31914
31915
31916
31917
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31849

class InstanceGroupManagerInstanceLifecyclePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The action that a MIG performs on a failed or an unhealthy VM.
  # A VM is marked as unhealthy when the application running on that
  # VM fails a health check.
  # Valid values are
  #
  #    - REPAIR (default): MIG automatically repairs a failed or
  #    an unhealthy VM by recreating it. For more information, see About
  #    repairing VMs in a MIG.
  #    - DO_NOTHING: MIG does not repair a failed or an unhealthy
  #    VM.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module DefaultActionOnFailure
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0

    DO_NOTHING = 451_307_513

    REPAIR = 266_277_773
  end

  # A bit indicating whether to forcefully apply the group's latest
  # configuration when repairing a VM. Valid options are:
  #
  #
  #
  #      -  NO (default): If configuration updates are available, they are not
  #      forcefully applied during repair. Instead, configuration updates are
  #      applied according to the group's update policy.
  #
  #      -  YES: If configuration updates are available, they are applied
  #      during repair.
  module ForceUpdateOnRepair
    # A value indicating that the enum field is not set.
    UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0

    NO = 2497

    YES = 87_751
  end

  # The action that a MIG performs on an unhealthy VM. A VM is marked as
  # unhealthy when the application running on that VM fails a health check.
  # Valid values are:
  #
  #    - DEFAULT_ACTION (default): MIG uses the same action
  #    configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  #    - REPAIR: MIG automatically repairs an unhealthy VM by
  #    recreating it.
  #    - DO_NOTHING: MIG doesn't repair an unhealthy VM.
  #    For more information, see
  #    About repairing VMs in a MIG.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module OnFailedHealthCheck
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_FAILED_HEALTH_CHECK = 0

    # (Default) MIG uses the same action configured for
    # instanceLifecyclePolicy.defaultActionOnFailure field.
    DEFAULT_ACTION = 463_967_764
  end
end

#on_failed_health_check::String

Returns The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:

  • DEFAULT_ACTION (default): MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  • REPAIR: MIG automatically repairs an unhealthy VM by recreating it.
  • DO_NOTHING: MIG doesn't repair an unhealthy VM. For more information, see About repairing VMs in a MIG. Check the OnFailedHealthCheck enum for the list of possible values.

Returns:

  • (::String)

    The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:

    • DEFAULT_ACTION (default): MIG uses the same action configured for instanceLifecyclePolicy.defaultActionOnFailure field.
    • REPAIR: MIG automatically repairs an unhealthy VM by recreating it.
    • DO_NOTHING: MIG doesn't repair an unhealthy VM. For more information, see About repairing VMs in a MIG. Check the OnFailedHealthCheck enum for the list of possible values.


31849
31850
31851
31852
31853
31854
31855
31856
31857
31858
31859
31860
31861
31862
31863
31864
31865
31866
31867
31868
31869
31870
31871
31872
31873
31874
31875
31876
31877
31878
31879
31880
31881
31882
31883
31884
31885
31886
31887
31888
31889
31890
31891
31892
31893
31894
31895
31896
31897
31898
31899
31900
31901
31902
31903
31904
31905
31906
31907
31908
31909
31910
31911
31912
31913
31914
31915
31916
31917
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31849

class InstanceGroupManagerInstanceLifecyclePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The action that a MIG performs on a failed or an unhealthy VM.
  # A VM is marked as unhealthy when the application running on that
  # VM fails a health check.
  # Valid values are
  #
  #    - REPAIR (default): MIG automatically repairs a failed or
  #    an unhealthy VM by recreating it. For more information, see About
  #    repairing VMs in a MIG.
  #    - DO_NOTHING: MIG does not repair a failed or an unhealthy
  #    VM.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module DefaultActionOnFailure
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0

    DO_NOTHING = 451_307_513

    REPAIR = 266_277_773
  end

  # A bit indicating whether to forcefully apply the group's latest
  # configuration when repairing a VM. Valid options are:
  #
  #
  #
  #      -  NO (default): If configuration updates are available, they are not
  #      forcefully applied during repair. Instead, configuration updates are
  #      applied according to the group's update policy.
  #
  #      -  YES: If configuration updates are available, they are applied
  #      during repair.
  module ForceUpdateOnRepair
    # A value indicating that the enum field is not set.
    UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0

    NO = 2497

    YES = 87_751
  end

  # The action that a MIG performs on an unhealthy VM. A VM is marked as
  # unhealthy when the application running on that VM fails a health check.
  # Valid values are:
  #
  #    - DEFAULT_ACTION (default): MIG uses the same action
  #    configured for instanceLifecyclePolicy.defaultActionOnFailure field.
  #    - REPAIR: MIG automatically repairs an unhealthy VM by
  #    recreating it.
  #    - DO_NOTHING: MIG doesn't repair an unhealthy VM.
  #    For more information, see
  #    About repairing VMs in a MIG.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # DO_NOTHING
  # REPAIR
  module OnFailedHealthCheck
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_FAILED_HEALTH_CHECK = 0

    # (Default) MIG uses the same action configured for
    # instanceLifecyclePolicy.defaultActionOnFailure field.
    DEFAULT_ACTION = 463_967_764
  end
end