Class: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DefaultActionOnFailure, ForceUpdateOnRepair

Instance Attribute Summary collapse

Instance Attribute Details

#default_action_on_failure::String

Returns The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are - REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG. - DO_NOTHING: MIG does not repair a failed or an unhealthy VM. Check the DefaultActionOnFailure enum for the list of possible values.

Returns:

  • (::String)

    The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are - REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG. - DO_NOTHING: MIG does not repair a failed or an unhealthy VM. Check the DefaultActionOnFailure enum for the list of possible values.



14286
14287
14288
14289
14290
14291
14292
14293
14294
14295
14296
14297
14298
14299
14300
14301
14302
14303
14304
14305
14306
14307
14308
14309
14310
14311
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14286

class InstanceGroupManagerInstanceLifecyclePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are - REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG. - DO_NOTHING: MIG does not repair a failed or an unhealthy VM.
  module DefaultActionOnFailure
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0

    # MIG does not repair a failed or an unhealthy VM.
    DO_NOTHING = 451_307_513

    # (Default) MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG.
    REPAIR = 266_277_773
  end

  # A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are: - NO (default): If configuration updates are available, they are not forcefully applied during repair. Instead, configuration updates are applied according to the group's update policy. - YES: If configuration updates are available, they are applied during repair.
  module ForceUpdateOnRepair
    # A value indicating that the enum field is not set.
    UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0

    NO = 2497

    YES = 87_751
  end
end

#force_update_on_repair::String

Returns A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are: - NO (default): If configuration updates are available, they are not forcefully applied during repair. Instead, configuration updates are applied according to the group's update policy. - YES: If configuration updates are available, they are applied during repair. Check the ForceUpdateOnRepair enum for the list of possible values.

Returns:

  • (::String)

    A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are: - NO (default): If configuration updates are available, they are not forcefully applied during repair. Instead, configuration updates are applied according to the group's update policy. - YES: If configuration updates are available, they are applied during repair. Check the ForceUpdateOnRepair enum for the list of possible values.



14286
14287
14288
14289
14290
14291
14292
14293
14294
14295
14296
14297
14298
14299
14300
14301
14302
14303
14304
14305
14306
14307
14308
14309
14310
14311
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14286

class InstanceGroupManagerInstanceLifecyclePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are - REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG. - DO_NOTHING: MIG does not repair a failed or an unhealthy VM.
  module DefaultActionOnFailure
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0

    # MIG does not repair a failed or an unhealthy VM.
    DO_NOTHING = 451_307_513

    # (Default) MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG.
    REPAIR = 266_277_773
  end

  # A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are: - NO (default): If configuration updates are available, they are not forcefully applied during repair. Instead, configuration updates are applied according to the group's update policy. - YES: If configuration updates are available, they are applied during repair.
  module ForceUpdateOnRepair
    # A value indicating that the enum field is not set.
    UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0

    NO = 2497

    YES = 87_751
  end
end