Class: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: DefaultActionOnFailure, ForceUpdateOnRepair, OnFailedHealthCheck
Instance Attribute Summary collapse
-
#default_action_on_failure ⇒ ::String
The action that a MIG performs on a failed VM.
-
#force_update_on_repair ⇒ ::String
A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM.
-
#on_failed_health_check ⇒ ::String
The action that a MIG performs on an unhealthy VM.
-
#on_repair ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicyOnRepair
Configuration for VM repairs in the MIG.
Instance Attribute Details
#default_action_on_failure ⇒ ::String
Returns The action that a MIG performs on a failed VM. If the value of the
onFailedHealthCheck field is DEFAULT_ACTION, then the same action also
applies to the VMs on which your application fails a health check.
Valid values are
- REPAIR (default): MIG automatically repairs a failed VM
by recreating it. For more information, see About
repairing VMs in a MIG.
- DO_NOTHING: MIG does not repair a failed VM.
Check the DefaultActionOnFailure enum for the list of possible values.
33939 33940 33941 33942 33943 33944 33945 33946 33947 33948 33949 33950 33951 33952 33953 33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 33982 33983 33984 33985 33986 33987 33988 33989 33990 33991 33992 33993 33994 33995 33996 33997 33998 33999 34000 34001 34002 34003 34004 34005 34006 34007 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33939 class InstanceGroupManagerInstanceLifecyclePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The action that a MIG performs on a failed VM. If the value of the # onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action also # applies to the VMs on which your application fails a health check. # Valid values are # # - REPAIR (default): MIG automatically repairs a failed VM # by recreating it. For more information, see About # repairing VMs in a MIG. # - DO_NOTHING: MIG does not repair a failed VM. module DefaultActionOnFailure # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0 # MIG does not repair a failed VM. DO_NOTHING = 451_307_513 # (default): MIG automatically repairs a failed VM by recreating it. # For more information, see About # repairing VMs in a MIG. REPAIR = 266_277_773 end # A bit indicating whether to forcefully apply the group's latest # configuration when repairing a VM. Valid options are: # # # # - NO (default): If configuration updates are available, they are not # forcefully applied during repair. Instead, configuration updates are # applied according to the group's update policy. # # - YES: If configuration updates are available, they are applied # during repair. module ForceUpdateOnRepair # A value indicating that the enum field is not set. UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0 NO = 2497 YES = 87_751 end # The action that a MIG performs on an unhealthy VM. A VM is marked as # unhealthy when the application running on that VM fails a health check. # Valid values are: # # - DEFAULT_ACTION (default): MIG uses the same action # configured for instanceLifecyclePolicy.defaultActionOnFailure field. # - REPAIR: MIG automatically repairs an unhealthy VM by # recreating it. # - DO_NOTHING: MIG doesn't repair an unhealthy VM. # For more information, see # About repairing VMs in a MIG. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module OnFailedHealthCheck # A value indicating that the enum field is not set. UNDEFINED_ON_FAILED_HEALTH_CHECK = 0 # (Default) MIG uses the same action configured for # instanceLifecyclePolicy.defaultActionOnFailure field. DEFAULT_ACTION = 463_967_764 end end |
#force_update_on_repair ⇒ ::String
Returns A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM. Valid options are:
- NO (default): If configuration updates are available, they are not
forcefully applied during repair. Instead, configuration updates are
applied according to the group's update policy.
- YES: If configuration updates are available, they are applied
during repair.
Check the ForceUpdateOnRepair enum for the list of possible values.
33939 33940 33941 33942 33943 33944 33945 33946 33947 33948 33949 33950 33951 33952 33953 33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 33982 33983 33984 33985 33986 33987 33988 33989 33990 33991 33992 33993 33994 33995 33996 33997 33998 33999 34000 34001 34002 34003 34004 34005 34006 34007 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33939 class InstanceGroupManagerInstanceLifecyclePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The action that a MIG performs on a failed VM. If the value of the # onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action also # applies to the VMs on which your application fails a health check. # Valid values are # # - REPAIR (default): MIG automatically repairs a failed VM # by recreating it. For more information, see About # repairing VMs in a MIG. # - DO_NOTHING: MIG does not repair a failed VM. module DefaultActionOnFailure # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0 # MIG does not repair a failed VM. DO_NOTHING = 451_307_513 # (default): MIG automatically repairs a failed VM by recreating it. # For more information, see About # repairing VMs in a MIG. REPAIR = 266_277_773 end # A bit indicating whether to forcefully apply the group's latest # configuration when repairing a VM. Valid options are: # # # # - NO (default): If configuration updates are available, they are not # forcefully applied during repair. Instead, configuration updates are # applied according to the group's update policy. # # - YES: If configuration updates are available, they are applied # during repair. module ForceUpdateOnRepair # A value indicating that the enum field is not set. UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0 NO = 2497 YES = 87_751 end # The action that a MIG performs on an unhealthy VM. A VM is marked as # unhealthy when the application running on that VM fails a health check. # Valid values are: # # - DEFAULT_ACTION (default): MIG uses the same action # configured for instanceLifecyclePolicy.defaultActionOnFailure field. # - REPAIR: MIG automatically repairs an unhealthy VM by # recreating it. # - DO_NOTHING: MIG doesn't repair an unhealthy VM. # For more information, see # About repairing VMs in a MIG. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module OnFailedHealthCheck # A value indicating that the enum field is not set. UNDEFINED_ON_FAILED_HEALTH_CHECK = 0 # (Default) MIG uses the same action configured for # instanceLifecyclePolicy.defaultActionOnFailure field. DEFAULT_ACTION = 463_967_764 end end |
#on_failed_health_check ⇒ ::String
Returns The action that a MIG performs on an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are:
- DEFAULT_ACTION (default): MIG uses the same action
configured for instanceLifecyclePolicy.defaultActionOnFailure field.
- REPAIR: MIG automatically repairs an unhealthy VM by
recreating it.
- DO_NOTHING: MIG doesn't repair an unhealthy VM.
For more information, see
About repairing VMs in a MIG.
Check the OnFailedHealthCheck enum for the list of possible values.
33939 33940 33941 33942 33943 33944 33945 33946 33947 33948 33949 33950 33951 33952 33953 33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 33982 33983 33984 33985 33986 33987 33988 33989 33990 33991 33992 33993 33994 33995 33996 33997 33998 33999 34000 34001 34002 34003 34004 34005 34006 34007 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33939 class InstanceGroupManagerInstanceLifecyclePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The action that a MIG performs on a failed VM. If the value of the # onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action also # applies to the VMs on which your application fails a health check. # Valid values are # # - REPAIR (default): MIG automatically repairs a failed VM # by recreating it. For more information, see About # repairing VMs in a MIG. # - DO_NOTHING: MIG does not repair a failed VM. module DefaultActionOnFailure # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0 # MIG does not repair a failed VM. DO_NOTHING = 451_307_513 # (default): MIG automatically repairs a failed VM by recreating it. # For more information, see About # repairing VMs in a MIG. REPAIR = 266_277_773 end # A bit indicating whether to forcefully apply the group's latest # configuration when repairing a VM. Valid options are: # # # # - NO (default): If configuration updates are available, they are not # forcefully applied during repair. Instead, configuration updates are # applied according to the group's update policy. # # - YES: If configuration updates are available, they are applied # during repair. module ForceUpdateOnRepair # A value indicating that the enum field is not set. UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0 NO = 2497 YES = 87_751 end # The action that a MIG performs on an unhealthy VM. A VM is marked as # unhealthy when the application running on that VM fails a health check. # Valid values are: # # - DEFAULT_ACTION (default): MIG uses the same action # configured for instanceLifecyclePolicy.defaultActionOnFailure field. # - REPAIR: MIG automatically repairs an unhealthy VM by # recreating it. # - DO_NOTHING: MIG doesn't repair an unhealthy VM. # For more information, see # About repairing VMs in a MIG. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module OnFailedHealthCheck # A value indicating that the enum field is not set. UNDEFINED_ON_FAILED_HEALTH_CHECK = 0 # (Default) MIG uses the same action configured for # instanceLifecyclePolicy.defaultActionOnFailure field. DEFAULT_ACTION = 463_967_764 end end |
#on_repair ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicyOnRepair
Returns Configuration for VM repairs in the MIG.
33939 33940 33941 33942 33943 33944 33945 33946 33947 33948 33949 33950 33951 33952 33953 33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 33982 33983 33984 33985 33986 33987 33988 33989 33990 33991 33992 33993 33994 33995 33996 33997 33998 33999 34000 34001 34002 34003 34004 34005 34006 34007 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33939 class InstanceGroupManagerInstanceLifecyclePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The action that a MIG performs on a failed VM. If the value of the # onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action also # applies to the VMs on which your application fails a health check. # Valid values are # # - REPAIR (default): MIG automatically repairs a failed VM # by recreating it. For more information, see About # repairing VMs in a MIG. # - DO_NOTHING: MIG does not repair a failed VM. module DefaultActionOnFailure # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_ACTION_ON_FAILURE = 0 # MIG does not repair a failed VM. DO_NOTHING = 451_307_513 # (default): MIG automatically repairs a failed VM by recreating it. # For more information, see About # repairing VMs in a MIG. REPAIR = 266_277_773 end # A bit indicating whether to forcefully apply the group's latest # configuration when repairing a VM. Valid options are: # # # # - NO (default): If configuration updates are available, they are not # forcefully applied during repair. Instead, configuration updates are # applied according to the group's update policy. # # - YES: If configuration updates are available, they are applied # during repair. module ForceUpdateOnRepair # A value indicating that the enum field is not set. UNDEFINED_FORCE_UPDATE_ON_REPAIR = 0 NO = 2497 YES = 87_751 end # The action that a MIG performs on an unhealthy VM. A VM is marked as # unhealthy when the application running on that VM fails a health check. # Valid values are: # # - DEFAULT_ACTION (default): MIG uses the same action # configured for instanceLifecyclePolicy.defaultActionOnFailure field. # - REPAIR: MIG automatically repairs an unhealthy VM by # recreating it. # - DO_NOTHING: MIG doesn't repair an unhealthy VM. # For more information, see # About repairing VMs in a MIG. # Additional supported values which may be not listed in the enum directly due to technical reasons: # DO_NOTHING # REPAIR module OnFailedHealthCheck # A value indicating that the enum field is not set. UNDEFINED_ON_FAILED_HEALTH_CHECK = 0 # (Default) MIG uses the same action configured for # instanceLifecyclePolicy.defaultActionOnFailure field. DEFAULT_ACTION = 463_967_764 end end |