Module: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicy::DefaultActionOnFailure
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The action that a MIG performs on a failed or an unhealthy VM. A VM is marked as unhealthy when the application running on that VM fails a health check. Valid values are
- REPAIR (default): MIG automatically repairs a failed or an unhealthy VM by recreating it. For more information, see About repairing VMs in a MIG.
- DO_NOTHING: MIG does not repair a failed or an unhealthy VM. Additional supported values which may be not listed in the enum directly due to technical reasons: DO_NOTHING REPAIR
Constant Summary collapse
- UNDEFINED_DEFAULT_ACTION_ON_FAILURE =
A value indicating that the enum field is not set.
0- DO_NOTHING =
451_307_513- REPAIR =
266_277_773