Class: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicyOnRepair

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Configuration for VM repairs in the MIG.

Defined Under Namespace

Modules: AllowChangingZone

Instance Attribute Summary collapse

Instance Attribute Details

#allow_changing_zone::String

Returns Specifies whether the MIG can change a VM's zone during a repair. Valid values are:

  • NO (default): MIG cannot change a VM's zone during a repair.
  • YES: MIG can select a different zone for the VM during a repair. Check the AllowChangingZone enum for the list of possible values.

Returns:

  • (::String)

    Specifies whether the MIG can change a VM's zone during a repair. Valid values are:

    • NO (default): MIG cannot change a VM's zone during a repair.
    • YES: MIG can select a different zone for the VM during a repair. Check the AllowChangingZone enum for the list of possible values.


32931
32932
32933
32934
32935
32936
32937
32938
32939
32940
32941
32942
32943
32944
32945
32946
32947
32948
32949
32950
32951
32952
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32931

class InstanceGroupManagerInstanceLifecyclePolicyOnRepair
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies whether the MIG can change a VM's zone during a repair.
  # Valid values are:
  #
  #    - NO (default): MIG cannot change a VM's zone during a
  #    repair.
  #    - YES: MIG can select a different zone for the VM during
  #    a repair.
  module AllowChangingZone
    # A value indicating that the enum field is not set.
    UNDEFINED_ALLOW_CHANGING_ZONE = 0

    # [Default] MIG cannot change a VM's zone during a repair.
    NO = 2497

    # MIG can select a different zone for the VM during a repair.
    YES = 87_751
  end
end