Class: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicyOnRepair
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicyOnRepair
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configuration for VM repairs in the MIG.
Defined Under Namespace
Modules: AllowChangingZone
Instance Attribute Summary collapse
-
#allow_changing_zone ⇒ ::String
Specifies whether the MIG can change a VM's zone during a repair.
Instance Attribute Details
#allow_changing_zone ⇒ ::String
Returns Specifies whether the MIG can change a VM's zone during a repair. Valid values are:
- NO (default): MIG cannot change a VM's zone during a
repair.
- YES: MIG can select a different zone for the VM during
a repair.
Check the AllowChangingZone enum for the list of possible values.
34020 34021 34022 34023 34024 34025 34026 34027 34028 34029 34030 34031 34032 34033 34034 34035 34036 34037 34038 34039 34040 34041 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34020 class InstanceGroupManagerInstanceLifecyclePolicyOnRepair include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies whether the MIG can change a VM's zone during a repair. # Valid values are: # # - NO (default): MIG cannot change a VM's zone during a # repair. # - YES: MIG can select a different zone for the VM during # a repair. module AllowChangingZone # A value indicating that the enum field is not set. UNDEFINED_ALLOW_CHANGING_ZONE = 0 # [Default] MIG cannot change a VM's zone during a repair. NO = 2497 # MIG can select a different zone for the VM during a repair. YES = 87_751 end end |