Module: Google::Cloud::Compute::V1::InstanceGroupManagerInstanceLifecyclePolicyOnRepair::AllowChangingZone
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies whether the MIG can change a VM's zone during a repair. Valid values are:
- NO (default): MIG cannot change a VM's zone during a repair.
- YES: MIG can select a different zone for the VM during a repair.
Constant Summary collapse
- UNDEFINED_ALLOW_CHANGING_ZONE =
A value indicating that the enum field is not set.
0- NO =
[Default] MIG cannot change a VM's zone during a repair.
2497- YES =
MIG can select a different zone for the VM during a repair.
87_751