Class: Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns Output only. The creation timestamp for this resize request inRFC3339 text format.

Returns:

  • (::String)

    Output only. The creation timestamp for this resize request inRFC3339 text format.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#description::String

Returns An optional description of this resource.

Returns:

  • (::String)

    An optional description of this resource.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#id::Integer

Returns Output only. A unique identifier for this resource type. The server generates this identifier.

Returns:

  • (::Integer)

    Output only. A unique identifier for this resource type. The server generates this identifier.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#kind::String

Returns Output only. The resource type, which is alwayscompute#instanceGroupManagerResizeRequest for resize requests.

Returns:

  • (::String)

    Output only. The resource type, which is alwayscompute#instanceGroupManagerResizeRequest for resize requests.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#name::String

Returns The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035.

Returns:

  • (::String)

    The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#region::String

Returns Output only. The URL of a region where the resize request is located. Populated only for regional resize requests.

Returns:

  • (::String)

    Output only. The URL of a region where the resize request is located. Populated only for regional resize requests.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#requested_run_duration::Google::Cloud::Compute::V1::Duration

Returns Requested run duration for instances that will be created by this request. At the end of the run duration instance will be deleted.

Returns:



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#resize_by::Integer

Returns The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'.

Returns:

  • (::Integer)

    The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

Returns Output only. The URL for this resize request. The server defines this URL.

Returns:

  • (::String)

    Output only. The URL for this resize request. The server defines this URL.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

Returns Output only. Server-defined URL for this resource with the resource id.

Returns:

  • (::String)

    Output only. Server-defined URL for this resource with the resource id.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#state::String

Returns Output only. Current state of the request. Check the State enum for the list of possible values.

Returns:

  • (::String)

    Output only. Current state of the request. Check the State enum for the list of possible values.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#status::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatus

Returns Output only. Status of the request.

Returns:



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#zone::String

Returns Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests.

Returns:

  • (::String)

    Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests.



32003
32004
32005
32006
32007
32008
32009
32010
32011
32012
32013
32014
32015
32016
32017
32018
32019
32020
32021
32022
32023
32024
32025
32026
32027
32028
32029
32030
32031
32032
32033
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32003

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning
    # when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails
    # during provisioning, any VMs that were created during provisioning are
    # rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end