Class: Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
[Output Only] The creation timestamp for this resize request in RFC3339 text format.
-
#description ⇒ ::String
An optional description of this resource.
-
#id ⇒ ::Integer
[Output Only] A unique identifier for this resource type.
-
#kind ⇒ ::String
[Output Only] The resource type, which is always compute#instanceGroupManagerResizeRequest for resize requests.
-
#name ⇒ ::String
The name of this resize request.
-
#requested_run_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Requested run duration for instances that will be created by this request.
-
#resize_by ⇒ ::Integer
The number of instances to be created by this resize request.
-
#self_link ⇒ ::String
[Output Only] The URL for this resize request.
-
#self_link_with_id ⇒ ::String
[Output Only] Server-defined URL for this resource with the resource id.
-
#state ⇒ ::String
[Output only] Current state of the request.
-
#status ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatus
[Output only] Status of the request.
-
#zone ⇒ ::String
[Output Only] The URL of a zone where the resize request is located.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns [Output Only] The creation timestamp for this resize request in RFC3339 text format.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#description ⇒ ::String
Returns An optional description of this resource.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#id ⇒ ::Integer
Returns [Output Only] A unique identifier for this resource type. The server generates this identifier.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#kind ⇒ ::String
Returns [Output Only] The resource type, which is always compute#instanceGroupManagerResizeRequest for resize requests.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#name ⇒ ::String
Returns The name of this resize request. The name must be 1-63 characters long, and comply with RFC1035.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#requested_run_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Returns Requested run duration for instances that will be created by this request. At the end of the run duration instance will be deleted.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#resize_by ⇒ ::Integer
Returns The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#self_link ⇒ ::String
Returns [Output Only] The URL for this resize request. The server defines this URL.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#self_link_with_id ⇒ ::String
Returns [Output Only] Server-defined URL for this resource with the resource id.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#state ⇒ ::String
Returns [Output only] Current state of the request. Check the State enum for the list of possible values.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#status ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatus
Returns [Output only] Status of the request.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#zone ⇒ ::String
Returns [Output Only] The URL of a zone where the resize request is located. Populated only for zonal resize requests.
14457 14458 14459 14460 14461 14462 14463 14464 14465 14466 14467 14468 14469 14470 14471 14472 14473 14474 14475 14476 14477 14478 14479 14480 14481 14482 14483 14484 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14457 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output only] Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |