Class: Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns [Output Only] The creation timestamp for this resize request in RFC3339 text format.

Returns:

  • (::String)

    [Output Only] The creation timestamp for this resize request in RFC3339 text format.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#description::String

Returns An optional description of this resource.

Returns:

  • (::String)

    An optional description of this resource.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#id::Integer

Returns [Output Only] A unique identifier for this resource type. The server generates this identifier.

Returns:

  • (::Integer)

    [Output Only] A unique identifier for this resource type. The server generates this identifier.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#kind::String

Returns [Output Only] The resource type, which is always compute#instanceGroupManagerResizeRequest for resize requests.

Returns:

  • (::String)

    [Output Only] The resource type, which is always compute#instanceGroupManagerResizeRequest for resize requests.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#name::String

Returns The name of this resize request. The name must be 1-63 characters long, and comply with RFC1035.

Returns:

  • (::String)

    The name of this resize request. The name must be 1-63 characters long, and comply with RFC1035.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#requested_run_duration::Google::Cloud::Compute::V1::Duration

Returns Requested run duration for instances that will be created by this request. At the end of the run duration instance will be deleted.

Returns:



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#resize_by::Integer

Returns The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'.

Returns:

  • (::Integer)

    The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

Returns [Output Only] The URL for this resize request. The server defines this URL.

Returns:

  • (::String)

    [Output Only] The URL for this resize request. The server defines this URL.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

Returns [Output Only] Server-defined URL for this resource with the resource id.

Returns:

  • (::String)

    [Output Only] Server-defined URL for this resource with the resource id.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#state::String

Returns [Output only] Current state of the request. Check the State enum for the list of possible values.

Returns:

  • (::String)

    [Output only] Current state of the request. Check the State enum for the list of possible values.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#status::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatus

Returns [Output only] Status of the request.

Returns:



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end

#zone::String

Returns [Output Only] The URL of a zone where the resize request is located. Populated only for zonal resize requests.

Returns:

  • (::String)

    [Output Only] The URL of a zone where the resize request is located. Populated only for zonal resize requests.



14375
14376
14377
14378
14379
14380
14381
14382
14383
14384
14385
14386
14387
14388
14389
14390
14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14375

class InstanceGroupManagerResizeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output only] Current state of the request.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The request was created successfully and was accepted for provisioning when the capacity becomes available.
    ACCEPTED = 246_714_279

    # The request is cancelled.
    CANCELLED = 41_957_681

    # Resize request is being created and may still fail creation.
    CREATING = 455_564_985

    # The request failed before or during provisioning. If the request fails during provisioning, any VMs that were created during provisioning are rolled back and removed from the MIG.
    FAILED = 455_706_685

    # Default value. This value should never be returned.
    STATE_UNSPECIFIED = 470_755_401

    # The request succeeded.
    SUCCEEDED = 511_103_553
  end
end