Class: Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#id ⇒ ::Integer
Output only.
-
#instances ⇒ ::Array<::Google::Cloud::Compute::V1::PerInstanceConfig>
The names of instances to be created by this resize request.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
The name of this resize request.
-
#region ⇒ ::String
Output only.
-
#requested_run_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Requested run duration for instances that will be created by this request.
-
#resize_by ⇒ ::Integer
The number of instances to be created by this resize request.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#state ⇒ ::String
Output only.
-
#status ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatus
Output only.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. The creation timestamp for this resize request inRFC3339 text format.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#description ⇒ ::String
Returns An optional description of this resource.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#id ⇒ ::Integer
Returns Output only. A unique identifier for this resource type. The server generates this identifier.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#instances ⇒ ::Array<::Google::Cloud::Compute::V1::PerInstanceConfig>
Returns The names of instances to be created by this resize request. The number of names specified determines the number of instances to create. The group's target size will be increased by this number. This field cannot be used together with 'resize_by'.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#kind ⇒ ::String
Returns Output only. The resource type, which is alwayscompute#instanceGroupManagerResizeRequest for resize requests.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#name ⇒ ::String
Returns The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#region ⇒ ::String
Returns Output only. The URL of a region where the resize request is located. Populated only for regional resize requests.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#requested_run_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Returns Requested run duration for instances that will be created by this request. At the end of the run duration instance will be deleted.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#resize_by ⇒ ::Integer
Returns The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#self_link ⇒ ::String
Returns Output only. The URL for this resize request. The server defines this URL.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#self_link_with_id ⇒ ::String
Returns Output only. Server-defined URL for this resource with the resource id.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#state ⇒ ::String
Returns Output only. Current state of the request. Check the State enum for the list of possible values.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#status ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerResizeRequestStatus
Returns Output only. Status of the request.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |
#zone ⇒ ::String
Returns Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests.
34133 34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34133 class InstanceGroupManagerResizeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Current state of the request. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The request was created successfully and was accepted for provisioning # when the capacity becomes available. ACCEPTED = 246_714_279 # The request is cancelled. CANCELLED = 41_957_681 # Resize request is being created and may still fail creation. CREATING = 455_564_985 # The request failed before or during provisioning. If the request fails # during provisioning, any VMs that were created during provisioning are # rolled back and removed from the MIG. FAILED = 455_706_685 # Default value. This value should never be returned. STATE_UNSPECIFIED = 470_755_401 # The request succeeded. SUCCEEDED = 511_103_553 end end |