Class: Google::Cloud::Compute::V1::InstanceGroupManagerStandbyPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerStandbyPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#initial_delay_sec ⇒ ::Integer
Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created.
-
#mode ⇒ ::String
Defines how a MIG resumes or starts VMs from a standby pool when the group scales out.
Instance Attribute Details
#initial_delay_sec ⇒ ::Integer
Returns Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created. The initial delay gives the initialization script the time to prepare your VM for a quick scale out. The value of initial delay must be between 0 and 3600 seconds. The default value is 0.
32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 32132 32133 32134 32135 32136 32137 32138 32139 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32121 class InstanceGroupManagerStandbyPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines how a MIG resumes or starts VMs from a standby pool when the # group scales out. The default mode is `MANUAL`. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # MIG does not automatically resume or start VMs in the standby pool when # the group scales out. MANUAL = 119_397_318 # MIG automatically resumes or starts VMs in the standby pool when the # group scales out, and replenishes the standby pool afterwards. SCALE_OUT_POOL = 635_394 end end |
#mode ⇒ ::String
Returns Defines how a MIG resumes or starts VMs from a standby pool when the
group scales out. The default mode is MANUAL.
Check the Mode enum for the list of possible values.
32121 32122 32123 32124 32125 32126 32127 32128 32129 32130 32131 32132 32133 32134 32135 32136 32137 32138 32139 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32121 class InstanceGroupManagerStandbyPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines how a MIG resumes or starts VMs from a standby pool when the # group scales out. The default mode is `MANUAL`. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # MIG does not automatically resume or start VMs in the standby pool when # the group scales out. MANUAL = 119_397_318 # MIG automatically resumes or starts VMs in the standby pool when the # group scales out, and replenishes the standby pool afterwards. SCALE_OUT_POOL = 635_394 end end |