Class: Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopology
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopology
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#accelerator_topology ⇒ ::String
Output only.
-
#state ⇒ ::String
Output only.
-
#state_details ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails
Output only.
Instance Attribute Details
#accelerator_topology ⇒ ::String
Returns Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.
33233 33234 33235 33236 33237 33238 33239 33240 33241 33242 33243 33244 33245 33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 33259 33260 33261 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33233 class InstanceGroupManagerStatusAcceleratorTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The state of the accelerator topology. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The accelerator topology is being activated. ACTIVATING = 378_825_968 # The accelerator topology is active. ACTIVE = 314_733_318 # The accelerator topology is being deactivated. DEACTIVATING = 57_182_257 # The accelerator topology failed. FAILED = 455_706_685 # The configuration is incomplete and the accelerator topology cannot # be activated due to insufficient number of running VMs. INCOMPLETE = 11_941_214 # The accelerator topology is being reactivated. REACTIVATING = 253_727_587 end end |
#state ⇒ ::String
Returns Output only. The state of the accelerator topology. Check the State enum for the list of possible values.
33233 33234 33235 33236 33237 33238 33239 33240 33241 33242 33243 33244 33245 33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 33259 33260 33261 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33233 class InstanceGroupManagerStatusAcceleratorTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The state of the accelerator topology. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The accelerator topology is being activated. ACTIVATING = 378_825_968 # The accelerator topology is active. ACTIVE = 314_733_318 # The accelerator topology is being deactivated. DEACTIVATING = 57_182_257 # The accelerator topology failed. FAILED = 455_706_685 # The configuration is incomplete and the accelerator topology cannot # be activated due to insufficient number of running VMs. INCOMPLETE = 11_941_214 # The accelerator topology is being reactivated. REACTIVATING = 253_727_587 end end |
#state_details ⇒ ::Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails
Returns Output only. The result of the latest accelerator topology state check.
33233 33234 33235 33236 33237 33238 33239 33240 33241 33242 33243 33244 33245 33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 33259 33260 33261 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33233 class InstanceGroupManagerStatusAcceleratorTopology include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The state of the accelerator topology. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The accelerator topology is being activated. ACTIVATING = 378_825_968 # The accelerator topology is active. ACTIVE = 314_733_318 # The accelerator topology is being deactivated. DEACTIVATING = 57_182_257 # The accelerator topology failed. FAILED = 455_706_685 # The configuration is incomplete and the accelerator topology cannot # be activated due to insufficient number of running VMs. INCOMPLETE = 11_941_214 # The accelerator topology is being reactivated. REACTIVATING = 253_727_587 end end |