Class: Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#accelerator_topology::String

Returns Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.

Returns:

  • (::String)

    Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.



32914
32915
32916
32917
32918
32919
32920
32921
32922
32923
32924
32925
32926
32927
32928
32929
32930
32931
32932
32933
32934
32935
32936
32937
32938
32939
32940
32941
32942
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32914

class InstanceGroupManagerStatusAcceleratorTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is being activated.
    ACTIVATING = 378_825_968

    # The accelerator topology is active.
    ACTIVE = 314_733_318

    # The accelerator topology is being deactivated.
    DEACTIVATING = 57_182_257

    # The accelerator topology failed.
    FAILED = 455_706_685

    # The configuration is incomplete and the accelerator topology cannot
    # be activated due to insufficient number of running VMs.
    INCOMPLETE = 11_941_214

    # The accelerator topology is being reactivated.
    REACTIVATING = 253_727_587
  end
end

#state::String

Returns Output only. The state of the accelerator topology. Check the State enum for the list of possible values.

Returns:

  • (::String)

    Output only. The state of the accelerator topology. Check the State enum for the list of possible values.



32914
32915
32916
32917
32918
32919
32920
32921
32922
32923
32924
32925
32926
32927
32928
32929
32930
32931
32932
32933
32934
32935
32936
32937
32938
32939
32940
32941
32942
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32914

class InstanceGroupManagerStatusAcceleratorTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is being activated.
    ACTIVATING = 378_825_968

    # The accelerator topology is active.
    ACTIVE = 314_733_318

    # The accelerator topology is being deactivated.
    DEACTIVATING = 57_182_257

    # The accelerator topology failed.
    FAILED = 455_706_685

    # The configuration is incomplete and the accelerator topology cannot
    # be activated due to insufficient number of running VMs.
    INCOMPLETE = 11_941_214

    # The accelerator topology is being reactivated.
    REACTIVATING = 253_727_587
  end
end

#state_details::Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails

Returns Output only. The result of the latest accelerator topology state check.

Returns:



32914
32915
32916
32917
32918
32919
32920
32921
32922
32923
32924
32925
32926
32927
32928
32929
32930
32931
32932
32933
32934
32935
32936
32937
32938
32939
32940
32941
32942
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32914

class InstanceGroupManagerStatusAcceleratorTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is being activated.
    ACTIVATING = 378_825_968

    # The accelerator topology is active.
    ACTIVE = 314_733_318

    # The accelerator topology is being deactivated.
    DEACTIVATING = 57_182_257

    # The accelerator topology failed.
    FAILED = 455_706_685

    # The configuration is incomplete and the accelerator topology cannot
    # be activated due to insufficient number of running VMs.
    INCOMPLETE = 11_941_214

    # The accelerator topology is being reactivated.
    REACTIVATING = 253_727_587
  end
end