Class: Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#accelerator_topology::String

Returns Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.

Returns:

  • (::String)

    Output only. Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.



32193
32194
32195
32196
32197
32198
32199
32200
32201
32202
32203
32204
32205
32206
32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
32221
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32193

class InstanceGroupManagerStatusAcceleratorTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is being activated.
    ACTIVATING = 378_825_968

    # The accelerator topology is active.
    ACTIVE = 314_733_318

    # The accelerator topology is being deactivated.
    DEACTIVATING = 57_182_257

    # The accelerator topology failed.
    FAILED = 455_706_685

    # The configuration is incomplete and the accelerator topology cannot
    # be activated due to insufficient number of running VMs.
    INCOMPLETE = 11_941_214

    # The accelerator topology is being reactivated.
    REACTIVATING = 253_727_587
  end
end

#state::String

Returns Output only. The state of the accelerator topology. Check the State enum for the list of possible values.

Returns:

  • (::String)

    Output only. The state of the accelerator topology. Check the State enum for the list of possible values.



32193
32194
32195
32196
32197
32198
32199
32200
32201
32202
32203
32204
32205
32206
32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
32221
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32193

class InstanceGroupManagerStatusAcceleratorTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is being activated.
    ACTIVATING = 378_825_968

    # The accelerator topology is active.
    ACTIVE = 314_733_318

    # The accelerator topology is being deactivated.
    DEACTIVATING = 57_182_257

    # The accelerator topology failed.
    FAILED = 455_706_685

    # The configuration is incomplete and the accelerator topology cannot
    # be activated due to insufficient number of running VMs.
    INCOMPLETE = 11_941_214

    # The accelerator topology is being reactivated.
    REACTIVATING = 253_727_587
  end
end

#state_details::Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails

Returns Output only. The result of the latest accelerator topology state check.

Returns:



32193
32194
32195
32196
32197
32198
32199
32200
32201
32202
32203
32204
32205
32206
32207
32208
32209
32210
32211
32212
32213
32214
32215
32216
32217
32218
32219
32220
32221
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32193

class InstanceGroupManagerStatusAcceleratorTopology
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. The state of the accelerator topology.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The accelerator topology is being activated.
    ACTIVATING = 378_825_968

    # The accelerator topology is active.
    ACTIVE = 314_733_318

    # The accelerator topology is being deactivated.
    DEACTIVATING = 57_182_257

    # The accelerator topology failed.
    FAILED = 455_706_685

    # The configuration is incomplete and the accelerator topology cannot
    # be activated due to insufficient number of running VMs.
    INCOMPLETE = 11_941_214

    # The accelerator topology is being reactivated.
    REACTIVATING = 253_727_587
  end
end