Module: Google::Cloud::Compute::V1::InstanceGroupManagerStatusAcceleratorTopology::State
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Output only. The state of the accelerator topology.
Constant Summary collapse
- UNDEFINED_STATE =
A value indicating that the enum field is not set.
0- ACTIVATING =
The accelerator topology is being activated.
378_825_968- ACTIVE =
The accelerator topology is active.
314_733_318- DEACTIVATING =
The accelerator topology is being deactivated.
57_182_257- FAILED =
The accelerator topology failed.
455_706_685- INCOMPLETE =
The configuration is incomplete and the accelerator topology cannot be activated due to insufficient number of running VMs.
11_941_214- REACTIVATING =
The accelerator topology is being reactivated.
253_727_587