Class: Google::Cloud::Compute::V1::InstanceGroupManagerTargetSizePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Attribute Details

#mode::String

Returns The mode of target size policy based on which the MIG creates its VMs individually or all at once. Check the Mode enum for the list of possible values.

Returns:

  • (::String)

    The mode of target size policy based on which the MIG creates its VMs individually or all at once. Check the Mode enum for the list of possible values.



33423
33424
33425
33426
33427
33428
33429
33430
33431
33432
33433
33434
33435
33436
33437
33438
33439
33440
33441
33442
33443
33444
33445
33446
33447
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33423

class InstanceGroupManagerTargetSizePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The mode of target size policy based on which the MIG creates its VMs
  # individually or all at once.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The mode in which the MIG creates VMs all at once. In this mode, if the
    # MIG is unable to create even one VM, the MIG waits until all VMs can be
    # created at the same time.
    BULK = 2_050_322

    # The mode in which the MIG creates VMs individually. In this mode, if
    # the MIG is unable to create a VM, the MIG will continue to create the
    # other VMs in the group. This is the default mode.
    INDIVIDUAL = 438_800_025

    # If mode is unspecified, MIG will behave as in the default `INDIVIDUAL`
    # mode.
    UNSPECIFIED_MODE = 53_715_403
  end
end