Class: Google::Cloud::Compute::V1::InstanceGroupManagerTargetSizePolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerTargetSizePolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#mode ⇒ ::String
The mode of target size policy based on which the MIG creates its VMs individually or all at once.
Instance Attribute Details
#mode ⇒ ::String
Returns The mode of target size policy based on which the MIG creates its VMs individually or all at once. Check the Mode enum for the list of possible values.
32383 32384 32385 32386 32387 32388 32389 32390 32391 32392 32393 32394 32395 32396 32397 32398 32399 32400 32401 32402 32403 32404 32405 32406 32407 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32383 class InstanceGroupManagerTargetSizePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The mode of target size policy based on which the MIG creates its VMs # individually or all at once. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # The mode in which the MIG creates VMs all at once. In this mode, if the # MIG is unable to create even one VM, the MIG waits until all VMs can be # created at the same time. BULK = 2_050_322 # The mode in which the MIG creates VMs individually. In this mode, if # the MIG is unable to create a VM, the MIG will continue to create the # other VMs in the group. This is the default mode. INDIVIDUAL = 438_800_025 # If mode is unspecified, MIG will behave as in the default `INDIVIDUAL` # mode. UNSPECIFIED_MODE = 53_715_403 end end |