Module: Google::Cloud::Compute::V1::InstanceGroupManagerTargetSizePolicy::Mode
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The mode of target size policy based on which the MIG creates its VMs individually or all at once.
Constant Summary collapse
- UNDEFINED_MODE =
A value indicating that the enum field is not set.
0- BULK =
The mode in which the MIG creates VMs all at once. In this mode, if the MIG is unable to create even one VM, the MIG waits until all VMs can be created at the same time.
2_050_322- INDIVIDUAL =
The mode in which the MIG creates VMs individually. In this mode, if the MIG is unable to create a VM, the MIG will continue to create the other VMs in the group. This is the default mode.
438_800_025- UNSPECIFIED_MODE =
If mode is unspecified, MIG will behave as in the default
INDIVIDUALmode. 53_715_403