Class: Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: InstanceRedistributionType, MinimalAction, MostDisruptiveAllowedAction, ReplacementMethod, Type

Instance Attribute Summary collapse

Instance Attribute Details

#instance_redistribution_type::String

Returns The instance redistribution policy for regional managed instance groups. Valid values are:

  • PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region.
  • NONE: For non-autoscaled groups, proactive redistribution is disabled. Check the InstanceRedistributionType enum for the list of possible values.

Returns:

  • (::String)

    The instance redistribution policy for regional managed instance groups. Valid values are:

    • PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region.
    • NONE: For non-autoscaled groups, proactive redistribution is disabled. Check the InstanceRedistributionType enum for the list of possible values.


33211
33212
33213
33214
33215
33216
33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
33227
33228
33229
33230
33231
33232
33233
33234
33235
33236
33237
33238
33239
33240
33241
33242
33243
33244
33245
33246
33247
33248
33249
33250
33251
33252
33253
33254
33255
33256
33257
33258
33259
33260
33261
33262
33263
33264
33265
33266
33267
33268
33269
33270
33271
33272
33273
33274
33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
33297
33298
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33211

class InstanceGroupManagerUpdatePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The
  # instance redistribution policy for regional managed instance groups.
  # Valid values are:
  #
  #    - PROACTIVE (default): The group attempts to maintain an
  #    even distribution of VM instances across zones in the region.
  #    - NONE: For non-autoscaled groups, proactive
  #    redistribution is disabled.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # PROACTIVE
  module InstanceRedistributionType
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0
  end

  # Minimal action to be taken on an instance. Use this option to minimize
  # disruption as much as possible or to apply a more disruptive action than
  # is necessary.
  #
  #    - To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action,
  #    Compute Engine performs the necessary action to execute the update.
  #    - To apply a more disruptive action than is strictly necessary, set the
  #    minimal action to RESTART or REPLACE. For
  #    example, Compute Engine does not need to restart a VM to change its
  #    metadata. But if your application reads instance metadata only when a VM
  #    is restarted, you can set the minimal action to RESTART in
  #    order to pick up metadata changes.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Most disruptive action that is allowed to be taken on an instance.
  # You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption
  # as much as possible. RESTART to allow actions that can be
  # applied without instance replacing or REPLACE to allow all
  # possible actions. If the Updater determines that the minimal update
  # action needed is more disruptive than most disruptive allowed action you
  # specify it will not perform the update at all.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end

  # What action should be used to replace instances.
  # See minimal_action.REPLACE
  module ReplacementMethod
    # A value indicating that the enum field is not set.
    UNDEFINED_REPLACEMENT_METHOD = 0

    # Instances will be recreated (with the same name)
    RECREATE = 522_644_719

    # Default option: instances will be deleted and created (with a new name)
    SUBSTITUTE = 280_924_314
  end

  # The type
  # of update process. You can specify either PROACTIVE so
  # that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want
  # to update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # PROACTIVE
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG will apply new configurations
    # to existing VMs only when you selectively target specific or all VMs to
    # be updated.
    OPPORTUNISTIC = 429_530_089
  end
end

#max_surge::Google::Cloud::Compute::V1::FixedOrPercent

Returns The maximum number of instances that can be created above the specifiedtargetSize during the update process. This value can be either a fixed number or, if the group has 10 or more instances, a percentage. If you set a percentage, the number of instances is rounded if necessary. The default value for maxSurge is a fixed value equal to the number of zones in which the managed instance group operates.

At least one of either maxSurge ormaxUnavailable must be greater than 0. Learn more about maxSurge.

Returns:

  • (::Google::Cloud::Compute::V1::FixedOrPercent)

    The maximum number of instances that can be created above the specifiedtargetSize during the update process. This value can be either a fixed number or, if the group has 10 or more instances, a percentage. If you set a percentage, the number of instances is rounded if necessary. The default value for maxSurge is a fixed value equal to the number of zones in which the managed instance group operates.

    At least one of either maxSurge ormaxUnavailable must be greater than 0. Learn more about maxSurge.



33211
33212
33213
33214
33215
33216
33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
33227
33228
33229
33230
33231
33232
33233
33234
33235
33236
33237
33238
33239
33240
33241
33242
33243
33244
33245
33246
33247
33248
33249
33250
33251
33252
33253
33254
33255
33256
33257
33258
33259
33260
33261
33262
33263
33264
33265
33266
33267
33268
33269
33270
33271
33272
33273
33274
33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
33297
33298
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33211

class InstanceGroupManagerUpdatePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The
  # instance redistribution policy for regional managed instance groups.
  # Valid values are:
  #
  #    - PROACTIVE (default): The group attempts to maintain an
  #    even distribution of VM instances across zones in the region.
  #    - NONE: For non-autoscaled groups, proactive
  #    redistribution is disabled.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # PROACTIVE
  module InstanceRedistributionType
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0
  end

  # Minimal action to be taken on an instance. Use this option to minimize
  # disruption as much as possible or to apply a more disruptive action than
  # is necessary.
  #
  #    - To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action,
  #    Compute Engine performs the necessary action to execute the update.
  #    - To apply a more disruptive action than is strictly necessary, set the
  #    minimal action to RESTART or REPLACE. For
  #    example, Compute Engine does not need to restart a VM to change its
  #    metadata. But if your application reads instance metadata only when a VM
  #    is restarted, you can set the minimal action to RESTART in
  #    order to pick up metadata changes.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Most disruptive action that is allowed to be taken on an instance.
  # You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption
  # as much as possible. RESTART to allow actions that can be
  # applied without instance replacing or REPLACE to allow all
  # possible actions. If the Updater determines that the minimal update
  # action needed is more disruptive than most disruptive allowed action you
  # specify it will not perform the update at all.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end

  # What action should be used to replace instances.
  # See minimal_action.REPLACE
  module ReplacementMethod
    # A value indicating that the enum field is not set.
    UNDEFINED_REPLACEMENT_METHOD = 0

    # Instances will be recreated (with the same name)
    RECREATE = 522_644_719

    # Default option: instances will be deleted and created (with a new name)
    SUBSTITUTE = 280_924_314
  end

  # The type
  # of update process. You can specify either PROACTIVE so
  # that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want
  # to update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # PROACTIVE
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG will apply new configurations
    # to existing VMs only when you selectively target specific or all VMs to
    # be updated.
    OPPORTUNISTIC = 429_530_089
  end
end

#max_unavailable::Google::Cloud::Compute::V1::FixedOrPercent

Returns The maximum number of instances that can be unavailable during the update process. An instance is considered available if all of the following conditions are satisfied:

 - The instance's status is
 RUNNING.
  • If there is a health check on the instance group, the instance's health check status must be HEALTHY at least once. If there is no health check on the group, then the instance only needs to have a status of RUNNING to be considered available.

This value can be either a fixed number or, if the group has 10 or more instances, a percentage. If you set a percentage, the number of instances is rounded if necessary. The default value formaxUnavailable is a fixed value equal to the number of zones in which the managed instance group operates.

At least one of either maxSurge ormaxUnavailable must be greater than 0. Learn more about maxUnavailable.

Returns:

  • (::Google::Cloud::Compute::V1::FixedOrPercent)

    The maximum number of instances that can be unavailable during the update process. An instance is considered available if all of the following conditions are satisfied:

     - The instance's status is
     RUNNING.
    
    • If there is a health check on the instance group, the instance's health check status must be HEALTHY at least once. If there is no health check on the group, then the instance only needs to have a status of RUNNING to be considered available.

    This value can be either a fixed number or, if the group has 10 or more instances, a percentage. If you set a percentage, the number of instances is rounded if necessary. The default value formaxUnavailable is a fixed value equal to the number of zones in which the managed instance group operates.

    At least one of either maxSurge ormaxUnavailable must be greater than 0. Learn more about maxUnavailable.



33211
33212
33213
33214
33215
33216
33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
33227
33228
33229
33230
33231
33232
33233
33234
33235
33236
33237
33238
33239
33240
33241
33242
33243
33244
33245
33246
33247
33248
33249
33250
33251
33252
33253
33254
33255
33256
33257
33258
33259
33260
33261
33262
33263
33264
33265
33266
33267
33268
33269
33270
33271
33272
33273
33274
33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
33297
33298
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33211

class InstanceGroupManagerUpdatePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The
  # instance redistribution policy for regional managed instance groups.
  # Valid values are:
  #
  #    - PROACTIVE (default): The group attempts to maintain an
  #    even distribution of VM instances across zones in the region.
  #    - NONE: For non-autoscaled groups, proactive
  #    redistribution is disabled.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # PROACTIVE
  module InstanceRedistributionType
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0
  end

  # Minimal action to be taken on an instance. Use this option to minimize
  # disruption as much as possible or to apply a more disruptive action than
  # is necessary.
  #
  #    - To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action,
  #    Compute Engine performs the necessary action to execute the update.
  #    - To apply a more disruptive action than is strictly necessary, set the
  #    minimal action to RESTART or REPLACE. For
  #    example, Compute Engine does not need to restart a VM to change its
  #    metadata. But if your application reads instance metadata only when a VM
  #    is restarted, you can set the minimal action to RESTART in
  #    order to pick up metadata changes.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Most disruptive action that is allowed to be taken on an instance.
  # You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption
  # as much as possible. RESTART to allow actions that can be
  # applied without instance replacing or REPLACE to allow all
  # possible actions. If the Updater determines that the minimal update
  # action needed is more disruptive than most disruptive allowed action you
  # specify it will not perform the update at all.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end

  # What action should be used to replace instances.
  # See minimal_action.REPLACE
  module ReplacementMethod
    # A value indicating that the enum field is not set.
    UNDEFINED_REPLACEMENT_METHOD = 0

    # Instances will be recreated (with the same name)
    RECREATE = 522_644_719

    # Default option: instances will be deleted and created (with a new name)
    SUBSTITUTE = 280_924_314
  end

  # The type
  # of update process. You can specify either PROACTIVE so
  # that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want
  # to update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # PROACTIVE
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG will apply new configurations
    # to existing VMs only when you selectively target specific or all VMs to
    # be updated.
    OPPORTUNISTIC = 429_530_089
  end
end

#minimal_action::String

Returns Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary.

  • To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update.
  • To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. Check the MinimalAction enum for the list of possible values.

Returns:

  • (::String)

    Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary.

    • To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update.
    • To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. Check the MinimalAction enum for the list of possible values.


33211
33212
33213
33214
33215
33216
33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
33227
33228
33229
33230
33231
33232
33233
33234
33235
33236
33237
33238
33239
33240
33241
33242
33243
33244
33245
33246
33247
33248
33249
33250
33251
33252
33253
33254
33255
33256
33257
33258
33259
33260
33261
33262
33263
33264
33265
33266
33267
33268
33269
33270
33271
33272
33273
33274
33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
33297
33298
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33211

class InstanceGroupManagerUpdatePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The
  # instance redistribution policy for regional managed instance groups.
  # Valid values are:
  #
  #    - PROACTIVE (default): The group attempts to maintain an
  #    even distribution of VM instances across zones in the region.
  #    - NONE: For non-autoscaled groups, proactive
  #    redistribution is disabled.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # PROACTIVE
  module InstanceRedistributionType
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0
  end

  # Minimal action to be taken on an instance. Use this option to minimize
  # disruption as much as possible or to apply a more disruptive action than
  # is necessary.
  #
  #    - To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action,
  #    Compute Engine performs the necessary action to execute the update.
  #    - To apply a more disruptive action than is strictly necessary, set the
  #    minimal action to RESTART or REPLACE. For
  #    example, Compute Engine does not need to restart a VM to change its
  #    metadata. But if your application reads instance metadata only when a VM
  #    is restarted, you can set the minimal action to RESTART in
  #    order to pick up metadata changes.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Most disruptive action that is allowed to be taken on an instance.
  # You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption
  # as much as possible. RESTART to allow actions that can be
  # applied without instance replacing or REPLACE to allow all
  # possible actions. If the Updater determines that the minimal update
  # action needed is more disruptive than most disruptive allowed action you
  # specify it will not perform the update at all.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end

  # What action should be used to replace instances.
  # See minimal_action.REPLACE
  module ReplacementMethod
    # A value indicating that the enum field is not set.
    UNDEFINED_REPLACEMENT_METHOD = 0

    # Instances will be recreated (with the same name)
    RECREATE = 522_644_719

    # Default option: instances will be deleted and created (with a new name)
    SUBSTITUTE = 280_924_314
  end

  # The type
  # of update process. You can specify either PROACTIVE so
  # that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want
  # to update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # PROACTIVE
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG will apply new configurations
    # to existing VMs only when you selectively target specific or all VMs to
    # be updated.
    OPPORTUNISTIC = 429_530_089
  end
end

#most_disruptive_allowed_action::String

Returns Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. Check the MostDisruptiveAllowedAction enum for the list of possible values.

Returns:

  • (::String)

    Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. Check the MostDisruptiveAllowedAction enum for the list of possible values.



33211
33212
33213
33214
33215
33216
33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
33227
33228
33229
33230
33231
33232
33233
33234
33235
33236
33237
33238
33239
33240
33241
33242
33243
33244
33245
33246
33247
33248
33249
33250
33251
33252
33253
33254
33255
33256
33257
33258
33259
33260
33261
33262
33263
33264
33265
33266
33267
33268
33269
33270
33271
33272
33273
33274
33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
33297
33298
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33211

class InstanceGroupManagerUpdatePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The
  # instance redistribution policy for regional managed instance groups.
  # Valid values are:
  #
  #    - PROACTIVE (default): The group attempts to maintain an
  #    even distribution of VM instances across zones in the region.
  #    - NONE: For non-autoscaled groups, proactive
  #    redistribution is disabled.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # PROACTIVE
  module InstanceRedistributionType
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0
  end

  # Minimal action to be taken on an instance. Use this option to minimize
  # disruption as much as possible or to apply a more disruptive action than
  # is necessary.
  #
  #    - To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action,
  #    Compute Engine performs the necessary action to execute the update.
  #    - To apply a more disruptive action than is strictly necessary, set the
  #    minimal action to RESTART or REPLACE. For
  #    example, Compute Engine does not need to restart a VM to change its
  #    metadata. But if your application reads instance metadata only when a VM
  #    is restarted, you can set the minimal action to RESTART in
  #    order to pick up metadata changes.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Most disruptive action that is allowed to be taken on an instance.
  # You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption
  # as much as possible. RESTART to allow actions that can be
  # applied without instance replacing or REPLACE to allow all
  # possible actions. If the Updater determines that the minimal update
  # action needed is more disruptive than most disruptive allowed action you
  # specify it will not perform the update at all.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end

  # What action should be used to replace instances.
  # See minimal_action.REPLACE
  module ReplacementMethod
    # A value indicating that the enum field is not set.
    UNDEFINED_REPLACEMENT_METHOD = 0

    # Instances will be recreated (with the same name)
    RECREATE = 522_644_719

    # Default option: instances will be deleted and created (with a new name)
    SUBSTITUTE = 280_924_314
  end

  # The type
  # of update process. You can specify either PROACTIVE so
  # that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want
  # to update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # PROACTIVE
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG will apply new configurations
    # to existing VMs only when you selectively target specific or all VMs to
    # be updated.
    OPPORTUNISTIC = 429_530_089
  end
end

#replacement_method::String

Returns What action should be used to replace instances. See minimal_action.REPLACE Check the ReplacementMethod enum for the list of possible values.

Returns:

  • (::String)

    What action should be used to replace instances. See minimal_action.REPLACE Check the ReplacementMethod enum for the list of possible values.



33211
33212
33213
33214
33215
33216
33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
33227
33228
33229
33230
33231
33232
33233
33234
33235
33236
33237
33238
33239
33240
33241
33242
33243
33244
33245
33246
33247
33248
33249
33250
33251
33252
33253
33254
33255
33256
33257
33258
33259
33260
33261
33262
33263
33264
33265
33266
33267
33268
33269
33270
33271
33272
33273
33274
33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
33297
33298
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33211

class InstanceGroupManagerUpdatePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The
  # instance redistribution policy for regional managed instance groups.
  # Valid values are:
  #
  #    - PROACTIVE (default): The group attempts to maintain an
  #    even distribution of VM instances across zones in the region.
  #    - NONE: For non-autoscaled groups, proactive
  #    redistribution is disabled.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # PROACTIVE
  module InstanceRedistributionType
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0
  end

  # Minimal action to be taken on an instance. Use this option to minimize
  # disruption as much as possible or to apply a more disruptive action than
  # is necessary.
  #
  #    - To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action,
  #    Compute Engine performs the necessary action to execute the update.
  #    - To apply a more disruptive action than is strictly necessary, set the
  #    minimal action to RESTART or REPLACE. For
  #    example, Compute Engine does not need to restart a VM to change its
  #    metadata. But if your application reads instance metadata only when a VM
  #    is restarted, you can set the minimal action to RESTART in
  #    order to pick up metadata changes.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Most disruptive action that is allowed to be taken on an instance.
  # You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption
  # as much as possible. RESTART to allow actions that can be
  # applied without instance replacing or REPLACE to allow all
  # possible actions. If the Updater determines that the minimal update
  # action needed is more disruptive than most disruptive allowed action you
  # specify it will not perform the update at all.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end

  # What action should be used to replace instances.
  # See minimal_action.REPLACE
  module ReplacementMethod
    # A value indicating that the enum field is not set.
    UNDEFINED_REPLACEMENT_METHOD = 0

    # Instances will be recreated (with the same name)
    RECREATE = 522_644_719

    # Default option: instances will be deleted and created (with a new name)
    SUBSTITUTE = 280_924_314
  end

  # The type
  # of update process. You can specify either PROACTIVE so
  # that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want
  # to update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # PROACTIVE
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG will apply new configurations
    # to existing VMs only when you selectively target specific or all VMs to
    # be updated.
    OPPORTUNISTIC = 429_530_089
  end
end

#type::String

Returns The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want to update. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want to update. Check the Type enum for the list of possible values.



33211
33212
33213
33214
33215
33216
33217
33218
33219
33220
33221
33222
33223
33224
33225
33226
33227
33228
33229
33230
33231
33232
33233
33234
33235
33236
33237
33238
33239
33240
33241
33242
33243
33244
33245
33246
33247
33248
33249
33250
33251
33252
33253
33254
33255
33256
33257
33258
33259
33260
33261
33262
33263
33264
33265
33266
33267
33268
33269
33270
33271
33272
33273
33274
33275
33276
33277
33278
33279
33280
33281
33282
33283
33284
33285
33286
33287
33288
33289
33290
33291
33292
33293
33294
33295
33296
33297
33298
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33211

class InstanceGroupManagerUpdatePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The
  # instance redistribution policy for regional managed instance groups.
  # Valid values are:
  #
  #    - PROACTIVE (default): The group attempts to maintain an
  #    even distribution of VM instances across zones in the region.
  #    - NONE: For non-autoscaled groups, proactive
  #    redistribution is disabled.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # PROACTIVE
  module InstanceRedistributionType
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0
  end

  # Minimal action to be taken on an instance. Use this option to minimize
  # disruption as much as possible or to apply a more disruptive action than
  # is necessary.
  #
  #    - To limit disruption as much as possible, set the minimal action toREFRESH. If your update requires a more disruptive action,
  #    Compute Engine performs the necessary action to execute the update.
  #    - To apply a more disruptive action than is strictly necessary, set the
  #    minimal action to RESTART or REPLACE. For
  #    example, Compute Engine does not need to restart a VM to change its
  #    metadata. But if your application reads instance metadata only when a VM
  #    is restarted, you can set the minimal action to RESTART in
  #    order to pick up metadata changes.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Most disruptive action that is allowed to be taken on an instance.
  # You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption
  # as much as possible. RESTART to allow actions that can be
  # applied without instance replacing or REPLACE to allow all
  # possible actions. If the Updater determines that the minimal update
  # action needed is more disruptive than most disruptive allowed action you
  # specify it will not perform the update at all.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end

  # What action should be used to replace instances.
  # See minimal_action.REPLACE
  module ReplacementMethod
    # A value indicating that the enum field is not set.
    UNDEFINED_REPLACEMENT_METHOD = 0

    # Instances will be recreated (with the same name)
    RECREATE = 522_644_719

    # Default option: instances will be deleted and created (with a new name)
    SUBSTITUTE = 280_924_314
  end

  # The type
  # of update process. You can specify either PROACTIVE so
  # that the MIG automatically updates VMs to the latest configurations orOPPORTUNISTIC so that you can select the VMs that you want
  # to update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # PROACTIVE
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG will apply new configurations
    # to existing VMs only when you selectively target specific or all VMs to
    # be updated.
    OPPORTUNISTIC = 429_530_089
  end
end