Class: Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: InstanceRedistributionType, MinimalAction, MostDisruptiveAllowedAction, ReplacementMethod, Type
Instance Attribute Summary collapse
-
#instance_redistribution_type ⇒ ::String
The instance redistribution policy for regional managed instance groups.
-
#max_surge ⇒ ::Google::Cloud::Compute::V1::FixedOrPercent
The maximum number of instances that can be created above the specified targetSize during the update process.
-
#max_unavailable ⇒ ::Google::Cloud::Compute::V1::FixedOrPercent
The maximum number of instances that can be unavailable during the update process.
-
#minimal_action ⇒ ::String
Minimal action to be taken on an instance.
-
#most_disruptive_allowed_action ⇒ ::String
Most disruptive action that is allowed to be taken on an instance.
-
#replacement_method ⇒ ::String
What action should be used to replace instances.
-
#type ⇒ ::String
The type of update process.
Instance Attribute Details
#instance_redistribution_type ⇒ ::String
14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 14683 14684 14685 14686 14687 14688 14689 14690 14691 14692 14693 14694 14695 14696 14697 14698 14699 14700 14701 14702 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14645 class InstanceGroupManagerUpdatePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # PROACTIVE module InstanceRedistributionType # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0 end # Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary. - To limit disruption as much as possible, set the minimal action to REFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update. - To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions, REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end # What action should be used to replace instances. See minimal_action.REPLACE module ReplacementMethod # A value indicating that the enum field is not set. UNDEFINED_REPLACEMENT_METHOD = 0 # Instances will be recreated (with the same name) RECREATE = 522_644_719 # Default option: instances will be deleted and created (with a new name) SUBSTITUTE = 280_924_314 end # The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations or OPPORTUNISTIC so that you can select the VMs that you want to update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # PROACTIVE module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG will apply new configurations to existing VMs only when you selectively target specific or all VMs to be updated. OPPORTUNISTIC = 429_530_089 end end |
#max_surge ⇒ ::Google::Cloud::Compute::V1::FixedOrPercent
14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 14683 14684 14685 14686 14687 14688 14689 14690 14691 14692 14693 14694 14695 14696 14697 14698 14699 14700 14701 14702 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14645 class InstanceGroupManagerUpdatePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # PROACTIVE module InstanceRedistributionType # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0 end # Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary. - To limit disruption as much as possible, set the minimal action to REFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update. - To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions, REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end # What action should be used to replace instances. See minimal_action.REPLACE module ReplacementMethod # A value indicating that the enum field is not set. UNDEFINED_REPLACEMENT_METHOD = 0 # Instances will be recreated (with the same name) RECREATE = 522_644_719 # Default option: instances will be deleted and created (with a new name) SUBSTITUTE = 280_924_314 end # The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations or OPPORTUNISTIC so that you can select the VMs that you want to update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # PROACTIVE module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG will apply new configurations to existing VMs only when you selectively target specific or all VMs to be updated. OPPORTUNISTIC = 429_530_089 end end |
#max_unavailable ⇒ ::Google::Cloud::Compute::V1::FixedOrPercent
14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 14683 14684 14685 14686 14687 14688 14689 14690 14691 14692 14693 14694 14695 14696 14697 14698 14699 14700 14701 14702 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14645 class InstanceGroupManagerUpdatePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # PROACTIVE module InstanceRedistributionType # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0 end # Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary. - To limit disruption as much as possible, set the minimal action to REFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update. - To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions, REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end # What action should be used to replace instances. See minimal_action.REPLACE module ReplacementMethod # A value indicating that the enum field is not set. UNDEFINED_REPLACEMENT_METHOD = 0 # Instances will be recreated (with the same name) RECREATE = 522_644_719 # Default option: instances will be deleted and created (with a new name) SUBSTITUTE = 280_924_314 end # The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations or OPPORTUNISTIC so that you can select the VMs that you want to update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # PROACTIVE module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG will apply new configurations to existing VMs only when you selectively target specific or all VMs to be updated. OPPORTUNISTIC = 429_530_089 end end |
#minimal_action ⇒ ::String
14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 14683 14684 14685 14686 14687 14688 14689 14690 14691 14692 14693 14694 14695 14696 14697 14698 14699 14700 14701 14702 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14645 class InstanceGroupManagerUpdatePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # PROACTIVE module InstanceRedistributionType # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0 end # Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary. - To limit disruption as much as possible, set the minimal action to REFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update. - To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions, REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end # What action should be used to replace instances. See minimal_action.REPLACE module ReplacementMethod # A value indicating that the enum field is not set. UNDEFINED_REPLACEMENT_METHOD = 0 # Instances will be recreated (with the same name) RECREATE = 522_644_719 # Default option: instances will be deleted and created (with a new name) SUBSTITUTE = 280_924_314 end # The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations or OPPORTUNISTIC so that you can select the VMs that you want to update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # PROACTIVE module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG will apply new configurations to existing VMs only when you selectively target specific or all VMs to be updated. OPPORTUNISTIC = 429_530_089 end end |
#most_disruptive_allowed_action ⇒ ::String
14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 14683 14684 14685 14686 14687 14688 14689 14690 14691 14692 14693 14694 14695 14696 14697 14698 14699 14700 14701 14702 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14645 class InstanceGroupManagerUpdatePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # PROACTIVE module InstanceRedistributionType # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0 end # Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary. - To limit disruption as much as possible, set the minimal action to REFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update. - To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions, REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end # What action should be used to replace instances. See minimal_action.REPLACE module ReplacementMethod # A value indicating that the enum field is not set. UNDEFINED_REPLACEMENT_METHOD = 0 # Instances will be recreated (with the same name) RECREATE = 522_644_719 # Default option: instances will be deleted and created (with a new name) SUBSTITUTE = 280_924_314 end # The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations or OPPORTUNISTIC so that you can select the VMs that you want to update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # PROACTIVE module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG will apply new configurations to existing VMs only when you selectively target specific or all VMs to be updated. OPPORTUNISTIC = 429_530_089 end end |
#replacement_method ⇒ ::String
14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 14683 14684 14685 14686 14687 14688 14689 14690 14691 14692 14693 14694 14695 14696 14697 14698 14699 14700 14701 14702 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14645 class InstanceGroupManagerUpdatePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # PROACTIVE module InstanceRedistributionType # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0 end # Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary. - To limit disruption as much as possible, set the minimal action to REFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update. - To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions, REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end # What action should be used to replace instances. See minimal_action.REPLACE module ReplacementMethod # A value indicating that the enum field is not set. UNDEFINED_REPLACEMENT_METHOD = 0 # Instances will be recreated (with the same name) RECREATE = 522_644_719 # Default option: instances will be deleted and created (with a new name) SUBSTITUTE = 280_924_314 end # The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations or OPPORTUNISTIC so that you can select the VMs that you want to update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # PROACTIVE module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG will apply new configurations to existing VMs only when you selectively target specific or all VMs to be updated. OPPORTUNISTIC = 429_530_089 end end |
#type ⇒ ::String
14645 14646 14647 14648 14649 14650 14651 14652 14653 14654 14655 14656 14657 14658 14659 14660 14661 14662 14663 14664 14665 14666 14667 14668 14669 14670 14671 14672 14673 14674 14675 14676 14677 14678 14679 14680 14681 14682 14683 14684 14685 14686 14687 14688 14689 14690 14691 14692 14693 14694 14695 14696 14697 14698 14699 14700 14701 14702 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14645 class InstanceGroupManagerUpdatePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # PROACTIVE module InstanceRedistributionType # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE = 0 end # Minimal action to be taken on an instance. Use this option to minimize disruption as much as possible or to apply a more disruptive action than is necessary. - To limit disruption as much as possible, set the minimal action to REFRESH. If your update requires a more disruptive action, Compute Engine performs the necessary action to execute the update. - To apply a more disruptive action than is strictly necessary, set the minimal action to RESTART or REPLACE. For example, Compute Engine does not need to restart a VM to change its metadata. But if your application reads instance metadata only when a VM is restarted, you can set the minimal action to RESTART in order to pick up metadata changes. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions, REFRESH to avoid restarting the VM and to limit disruption as much as possible. RESTART to allow actions that can be applied without instance replacing or REPLACE to allow all possible actions. If the Updater determines that the minimal update action needed is more disruptive than most disruptive allowed action you specify it will not perform the update at all. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end # What action should be used to replace instances. See minimal_action.REPLACE module ReplacementMethod # A value indicating that the enum field is not set. UNDEFINED_REPLACEMENT_METHOD = 0 # Instances will be recreated (with the same name) RECREATE = 522_644_719 # Default option: instances will be deleted and created (with a new name) SUBSTITUTE = 280_924_314 end # The type of update process. You can specify either PROACTIVE so that the MIG automatically updates VMs to the latest configurations or OPPORTUNISTIC so that you can select the VMs that you want to update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # PROACTIVE module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG will apply new configurations to existing VMs only when you selectively target specific or all VMs to be updated. OPPORTUNISTIC = 429_530_089 end end |