Module: Google::Cloud::Compute::V1::InstanceGroupManagerUpdatePolicy::InstanceRedistributionType
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The instance redistribution policy for regional managed instance groups. Valid values are: - PROACTIVE (default): The group attempts to maintain an even distribution of VM instances across zones in the region. - NONE: For non-autoscaled groups, proactive redistribution is disabled. Additional supported values which may be not listed in the enum directly due to technical reasons: NONE PROACTIVE
Constant Summary collapse
- UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE =
A value indicating that the enum field is not set.
0