Class: Google::Cloud::Compute::V1::InstanceGroupManagerVersion
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagerVersion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#instance_template ⇒ ::String
The URL of the instance template that is specified for this managed instance group.
-
#name ⇒ ::String
Name of the version.
-
#target_size ⇒ ::Google::Cloud::Compute::V1::FixedOrPercent
Specifies the intended number of instances to be created from theinstanceTemplate.
Instance Attribute Details
#instance_template ⇒ ::String
Returns The URL of the instance template that is specified for this managed
instance group. The group uses this template to create new instances in
the managed instance group until the targetSize for this version is
reached. The templates for existing instances in the group do not change
unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE; in those cases,
existing instances are updated until the targetSize for this version is
reached.
32609 32610 32611 32612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32609 class InstanceGroupManagerVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Name of the version. Unique among all versions in the scope of this managed instance group.
32609 32610 32611 32612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32609 class InstanceGroupManagerVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_size ⇒ ::Google::Cloud::Compute::V1::FixedOrPercent
Returns Specifies the intended number of instances to be created from theinstanceTemplate. The final number of instances created from the template will be equal to:
- If expressed as a fixed number, the minimum of either
targetSize.fixed or
instanceGroupManager.targetSize is used.
- if expressed as a percent, the targetSize
would be (targetSize.percent/100 *
InstanceGroupManager.targetSize) If there is a remainder, the
number is rounded.
If unset, this version will update any remaining instances not updated by another version. ReadStarting a canary update for more information.
32609 32610 32611 32612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32609 class InstanceGroupManagerVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |