Class: Google::Cloud::Compute::V1::InstanceGroupManagersApplyUpdatesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

InstanceGroupManagers.applyUpdatesToInstances

Defined Under Namespace

Modules: MinimalAction, MostDisruptiveAllowedAction

Instance Attribute Summary collapse

Instance Attribute Details

#all_instances::Boolean

Returns Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.

Returns:

  • (::Boolean)

    Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.



33711
33712
33713
33714
33715
33716
33717
33718
33719
33720
33721
33722
33723
33724
33725
33726
33727
33728
33729
33730
33731
33732
33733
33734
33735
33736
33737
33738
33739
33740
33741
33742
33743
33744
33745
33746
33747
33748
33749
33750
33751
33752
33753
33754
33755
33756
33757
33758
33759
33760
33761
33762
33763
33764
33765
33766
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33711

class InstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#instances::Array<::String>

Returns The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].

Returns:

  • (::Array<::String>)

    The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].



33711
33712
33713
33714
33715
33716
33717
33718
33719
33720
33721
33722
33723
33724
33725
33726
33727
33728
33729
33730
33731
33732
33733
33734
33735
33736
33737
33738
33739
33740
33741
33742
33743
33744
33745
33746
33747
33748
33749
33750
33751
33752
33753
33754
33755
33756
33757
33758
33759
33760
33761
33762
33763
33764
33765
33766
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33711

class InstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#minimal_action::String

Returns The minimal action that you want to perform on each instance during the update:

 - REPLACE: At minimum, delete the instance and create it
 again.
  • RESTART: Stop the instance and start it again.
  • REFRESH: Do not stop the instance and limit disruption as much as possible.
  • NONE: Do not disrupt the instance at all.

By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.

Returns:

  • (::String)

    The minimal action that you want to perform on each instance during the update:

     - REPLACE: At minimum, delete the instance and create it
     again.
    
    • RESTART: Stop the instance and start it again.
    • REFRESH: Do not stop the instance and limit disruption as much as possible.
    • NONE: Do not disrupt the instance at all.

    By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.



33711
33712
33713
33714
33715
33716
33717
33718
33719
33720
33721
33722
33723
33724
33725
33726
33727
33728
33729
33730
33731
33732
33733
33734
33735
33736
33737
33738
33739
33740
33741
33742
33743
33744
33745
33746
33747
33748
33749
33750
33751
33752
33753
33754
33755
33756
33757
33758
33759
33760
33761
33762
33763
33764
33765
33766
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33711

class InstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#most_disruptive_allowed_action::String

Returns The most disruptive action that you want to perform on each instance during the update:

 - REPLACE: Delete the instance and create it again.
 - RESTART: Stop the instance and start it again.
 - REFRESH: Do not stop the instance and limit disruption
 as much as possible.
  • NONE: Do not disrupt the instance at all.

By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.

Returns:

  • (::String)

    The most disruptive action that you want to perform on each instance during the update:

     - REPLACE: Delete the instance and create it again.
     - RESTART: Stop the instance and start it again.
     - REFRESH: Do not stop the instance and limit disruption
     as much as possible.
    
    • NONE: Do not disrupt the instance at all.

    By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.



33711
33712
33713
33714
33715
33716
33717
33718
33719
33720
33721
33722
33723
33724
33725
33726
33727
33728
33729
33730
33731
33732
33733
33734
33735
33736
33737
33738
33739
33740
33741
33742
33743
33744
33745
33746
33747
33748
33749
33750
33751
33752
33753
33754
33755
33756
33757
33758
33759
33760
33761
33762
33763
33764
33765
33766
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33711

class InstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end