Class: Google::Cloud::Compute::V1::InstanceGroupManagersApplyUpdatesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagersApplyUpdatesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
InstanceGroupManagers.applyUpdatesToInstances
Defined Under Namespace
Modules: MinimalAction, MostDisruptiveAllowedAction
Instance Attribute Summary collapse
-
#all_instances ⇒ ::Boolean
Flag to update all instances instead of specified list of “instances”.
-
#instances ⇒ ::Array<::String>
The list of URLs of one or more instances for which you want to apply updates.
-
#minimal_action ⇒ ::String
The minimal action that you want to perform on each instance during the update:.
-
#most_disruptive_allowed_action ⇒ ::String
The most disruptive action that you want to perform on each instance during the update:.
Instance Attribute Details
#all_instances ⇒ ::Boolean
Returns Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.
33392 33393 33394 33395 33396 33397 33398 33399 33400 33401 33402 33403 33404 33405 33406 33407 33408 33409 33410 33411 33412 33413 33414 33415 33416 33417 33418 33419 33420 33421 33422 33423 33424 33425 33426 33427 33428 33429 33430 33431 33432 33433 33434 33435 33436 33437 33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33392 class InstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#instances ⇒ ::Array<::String>
Returns The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].
33392 33393 33394 33395 33396 33397 33398 33399 33400 33401 33402 33403 33404 33405 33406 33407 33408 33409 33410 33411 33412 33413 33414 33415 33416 33417 33418 33419 33420 33421 33422 33423 33424 33425 33426 33427 33428 33429 33430 33431 33432 33433 33434 33435 33436 33437 33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33392 class InstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#minimal_action ⇒ ::String
Returns The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it
again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not disrupt the instance at all.
By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.
33392 33393 33394 33395 33396 33397 33398 33399 33400 33401 33402 33403 33404 33405 33406 33407 33408 33409 33410 33411 33412 33413 33414 33415 33416 33417 33418 33419 33420 33421 33422 33423 33424 33425 33426 33427 33428 33429 33430 33431 33432 33433 33434 33435 33436 33437 33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33392 class InstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#most_disruptive_allowed_action ⇒ ::String
Returns The most disruptive action that you want to perform on each instance during the update:
- REPLACE: Delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption
as much as possible.
- NONE: Do not disrupt the instance at all.
By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.
33392 33393 33394 33395 33396 33397 33398 33399 33400 33401 33402 33403 33404 33405 33406 33407 33408 33409 33410 33411 33412 33413 33414 33415 33416 33417 33418 33419 33420 33421 33422 33423 33424 33425 33426 33427 33428 33429 33430 33431 33432 33433 33434 33435 33436 33437 33438 33439 33440 33441 33442 33443 33444 33445 33446 33447 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33392 class InstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |