Class: Google::Cloud::Compute::V1::InstanceGroupManagersApplyUpdatesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

InstanceGroupManagers.applyUpdatesToInstances

Defined Under Namespace

Modules: MinimalAction, MostDisruptiveAllowedAction

Instance Attribute Summary collapse

Instance Attribute Details

#all_instances::Boolean

Returns Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.

Returns:

  • (::Boolean)

    Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.



32671
32672
32673
32674
32675
32676
32677
32678
32679
32680
32681
32682
32683
32684
32685
32686
32687
32688
32689
32690
32691
32692
32693
32694
32695
32696
32697
32698
32699
32700
32701
32702
32703
32704
32705
32706
32707
32708
32709
32710
32711
32712
32713
32714
32715
32716
32717
32718
32719
32720
32721
32722
32723
32724
32725
32726
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32671

class InstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#instances::Array<::String>

Returns The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].

Returns:

  • (::Array<::String>)

    The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].



32671
32672
32673
32674
32675
32676
32677
32678
32679
32680
32681
32682
32683
32684
32685
32686
32687
32688
32689
32690
32691
32692
32693
32694
32695
32696
32697
32698
32699
32700
32701
32702
32703
32704
32705
32706
32707
32708
32709
32710
32711
32712
32713
32714
32715
32716
32717
32718
32719
32720
32721
32722
32723
32724
32725
32726
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32671

class InstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#minimal_action::String

Returns The minimal action that you want to perform on each instance during the update:

 - REPLACE: At minimum, delete the instance and create it
 again.
  • RESTART: Stop the instance and start it again.
  • REFRESH: Do not stop the instance and limit disruption as much as possible.
  • NONE: Do not disrupt the instance at all.

By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.

Returns:

  • (::String)

    The minimal action that you want to perform on each instance during the update:

     - REPLACE: At minimum, delete the instance and create it
     again.
    
    • RESTART: Stop the instance and start it again.
    • REFRESH: Do not stop the instance and limit disruption as much as possible.
    • NONE: Do not disrupt the instance at all.

    By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.



32671
32672
32673
32674
32675
32676
32677
32678
32679
32680
32681
32682
32683
32684
32685
32686
32687
32688
32689
32690
32691
32692
32693
32694
32695
32696
32697
32698
32699
32700
32701
32702
32703
32704
32705
32706
32707
32708
32709
32710
32711
32712
32713
32714
32715
32716
32717
32718
32719
32720
32721
32722
32723
32724
32725
32726
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32671

class InstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#most_disruptive_allowed_action::String

Returns The most disruptive action that you want to perform on each instance during the update:

 - REPLACE: Delete the instance and create it again.
 - RESTART: Stop the instance and start it again.
 - REFRESH: Do not stop the instance and limit disruption
 as much as possible.
  • NONE: Do not disrupt the instance at all.

By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.

Returns:

  • (::String)

    The most disruptive action that you want to perform on each instance during the update:

     - REPLACE: Delete the instance and create it again.
     - RESTART: Stop the instance and start it again.
     - REFRESH: Do not stop the instance and limit disruption
     as much as possible.
    
    • NONE: Do not disrupt the instance at all.

    By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.



32671
32672
32673
32674
32675
32676
32677
32678
32679
32680
32681
32682
32683
32684
32685
32686
32687
32688
32689
32690
32691
32692
32693
32694
32695
32696
32697
32698
32699
32700
32701
32702
32703
32704
32705
32706
32707
32708
32709
32710
32711
32712
32713
32714
32715
32716
32717
32718
32719
32720
32721
32722
32723
32724
32725
32726
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32671

class InstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end