Class: Google::Cloud::Compute::V1::InstanceGroupManagersApplyUpdatesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagersApplyUpdatesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
InstanceGroupManagers.applyUpdatesToInstances
Defined Under Namespace
Modules: MinimalAction, MostDisruptiveAllowedAction
Instance Attribute Summary collapse
-
#all_instances ⇒ ::Boolean
Flag to update all instances instead of specified list of "instances".
-
#instances ⇒ ::Array<::String>
The list of URLs of one or more instances for which you want to apply updates.
-
#minimal_action ⇒ ::String
The minimal action that you want to perform on each instance during the update:.
-
#most_disruptive_allowed_action ⇒ ::String
The most disruptive action that you want to perform on each instance during the update:.
Instance Attribute Details
#all_instances ⇒ ::Boolean
Returns Flag to update all instances instead of specified list of "instances". If the flag is set to true then the instances may not be specified in the request.
34800 34801 34802 34803 34804 34805 34806 34807 34808 34809 34810 34811 34812 34813 34814 34815 34816 34817 34818 34819 34820 34821 34822 34823 34824 34825 34826 34827 34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 34842 34843 34844 34845 34846 34847 34848 34849 34850 34851 34852 34853 34854 34855 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34800 class InstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#instances ⇒ ::Array<::String>
Returns The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].
34800 34801 34802 34803 34804 34805 34806 34807 34808 34809 34810 34811 34812 34813 34814 34815 34816 34817 34818 34819 34820 34821 34822 34823 34824 34825 34826 34827 34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 34842 34843 34844 34845 34846 34847 34848 34849 34850 34851 34852 34853 34854 34855 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34800 class InstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#minimal_action ⇒ ::String
Returns The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it
again.
- RESTART: Stop the instance and start it
again.
- REFRESH: Do not stop the instance and limit
disruption as much as possible.
- NONE: Do not
disrupt the instance at all.
By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.
34800 34801 34802 34803 34804 34805 34806 34807 34808 34809 34810 34811 34812 34813 34814 34815 34816 34817 34818 34819 34820 34821 34822 34823 34824 34825 34826 34827 34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 34842 34843 34844 34845 34846 34847 34848 34849 34850 34851 34852 34853 34854 34855 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34800 class InstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#most_disruptive_allowed_action ⇒ ::String
Returns The most disruptive action that you want to perform on each instance during the update:
- REPLACE: Delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption
as much as possible.
- NONE: Do not disrupt the
instance at all.
By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.
34800 34801 34802 34803 34804 34805 34806 34807 34808 34809 34810 34811 34812 34813 34814 34815 34816 34817 34818 34819 34820 34821 34822 34823 34824 34825 34826 34827 34828 34829 34830 34831 34832 34833 34834 34835 34836 34837 34838 34839 34840 34841 34842 34843 34844 34845 34846 34847 34848 34849 34850 34851 34852 34853 34854 34855 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34800 class InstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |