Class: Google::Cloud::Compute::V1::InstanceGroupManagersSetInstanceTemplateRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupManagersSetInstanceTemplateRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#instance_template ⇒ ::String
The URL of the instance template that is specified for this managed instance group.
Instance Attribute Details
#instance_template ⇒ ::String
Returns The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, run applyUpdatesToInstances, or set the group's updatePolicy.type to PROACTIVE.
12768 12769 12770 12771 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 12768 class InstanceGroupManagersSetInstanceTemplateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |