Class: Google::Cloud::Compute::V1::InstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: InstanceState

Instance Attribute Summary collapse

Instance Attribute Details

#instance_state::String

Returns A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Check the InstanceState enum for the list of possible values.

Returns:

  • (::String)

    A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Check the InstanceState enum for the list of possible values.



34013
34014
34015
34016
34017
34018
34019
34020
34021
34022
34023
34024
34025
34026
34027
34028
34029
34030
34031
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34013

class InstanceGroupsListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A filter for the state of the instances in the instance group. Valid
  # options are ALL or RUNNING. If you do not specify
  # this parameter the list includes all instances regardless of their state.
  module InstanceState
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_STATE = 0

    # Includes all instances in the generated list regardless of their state.
    ALL = 64_897

    # Includes instances in the generated list only if they have a RUNNING
    # state.
    RUNNING = 121_282_975
  end
end