Class: Google::Cloud::Compute::V1::InstanceGroupsListInstancesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceGroupsListInstancesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: InstanceState
Instance Attribute Summary collapse
-
#instance_state ⇒ ::String
A filter for the state of the instances in the instance group.
Instance Attribute Details
#instance_state ⇒ ::String
Returns A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Check the InstanceState enum for the list of possible values.
33694 33695 33696 33697 33698 33699 33700 33701 33702 33703 33704 33705 33706 33707 33708 33709 33710 33711 33712 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33694 class InstanceGroupsListInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A filter for the state of the instances in the instance group. Valid # options are ALL or RUNNING. If you do not specify # this parameter the list includes all instances regardless of their state. module InstanceState # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_STATE = 0 # Includes all instances in the generated list regardless of their state. ALL = 64_897 # Includes instances in the generated list only if they have a RUNNING # state. RUNNING = 121_282_975 end end |