Class: Google::Cloud::Compute::V1::InstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: InstanceState

Instance Attribute Summary collapse

Instance Attribute Details

#instance_state::String

Returns A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Check the InstanceState enum for the list of possible values.

Returns:

  • (::String)

    A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Check the InstanceState enum for the list of possible values.



32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
32988
32989
32990
32991
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 32973

class InstanceGroupsListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A filter for the state of the instances in the instance group. Valid
  # options are ALL or RUNNING. If you do not specify
  # this parameter the list includes all instances regardless of their state.
  module InstanceState
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_STATE = 0

    # Includes all instances in the generated list regardless of their state.
    ALL = 64_897

    # Includes instances in the generated list only if they have a RUNNING
    # state.
    RUNNING = 121_282_975
  end
end