Class: Google::Cloud::Compute::V1::InstanceManagedByIgmError

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#error::Google::Cloud::Compute::V1::InstanceManagedByIgmErrorManagedInstanceError

Returns Output only. Contents of the error.

Returns:



34138
34139
34140
34141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34138

class InstanceManagedByIgmError
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_action_details::Google::Cloud::Compute::V1::InstanceManagedByIgmErrorInstanceActionDetails

Returns Output only. Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional.

Returns:



34138
34139
34140
34141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34138

class InstanceManagedByIgmError
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#timestamp::String

Returns Output only. The time that this error occurred. This value is in RFC3339 text format.

Returns:

  • (::String)

    Output only. The time that this error occurred. This value is in RFC3339 text format.



34138
34139
34140
34141
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34138

class InstanceManagedByIgmError
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end