Class: Google::Cloud::Compute::V1::InstanceManagedByIgmErrorInstanceActionDetails
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceManagedByIgmErrorInstanceActionDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Action
Instance Attribute Summary collapse
-
#action ⇒ ::String
Output only.
-
#instance ⇒ ::String
Output only.
-
#version ⇒ ::Google::Cloud::Compute::V1::ManagedInstanceVersion
Output only.
Instance Attribute Details
#action ⇒ ::String
Returns Output only. Action that managed instance group was executing on the instance when the error occurred. Possible values: Check the Action enum for the list of possible values.
34158 34159 34160 34161 34162 34163 34164 34165 34166 34167 34168 34169 34170 34171 34172 34173 34174 34175 34176 34177 34178 34179 34180 34181 34182 34183 34184 34185 34186 34187 34188 34189 34190 34191 34192 34193 34194 34195 34196 34197 34198 34199 34200 34201 34202 34203 34204 34205 34206 34207 34208 34209 34210 34211 34212 34213 34214 34215 34216 34217 34218 34219 34220 34221 34222 34223 34224 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34158 class InstanceManagedByIgmErrorInstanceActionDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Action that managed instance group was executing on the instance when the # error occurred. Possible values: module Action # A value indicating that the enum field is not set. UNDEFINED_ACTION = 0 # The managed instance group is abandoning this instance. The instance # will be removed from the instance group and from any target pools that # are associated with this group. ABANDONING = 388_244_813 # The managed instance group is creating this instance. If the group # fails to create this instance, it will try again until it is # successful. CREATING = 455_564_985 # The managed instance group is attempting to create this instance # only once. If the group fails to create this instance, it does # not try again and the group's targetSize value is # decreased. CREATING_WITHOUT_RETRIES = 428_843_785 # The managed instance group is permanently deleting this instance. DELETING = 528_602_024 # The managed instance group has not scheduled any actions for this # instance. NONE = 2_402_104 # The managed instance group is recreating this instance. RECREATING = 287_278_572 # The managed instance group is applying configuration changes to the # instance without stopping it. For example, the group can update the # target pool list for an instance without stopping that instance. REFRESHING = 163_266_343 # The managed instance group is restarting this instance. RESTARTING = 320_534_387 # The managed instance group is resuming this instance. RESUMING = 446_856_618 # The managed instance group is starting this instance. STARTING = 488_820_800 # The managed instance group is stopping this instance. STOPPING = 350_791_796 # The managed instance group is suspending this instance. SUSPENDING = 514_206_246 # The managed instance group is verifying this already created instance. # Verification happens every time the instance is (re)created or restarted # and consists of: # 1. Waiting until health check specified as part of this managed instance # group's autohealing policy reports HEALTHY. # Note: Applies only if autohealing policy has a health check specified # 2. Waiting for addition verification steps performed as post-instance # creation (subject to future extensions). VERIFYING = 16_982_185 end end |
#instance ⇒ ::String
Returns Output only. The URL of the instance. The URL can be set even if the instance has not yet been created.
34158 34159 34160 34161 34162 34163 34164 34165 34166 34167 34168 34169 34170 34171 34172 34173 34174 34175 34176 34177 34178 34179 34180 34181 34182 34183 34184 34185 34186 34187 34188 34189 34190 34191 34192 34193 34194 34195 34196 34197 34198 34199 34200 34201 34202 34203 34204 34205 34206 34207 34208 34209 34210 34211 34212 34213 34214 34215 34216 34217 34218 34219 34220 34221 34222 34223 34224 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34158 class InstanceManagedByIgmErrorInstanceActionDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Action that managed instance group was executing on the instance when the # error occurred. Possible values: module Action # A value indicating that the enum field is not set. UNDEFINED_ACTION = 0 # The managed instance group is abandoning this instance. The instance # will be removed from the instance group and from any target pools that # are associated with this group. ABANDONING = 388_244_813 # The managed instance group is creating this instance. If the group # fails to create this instance, it will try again until it is # successful. CREATING = 455_564_985 # The managed instance group is attempting to create this instance # only once. If the group fails to create this instance, it does # not try again and the group's targetSize value is # decreased. CREATING_WITHOUT_RETRIES = 428_843_785 # The managed instance group is permanently deleting this instance. DELETING = 528_602_024 # The managed instance group has not scheduled any actions for this # instance. NONE = 2_402_104 # The managed instance group is recreating this instance. RECREATING = 287_278_572 # The managed instance group is applying configuration changes to the # instance without stopping it. For example, the group can update the # target pool list for an instance without stopping that instance. REFRESHING = 163_266_343 # The managed instance group is restarting this instance. RESTARTING = 320_534_387 # The managed instance group is resuming this instance. RESUMING = 446_856_618 # The managed instance group is starting this instance. STARTING = 488_820_800 # The managed instance group is stopping this instance. STOPPING = 350_791_796 # The managed instance group is suspending this instance. SUSPENDING = 514_206_246 # The managed instance group is verifying this already created instance. # Verification happens every time the instance is (re)created or restarted # and consists of: # 1. Waiting until health check specified as part of this managed instance # group's autohealing policy reports HEALTHY. # Note: Applies only if autohealing policy has a health check specified # 2. Waiting for addition verification steps performed as post-instance # creation (subject to future extensions). VERIFYING = 16_982_185 end end |
#version ⇒ ::Google::Cloud::Compute::V1::ManagedInstanceVersion
Returns Output only. Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created.
34158 34159 34160 34161 34162 34163 34164 34165 34166 34167 34168 34169 34170 34171 34172 34173 34174 34175 34176 34177 34178 34179 34180 34181 34182 34183 34184 34185 34186 34187 34188 34189 34190 34191 34192 34193 34194 34195 34196 34197 34198 34199 34200 34201 34202 34203 34204 34205 34206 34207 34208 34209 34210 34211 34212 34213 34214 34215 34216 34217 34218 34219 34220 34221 34222 34223 34224 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34158 class InstanceManagedByIgmErrorInstanceActionDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Action that managed instance group was executing on the instance when the # error occurred. Possible values: module Action # A value indicating that the enum field is not set. UNDEFINED_ACTION = 0 # The managed instance group is abandoning this instance. The instance # will be removed from the instance group and from any target pools that # are associated with this group. ABANDONING = 388_244_813 # The managed instance group is creating this instance. If the group # fails to create this instance, it will try again until it is # successful. CREATING = 455_564_985 # The managed instance group is attempting to create this instance # only once. If the group fails to create this instance, it does # not try again and the group's targetSize value is # decreased. CREATING_WITHOUT_RETRIES = 428_843_785 # The managed instance group is permanently deleting this instance. DELETING = 528_602_024 # The managed instance group has not scheduled any actions for this # instance. NONE = 2_402_104 # The managed instance group is recreating this instance. RECREATING = 287_278_572 # The managed instance group is applying configuration changes to the # instance without stopping it. For example, the group can update the # target pool list for an instance without stopping that instance. REFRESHING = 163_266_343 # The managed instance group is restarting this instance. RESTARTING = 320_534_387 # The managed instance group is resuming this instance. RESUMING = 446_856_618 # The managed instance group is starting this instance. STARTING = 488_820_800 # The managed instance group is stopping this instance. STOPPING = 350_791_796 # The managed instance group is suspending this instance. SUSPENDING = 514_206_246 # The managed instance group is verifying this already created instance. # Verification happens every time the instance is (re)created or restarted # and consists of: # 1. Waiting until health check specified as part of this managed instance # group's autohealing policy reports HEALTHY. # Note: Applies only if autohealing policy has a health check specified # 2. Waiting for addition verification steps performed as post-instance # creation (subject to future extensions). VERIFYING = 16_982_185 end end |