Class: Google::Cloud::Compute::V1::InstanceManagedByIgmErrorInstanceActionDetails
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceManagedByIgmErrorInstanceActionDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Action
Instance Attribute Summary collapse
-
#action ⇒ ::String
Output only.
-
#instance ⇒ ::String
Output only.
-
#version ⇒ ::Google::Cloud::Compute::V1::ManagedInstanceVersion
Output only.
Instance Attribute Details
#action ⇒ ::String
Returns Output only. [Output Only] Action that managed instance group was executing on the instance when the error occurred. Possible values: Check the Action enum for the list of possible values.
33840 33841 33842 33843 33844 33845 33846 33847 33848 33849 33850 33851 33852 33853 33854 33855 33856 33857 33858 33859 33860 33861 33862 33863 33864 33865 33866 33867 33868 33869 33870 33871 33872 33873 33874 33875 33876 33877 33878 33879 33880 33881 33882 33883 33884 33885 33886 33887 33888 33889 33890 33891 33892 33893 33894 33895 33896 33897 33898 33899 33900 33901 33902 33903 33904 33905 33906 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33840 class InstanceManagedByIgmErrorInstanceActionDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Action that managed instance group was executing on # the instance when the error occurred. Possible values: module Action # A value indicating that the enum field is not set. UNDEFINED_ACTION = 0 # The managed instance group is abandoning this instance. The instance # will be removed from the instance group and from any target pools that # are associated with this group. ABANDONING = 388_244_813 # The managed instance group is creating this instance. If the group # fails to create this instance, it will try again until it is # successful. CREATING = 455_564_985 # The managed instance group is attempting to create this instance # only once. If the group fails to create this instance, it does # not try again and the group's targetSize value is # decreased. CREATING_WITHOUT_RETRIES = 428_843_785 # The managed instance group is permanently deleting this instance. DELETING = 528_602_024 # The managed instance group has not scheduled any actions for this # instance. NONE = 2_402_104 # The managed instance group is recreating this instance. RECREATING = 287_278_572 # The managed instance group is applying configuration changes to the # instance without stopping it. For example, the group can update the # target pool list for an instance without stopping that instance. REFRESHING = 163_266_343 # The managed instance group is restarting this instance. RESTARTING = 320_534_387 # The managed instance group is resuming this instance. RESUMING = 446_856_618 # The managed instance group is starting this instance. STARTING = 488_820_800 # The managed instance group is stopping this instance. STOPPING = 350_791_796 # The managed instance group is suspending this instance. SUSPENDING = 514_206_246 # The managed instance group is verifying this already created instance. # Verification happens every time the instance is (re)created or restarted # and consists of: # 1. Waiting until health check specified as part of this managed instance # group's autohealing policy reports HEALTHY. # Note: Applies only if autohealing policy has a health check specified # 2. Waiting for addition verification steps performed as post-instance # creation (subject to future extensions). VERIFYING = 16_982_185 end end |
#instance ⇒ ::String
Returns Output only. [Output Only] The URL of the instance. The URL can be set even if the instance has not yet been created.
33840 33841 33842 33843 33844 33845 33846 33847 33848 33849 33850 33851 33852 33853 33854 33855 33856 33857 33858 33859 33860 33861 33862 33863 33864 33865 33866 33867 33868 33869 33870 33871 33872 33873 33874 33875 33876 33877 33878 33879 33880 33881 33882 33883 33884 33885 33886 33887 33888 33889 33890 33891 33892 33893 33894 33895 33896 33897 33898 33899 33900 33901 33902 33903 33904 33905 33906 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33840 class InstanceManagedByIgmErrorInstanceActionDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Action that managed instance group was executing on # the instance when the error occurred. Possible values: module Action # A value indicating that the enum field is not set. UNDEFINED_ACTION = 0 # The managed instance group is abandoning this instance. The instance # will be removed from the instance group and from any target pools that # are associated with this group. ABANDONING = 388_244_813 # The managed instance group is creating this instance. If the group # fails to create this instance, it will try again until it is # successful. CREATING = 455_564_985 # The managed instance group is attempting to create this instance # only once. If the group fails to create this instance, it does # not try again and the group's targetSize value is # decreased. CREATING_WITHOUT_RETRIES = 428_843_785 # The managed instance group is permanently deleting this instance. DELETING = 528_602_024 # The managed instance group has not scheduled any actions for this # instance. NONE = 2_402_104 # The managed instance group is recreating this instance. RECREATING = 287_278_572 # The managed instance group is applying configuration changes to the # instance without stopping it. For example, the group can update the # target pool list for an instance without stopping that instance. REFRESHING = 163_266_343 # The managed instance group is restarting this instance. RESTARTING = 320_534_387 # The managed instance group is resuming this instance. RESUMING = 446_856_618 # The managed instance group is starting this instance. STARTING = 488_820_800 # The managed instance group is stopping this instance. STOPPING = 350_791_796 # The managed instance group is suspending this instance. SUSPENDING = 514_206_246 # The managed instance group is verifying this already created instance. # Verification happens every time the instance is (re)created or restarted # and consists of: # 1. Waiting until health check specified as part of this managed instance # group's autohealing policy reports HEALTHY. # Note: Applies only if autohealing policy has a health check specified # 2. Waiting for addition verification steps performed as post-instance # creation (subject to future extensions). VERIFYING = 16_982_185 end end |
#version ⇒ ::Google::Cloud::Compute::V1::ManagedInstanceVersion
Returns Output only. [Output Only] Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created.
33840 33841 33842 33843 33844 33845 33846 33847 33848 33849 33850 33851 33852 33853 33854 33855 33856 33857 33858 33859 33860 33861 33862 33863 33864 33865 33866 33867 33868 33869 33870 33871 33872 33873 33874 33875 33876 33877 33878 33879 33880 33881 33882 33883 33884 33885 33886 33887 33888 33889 33890 33891 33892 33893 33894 33895 33896 33897 33898 33899 33900 33901 33902 33903 33904 33905 33906 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33840 class InstanceManagedByIgmErrorInstanceActionDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Action that managed instance group was executing on # the instance when the error occurred. Possible values: module Action # A value indicating that the enum field is not set. UNDEFINED_ACTION = 0 # The managed instance group is abandoning this instance. The instance # will be removed from the instance group and from any target pools that # are associated with this group. ABANDONING = 388_244_813 # The managed instance group is creating this instance. If the group # fails to create this instance, it will try again until it is # successful. CREATING = 455_564_985 # The managed instance group is attempting to create this instance # only once. If the group fails to create this instance, it does # not try again and the group's targetSize value is # decreased. CREATING_WITHOUT_RETRIES = 428_843_785 # The managed instance group is permanently deleting this instance. DELETING = 528_602_024 # The managed instance group has not scheduled any actions for this # instance. NONE = 2_402_104 # The managed instance group is recreating this instance. RECREATING = 287_278_572 # The managed instance group is applying configuration changes to the # instance without stopping it. For example, the group can update the # target pool list for an instance without stopping that instance. REFRESHING = 163_266_343 # The managed instance group is restarting this instance. RESTARTING = 320_534_387 # The managed instance group is resuming this instance. RESUMING = 446_856_618 # The managed instance group is starting this instance. STARTING = 488_820_800 # The managed instance group is stopping this instance. STOPPING = 350_791_796 # The managed instance group is suspending this instance. SUSPENDING = 514_206_246 # The managed instance group is verifying this already created instance. # Verification happens every time the instance is (re)created or restarted # and consists of: # 1. Waiting until health check specified as part of this managed instance # group's autohealing policy reports HEALTHY. # Note: Applies only if autohealing policy has a health check specified # 2. Waiting for addition verification steps performed as post-instance # creation (subject to future extensions). VERIFYING = 16_982_185 end end |