Class: Google::Cloud::Compute::V1::InstanceParams
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceParams
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Additional instance params.
Defined Under Namespace
Classes: ResourceManagerTagsEntry
Instance Attribute Summary collapse
-
#request_valid_for_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Relative deadline for waiting for capacity.
-
#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Input only.
Instance Attribute Details
#request_valid_for_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Returns Relative deadline for waiting for capacity. Relevant only for Instances.Insert API.
33233 33234 33235 33236 33237 33238 33239 33240 33241 33242 33243 33244 33245 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33233 class InstanceParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Input only. Resource manager tags to be bound to the instance. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/{tag_key_id} and tagValues/456 or in namespaced
format such as {org_id|project_id}/{tag_key_short_name} and
{tag_value_short_name}. The field is ignored (both PUT &
PATCH) when empty.
33233 33234 33235 33236 33237 33238 33239 33240 33241 33242 33243 33244 33245 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33233 class InstanceParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |