Class: Google::Cloud::Compute::V1::InstancePropertiesPatch
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstancePropertiesPatch
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents the change that you want to make to the instance properties.
Defined Under Namespace
Classes: LabelsEntry, MetadataEntry
Instance Attribute Summary collapse
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
The label key-value pairs that you want to patch onto the instance.
-
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
The metadata key-value pairs that you want to patch onto the instance.
Instance Attribute Details
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The label key-value pairs that you want to patch onto the instance.
34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 34164 34165 34166 34167 34168 34169 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34148 class InstancePropertiesPatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The metadata key-value pairs that you want to patch onto the instance. For more information, see Project and instance metadata.
34148 34149 34150 34151 34152 34153 34154 34155 34156 34157 34158 34159 34160 34161 34162 34163 34164 34165 34166 34167 34168 34169 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34148 class InstancePropertiesPatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |