Class: Google::Cloud::Compute::V1::InstancePropertiesPatch
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstancePropertiesPatch
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents the change that you want to make to the instance properties.
Defined Under Namespace
Classes: LabelsEntry, MetadataEntry
Instance Attribute Summary collapse
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
The label key-value pairs that you want to patch onto the instance.
-
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
The metadata key-value pairs that you want to patch onto the instance.
Instance Attribute Details
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The label key-value pairs that you want to patch onto the instance.
33425 33426 33427 33428 33429 33430 33431 33432 33433 33434 33435 33436 33437 33438 33439 33440 33441 33442 33443 33444 33445 33446 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33425 class InstancePropertiesPatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The metadata key-value pairs that you want to patch onto the instance. For more information, see Project and instance metadata.
33425 33426 33427 33428 33429 33430 33431 33432 33433 33434 33435 33436 33437 33438 33439 33440 33441 33442 33443 33444 33445 33446 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33425 class InstancePropertiesPatch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |