Class: Google::Cloud::Compute::V1::InstanceSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Instance Settings resource. You can use instance settings to configure default settings for Compute Engine VM instances. For example, you can use it to configure default machine type of Compute Engine VM instances.
Instance Attribute Summary collapse
-
#fingerprint ⇒ ::String
Specifies a fingerprint for instance settings, which is essentially a hash of the instance settings resource's contents and used for optimistic locking.
-
#kind ⇒ ::String
Output only.
-
#metadata ⇒ ::Google::Cloud::Compute::V1::InstanceSettingsMetadata
The metadata key/value pairs assigned to all the instances in the corresponding scope.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#fingerprint ⇒ ::String
Returns Specifies a fingerprint for instance settings, which is essentially a hash of the instance settings resource's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance settings resource. You must always provide an up-to-date fingerprint hash in order to update or change the resource, otherwise the request will fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to retrieve the resource.
33484 33485 33486 33487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33484 class InstanceSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#instance_settings for instance settings.
33484 33485 33486 33487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33484 class InstanceSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metadata ⇒ ::Google::Cloud::Compute::V1::InstanceSettingsMetadata
Returns The metadata key/value pairs assigned to all the instances in the corresponding scope.
33484 33485 33486 33487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33484 class InstanceSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#zone ⇒ ::String
Returns Output only. [Output Only] URL of the zone where the resource resides You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
33484 33485 33486 33487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33484 class InstanceSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |