Method: Google::Cloud::Compute::V1::InstanceTemplate#source_instance
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
#source_instance ⇒ ::String
Returns The source instance used to create the template. You can provide this as a partial or full URL to the resource. For example, the following are valid values: - https://www.googleapis.com/compute/v1/projects/project/zones/zone /instances/instance - projects/project/zones/zone/instances/instance.
15934 15935 15936 15937 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15934 class InstanceTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |