Class: Google::Cloud::Compute::V1::InstanceWithNamedPorts

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String

Returns Output only. [Output Only] The URL of the instance.

Returns:

  • (::String)

    Output only. [Output Only] The URL of the instance.



34737
34738
34739
34740
34741
34742
34743
34744
34745
34746
34747
34748
34749
34750
34751
34752
34753
34754
34755
34756
34757
34758
34759
34760
34761
34762
34763
34764
34765
34766
34767
34768
34769
34770
34771
34772
34773
34774
34775
34776
34777
34778
34779
34780
34781
34782
34783
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34737

class InstanceWithNamedPorts
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the instance.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The instance is halted and we are performing tear down tasks like network
    # deprogramming, releasing quota, IP, tearing down disks etc.
    DEPROVISIONING = 428_935_662

    # For Flex Start provisioning instance is waiting for available capacity
    # from Dynamic Workload Scheduler (DWS).
    PENDING = 35_394_935

    # Resources are being allocated for the instance.
    PROVISIONING = 290_896_621

    # The instance is in repair.
    REPAIRING = 413_483_285

    # The instance is running.
    RUNNING = 121_282_975

    # All required resources have been allocated and the instance
    # is being started.
    STAGING = 431_072_283

    # The instance has stopped successfully.
    STOPPED = 444_276_141

    # The instance is currently stopping (either being deleted or killed).
    STOPPING = 350_791_796

    # The instance has suspended.
    SUSPENDED = 51_223_995

    # The instance is suspending.
    SUSPENDING = 514_206_246

    # The instance has stopped (either by explicit action or underlying
    # failure).
    TERMINATED = 250_018_339
  end
end

#named_ports::Array<::Google::Cloud::Compute::V1::NamedPort>

Returns Output only. [Output Only] The named ports that belong to this instance group.

Returns:



34737
34738
34739
34740
34741
34742
34743
34744
34745
34746
34747
34748
34749
34750
34751
34752
34753
34754
34755
34756
34757
34758
34759
34760
34761
34762
34763
34764
34765
34766
34767
34768
34769
34770
34771
34772
34773
34774
34775
34776
34777
34778
34779
34780
34781
34782
34783
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34737

class InstanceWithNamedPorts
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the instance.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The instance is halted and we are performing tear down tasks like network
    # deprogramming, releasing quota, IP, tearing down disks etc.
    DEPROVISIONING = 428_935_662

    # For Flex Start provisioning instance is waiting for available capacity
    # from Dynamic Workload Scheduler (DWS).
    PENDING = 35_394_935

    # Resources are being allocated for the instance.
    PROVISIONING = 290_896_621

    # The instance is in repair.
    REPAIRING = 413_483_285

    # The instance is running.
    RUNNING = 121_282_975

    # All required resources have been allocated and the instance
    # is being started.
    STAGING = 431_072_283

    # The instance has stopped successfully.
    STOPPED = 444_276_141

    # The instance is currently stopping (either being deleted or killed).
    STOPPING = 350_791_796

    # The instance has suspended.
    SUSPENDED = 51_223_995

    # The instance is suspending.
    SUSPENDING = 514_206_246

    # The instance has stopped (either by explicit action or underlying
    # failure).
    TERMINATED = 250_018_339
  end
end

#status::String

Returns Output only. [Output Only] The status of the instance. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The status of the instance. Check the Status enum for the list of possible values.



34737
34738
34739
34740
34741
34742
34743
34744
34745
34746
34747
34748
34749
34750
34751
34752
34753
34754
34755
34756
34757
34758
34759
34760
34761
34762
34763
34764
34765
34766
34767
34768
34769
34770
34771
34772
34773
34774
34775
34776
34777
34778
34779
34780
34781
34782
34783
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34737

class InstanceWithNamedPorts
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the instance.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The instance is halted and we are performing tear down tasks like network
    # deprogramming, releasing quota, IP, tearing down disks etc.
    DEPROVISIONING = 428_935_662

    # For Flex Start provisioning instance is waiting for available capacity
    # from Dynamic Workload Scheduler (DWS).
    PENDING = 35_394_935

    # Resources are being allocated for the instance.
    PROVISIONING = 290_896_621

    # The instance is in repair.
    REPAIRING = 413_483_285

    # The instance is running.
    RUNNING = 121_282_975

    # All required resources have been allocated and the instance
    # is being started.
    STAGING = 431_072_283

    # The instance has stopped successfully.
    STOPPED = 444_276_141

    # The instance is currently stopping (either being deleted or killed).
    STOPPING = 350_791_796

    # The instance has suspended.
    SUSPENDED = 51_223_995

    # The instance is suspending.
    SUSPENDING = 514_206_246

    # The instance has stopped (either by explicit action or underlying
    # failure).
    TERMINATED = 250_018_339
  end
end