Class: Google::Cloud::Compute::V1::InstanceWithNamedPorts
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceWithNamedPorts
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#instance ⇒ ::String
Output only.
-
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
Output only.
-
#status ⇒ ::String
Output only.
Instance Attribute Details
#instance ⇒ ::String
Returns Output only. [Output Only] The URL of the instance.
34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 34410 34411 34412 34413 34414 34415 34416 34417 34418 34419 34420 34421 34422 34423 34424 34425 34426 34427 34428 34429 34430 34431 34432 34433 34434 34435 34436 34437 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34391 class InstanceWithNamedPorts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The instance is halted and we are performing tear down tasks like network # deprogramming, releasing quota, IP, tearing down disks etc. DEPROVISIONING = 428_935_662 # For Flex Start provisioning instance is waiting for available capacity # from Dynamic Workload Scheduler (DWS). PENDING = 35_394_935 # Resources are being allocated for the instance. PROVISIONING = 290_896_621 # The instance is in repair. REPAIRING = 413_483_285 # The instance is running. RUNNING = 121_282_975 # All required resources have been allocated and the instance # is being started. STAGING = 431_072_283 # The instance has stopped successfully. STOPPED = 444_276_141 # The instance is currently stopping (either being deleted or killed). STOPPING = 350_791_796 # The instance has suspended. SUSPENDED = 51_223_995 # The instance is suspending. SUSPENDING = 514_206_246 # The instance has stopped (either by explicit action or underlying # failure). TERMINATED = 250_018_339 end end |
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
Returns Output only. [Output Only] The named ports that belong to this instance group.
34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 34410 34411 34412 34413 34414 34415 34416 34417 34418 34419 34420 34421 34422 34423 34424 34425 34426 34427 34428 34429 34430 34431 34432 34433 34434 34435 34436 34437 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34391 class InstanceWithNamedPorts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The instance is halted and we are performing tear down tasks like network # deprogramming, releasing quota, IP, tearing down disks etc. DEPROVISIONING = 428_935_662 # For Flex Start provisioning instance is waiting for available capacity # from Dynamic Workload Scheduler (DWS). PENDING = 35_394_935 # Resources are being allocated for the instance. PROVISIONING = 290_896_621 # The instance is in repair. REPAIRING = 413_483_285 # The instance is running. RUNNING = 121_282_975 # All required resources have been allocated and the instance # is being started. STAGING = 431_072_283 # The instance has stopped successfully. STOPPED = 444_276_141 # The instance is currently stopping (either being deleted or killed). STOPPING = 350_791_796 # The instance has suspended. SUSPENDED = 51_223_995 # The instance is suspending. SUSPENDING = 514_206_246 # The instance has stopped (either by explicit action or underlying # failure). TERMINATED = 250_018_339 end end |
#status ⇒ ::String
Returns Output only. [Output Only] The status of the instance. Check the Status enum for the list of possible values.
34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 34410 34411 34412 34413 34414 34415 34416 34417 34418 34419 34420 34421 34422 34423 34424 34425 34426 34427 34428 34429 34430 34431 34432 34433 34434 34435 34436 34437 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34391 class InstanceWithNamedPorts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The instance is halted and we are performing tear down tasks like network # deprogramming, releasing quota, IP, tearing down disks etc. DEPROVISIONING = 428_935_662 # For Flex Start provisioning instance is waiting for available capacity # from Dynamic Workload Scheduler (DWS). PENDING = 35_394_935 # Resources are being allocated for the instance. PROVISIONING = 290_896_621 # The instance is in repair. REPAIRING = 413_483_285 # The instance is running. RUNNING = 121_282_975 # All required resources have been allocated and the instance # is being started. STAGING = 431_072_283 # The instance has stopped successfully. STOPPED = 444_276_141 # The instance is currently stopping (either being deleted or killed). STOPPING = 350_791_796 # The instance has suspended. SUSPENDED = 51_223_995 # The instance is suspending. SUSPENDING = 514_206_246 # The instance has stopped (either by explicit action or underlying # failure). TERMINATED = 250_018_339 end end |