Class: Google::Cloud::Compute::V1::InstanceWithNamedPorts

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String

Returns Output only. [Output Only] The URL of the instance.

Returns:

  • (::String)

    Output only. [Output Only] The URL of the instance.



33668
33669
33670
33671
33672
33673
33674
33675
33676
33677
33678
33679
33680
33681
33682
33683
33684
33685
33686
33687
33688
33689
33690
33691
33692
33693
33694
33695
33696
33697
33698
33699
33700
33701
33702
33703
33704
33705
33706
33707
33708
33709
33710
33711
33712
33713
33714
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33668

class InstanceWithNamedPorts
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the instance.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The instance is halted and we are performing tear down tasks like network
    # deprogramming, releasing quota, IP, tearing down disks etc.
    DEPROVISIONING = 428_935_662

    # For Flex Start provisioning instance is waiting for available capacity
    # from Dynamic Workload Scheduler (DWS).
    PENDING = 35_394_935

    # Resources are being allocated for the instance.
    PROVISIONING = 290_896_621

    # The instance is in repair.
    REPAIRING = 413_483_285

    # The instance is running.
    RUNNING = 121_282_975

    # All required resources have been allocated and the instance
    # is being started.
    STAGING = 431_072_283

    # The instance has stopped successfully.
    STOPPED = 444_276_141

    # The instance is currently stopping (either being deleted or killed).
    STOPPING = 350_791_796

    # The instance has suspended.
    SUSPENDED = 51_223_995

    # The instance is suspending.
    SUSPENDING = 514_206_246

    # The instance has stopped (either by explicit action or underlying
    # failure).
    TERMINATED = 250_018_339
  end
end

#named_ports::Array<::Google::Cloud::Compute::V1::NamedPort>

Returns Output only. [Output Only] The named ports that belong to this instance group.

Returns:



33668
33669
33670
33671
33672
33673
33674
33675
33676
33677
33678
33679
33680
33681
33682
33683
33684
33685
33686
33687
33688
33689
33690
33691
33692
33693
33694
33695
33696
33697
33698
33699
33700
33701
33702
33703
33704
33705
33706
33707
33708
33709
33710
33711
33712
33713
33714
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33668

class InstanceWithNamedPorts
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the instance.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The instance is halted and we are performing tear down tasks like network
    # deprogramming, releasing quota, IP, tearing down disks etc.
    DEPROVISIONING = 428_935_662

    # For Flex Start provisioning instance is waiting for available capacity
    # from Dynamic Workload Scheduler (DWS).
    PENDING = 35_394_935

    # Resources are being allocated for the instance.
    PROVISIONING = 290_896_621

    # The instance is in repair.
    REPAIRING = 413_483_285

    # The instance is running.
    RUNNING = 121_282_975

    # All required resources have been allocated and the instance
    # is being started.
    STAGING = 431_072_283

    # The instance has stopped successfully.
    STOPPED = 444_276_141

    # The instance is currently stopping (either being deleted or killed).
    STOPPING = 350_791_796

    # The instance has suspended.
    SUSPENDED = 51_223_995

    # The instance is suspending.
    SUSPENDING = 514_206_246

    # The instance has stopped (either by explicit action or underlying
    # failure).
    TERMINATED = 250_018_339
  end
end

#status::String

Returns Output only. [Output Only] The status of the instance. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The status of the instance. Check the Status enum for the list of possible values.



33668
33669
33670
33671
33672
33673
33674
33675
33676
33677
33678
33679
33680
33681
33682
33683
33684
33685
33686
33687
33688
33689
33690
33691
33692
33693
33694
33695
33696
33697
33698
33699
33700
33701
33702
33703
33704
33705
33706
33707
33708
33709
33710
33711
33712
33713
33714
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33668

class InstanceWithNamedPorts
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The status of the instance.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The instance is halted and we are performing tear down tasks like network
    # deprogramming, releasing quota, IP, tearing down disks etc.
    DEPROVISIONING = 428_935_662

    # For Flex Start provisioning instance is waiting for available capacity
    # from Dynamic Workload Scheduler (DWS).
    PENDING = 35_394_935

    # Resources are being allocated for the instance.
    PROVISIONING = 290_896_621

    # The instance is in repair.
    REPAIRING = 413_483_285

    # The instance is running.
    RUNNING = 121_282_975

    # All required resources have been allocated and the instance
    # is being started.
    STAGING = 431_072_283

    # The instance has stopped successfully.
    STOPPED = 444_276_141

    # The instance is currently stopping (either being deleted or killed).
    STOPPING = 350_791_796

    # The instance has suspended.
    SUSPENDED = 51_223_995

    # The instance is suspending.
    SUSPENDING = 514_206_246

    # The instance has stopped (either by explicit action or underlying
    # failure).
    TERMINATED = 250_018_339
  end
end