Class: Google::Cloud::Compute::V1::InstanceWithNamedPorts
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstanceWithNamedPorts
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#instance ⇒ ::String
Output only.
-
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
Output only.
-
#status ⇒ ::String
Output only.
Instance Attribute Details
#instance ⇒ ::String
Returns Output only. [Output Only] The URL of the instance.
35830 35831 35832 35833 35834 35835 35836 35837 35838 35839 35840 35841 35842 35843 35844 35845 35846 35847 35848 35849 35850 35851 35852 35853 35854 35855 35856 35857 35858 35859 35860 35861 35862 35863 35864 35865 35866 35867 35868 35869 35870 35871 35872 35873 35874 35875 35876 35877 35878 35879 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35830 class InstanceWithNamedPorts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The instance is halted and we are performing tear down tasks like network # deprogramming, releasing quota, IP, tearing down disks etc. DEPROVISIONING = 428_935_662 # For Flex Start provisioning instance is waiting for available capacity # from Dynamic Workload Scheduler (DWS). PENDING = 35_394_935 # The instance is gracefully shutting down. PENDING_STOP = 362_509_770 # Resources are being allocated for the instance. PROVISIONING = 290_896_621 # The instance is in repair. REPAIRING = 413_483_285 # The instance is running. RUNNING = 121_282_975 # All required resources have been allocated and the instance # is being started. STAGING = 431_072_283 # The instance has stopped successfully. STOPPED = 444_276_141 # The instance is currently stopping (either being deleted or killed). STOPPING = 350_791_796 # The instance has suspended. SUSPENDED = 51_223_995 # The instance is suspending. SUSPENDING = 514_206_246 # The instance has stopped (either by explicit action or underlying # failure). TERMINATED = 250_018_339 end end |
#named_ports ⇒ ::Array<::Google::Cloud::Compute::V1::NamedPort>
Returns Output only. [Output Only] The named ports that belong to this instance group.
35830 35831 35832 35833 35834 35835 35836 35837 35838 35839 35840 35841 35842 35843 35844 35845 35846 35847 35848 35849 35850 35851 35852 35853 35854 35855 35856 35857 35858 35859 35860 35861 35862 35863 35864 35865 35866 35867 35868 35869 35870 35871 35872 35873 35874 35875 35876 35877 35878 35879 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35830 class InstanceWithNamedPorts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The instance is halted and we are performing tear down tasks like network # deprogramming, releasing quota, IP, tearing down disks etc. DEPROVISIONING = 428_935_662 # For Flex Start provisioning instance is waiting for available capacity # from Dynamic Workload Scheduler (DWS). PENDING = 35_394_935 # The instance is gracefully shutting down. PENDING_STOP = 362_509_770 # Resources are being allocated for the instance. PROVISIONING = 290_896_621 # The instance is in repair. REPAIRING = 413_483_285 # The instance is running. RUNNING = 121_282_975 # All required resources have been allocated and the instance # is being started. STAGING = 431_072_283 # The instance has stopped successfully. STOPPED = 444_276_141 # The instance is currently stopping (either being deleted or killed). STOPPING = 350_791_796 # The instance has suspended. SUSPENDED = 51_223_995 # The instance is suspending. SUSPENDING = 514_206_246 # The instance has stopped (either by explicit action or underlying # failure). TERMINATED = 250_018_339 end end |
#status ⇒ ::String
Returns Output only. [Output Only] The status of the instance. Check the Status enum for the list of possible values.
35830 35831 35832 35833 35834 35835 35836 35837 35838 35839 35840 35841 35842 35843 35844 35845 35846 35847 35848 35849 35850 35851 35852 35853 35854 35855 35856 35857 35858 35859 35860 35861 35862 35863 35864 35865 35866 35867 35868 35869 35870 35871 35872 35873 35874 35875 35876 35877 35878 35879 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35830 class InstanceWithNamedPorts include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of the instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The instance is halted and we are performing tear down tasks like network # deprogramming, releasing quota, IP, tearing down disks etc. DEPROVISIONING = 428_935_662 # For Flex Start provisioning instance is waiting for available capacity # from Dynamic Workload Scheduler (DWS). PENDING = 35_394_935 # The instance is gracefully shutting down. PENDING_STOP = 362_509_770 # Resources are being allocated for the instance. PROVISIONING = 290_896_621 # The instance is in repair. REPAIRING = 413_483_285 # The instance is running. RUNNING = 121_282_975 # All required resources have been allocated and the instance # is being started. STAGING = 431_072_283 # The instance has stopped successfully. STOPPED = 444_276_141 # The instance is currently stopping (either being deleted or killed). STOPPING = 350_791_796 # The instance has suspended. SUSPENDED = 51_223_995 # The instance is suspending. SUSPENDING = 514_206_246 # The instance has stopped (either by explicit action or underlying # failure). TERMINATED = 250_018_339 end end |