Class: Google::Cloud::Compute::V1::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy.



34503
34504
34505
34506
34507
34508
34509
34510
34511
34512
34513
34514
34515
34516
34517
34518
34519
34520
34521
34522
34523
34524
34525
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34503

class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#name::String

Returns Output only. [Output Only] The name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] The name of the firewall policy.



34503
34504
34505
34506
34507
34508
34509
34510
34511
34512
34513
34514
34515
34516
34517
34518
34519
34520
34521
34522
34523
34524
34525
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34503

class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#packet_mirroring_rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns Output only. [Output Only] The packet mirroring rules that apply to the instance.

Returns:



34503
34504
34505
34506
34507
34508
34509
34510
34511
34512
34513
34514
34515
34516
34517
34518
34519
34520
34521
34522
34523
34524
34525
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34503

class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#priority::Integer

Returns Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.

Returns:

  • (::Integer)

    Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.



34503
34504
34505
34506
34507
34508
34509
34510
34511
34512
34513
34514
34515
34516
34517
34518
34519
34520
34521
34522
34523
34524
34525
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34503

class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns [Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>)

    [Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules.



34503
34504
34505
34506
34507
34508
34509
34510
34511
34512
34513
34514
34515
34516
34517
34518
34519
34520
34521
34522
34523
34524
34525
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34503

class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#short_name::String

Returns Output only. [Output Only] The short name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] The short name of the firewall policy.



34503
34504
34505
34506
34507
34508
34509
34510
34511
34512
34513
34514
34515
34516
34517
34518
34519
34520
34521
34522
34523
34524
34525
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34503

class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#type::String

Returns Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Check the Type enum for the list of possible values.



34503
34504
34505
34506
34507
34508
34509
34510
34511
34512
34513
34514
34515
34516
34517
34518
34519
34520
34521
34522
34523
34524
34525
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34503

class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end