Class: Google::Cloud::Compute::V1::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
Output only.
-
#name ⇒ ::String
Output only.
-
#packet_mirroring_rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
Output only.
-
#priority ⇒ ::Integer
Output only.
-
#rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
[Output Only] The rules that apply to the instance.
-
#short_name ⇒ ::String
Output only.
-
#type ⇒ ::String
Output only.
Instance Attribute Details
#display_name ⇒ ::String
Returns Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy.
33780 33781 33782 33783 33784 33785 33786 33787 33788 33789 33790 33791 33792 33793 33794 33795 33796 33797 33798 33799 33800 33801 33802 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33780 class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 NETWORK_REGIONAL = 190_804_272 SYSTEM_GLOBAL = 60_099_507 SYSTEM_REGIONAL = 161_777_199 UNSPECIFIED = 526_786_327 end end |
#name ⇒ ::String
Returns Output only. [Output Only] The name of the firewall policy.
33780 33781 33782 33783 33784 33785 33786 33787 33788 33789 33790 33791 33792 33793 33794 33795 33796 33797 33798 33799 33800 33801 33802 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33780 class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 NETWORK_REGIONAL = 190_804_272 SYSTEM_GLOBAL = 60_099_507 SYSTEM_REGIONAL = 161_777_199 UNSPECIFIED = 526_786_327 end end |
#packet_mirroring_rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
Returns Output only. [Output Only] The packet mirroring rules that apply to the instance.
33780 33781 33782 33783 33784 33785 33786 33787 33788 33789 33790 33791 33792 33793 33794 33795 33796 33797 33798 33799 33800 33801 33802 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33780 class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 NETWORK_REGIONAL = 190_804_272 SYSTEM_GLOBAL = 60_099_507 SYSTEM_REGIONAL = 161_777_199 UNSPECIFIED = 526_786_327 end end |
#priority ⇒ ::Integer
Returns Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.
33780 33781 33782 33783 33784 33785 33786 33787 33788 33789 33790 33791 33792 33793 33794 33795 33796 33797 33798 33799 33800 33801 33802 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33780 class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 NETWORK_REGIONAL = 190_804_272 SYSTEM_GLOBAL = 60_099_507 SYSTEM_REGIONAL = 161_777_199 UNSPECIFIED = 526_786_327 end end |
#rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
Returns [Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules.
33780 33781 33782 33783 33784 33785 33786 33787 33788 33789 33790 33791 33792 33793 33794 33795 33796 33797 33798 33799 33800 33801 33802 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33780 class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 NETWORK_REGIONAL = 190_804_272 SYSTEM_GLOBAL = 60_099_507 SYSTEM_REGIONAL = 161_777_199 UNSPECIFIED = 526_786_327 end end |
#short_name ⇒ ::String
Returns Output only. [Output Only] The short name of the firewall policy.
33780 33781 33782 33783 33784 33785 33786 33787 33788 33789 33790 33791 33792 33793 33794 33795 33796 33797 33798 33799 33800 33801 33802 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33780 class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 NETWORK_REGIONAL = 190_804_272 SYSTEM_GLOBAL = 60_099_507 SYSTEM_REGIONAL = 161_777_199 UNSPECIFIED = 526_786_327 end end |
#type ⇒ ::String
Returns Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Check the Type enum for the list of possible values.
33780 33781 33782 33783 33784 33785 33786 33787 33788 33789 33790 33791 33792 33793 33794 33795 33796 33797 33798 33799 33800 33801 33802 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33780 class InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 NETWORK_REGIONAL = 190_804_272 SYSTEM_GLOBAL = 60_099_507 SYSTEM_REGIONAL = 161_777_199 UNSPECIFIED = 526_786_327 end end |