Class: Google::Cloud::Compute::V1::InstancesReportHostAsFaultyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstancesReportHostAsFaultyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: DisruptionSchedule
Instance Attribute Summary collapse
-
#disruption_schedule ⇒ ::String
The disruption schedule for the VM.
- #fault_reasons ⇒ ::Array<::Google::Cloud::Compute::V1::InstancesReportHostAsFaultyRequestFaultReason>
Instance Attribute Details
#disruption_schedule ⇒ ::String
Returns The disruption schedule for the VM. Required field, only allows IMMEDIATE. Check the DisruptionSchedule enum for the list of possible values.
34887 34888 34889 34890 34891 34892 34893 34894 34895 34896 34897 34898 34899 34900 34901 34902 34903 34904 34905 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34887 class InstancesReportHostAsFaultyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The disruption schedule for the VM. Required field, only allows IMMEDIATE. module DisruptionSchedule # A value indicating that the enum field is not set. UNDEFINED_DISRUPTION_SCHEDULE = 0 # Not used. Required as per aip/126. DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835 # Delay disruption for caller control. Will be default soon. FUTURE = 474_513_859 # Default value. Disrupt the VM immediately. IMMEDIATE = 152_881_041 end end |
#fault_reasons ⇒ ::Array<::Google::Cloud::Compute::V1::InstancesReportHostAsFaultyRequestFaultReason>
34887 34888 34889 34890 34891 34892 34893 34894 34895 34896 34897 34898 34899 34900 34901 34902 34903 34904 34905 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34887 class InstancesReportHostAsFaultyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The disruption schedule for the VM. Required field, only allows IMMEDIATE. module DisruptionSchedule # A value indicating that the enum field is not set. UNDEFINED_DISRUPTION_SCHEDULE = 0 # Not used. Required as per aip/126. DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835 # Delay disruption for caller control. Will be default soon. FUTURE = 474_513_859 # Default value. Disrupt the VM immediately. IMMEDIATE = 152_881_041 end end |