Class: Google::Cloud::Compute::V1::InstancesReportHostAsFaultyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DisruptionSchedule

Instance Attribute Summary collapse

Instance Attribute Details

#disruption_schedule::String

Returns The disruption schedule for the VM. Required field, only allows IMMEDIATE. Check the DisruptionSchedule enum for the list of possible values.

Returns:

  • (::String)

    The disruption schedule for the VM. Required field, only allows IMMEDIATE. Check the DisruptionSchedule enum for the list of possible values.



34541
34542
34543
34544
34545
34546
34547
34548
34549
34550
34551
34552
34553
34554
34555
34556
34557
34558
34559
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34541

class InstancesReportHostAsFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the VM. Required field, only allows IMMEDIATE.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    # Not used. Required as per aip/126.
    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # Delay disruption for caller control. Will be default soon.
    FUTURE = 474_513_859

    # Default value. Disrupt the VM immediately.
    IMMEDIATE = 152_881_041
  end
end

#fault_reasons::Array<::Google::Cloud::Compute::V1::InstancesReportHostAsFaultyRequestFaultReason>



34541
34542
34543
34544
34545
34546
34547
34548
34549
34550
34551
34552
34553
34554
34555
34556
34557
34558
34559
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34541

class InstancesReportHostAsFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the VM. Required field, only allows IMMEDIATE.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    # Not used. Required as per aip/126.
    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # Delay disruption for caller control. Will be default soon.
    FUTURE = 474_513_859

    # Default value. Disrupt the VM immediately.
    IMMEDIATE = 152_881_041
  end
end