Class: Google::Cloud::Compute::V1::InstancesReportHostAsFaultyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DisruptionSchedule

Instance Attribute Summary collapse

Instance Attribute Details

#disruption_schedule::String

Returns The disruption schedule for the VM. Required field, only allows IMMEDIATE. Check the DisruptionSchedule enum for the list of possible values.

Returns:

  • (::String)

    The disruption schedule for the VM. Required field, only allows IMMEDIATE. Check the DisruptionSchedule enum for the list of possible values.



33818
33819
33820
33821
33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
33835
33836
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33818

class InstancesReportHostAsFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the VM. Required field, only allows IMMEDIATE.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    # Not used. Required as per aip/126.
    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # Delay disruption for caller control. Will be default soon.
    FUTURE = 474_513_859

    # Default value. Disrupt the VM immediately.
    IMMEDIATE = 152_881_041
  end
end

#fault_reasons::Array<::Google::Cloud::Compute::V1::InstancesReportHostAsFaultyRequestFaultReason>



33818
33819
33820
33821
33822
33823
33824
33825
33826
33827
33828
33829
33830
33831
33832
33833
33834
33835
33836
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33818

class InstancesReportHostAsFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the VM. Required field, only allows IMMEDIATE.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    # Not used. Required as per aip/126.
    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # Delay disruption for caller control. Will be default soon.
    FUTURE = 474_513_859

    # Default value. Disrupt the VM immediately.
    IMMEDIATE = 152_881_041
  end
end