Class: Google::Cloud::Compute::V1::InstancesReportHostAsFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Behavior

Instance Attribute Summary collapse

Instance Attribute Details

#behavior::String

Returns Check the Behavior enum for the list of possible values.

Returns:

  • (::String)

    Check the Behavior enum for the list of possible values.



34912
34913
34914
34915
34916
34917
34918
34919
34920
34921
34922
34923
34924
34925
34926
34927
34928
34929
34930
34931
34932
34933
34934
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34912

class InstancesReportHostAsFaultyRequestFaultReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Behavior
    # A value indicating that the enum field is not set.
    UNDEFINED_BEHAVIOR = 0

    # Public reportable behaviors
    BEHAVIOR_UNSPECIFIED = 85_734_570

    # Any GPU or TPU errors or faults where the accelerator becomes unusable
    CHIP_ERROR = 263_151_669

    PERFORMANCE = 135_701_520

    SILENT_DATA_CORRUPTION = 111_360_678

    # Unrecoverable GPU error identified by an XID
    UNRECOVERABLE_GPU_ERROR = 363_710_747
  end
end

#description::String

Returns:

  • (::String)


34912
34913
34914
34915
34916
34917
34918
34919
34920
34921
34922
34923
34924
34925
34926
34927
34928
34929
34930
34931
34932
34933
34934
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34912

class InstancesReportHostAsFaultyRequestFaultReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Behavior
    # A value indicating that the enum field is not set.
    UNDEFINED_BEHAVIOR = 0

    # Public reportable behaviors
    BEHAVIOR_UNSPECIFIED = 85_734_570

    # Any GPU or TPU errors or faults where the accelerator becomes unusable
    CHIP_ERROR = 263_151_669

    PERFORMANCE = 135_701_520

    SILENT_DATA_CORRUPTION = 111_360_678

    # Unrecoverable GPU error identified by an XID
    UNRECOVERABLE_GPU_ERROR = 363_710_747
  end
end