Class: Google::Cloud::Compute::V1::InstancesSetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstancesSetLabelsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#label_fingerprint ⇒ ::String
Fingerprint of the previous set of labels for this resource, used to prevent conflicts.
- #labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Instance Attribute Details
#label_fingerprint ⇒ ::String
Returns Fingerprint of the previous set of labels for this resource, used to prevent conflicts. Provide the latest fingerprint value when making a request to add or change labels.
15676 15677 15678 15679 15680 15681 15682 15683 15684 15685 15686 15687 15688 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15676 class InstancesSetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
15676 15677 15678 15679 15680 15681 15682 15683 15684 15685 15686 15687 15688 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 15676 class InstancesSetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |