Class: Google::Cloud::Compute::V1::InstantSnapshot

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a InstantSnapshot resource.

You can use instant snapshots to create disk rollback points quickly..

Defined Under Namespace

Modules: Architecture, Status Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#architecture::String

Returns Output only. [Output Only] The architecture of the instant snapshot. Valid values are ARM64 or X86_64. Check the Architecture enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The architecture of the instant snapshot. Valid values are ARM64 or X86_64. Check the Architecture enum for the list of possible values.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#disk_size_gb::Integer

Returns Output only. [Output Only] Size of the source disk, specified in GB.

Returns:

  • (::Integer)

    Output only. [Output Only] Size of the source disk, specified in GB.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#instantSnapshot for InstantSnapshot resources.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Alwayscompute#instantSnapshot for InstantSnapshot resources.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#label_fingerprint::String

Returns A fingerprint for the labels being applied to this InstantSnapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.

To see the latest fingerprint, make a get() request to retrieve a InstantSnapshot.

Returns:

  • (::String)

    A fingerprint for the labels being applied to this InstantSnapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.

    To see the latest fingerprint, make a get() request to retrieve a InstantSnapshot.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Labels to apply to this InstantSnapshot. These can be later modified by the setLabels method. Label values may be empty.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Labels to apply to this InstantSnapshot. These can be later modified by the setLabels method. Label values may be empty.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#name::String

Returns Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#params::Google::Cloud::Compute::V1::InstantSnapshotParams

Returns Input only. Additional params passed with the request, but not persisted as part of resource payload.

Returns:



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#region::String

Returns Output only. [Output Only] URL of the region where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Returns:

  • (::String)

    Output only. [Output Only] URL of the region where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#resource_status::Google::Cloud::Compute::V1::InstantSnapshotResourceStatus

Returns Output only. [Output Only] Status information for the instant snapshot resource.

Returns:



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#satisfies_pzi::Boolean

Returns Output only. Reserved for future use.

Returns:

  • (::Boolean)

    Output only. Reserved for future use.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#satisfies_pzs::Boolean

Returns Output only. [Output Only] Reserved for future use.

Returns:

  • (::Boolean)

    Output only. [Output Only] Reserved for future use.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for the resource.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource's resource id.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource's resource id.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#source_disk::String

Returns URL of the source disk used to create this instant snapshot. Note that the source disk must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL. For example, the following are valid values:

 -
   https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk

 -
   https://www.googleapis.com/compute/v1/projects/project/regions/region/disks/disk

 -
   projects/project/zones/zone/disks/disk

 -
   projects/project/regions/region/disks/disk

 -
   zones/zone/disks/disk

 -
   regions/region/disks/disk.

Returns:

  • (::String)

    URL of the source disk used to create this instant snapshot. Note that the source disk must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL. For example, the following are valid values:

     -
       https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
    
     -
       https://www.googleapis.com/compute/v1/projects/project/regions/region/disks/disk
    
     -
       projects/project/zones/zone/disks/disk
    
     -
       projects/project/regions/region/disks/disk
    
     -
       zones/zone/disks/disk
    
     -
       regions/region/disks/disk
    


35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#source_disk_id::String

Returns Output only. [Output Only] The ID value of the disk used to create this InstantSnapshot. This value may be used to determine whether the InstantSnapshot was taken from the current or a previous instance of a given disk name.

Returns:

  • (::String)

    Output only. [Output Only] The ID value of the disk used to create this InstantSnapshot. This value may be used to determine whether the InstantSnapshot was taken from the current or a previous instance of a given disk name.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#source_instant_snapshot_group::String

Returns Output only. [Output Only] URL of the source instant snapshot this instant snapshot is part of. Note that the source instant snapshot group must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL.

Returns:

  • (::String)

    Output only. [Output Only] URL of the source instant snapshot this instant snapshot is part of. Note that the source instant snapshot group must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#source_instant_snapshot_group_id::String

Returns Output only. [Output Only] The ID value of the source instant snapshot group this InstantSnapshot is part of. This value may be used to determine whether the InstantSnapshot was created as part of an InstantSnapshotGroup creation.

Returns:

  • (::String)

    Output only. [Output Only] The ID value of the source instant snapshot group this InstantSnapshot is part of. This value may be used to determine whether the InstantSnapshot was created as part of an InstantSnapshotGroup creation.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#status::String

Returns Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY. Check the Status enum for the list of possible values.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end

#zone::String

Returns Output only. [Output Only] URL of the zone where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.

Returns:

  • (::String)

    Output only. [Output Only] URL of the zone where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.



35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
35184
35185
35186
35187
35188
35189
35190
35191
35192
35193
35194
35195
35196
35197
35198
35199
35200
35201
35202
35203
35204
35205
35206
35207
35208
35209
35210
35211
35212
35213
35214
35215
35216
35217
35218
35219
35220
35221
35222
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35172

class InstantSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The architecture of the instant snapshot. Valid values are
  # ARM64 or X86_64.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # InstantSnapshot creation is in progress.
    CREATING = 455_564_985

    # InstantSnapshot is currently being deleted.
    DELETING = 528_602_024

    # InstantSnapshot creation failed.
    FAILED = 455_706_685

    # InstantSnapshot has been created successfully.
    READY = 77_848_963

    # InstantSnapshot is currently unavailable and cannot be used for
    # Disk restoration
    UNAVAILABLE = 413_756_464
  end
end