Class: Google::Cloud::Compute::V1::InstantSnapshotGroup
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InstantSnapshotGroup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents an InstantSnapshotGroup resource.
An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
Optional.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Identifier.
-
#region ⇒ ::String
Output only.
- #resource_status ⇒ ::Google::Cloud::Compute::V1::InstantSnapshotGroupResourceStatus
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
- #source_consistency_group ⇒ ::String
-
#status ⇒ ::String
Output only.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#description ⇒ ::String
Returns Optional. An optional description of this resource. Provide this property when you create the resource.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#instantSnapshotGroup for InstantSnapshotGroup resources.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#name ⇒ ::String
Returns Identifier. Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#resource_status ⇒ ::Google::Cloud::Compute::V1::InstantSnapshotGroupResourceStatus
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource's resource id.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#source_consistency_group ⇒ ::String
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#status ⇒ ::String
Returns Output only. [Output Only] Check the Status enum for the list of possible values.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |
#zone ⇒ ::String
Returns Output only. [Output Only] URL of the zone where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 34983 34984 34985 34986 34987 34988 34989 34990 34991 34992 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34971 class InstantSnapshotGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 INVALID = 530_283_991 READY = 77_848_963 UNKNOWN = 433_141_802 end end |