Class: Google::Cloud::Compute::V1::InterconnectApplicationAwareInterconnectBandwidthPercentage
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectApplicationAwareInterconnectBandwidthPercentage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specify bandwidth percentages [1-100] for various traffic classes in BandwidthPercentagePolicy. The sum of all percentages must equal 100. All traffic classes must have a percentage value specified.
Defined Under Namespace
Modules: TrafficClass
Instance Attribute Summary collapse
-
#percentage ⇒ ::Integer
Bandwidth percentage for a specific traffic class.
-
#traffic_class ⇒ ::String
TrafficClass whose bandwidth percentage is being specified.
Instance Attribute Details
#percentage ⇒ ::Integer
Returns Bandwidth percentage for a specific traffic class.
35501 35502 35503 35504 35505 35506 35507 35508 35509 35510 35511 35512 35513 35514 35515 35516 35517 35518 35519 35520 35521 35522 35523 35524 35525 35526 35527 35528 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35501 class InterconnectApplicationAwareInterconnectBandwidthPercentage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # TrafficClass whose bandwidth percentage is being specified. module TrafficClass # A value indicating that the enum field is not set. UNDEFINED_TRAFFIC_CLASS = 0 # Traffic Class 1, corresponding to DSCP ranges (0-7) 000xxx. TC1 = 82_850 # Traffic Class 2, corresponding to DSCP ranges (8-15) 001xxx. TC2 = 82_851 # Traffic Class 3, corresponding to DSCP ranges (16-23) 010xxx. TC3 = 82_852 # Traffic Class 4, corresponding to DSCP ranges (24-31) 011xxx. TC4 = 82_853 # Traffic Class 5, corresponding to DSCP ranges (32-47) 10xxxx. TC5 = 82_854 # Traffic Class 6, corresponding to DSCP ranges (48-63) 11xxxx. TC6 = 82_855 end end |
#traffic_class ⇒ ::String
Returns TrafficClass whose bandwidth percentage is being specified. Check the TrafficClass enum for the list of possible values.
35501 35502 35503 35504 35505 35506 35507 35508 35509 35510 35511 35512 35513 35514 35515 35516 35517 35518 35519 35520 35521 35522 35523 35524 35525 35526 35527 35528 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35501 class InterconnectApplicationAwareInterconnectBandwidthPercentage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # TrafficClass whose bandwidth percentage is being specified. module TrafficClass # A value indicating that the enum field is not set. UNDEFINED_TRAFFIC_CLASS = 0 # Traffic Class 1, corresponding to DSCP ranges (0-7) 000xxx. TC1 = 82_850 # Traffic Class 2, corresponding to DSCP ranges (8-15) 001xxx. TC2 = 82_851 # Traffic Class 3, corresponding to DSCP ranges (16-23) 010xxx. TC3 = 82_852 # Traffic Class 4, corresponding to DSCP ranges (24-31) 011xxx. TC4 = 82_853 # Traffic Class 5, corresponding to DSCP ranges (32-47) 10xxxx. TC5 = 82_854 # Traffic Class 6, corresponding to DSCP ranges (48-63) 11xxxx. TC6 = 82_855 end end |