Class: Google::Cloud::Compute::V1::InterconnectApplicationAwareInterconnectBandwidthPercentage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specify bandwidth percentages [1-100] for various traffic classes in BandwidthPercentagePolicy. The sum of all percentages must equal 100. All traffic classes must have a percentage value specified.

Defined Under Namespace

Modules: TrafficClass

Instance Attribute Summary collapse

Instance Attribute Details

#percentage::Integer

Returns Bandwidth percentage for a specific traffic class.

Returns:

  • (::Integer)

    Bandwidth percentage for a specific traffic class.



34778
34779
34780
34781
34782
34783
34784
34785
34786
34787
34788
34789
34790
34791
34792
34793
34794
34795
34796
34797
34798
34799
34800
34801
34802
34803
34804
34805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34778

class InterconnectApplicationAwareInterconnectBandwidthPercentage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # TrafficClass whose bandwidth percentage is being specified.
  module TrafficClass
    # A value indicating that the enum field is not set.
    UNDEFINED_TRAFFIC_CLASS = 0

    # Traffic Class 1, corresponding to DSCP ranges (0-7) 000xxx.
    TC1 = 82_850

    # Traffic Class 2, corresponding to DSCP ranges (8-15) 001xxx.
    TC2 = 82_851

    # Traffic Class 3, corresponding to DSCP ranges (16-23) 010xxx.
    TC3 = 82_852

    # Traffic Class 4, corresponding to DSCP ranges (24-31) 011xxx.
    TC4 = 82_853

    # Traffic Class 5, corresponding to DSCP ranges (32-47) 10xxxx.
    TC5 = 82_854

    # Traffic Class 6, corresponding to DSCP ranges (48-63) 11xxxx.
    TC6 = 82_855
  end
end

#traffic_class::String

Returns TrafficClass whose bandwidth percentage is being specified. Check the TrafficClass enum for the list of possible values.

Returns:

  • (::String)

    TrafficClass whose bandwidth percentage is being specified. Check the TrafficClass enum for the list of possible values.



34778
34779
34780
34781
34782
34783
34784
34785
34786
34787
34788
34789
34790
34791
34792
34793
34794
34795
34796
34797
34798
34799
34800
34801
34802
34803
34804
34805
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34778

class InterconnectApplicationAwareInterconnectBandwidthPercentage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # TrafficClass whose bandwidth percentage is being specified.
  module TrafficClass
    # A value indicating that the enum field is not set.
    UNDEFINED_TRAFFIC_CLASS = 0

    # Traffic Class 1, corresponding to DSCP ranges (0-7) 000xxx.
    TC1 = 82_850

    # Traffic Class 2, corresponding to DSCP ranges (8-15) 001xxx.
    TC2 = 82_851

    # Traffic Class 3, corresponding to DSCP ranges (16-23) 010xxx.
    TC3 = 82_852

    # Traffic Class 4, corresponding to DSCP ranges (24-31) 011xxx.
    TC4 = 82_853

    # Traffic Class 5, corresponding to DSCP ranges (32-47) 10xxxx.
    TC5 = 82_854

    # Traffic Class 6, corresponding to DSCP ranges (48-63) 11xxxx.
    TC6 = 82_855
  end
end