Module: Google::Cloud::Compute::V1::InterconnectAttachment::StackType
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used. This field can be both set at interconnect attachments creation and update interconnect attachment operations.
Constant Summary collapse
- UNDEFINED_STACK_TYPE =
A value indicating that the enum field is not set.
0- IPV4_IPV6 =
The interconnect attachment can have both IPv4 and IPv6 addresses.
22_197_249- IPV4_ONLY =
The interconnect attachment will only be assigned IPv4 addresses.
22_373_798