Module: Google::Cloud::Compute::V1::InterconnectAttachment::Type
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The type of interconnect attachment this is, which can take one of the following values: - DEDICATED: an attachment to a Dedicated Interconnect. - PARTNER: an attachment to a Partner Interconnect, created by the customer. - PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the partner.
Constant Summary collapse
- UNDEFINED_TYPE =
A value indicating that the enum field is not set.
0- DEDICATED =
Attachment to a dedicated interconnect.
258_411_983- PARTNER =
Attachment to a partner interconnect, created by the customer.
461_924_520- PARTNER_PROVIDER =
Attachment to a partner interconnect, created by the partner.
483_261_352