Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfiguredAvailabilitySLA
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfiguredAvailabilitySLA
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements.
Defined Under Namespace
Modules: EffectiveSla
Instance Attribute Summary collapse
-
#effective_sla ⇒ ::String
Check the EffectiveSla enum for the list of possible values.
- #intended_sla_blockers ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers>
Instance Attribute Details
#effective_sla ⇒ ::String
Returns Check the EffectiveSla enum for the list of possible values.
36348 36349 36350 36351 36352 36353 36354 36355 36356 36357 36358 36359 36360 36361 36362 36363 36364 36365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36348 class InterconnectAttachmentGroupConfiguredAvailabilitySLA include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module EffectiveSla # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_SLA = 0 EFFECTIVE_SLA_UNSPECIFIED = 491_000_744 NO_SLA = 161_460_618 PRODUCTION_CRITICAL = 470_416_485 PRODUCTION_NON_CRITICAL = 117_399_223 end end |
#intended_sla_blockers ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers>
36348 36349 36350 36351 36352 36353 36354 36355 36356 36357 36358 36359 36360 36361 36362 36363 36364 36365 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36348 class InterconnectAttachmentGroupConfiguredAvailabilitySLA include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module EffectiveSla # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_SLA = 0 EFFECTIVE_SLA_UNSPECIFIED = 491_000_744 NO_SLA = 161_460_618 PRODUCTION_CRITICAL = 470_416_485 PRODUCTION_NON_CRITICAL = 117_399_223 end end |