Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] Reasons why configuration.availabilitySLA.sla differs from intent.availabilitySLA. This list is empty if and only if those are the same.
Defined Under Namespace
Modules: BlockerType
Instance Attribute Summary collapse
-
#attachments ⇒ ::Array<::String>
Output only.
-
#blocker_type ⇒ ::String
Check the BlockerType enum for the list of possible values.
-
#documentation_link ⇒ ::String
Output only.
-
#explanation ⇒ ::String
Output only.
-
#metros ⇒ ::Array<::String>
Output only.
-
#regions ⇒ ::Array<::String>
Output only.
-
#zones ⇒ ::Array<::String>
Output only.
Instance Attribute Details
#attachments ⇒ ::Array<::String>
Returns Output only. [Output Only] URLs of any particular Attachments to explain this blocker in more detail.
36402 36403 36404 36405 36406 36407 36408 36409 36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 36420 36421 36422 36423 36424 36425 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36402 class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 BLOCKER_TYPE_UNSPECIFIED = 429_793_623 INCOMPATIBLE_METROS = 290_410_432 INCOMPATIBLE_REGIONS = 6_195_033 MISSING_GLOBAL_ROUTING = 165_913_635 NO_ATTACHMENTS = 456_535_570 NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135 OTHER = 75_532_016 end end |
#blocker_type ⇒ ::String
Returns Check the BlockerType enum for the list of possible values.
36402 36403 36404 36405 36406 36407 36408 36409 36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 36420 36421 36422 36423 36424 36425 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36402 class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 BLOCKER_TYPE_UNSPECIFIED = 429_793_623 INCOMPATIBLE_METROS = 290_410_432 INCOMPATIBLE_REGIONS = 6_195_033 MISSING_GLOBAL_ROUTING = 165_913_635 NO_ATTACHMENTS = 456_535_570 NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135 OTHER = 75_532_016 end end |
#documentation_link ⇒ ::String
Returns Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement.
36402 36403 36404 36405 36406 36407 36408 36409 36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 36420 36421 36422 36423 36424 36425 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36402 class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 BLOCKER_TYPE_UNSPECIFIED = 429_793_623 INCOMPATIBLE_METROS = 290_410_432 INCOMPATIBLE_REGIONS = 6_195_033 MISSING_GLOBAL_ROUTING = 165_913_635 NO_ATTACHMENTS = 456_535_570 NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135 OTHER = 75_532_016 end end |
#explanation ⇒ ::String
Returns Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement.
36402 36403 36404 36405 36406 36407 36408 36409 36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 36420 36421 36422 36423 36424 36425 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36402 class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 BLOCKER_TYPE_UNSPECIFIED = 429_793_623 INCOMPATIBLE_METROS = 290_410_432 INCOMPATIBLE_REGIONS = 6_195_033 MISSING_GLOBAL_ROUTING = 165_913_635 NO_ATTACHMENTS = 456_535_570 NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135 OTHER = 75_532_016 end end |
#metros ⇒ ::Array<::String>
Returns Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". This will be set for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does not apply to others.
36402 36403 36404 36405 36406 36407 36408 36409 36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 36420 36421 36422 36423 36424 36425 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36402 class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 BLOCKER_TYPE_UNSPECIFIED = 429_793_623 INCOMPATIBLE_METROS = 290_410_432 INCOMPATIBLE_REGIONS = 6_195_033 MISSING_GLOBAL_ROUTING = 165_913_635 NO_ATTACHMENTS = 456_535_570 NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135 OTHER = 75_532_016 end end |
#regions ⇒ ::Array<::String>
Returns Output only. [Output Only] Regions used to explain this blocker in more detail. These are region names formatted like "us-central1". This will be set for some blockers (like INCOMPATIBLE_REGIONS) but does not apply to others.
36402 36403 36404 36405 36406 36407 36408 36409 36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 36420 36421 36422 36423 36424 36425 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36402 class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 BLOCKER_TYPE_UNSPECIFIED = 429_793_623 INCOMPATIBLE_METROS = 290_410_432 INCOMPATIBLE_REGIONS = 6_195_033 MISSING_GLOBAL_ROUTING = 165_913_635 NO_ATTACHMENTS = 456_535_570 NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135 OTHER = 75_532_016 end end |
#zones ⇒ ::Array<::String>
Returns Output only. [Output Only] Zones used to explain this blocker in more detail. Format is "zone1" and/or "zone2". This will be set for some blockers (like MISSING_ZONE) but does not apply to others.
36402 36403 36404 36405 36406 36407 36408 36409 36410 36411 36412 36413 36414 36415 36416 36417 36418 36419 36420 36421 36422 36423 36424 36425 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36402 class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 BLOCKER_TYPE_UNSPECIFIED = 429_793_623 INCOMPATIBLE_METROS = 290_410_432 INCOMPATIBLE_REGIONS = 6_195_033 MISSING_GLOBAL_ROUTING = 165_913_635 NO_ATTACHMENTS = 456_535_570 NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135 OTHER = 75_532_016 end end |