Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] Reasons why configuration.availabilitySLA.sla differs from intent.availabilitySLA. This list is empty if and only if those are the same.

Defined Under Namespace

Modules: BlockerType

Instance Attribute Summary collapse

Instance Attribute Details

#attachments::Array<::String>

Returns Output only. [Output Only] URLs of any particular Attachments to explain this blocker in more detail.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] URLs of any particular Attachments to explain this blocker in more detail.



35679
35680
35681
35682
35683
35684
35685
35686
35687
35688
35689
35690
35691
35692
35693
35694
35695
35696
35697
35698
35699
35700
35701
35702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35679

class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    BLOCKER_TYPE_UNSPECIFIED = 429_793_623

    INCOMPATIBLE_METROS = 290_410_432

    INCOMPATIBLE_REGIONS = 6_195_033

    MISSING_GLOBAL_ROUTING = 165_913_635

    NO_ATTACHMENTS = 456_535_570

    NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135

    OTHER = 75_532_016
  end
end

#blocker_type::String

Returns Check the BlockerType enum for the list of possible values.

Returns:

  • (::String)

    Check the BlockerType enum for the list of possible values.



35679
35680
35681
35682
35683
35684
35685
35686
35687
35688
35689
35690
35691
35692
35693
35694
35695
35696
35697
35698
35699
35700
35701
35702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35679

class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    BLOCKER_TYPE_UNSPECIFIED = 429_793_623

    INCOMPATIBLE_METROS = 290_410_432

    INCOMPATIBLE_REGIONS = 6_195_033

    MISSING_GLOBAL_ROUTING = 165_913_635

    NO_ATTACHMENTS = 456_535_570

    NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135

    OTHER = 75_532_016
  end
end

Returns Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement.

Returns:

  • (::String)

    Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement.



35679
35680
35681
35682
35683
35684
35685
35686
35687
35688
35689
35690
35691
35692
35693
35694
35695
35696
35697
35698
35699
35700
35701
35702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35679

class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    BLOCKER_TYPE_UNSPECIFIED = 429_793_623

    INCOMPATIBLE_METROS = 290_410_432

    INCOMPATIBLE_REGIONS = 6_195_033

    MISSING_GLOBAL_ROUTING = 165_913_635

    NO_ATTACHMENTS = 456_535_570

    NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135

    OTHER = 75_532_016
  end
end

#explanation::String

Returns Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement.

Returns:

  • (::String)

    Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement.



35679
35680
35681
35682
35683
35684
35685
35686
35687
35688
35689
35690
35691
35692
35693
35694
35695
35696
35697
35698
35699
35700
35701
35702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35679

class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    BLOCKER_TYPE_UNSPECIFIED = 429_793_623

    INCOMPATIBLE_METROS = 290_410_432

    INCOMPATIBLE_REGIONS = 6_195_033

    MISSING_GLOBAL_ROUTING = 165_913_635

    NO_ATTACHMENTS = 456_535_570

    NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135

    OTHER = 75_532_016
  end
end

#metros::Array<::String>

Returns Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". This will be set for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does not apply to others.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". This will be set for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does not apply to others.



35679
35680
35681
35682
35683
35684
35685
35686
35687
35688
35689
35690
35691
35692
35693
35694
35695
35696
35697
35698
35699
35700
35701
35702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35679

class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    BLOCKER_TYPE_UNSPECIFIED = 429_793_623

    INCOMPATIBLE_METROS = 290_410_432

    INCOMPATIBLE_REGIONS = 6_195_033

    MISSING_GLOBAL_ROUTING = 165_913_635

    NO_ATTACHMENTS = 456_535_570

    NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135

    OTHER = 75_532_016
  end
end

#regions::Array<::String>

Returns Output only. [Output Only] Regions used to explain this blocker in more detail. These are region names formatted like "us-central1". This will be set for some blockers (like INCOMPATIBLE_REGIONS) but does not apply to others.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Regions used to explain this blocker in more detail. These are region names formatted like "us-central1". This will be set for some blockers (like INCOMPATIBLE_REGIONS) but does not apply to others.



35679
35680
35681
35682
35683
35684
35685
35686
35687
35688
35689
35690
35691
35692
35693
35694
35695
35696
35697
35698
35699
35700
35701
35702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35679

class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    BLOCKER_TYPE_UNSPECIFIED = 429_793_623

    INCOMPATIBLE_METROS = 290_410_432

    INCOMPATIBLE_REGIONS = 6_195_033

    MISSING_GLOBAL_ROUTING = 165_913_635

    NO_ATTACHMENTS = 456_535_570

    NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135

    OTHER = 75_532_016
  end
end

#zones::Array<::String>

Returns Output only. [Output Only] Zones used to explain this blocker in more detail. Format is "zone1" and/or "zone2". This will be set for some blockers (like MISSING_ZONE) but does not apply to others.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Zones used to explain this blocker in more detail. Format is "zone1" and/or "zone2". This will be set for some blockers (like MISSING_ZONE) but does not apply to others.



35679
35680
35681
35682
35683
35684
35685
35686
35687
35688
35689
35690
35691
35692
35693
35694
35695
35696
35697
35698
35699
35700
35701
35702
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35679

class InterconnectAttachmentGroupConfiguredAvailabilitySLAIntendedSlaBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    BLOCKER_TYPE_UNSPECIFIED = 429_793_623

    INCOMPATIBLE_METROS = 290_410_432

    INCOMPATIBLE_REGIONS = 6_195_033

    MISSING_GLOBAL_ROUTING = 165_913_635

    NO_ATTACHMENTS = 456_535_570

    NO_ATTACHMENTS_IN_METRO_AND_ZONE = 51_684_135

    OTHER = 75_532_016
  end
end