Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupIntent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation.

Defined Under Namespace

Modules: AvailabilitySla

Instance Attribute Summary collapse

Instance Attribute Details

#availability_sla::String

Returns Check the AvailabilitySla enum for the list of possible values.

Returns:

  • (::String)

    Check the AvailabilitySla enum for the list of possible values.



36432
36433
36434
36435
36436
36437
36438
36439
36440
36441
36442
36443
36444
36445
36446
36447
36448
36449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36432

class InterconnectAttachmentGroupIntent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module AvailabilitySla
    # A value indicating that the enum field is not set.
    UNDEFINED_AVAILABILITY_SLA = 0

    AVAILABILITY_SLA_UNSPECIFIED = 11_186_044

    NO_SLA = 161_460_618

    PRODUCTION_CRITICAL = 470_416_485

    PRODUCTION_NON_CRITICAL = 117_399_223
  end
end