Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.

Instance Attribute Summary collapse

Instance Attribute Details

#attachments::Array<::String>

Returns Output only. [Output Only] URLs of Attachments in the given zone, to the given region, on Interconnects in the given facility and metro. Every Attachment in the AG has such an entry.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] URLs of Attachments in the given zone, to the given region, on Interconnects in the given facility and metro. Every Attachment in the AG has such an entry.



36507
36508
36509
36510
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36507

class InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String

Returns Output only. [Output Only] The name of a zone, either "zone1" or "zone2".

Returns:

  • (::String)

    Output only. [Output Only] The name of a zone, either "zone1" or "zone2".



36507
36508
36509
36510
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36507

class InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end