Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: GroupStatus

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_statuses::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>



36919
36920
36921
36922
36923
36924
36925
36926
36927
36928
36929
36930
36931
36932
36933
36934
36935
36936
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36919

class InterconnectAttachmentGroupsOperationalStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Summarizes the status of the group.
  module GroupStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_GROUP_STATUS = 0

    DEGRADED = 396_890_926

    FULLY_DOWN = 255_514_647

    FULLY_UP = 504_176_464

    UNSPECIFIED = 526_786_327
  end
end

#configured::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured



36919
36920
36921
36922
36923
36924
36925
36926
36927
36928
36929
36930
36931
36932
36933
36934
36935
36936
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36919

class InterconnectAttachmentGroupsOperationalStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Summarizes the status of the group.
  module GroupStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_GROUP_STATUS = 0

    DEGRADED = 396_890_926

    FULLY_DOWN = 255_514_647

    FULLY_UP = 504_176_464

    UNSPECIFIED = 526_786_327
  end
end

#group_status::String

Returns Output only. Summarizes the status of the group. Check the GroupStatus enum for the list of possible values.

Returns:

  • (::String)

    Output only. Summarizes the status of the group. Check the GroupStatus enum for the list of possible values.



36919
36920
36921
36922
36923
36924
36925
36926
36927
36928
36929
36930
36931
36932
36933
36934
36935
36936
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36919

class InterconnectAttachmentGroupsOperationalStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Summarizes the status of the group.
  module GroupStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_GROUP_STATUS = 0

    DEGRADED = 396_890_926

    FULLY_DOWN = 255_514_647

    FULLY_UP = 504_176_464

    UNSPECIFIED = 526_786_327
  end
end

#intent::Google::Cloud::Compute::V1::InterconnectAttachmentGroupIntent



36919
36920
36921
36922
36923
36924
36925
36926
36927
36928
36929
36930
36931
36932
36933
36934
36935
36936
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36919

class InterconnectAttachmentGroupsOperationalStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Summarizes the status of the group.
  module GroupStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_GROUP_STATUS = 0

    DEGRADED = 396_890_926

    FULLY_DOWN = 255_514_647

    FULLY_UP = 504_176_464

    UNSPECIFIED = 526_786_327
  end
end

#operational::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured

Returns Output only. The operational state of the group, including only active Attachments.

Returns:



36919
36920
36921
36922
36923
36924
36925
36926
36927
36928
36929
36930
36931
36932
36933
36934
36935
36936
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36919

class InterconnectAttachmentGroupsOperationalStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Summarizes the status of the group.
  module GroupStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_GROUP_STATUS = 0

    DEGRADED = 396_890_926

    FULLY_DOWN = 255_514_647

    FULLY_UP = 504_176_464

    UNSPECIFIED = 526_786_327
  end
end