Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: GroupStatus
Instance Attribute Summary collapse
- #attachment_statuses ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
- #configured ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
-
#group_status ⇒ ::String
Output only.
- #intent ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupIntent
-
#operational ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
Output only.
Instance Attribute Details
#attachment_statuses ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
36568 36569 36570 36571 36572 36573 36574 36575 36576 36577 36578 36579 36580 36581 36582 36583 36584 36585 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36568 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |
#configured ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
36568 36569 36570 36571 36572 36573 36574 36575 36576 36577 36578 36579 36580 36581 36582 36583 36584 36585 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36568 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |
#group_status ⇒ ::String
Returns Output only. Summarizes the status of the group. Check the GroupStatus enum for the list of possible values.
36568 36569 36570 36571 36572 36573 36574 36575 36576 36577 36578 36579 36580 36581 36582 36583 36584 36585 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36568 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |
#intent ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupIntent
36568 36569 36570 36571 36572 36573 36574 36575 36576 36577 36578 36579 36580 36581 36582 36583 36584 36585 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36568 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |
#operational ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
Returns Output only. The operational state of the group, including only active Attachments.
36568 36569 36570 36571 36572 36573 36574 36575 36576 36577 36578 36579 36580 36581 36582 36583 36584 36585 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36568 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |