Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: GroupStatus
Instance Attribute Summary collapse
- #attachment_statuses ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
- #configured ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
-
#group_status ⇒ ::String
Output only.
- #intent ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupIntent
-
#operational ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
Output only.
Instance Attribute Details
#attachment_statuses ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38018 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |
#configured ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38018 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |
#group_status ⇒ ::String
Returns Output only. Summarizes the status of the group. Check the GroupStatus enum for the list of possible values.
38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38018 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |
#intent ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupIntent
38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38018 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |
#operational ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentGroupConfigured
Returns Output only. The operational state of the group, including only active Attachments.
38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38018 class InterconnectAttachmentGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 UNSPECIFIED = 526_786_327 end end |