Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The status of one Attachment in the group. List order is arbitrary.

Defined Under Namespace

Modules: IsActive, Status

Instance Attribute Summary collapse

Instance Attribute Details

#admin_enabled::Boolean

Returns Output only. Whether this Attachment is enabled. This becomes false when the customer drains their Attachment.

Returns:

  • (::Boolean)

    Output only. Whether this Attachment is enabled. This becomes false when the customer drains their Attachment.



36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
36621
36622
36623
36624
36625
36626
36627
36628
36629
36630
36631
36632
36633
36634
36635
36636
36637
36638
36639
36640
36641
36642
36643
36644
36645
36646
36647
36648
36649
36650
36651
36652
36653
36654
36655
36656
36657
36658
36659
36660
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36606

class InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Whether this Attachment is participating in the redundant configuration.
  # This will be ACTIVE if and only if the status below is CONNECTION_UP.
  # Any INACTIVE Attachments are excluded from the analysis that generates
  # operational.availabilitySLA.
  module IsActive
    # A value indicating that the enum field is not set.
    UNDEFINED_IS_ACTIVE = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099

    UNSPECIFIED = 526_786_327
  end

  # Output only. Whether this Attachment is active, and if so, whether BGP is up.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ATTACHMENT_STATUS_UNKNOWN = 472_477_561

    CONNECTION_DISABLED = 432_687_805

    CONNECTION_DOWN = 267_552_099

    CONNECTION_UP = 455_585_692

    DEFUNCT = 115_891_759

    IPSEC_CONFIGURATION_NEEDED_STATUS = 455_203_582

    IPSEC_READY_TO_RESUME_FLOW_STATUS = 384_830_596

    IPV4_DOWN_IPV6_UP = 277_490_992

    IPV4_UP_IPV6_DOWN = 316_051_248

    PARTNER_REQUEST_RECEIVED = 513_587_304

    PENDING_CUSTOMER = 167_494_054

    PENDING_PARTNER = 387_890_656

    PROVISIONED = 355_751_956

    ROUTER_CONFIGURATION_BROKEN = 150_505_108

    UNPROVISIONED = 517_333_979
  end
end

#attachment::String

Returns Output only. The URL of the Attachment being described.

Returns:

  • (::String)

    Output only. The URL of the Attachment being described.



36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
36621
36622
36623
36624
36625
36626
36627
36628
36629
36630
36631
36632
36633
36634
36635
36636
36637
36638
36639
36640
36641
36642
36643
36644
36645
36646
36647
36648
36649
36650
36651
36652
36653
36654
36655
36656
36657
36658
36659
36660
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36606

class InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Whether this Attachment is participating in the redundant configuration.
  # This will be ACTIVE if and only if the status below is CONNECTION_UP.
  # Any INACTIVE Attachments are excluded from the analysis that generates
  # operational.availabilitySLA.
  module IsActive
    # A value indicating that the enum field is not set.
    UNDEFINED_IS_ACTIVE = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099

    UNSPECIFIED = 526_786_327
  end

  # Output only. Whether this Attachment is active, and if so, whether BGP is up.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ATTACHMENT_STATUS_UNKNOWN = 472_477_561

    CONNECTION_DISABLED = 432_687_805

    CONNECTION_DOWN = 267_552_099

    CONNECTION_UP = 455_585_692

    DEFUNCT = 115_891_759

    IPSEC_CONFIGURATION_NEEDED_STATUS = 455_203_582

    IPSEC_READY_TO_RESUME_FLOW_STATUS = 384_830_596

    IPV4_DOWN_IPV6_UP = 277_490_992

    IPV4_UP_IPV6_DOWN = 316_051_248

    PARTNER_REQUEST_RECEIVED = 513_587_304

    PENDING_CUSTOMER = 167_494_054

    PENDING_PARTNER = 387_890_656

    PROVISIONED = 355_751_956

    ROUTER_CONFIGURATION_BROKEN = 150_505_108

    UNPROVISIONED = 517_333_979
  end
end

#is_active::String

Returns Output only. Whether this Attachment is participating in the redundant configuration. This will be ACTIVE if and only if the status below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis that generates operational.availabilitySLA. Check the IsActive enum for the list of possible values.

Returns:

  • (::String)

    Output only. Whether this Attachment is participating in the redundant configuration. This will be ACTIVE if and only if the status below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis that generates operational.availabilitySLA. Check the IsActive enum for the list of possible values.



36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
36621
36622
36623
36624
36625
36626
36627
36628
36629
36630
36631
36632
36633
36634
36635
36636
36637
36638
36639
36640
36641
36642
36643
36644
36645
36646
36647
36648
36649
36650
36651
36652
36653
36654
36655
36656
36657
36658
36659
36660
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36606

class InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Whether this Attachment is participating in the redundant configuration.
  # This will be ACTIVE if and only if the status below is CONNECTION_UP.
  # Any INACTIVE Attachments are excluded from the analysis that generates
  # operational.availabilitySLA.
  module IsActive
    # A value indicating that the enum field is not set.
    UNDEFINED_IS_ACTIVE = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099

    UNSPECIFIED = 526_786_327
  end

  # Output only. Whether this Attachment is active, and if so, whether BGP is up.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ATTACHMENT_STATUS_UNKNOWN = 472_477_561

    CONNECTION_DISABLED = 432_687_805

    CONNECTION_DOWN = 267_552_099

    CONNECTION_UP = 455_585_692

    DEFUNCT = 115_891_759

    IPSEC_CONFIGURATION_NEEDED_STATUS = 455_203_582

    IPSEC_READY_TO_RESUME_FLOW_STATUS = 384_830_596

    IPV4_DOWN_IPV6_UP = 277_490_992

    IPV4_UP_IPV6_DOWN = 316_051_248

    PARTNER_REQUEST_RECEIVED = 513_587_304

    PENDING_CUSTOMER = 167_494_054

    PENDING_PARTNER = 387_890_656

    PROVISIONED = 355_751_956

    ROUTER_CONFIGURATION_BROKEN = 150_505_108

    UNPROVISIONED = 517_333_979
  end
end

#status::String

Returns Output only. Whether this Attachment is active, and if so, whether BGP is up. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. Whether this Attachment is active, and if so, whether BGP is up. Check the Status enum for the list of possible values.



36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
36621
36622
36623
36624
36625
36626
36627
36628
36629
36630
36631
36632
36633
36634
36635
36636
36637
36638
36639
36640
36641
36642
36643
36644
36645
36646
36647
36648
36649
36650
36651
36652
36653
36654
36655
36656
36657
36658
36659
36660
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36606

class InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Whether this Attachment is participating in the redundant configuration.
  # This will be ACTIVE if and only if the status below is CONNECTION_UP.
  # Any INACTIVE Attachments are excluded from the analysis that generates
  # operational.availabilitySLA.
  module IsActive
    # A value indicating that the enum field is not set.
    UNDEFINED_IS_ACTIVE = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099

    UNSPECIFIED = 526_786_327
  end

  # Output only. Whether this Attachment is active, and if so, whether BGP is up.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ATTACHMENT_STATUS_UNKNOWN = 472_477_561

    CONNECTION_DISABLED = 432_687_805

    CONNECTION_DOWN = 267_552_099

    CONNECTION_UP = 455_585_692

    DEFUNCT = 115_891_759

    IPSEC_CONFIGURATION_NEEDED_STATUS = 455_203_582

    IPSEC_READY_TO_RESUME_FLOW_STATUS = 384_830_596

    IPV4_DOWN_IPV6_UP = 277_490_992

    IPV4_UP_IPV6_DOWN = 316_051_248

    PARTNER_REQUEST_RECEIVED = 513_587_304

    PENDING_CUSTOMER = 167_494_054

    PENDING_PARTNER = 387_890_656

    PROVISIONED = 355_751_956

    ROUTER_CONFIGURATION_BROKEN = 150_505_108

    UNPROVISIONED = 517_333_979
  end
end