Class: Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The status of one Attachment in the group. List order is arbitrary.
Defined Under Namespace
Instance Attribute Summary collapse
-
#admin_enabled ⇒ ::Boolean
Output only.
-
#attachment ⇒ ::String
Output only.
-
#is_active ⇒ ::String
Output only.
-
#status ⇒ ::String
Output only.
Instance Attribute Details
#admin_enabled ⇒ ::Boolean
Returns Output only. Whether this Attachment is enabled. This becomes false when the customer drains their Attachment.
38056 38057 38058 38059 38060 38061 38062 38063 38064 38065 38066 38067 38068 38069 38070 38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 38081 38082 38083 38084 38085 38086 38087 38088 38089 38090 38091 38092 38093 38094 38095 38096 38097 38098 38099 38100 38101 38102 38103 38104 38105 38106 38107 38108 38109 38110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38056 class InterconnectAttachmentGroupsOperationalStatusAttachmentStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Whether this Attachment is participating in the redundant configuration. # This will be ACTIVE if and only if the status below is CONNECTION_UP. # Any INACTIVE Attachments are excluded from the analysis that generates # operational.availabilitySLA. module IsActive # A value indicating that the enum field is not set. UNDEFINED_IS_ACTIVE = 0 ACTIVE = 314_733_318 INACTIVE = 270_421_099 UNSPECIFIED = 526_786_327 end # Output only. Whether this Attachment is active, and if so, whether BGP is up. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 ATTACHMENT_STATUS_UNKNOWN = 472_477_561 CONNECTION_DISABLED = 432_687_805 CONNECTION_DOWN = 267_552_099 CONNECTION_UP = 455_585_692 DEFUNCT = 115_891_759 IPSEC_CONFIGURATION_NEEDED_STATUS = 455_203_582 IPSEC_READY_TO_RESUME_FLOW_STATUS = 384_830_596 IPV4_DOWN_IPV6_UP = 277_490_992 IPV4_UP_IPV6_DOWN = 316_051_248 PARTNER_REQUEST_RECEIVED = 513_587_304 PENDING_CUSTOMER = 167_494_054 PENDING_PARTNER = 387_890_656 PROVISIONED = 355_751_956 ROUTER_CONFIGURATION_BROKEN = 150_505_108 UNPROVISIONED = 517_333_979 end end |
#attachment ⇒ ::String
Returns Output only. The URL of the Attachment being described.
38056 38057 38058 38059 38060 38061 38062 38063 38064 38065 38066 38067 38068 38069 38070 38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 38081 38082 38083 38084 38085 38086 38087 38088 38089 38090 38091 38092 38093 38094 38095 38096 38097 38098 38099 38100 38101 38102 38103 38104 38105 38106 38107 38108 38109 38110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38056 class InterconnectAttachmentGroupsOperationalStatusAttachmentStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Whether this Attachment is participating in the redundant configuration. # This will be ACTIVE if and only if the status below is CONNECTION_UP. # Any INACTIVE Attachments are excluded from the analysis that generates # operational.availabilitySLA. module IsActive # A value indicating that the enum field is not set. UNDEFINED_IS_ACTIVE = 0 ACTIVE = 314_733_318 INACTIVE = 270_421_099 UNSPECIFIED = 526_786_327 end # Output only. Whether this Attachment is active, and if so, whether BGP is up. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 ATTACHMENT_STATUS_UNKNOWN = 472_477_561 CONNECTION_DISABLED = 432_687_805 CONNECTION_DOWN = 267_552_099 CONNECTION_UP = 455_585_692 DEFUNCT = 115_891_759 IPSEC_CONFIGURATION_NEEDED_STATUS = 455_203_582 IPSEC_READY_TO_RESUME_FLOW_STATUS = 384_830_596 IPV4_DOWN_IPV6_UP = 277_490_992 IPV4_UP_IPV6_DOWN = 316_051_248 PARTNER_REQUEST_RECEIVED = 513_587_304 PENDING_CUSTOMER = 167_494_054 PENDING_PARTNER = 387_890_656 PROVISIONED = 355_751_956 ROUTER_CONFIGURATION_BROKEN = 150_505_108 UNPROVISIONED = 517_333_979 end end |
#is_active ⇒ ::String
Returns Output only. Whether this Attachment is participating in the redundant configuration. This will be ACTIVE if and only if the status below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis that generates operational.availabilitySLA. Check the IsActive enum for the list of possible values.
38056 38057 38058 38059 38060 38061 38062 38063 38064 38065 38066 38067 38068 38069 38070 38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 38081 38082 38083 38084 38085 38086 38087 38088 38089 38090 38091 38092 38093 38094 38095 38096 38097 38098 38099 38100 38101 38102 38103 38104 38105 38106 38107 38108 38109 38110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38056 class InterconnectAttachmentGroupsOperationalStatusAttachmentStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Whether this Attachment is participating in the redundant configuration. # This will be ACTIVE if and only if the status below is CONNECTION_UP. # Any INACTIVE Attachments are excluded from the analysis that generates # operational.availabilitySLA. module IsActive # A value indicating that the enum field is not set. UNDEFINED_IS_ACTIVE = 0 ACTIVE = 314_733_318 INACTIVE = 270_421_099 UNSPECIFIED = 526_786_327 end # Output only. Whether this Attachment is active, and if so, whether BGP is up. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 ATTACHMENT_STATUS_UNKNOWN = 472_477_561 CONNECTION_DISABLED = 432_687_805 CONNECTION_DOWN = 267_552_099 CONNECTION_UP = 455_585_692 DEFUNCT = 115_891_759 IPSEC_CONFIGURATION_NEEDED_STATUS = 455_203_582 IPSEC_READY_TO_RESUME_FLOW_STATUS = 384_830_596 IPV4_DOWN_IPV6_UP = 277_490_992 IPV4_UP_IPV6_DOWN = 316_051_248 PARTNER_REQUEST_RECEIVED = 513_587_304 PENDING_CUSTOMER = 167_494_054 PENDING_PARTNER = 387_890_656 PROVISIONED = 355_751_956 ROUTER_CONFIGURATION_BROKEN = 150_505_108 UNPROVISIONED = 517_333_979 end end |
#status ⇒ ::String
Returns Output only. Whether this Attachment is active, and if so, whether BGP is up. Check the Status enum for the list of possible values.
38056 38057 38058 38059 38060 38061 38062 38063 38064 38065 38066 38067 38068 38069 38070 38071 38072 38073 38074 38075 38076 38077 38078 38079 38080 38081 38082 38083 38084 38085 38086 38087 38088 38089 38090 38091 38092 38093 38094 38095 38096 38097 38098 38099 38100 38101 38102 38103 38104 38105 38106 38107 38108 38109 38110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38056 class InterconnectAttachmentGroupsOperationalStatusAttachmentStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Whether this Attachment is participating in the redundant configuration. # This will be ACTIVE if and only if the status below is CONNECTION_UP. # Any INACTIVE Attachments are excluded from the analysis that generates # operational.availabilitySLA. module IsActive # A value indicating that the enum field is not set. UNDEFINED_IS_ACTIVE = 0 ACTIVE = 314_733_318 INACTIVE = 270_421_099 UNSPECIFIED = 526_786_327 end # Output only. Whether this Attachment is active, and if so, whether BGP is up. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 ATTACHMENT_STATUS_UNKNOWN = 472_477_561 CONNECTION_DISABLED = 432_687_805 CONNECTION_DOWN = 267_552_099 CONNECTION_UP = 455_585_692 DEFUNCT = 115_891_759 IPSEC_CONFIGURATION_NEEDED_STATUS = 455_203_582 IPSEC_READY_TO_RESUME_FLOW_STATUS = 384_830_596 IPV4_DOWN_IPV6_UP = 277_490_992 IPV4_UP_IPV6_DOWN = 316_051_248 PARTNER_REQUEST_RECEIVED = 513_587_304 PENDING_CUSTOMER = 167_494_054 PENDING_PARTNER = 387_890_656 PROVISIONED = 355_751_956 ROUTER_CONFIGURATION_BROKEN = 150_505_108 UNPROVISIONED = 517_333_979 end end |