Class: Google::Cloud::Compute::V1::InterconnectAttachmentL2Forwarding
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentL2Forwarding
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
L2 Interconnect Attachment related configuration.
Defined Under Namespace
Classes: ApplianceMappingsEntry
Instance Attribute Summary collapse
-
#appliance_mappings ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMapping}
Optional.
-
#default_appliance_ip_address ⇒ ::String
Optional.
-
#geneve_header ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingGeneveHeader
Optional.
-
#network ⇒ ::String
Required.
-
#tunnel_endpoint_ip_address ⇒ ::String
Required.
Instance Attribute Details
#appliance_mappings ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMapping}
Returns Optional. A map of VLAN tags to appliances and optional inner mapping rules. If VLANs are not explicitly mapped to any appliance, the defaultApplianceIpAddress is used.
Each VLAN tag can be a single number or a range of numbers in the range of 1 to 4094, e.g., "1" or "4001-4094". Non-empty and non-overlapping VLAN tag ranges are enforced, and violating operations will be rejected.
The VLAN tags in the Ethernet header must use an ethertype value of 0x88A8 or 0x8100.
35974 35975 35976 35977 35978 35979 35980 35981 35982 35983 35984 35985 35986 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35974 class InterconnectAttachmentL2Forwarding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMapping] class ApplianceMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_appliance_ip_address ⇒ ::String
Returns Optional. A single IPv4 or IPv6 address used as the default destination IP when there is no VLAN mapping result found.
Unset field (null-value) indicates the unmatched packet should be dropped.
35974 35975 35976 35977 35978 35979 35980 35981 35982 35983 35984 35985 35986 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35974 class InterconnectAttachmentL2Forwarding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMapping] class ApplianceMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#geneve_header ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingGeneveHeader
Returns Optional. It represents the structure of a Geneve (Generic Network Virtualization Encapsulation) header, as defined in RFC8926. It encapsulates packets from various protocols (e.g., Ethernet, IPv4, IPv6) for use in network virtualization environments.
35974 35975 35976 35977 35978 35979 35980 35981 35982 35983 35984 35985 35986 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35974 class InterconnectAttachmentL2Forwarding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMapping] class ApplianceMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#network ⇒ ::String
Returns Required. Resource URL of the network to which this attachment belongs.
35974 35975 35976 35977 35978 35979 35980 35981 35982 35983 35984 35985 35986 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35974 class InterconnectAttachmentL2Forwarding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMapping] class ApplianceMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tunnel_endpoint_ip_address ⇒ ::String
Returns Required. A single IPv4 or IPv6 address. This address will be used as the source IP address for packets sent to the appliances, and must be used as the destination IP address for packets that should be sent out through this attachment.
35974 35975 35976 35977 35978 35979 35980 35981 35982 35983 35984 35985 35986 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35974 class InterconnectAttachmentL2Forwarding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMapping] class ApplianceMappingsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |