Class: Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMapping
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMapping
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Two-level VLAN-to-Appliance mapping rule.
Instance Attribute Summary collapse
-
#appliance_ip_address ⇒ ::String
Optional.
-
#inner_vlan_to_appliance_mappings ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping>
Optional.
-
#name ⇒ ::String
Optional.
Instance Attribute Details
#appliance_ip_address ⇒ ::String
Returns Optional. A single IPv4 or IPv6 address used as the destination IP address for ingress packets that match on a VLAN tag, but do not match a more specific inner VLAN tag.
Unset field (null-value) indicates both VLAN tags are required to be mapped. Otherwise, defaultApplianceIpAddress is used.
36008 36009 36010 36011 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36008 class InterconnectAttachmentL2ForwardingApplianceMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#inner_vlan_to_appliance_mappings ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping>
Returns Optional. Used to match against the inner VLAN when the packet contains two VLAN tags.
A list of mapping rules from inner VLAN tags to IP addresses. If the inner VLAN is not explicitly mapped to an IP address range, the applianceIpAddress is used.
36008 36009 36010 36011 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36008 class InterconnectAttachmentL2ForwardingApplianceMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Optional. The name of this appliance mapping rule.
36008 36009 36010 36011 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36008 class InterconnectAttachmentL2ForwardingApplianceMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |