Class: Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The inner VLAN-to-Appliance mapping.
Instance Attribute Summary collapse
-
#inner_appliance_ip_address ⇒ ::String
Required in this object.
-
#inner_vlan_tags ⇒ ::Array<::String>
Required in this object.
Instance Attribute Details
#inner_appliance_ip_address ⇒ ::String
Returns Required in this object. A single IPv4 or IPv6 address used as the destination IP address for ingress packets that match on both VLAN tags.
36028 36029 36030 36031 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36028 class InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#inner_vlan_tags ⇒ ::Array<::String>
Returns Required in this object. Used to match the inner VLAN tag on the packet. Each entry can be a single number or a range of numbers in the range of 1 to 4094, e.g., ["1", "4001-4094"] is valid. Non-empty and Non-overlapping VLAN tag ranges are enforced, and violating operations will be rejected.
The inner VLAN tags must have an ethertype value of 0x8100.
36028 36029 36030 36031 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36028 class InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |