Class: Google::Cloud::Compute::V1::InterconnectDiagnostics
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectDiagnostics
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection.
Defined Under Namespace
Modules: BundleAggregationType, BundleOperationalStatus
Instance Attribute Summary collapse
-
#arp_caches ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectDiagnosticsARPEntry>
A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect.
-
#bundle_aggregation_type ⇒ ::String
The aggregation type of the bundle interface.
-
#bundle_operational_status ⇒ ::String
The operational status of the bundle interface.
-
#links ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkStatus>
A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect.
-
#mac_address ⇒ ::String
The MAC address of the Interconnect's bundle interface.
Instance Attribute Details
#arp_caches ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectDiagnosticsARPEntry>
Returns A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect. This will be empty when the Interconnect is not bundled.
36913 36914 36915 36916 36917 36918 36919 36920 36921 36922 36923 36924 36925 36926 36927 36928 36929 36930 36931 36932 36933 36934 36935 36936 36937 36938 36939 36940 36941 36942 36943 36944 36945 36946 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36913 class InterconnectDiagnostics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The aggregation type of the bundle interface. module BundleAggregationType # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_AGGREGATION_TYPE = 0 # LACP is enabled. BUNDLE_AGGREGATION_TYPE_LACP = 27_758_925 # LACP is disabled. BUNDLE_AGGREGATION_TYPE_STATIC = 50_678_873 end # The operational status of the bundle interface. module BundleOperationalStatus # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_OPERATIONAL_STATUS = 0 # If bundleAggregationType is LACP: LACP is not established and/or all # links in the bundle have DOWN operational status. If # bundleAggregationType is STATIC: one or more links in the bundle has # DOWN operational status. BUNDLE_OPERATIONAL_STATUS_DOWN = 453_842_693 # If bundleAggregationType is LACP: LACP is established and at least one # link in the bundle has UP operational status. If bundleAggregationType # is STATIC: all links in the bundle (typically just one) have UP # operational status. BUNDLE_OPERATIONAL_STATUS_UP = 161_366_462 end end |
#bundle_aggregation_type ⇒ ::String
Returns The aggregation type of the bundle interface. Check the BundleAggregationType enum for the list of possible values.
36913 36914 36915 36916 36917 36918 36919 36920 36921 36922 36923 36924 36925 36926 36927 36928 36929 36930 36931 36932 36933 36934 36935 36936 36937 36938 36939 36940 36941 36942 36943 36944 36945 36946 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36913 class InterconnectDiagnostics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The aggregation type of the bundle interface. module BundleAggregationType # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_AGGREGATION_TYPE = 0 # LACP is enabled. BUNDLE_AGGREGATION_TYPE_LACP = 27_758_925 # LACP is disabled. BUNDLE_AGGREGATION_TYPE_STATIC = 50_678_873 end # The operational status of the bundle interface. module BundleOperationalStatus # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_OPERATIONAL_STATUS = 0 # If bundleAggregationType is LACP: LACP is not established and/or all # links in the bundle have DOWN operational status. If # bundleAggregationType is STATIC: one or more links in the bundle has # DOWN operational status. BUNDLE_OPERATIONAL_STATUS_DOWN = 453_842_693 # If bundleAggregationType is LACP: LACP is established and at least one # link in the bundle has UP operational status. If bundleAggregationType # is STATIC: all links in the bundle (typically just one) have UP # operational status. BUNDLE_OPERATIONAL_STATUS_UP = 161_366_462 end end |
#bundle_operational_status ⇒ ::String
Returns The operational status of the bundle interface. Check the BundleOperationalStatus enum for the list of possible values.
36913 36914 36915 36916 36917 36918 36919 36920 36921 36922 36923 36924 36925 36926 36927 36928 36929 36930 36931 36932 36933 36934 36935 36936 36937 36938 36939 36940 36941 36942 36943 36944 36945 36946 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36913 class InterconnectDiagnostics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The aggregation type of the bundle interface. module BundleAggregationType # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_AGGREGATION_TYPE = 0 # LACP is enabled. BUNDLE_AGGREGATION_TYPE_LACP = 27_758_925 # LACP is disabled. BUNDLE_AGGREGATION_TYPE_STATIC = 50_678_873 end # The operational status of the bundle interface. module BundleOperationalStatus # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_OPERATIONAL_STATUS = 0 # If bundleAggregationType is LACP: LACP is not established and/or all # links in the bundle have DOWN operational status. If # bundleAggregationType is STATIC: one or more links in the bundle has # DOWN operational status. BUNDLE_OPERATIONAL_STATUS_DOWN = 453_842_693 # If bundleAggregationType is LACP: LACP is established and at least one # link in the bundle has UP operational status. If bundleAggregationType # is STATIC: all links in the bundle (typically just one) have UP # operational status. BUNDLE_OPERATIONAL_STATUS_UP = 161_366_462 end end |
#links ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkStatus>
Returns A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect.
36913 36914 36915 36916 36917 36918 36919 36920 36921 36922 36923 36924 36925 36926 36927 36928 36929 36930 36931 36932 36933 36934 36935 36936 36937 36938 36939 36940 36941 36942 36943 36944 36945 36946 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36913 class InterconnectDiagnostics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The aggregation type of the bundle interface. module BundleAggregationType # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_AGGREGATION_TYPE = 0 # LACP is enabled. BUNDLE_AGGREGATION_TYPE_LACP = 27_758_925 # LACP is disabled. BUNDLE_AGGREGATION_TYPE_STATIC = 50_678_873 end # The operational status of the bundle interface. module BundleOperationalStatus # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_OPERATIONAL_STATUS = 0 # If bundleAggregationType is LACP: LACP is not established and/or all # links in the bundle have DOWN operational status. If # bundleAggregationType is STATIC: one or more links in the bundle has # DOWN operational status. BUNDLE_OPERATIONAL_STATUS_DOWN = 453_842_693 # If bundleAggregationType is LACP: LACP is established and at least one # link in the bundle has UP operational status. If bundleAggregationType # is STATIC: all links in the bundle (typically just one) have UP # operational status. BUNDLE_OPERATIONAL_STATUS_UP = 161_366_462 end end |
#mac_address ⇒ ::String
Returns The MAC address of the Interconnect's bundle interface.
36913 36914 36915 36916 36917 36918 36919 36920 36921 36922 36923 36924 36925 36926 36927 36928 36929 36930 36931 36932 36933 36934 36935 36936 36937 36938 36939 36940 36941 36942 36943 36944 36945 36946 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36913 class InterconnectDiagnostics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The aggregation type of the bundle interface. module BundleAggregationType # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_AGGREGATION_TYPE = 0 # LACP is enabled. BUNDLE_AGGREGATION_TYPE_LACP = 27_758_925 # LACP is disabled. BUNDLE_AGGREGATION_TYPE_STATIC = 50_678_873 end # The operational status of the bundle interface. module BundleOperationalStatus # A value indicating that the enum field is not set. UNDEFINED_BUNDLE_OPERATIONAL_STATUS = 0 # If bundleAggregationType is LACP: LACP is not established and/or all # links in the bundle have DOWN operational status. If # bundleAggregationType is STATIC: one or more links in the bundle has # DOWN operational status. BUNDLE_OPERATIONAL_STATUS_DOWN = 453_842_693 # If bundleAggregationType is LACP: LACP is established and at least one # link in the bundle has UP operational status. If bundleAggregationType # is STATIC: all links in the bundle (typically just one) have UP # operational status. BUNDLE_OPERATIONAL_STATUS_UP = 161_366_462 end end |