Class: Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkLACPStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#google_system_id::String

Returns System ID of the port on Google's side of the LACP exchange.

Returns:

  • (::String)

    System ID of the port on Google's side of the LACP exchange.



37325
37326
37327
37328
37329
37330
37331
37332
37333
37334
37335
37336
37337
37338
37339
37340
37341
37342
37343
37344
37345
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37325

class InterconnectDiagnosticsLinkLACPStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of a LACP link, which can take one of the following values:
  #
  #    - ACTIVE: The link is configured and active within the bundle.
  #    - DETACHED: The link is not configured within the bundle. This means
  #    that the rest of the object should be empty.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The link is configured and active within the bundle.
    ACTIVE = 314_733_318

    # The link is not configured within the bundle, this means the rest of
    # the object should be empty.
    DETACHED = 216_562_546
  end
end

#neighbor_system_id::String

Returns System ID of the port on the neighbor's side of the LACP exchange.

Returns:

  • (::String)

    System ID of the port on the neighbor's side of the LACP exchange.



37325
37326
37327
37328
37329
37330
37331
37332
37333
37334
37335
37336
37337
37338
37339
37340
37341
37342
37343
37344
37345
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37325

class InterconnectDiagnosticsLinkLACPStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of a LACP link, which can take one of the following values:
  #
  #    - ACTIVE: The link is configured and active within the bundle.
  #    - DETACHED: The link is not configured within the bundle. This means
  #    that the rest of the object should be empty.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The link is configured and active within the bundle.
    ACTIVE = 314_733_318

    # The link is not configured within the bundle, this means the rest of
    # the object should be empty.
    DETACHED = 216_562_546
  end
end

#state::String

Returns The state of a LACP link, which can take one of the following values:

  • ACTIVE: The link is configured and active within the bundle.
  • DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty. Check the State enum for the list of possible values.

Returns:

  • (::String)

    The state of a LACP link, which can take one of the following values:

    • ACTIVE: The link is configured and active within the bundle.
    • DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty. Check the State enum for the list of possible values.


37325
37326
37327
37328
37329
37330
37331
37332
37333
37334
37335
37336
37337
37338
37339
37340
37341
37342
37343
37344
37345
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37325

class InterconnectDiagnosticsLinkLACPStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The state of a LACP link, which can take one of the following values:
  #
  #    - ACTIVE: The link is configured and active within the bundle.
  #    - DETACHED: The link is not configured within the bundle. This means
  #    that the rest of the object should be empty.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The link is configured and active within the bundle.
    ACTIVE = 314_733_318

    # The link is not configured within the bundle, this means the rest of
    # the object should be empty.
    DETACHED = 216_562_546
  end
end