Class: Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkLACPStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkLACPStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#google_system_id ⇒ ::String
System ID of the port on Google's side of the LACP exchange.
-
#neighbor_system_id ⇒ ::String
System ID of the port on the neighbor's side of the LACP exchange.
-
#state ⇒ ::String
The state of a LACP link, which can take one of the following values:.
Instance Attribute Details
#google_system_id ⇒ ::String
Returns System ID of the port on Google's side of the LACP exchange.
36251 36252 36253 36254 36255 36256 36257 36258 36259 36260 36261 36262 36263 36264 36265 36266 36267 36268 36269 36270 36271 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36251 class InterconnectDiagnosticsLinkLACPStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a LACP link, which can take one of the following values: # # - ACTIVE: The link is configured and active within the bundle. # - DETACHED: The link is not configured within the bundle. This means # that the rest of the object should be empty. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The link is configured and active within the bundle. ACTIVE = 314_733_318 # The link is not configured within the bundle, this means the rest of # the object should be empty. DETACHED = 216_562_546 end end |
#neighbor_system_id ⇒ ::String
Returns System ID of the port on the neighbor's side of the LACP exchange.
36251 36252 36253 36254 36255 36256 36257 36258 36259 36260 36261 36262 36263 36264 36265 36266 36267 36268 36269 36270 36271 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36251 class InterconnectDiagnosticsLinkLACPStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a LACP link, which can take one of the following values: # # - ACTIVE: The link is configured and active within the bundle. # - DETACHED: The link is not configured within the bundle. This means # that the rest of the object should be empty. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The link is configured and active within the bundle. ACTIVE = 314_733_318 # The link is not configured within the bundle, this means the rest of # the object should be empty. DETACHED = 216_562_546 end end |
#state ⇒ ::String
Returns The state of a LACP link, which can take one of the following values:
- ACTIVE: The link is configured and active within the bundle.
- DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty. Check the State enum for the list of possible values.
36251 36252 36253 36254 36255 36256 36257 36258 36259 36260 36261 36262 36263 36264 36265 36266 36267 36268 36269 36270 36271 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36251 class InterconnectDiagnosticsLinkLACPStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The state of a LACP link, which can take one of the following values: # # - ACTIVE: The link is configured and active within the bundle. # - DETACHED: The link is not configured within the bundle. This means # that the rest of the object should be empty. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The link is configured and active within the bundle. ACTIVE = 314_733_318 # The link is not configured within the bundle, this means the rest of # the object should be empty. DETACHED = 216_562_546 end end |