Class: Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkOpticalPower

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#state::String

Returns The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include:

- OK: The value has not crossed a warning threshold.
- LOW_WARNING: The value has crossed below the low
warning threshold.
  • HIGH_WARNING: The value has crossed above the high warning threshold.
    • LOW_ALARM: The value has crossed below the low alarm threshold.
    • HIGH_ALARM: The value has crossed above the high alarm threshold. Check the State enum for the list of possible values.

Returns:

  • (::String)

    The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include:

    - OK: The value has not crossed a warning threshold.
    - LOW_WARNING: The value has crossed below the low
    warning threshold.
    
    • HIGH_WARNING: The value has crossed above the high warning threshold.
      • LOW_ALARM: The value has crossed below the low alarm threshold.
      • HIGH_ALARM: The value has crossed above the high alarm threshold. Check the State enum for the list of possible values.


37370
37371
37372
37373
37374
37375
37376
37377
37378
37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37370

class InterconnectDiagnosticsLinkOpticalPower
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the current value when compared to the warning and alarm
  # levels for the receiving or transmitting transceiver. Possible states
  # include:
  #
  #
  #     - OK: The value has not crossed a warning threshold.
  #     - LOW_WARNING: The value has crossed below the low
  #     warning threshold.
  #    - HIGH_WARNING: The value has
  #     crossed above the high warning threshold.
  #     - LOW_ALARM: The value has crossed below the low alarm
  #     threshold.
  #     - HIGH_ALARM: The value has crossed above the high alarm
  #     threshold.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The value has crossed above the high alarm threshold.
    HIGH_ALARM = 305_363_284

    # The value of the current optical power has crossed above the high
    # warning threshold.
    HIGH_WARNING = 220_984_799

    # The value of the current optical power has crossed below the low alarm
    # threshold.
    LOW_ALARM = 316_659_046

    # The value of the current optical power has crossed below the low
    # warning threshold.
    LOW_WARNING = 338_793_841

    # The value of the current optical power has not crossed a warning
    # threshold.
    OK = 2524
  end
end

#value::Float

Returns Value of the current receiving or transmitting optical power, read in dBm. Take a known good optical value, give it a 10% margin and trigger warnings relative to that value. In general, a -7dBm warning and a -11dBm alarm are good optical value estimates for most links.

Returns:

  • (::Float)

    Value of the current receiving or transmitting optical power, read in dBm. Take a known good optical value, give it a 10% margin and trigger warnings relative to that value. In general, a -7dBm warning and a -11dBm alarm are good optical value estimates for most links.



37370
37371
37372
37373
37374
37375
37376
37377
37378
37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37370

class InterconnectDiagnosticsLinkOpticalPower
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the current value when compared to the warning and alarm
  # levels for the receiving or transmitting transceiver. Possible states
  # include:
  #
  #
  #     - OK: The value has not crossed a warning threshold.
  #     - LOW_WARNING: The value has crossed below the low
  #     warning threshold.
  #    - HIGH_WARNING: The value has
  #     crossed above the high warning threshold.
  #     - LOW_ALARM: The value has crossed below the low alarm
  #     threshold.
  #     - HIGH_ALARM: The value has crossed above the high alarm
  #     threshold.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The value has crossed above the high alarm threshold.
    HIGH_ALARM = 305_363_284

    # The value of the current optical power has crossed above the high
    # warning threshold.
    HIGH_WARNING = 220_984_799

    # The value of the current optical power has crossed below the low alarm
    # threshold.
    LOW_ALARM = 316_659_046

    # The value of the current optical power has crossed below the low
    # warning threshold.
    LOW_WARNING = 338_793_841

    # The value of the current optical power has not crossed a warning
    # threshold.
    OK = 2524
  end
end