Class: Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkOpticalPower
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkOpticalPower
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::String
The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver.
-
#value ⇒ ::Float
Value of the current receiving or transmitting optical power, read in dBm.
Instance Attribute Details
#state ⇒ ::String
Returns The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include:
- OK: The value has not crossed a warning threshold.
- LOW_WARNING: The value has crossed below the low
warning threshold.
- HIGH_WARNING: The value has
crossed above the high warning threshold.
- LOW_ALARM: The value has crossed below the low alarm threshold.
- HIGH_ALARM: The value has crossed above the high alarm threshold. Check the State enum for the list of possible values.
36296 36297 36298 36299 36300 36301 36302 36303 36304 36305 36306 36307 36308 36309 36310 36311 36312 36313 36314 36315 36316 36317 36318 36319 36320 36321 36322 36323 36324 36325 36326 36327 36328 36329 36330 36331 36332 36333 36334 36335 36336 36337 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36296 class InterconnectDiagnosticsLinkOpticalPower include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of the current value when compared to the warning and alarm # levels for the receiving or transmitting transceiver. Possible states # include: # # # - OK: The value has not crossed a warning threshold. # - LOW_WARNING: The value has crossed below the low # warning threshold. # - HIGH_WARNING: The value has # crossed above the high warning threshold. # - LOW_ALARM: The value has crossed below the low alarm # threshold. # - HIGH_ALARM: The value has crossed above the high alarm # threshold. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The value has crossed above the high alarm threshold. HIGH_ALARM = 305_363_284 # The value of the current optical power has crossed above the high # warning threshold. HIGH_WARNING = 220_984_799 # The value of the current optical power has crossed below the low alarm # threshold. LOW_ALARM = 316_659_046 # The value of the current optical power has crossed below the low # warning threshold. LOW_WARNING = 338_793_841 # The value of the current optical power has not crossed a warning # threshold. OK = 2524 end end |
#value ⇒ ::Float
Returns Value of the current receiving or transmitting optical power, read in dBm. Take a known good optical value, give it a 10% margin and trigger warnings relative to that value. In general, a -7dBm warning and a -11dBm alarm are good optical value estimates for most links.
36296 36297 36298 36299 36300 36301 36302 36303 36304 36305 36306 36307 36308 36309 36310 36311 36312 36313 36314 36315 36316 36317 36318 36319 36320 36321 36322 36323 36324 36325 36326 36327 36328 36329 36330 36331 36332 36333 36334 36335 36336 36337 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36296 class InterconnectDiagnosticsLinkOpticalPower include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of the current value when compared to the warning and alarm # levels for the receiving or transmitting transceiver. Possible states # include: # # # - OK: The value has not crossed a warning threshold. # - LOW_WARNING: The value has crossed below the low # warning threshold. # - HIGH_WARNING: The value has # crossed above the high warning threshold. # - LOW_ALARM: The value has crossed below the low alarm # threshold. # - HIGH_ALARM: The value has crossed above the high alarm # threshold. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The value has crossed above the high alarm threshold. HIGH_ALARM = 305_363_284 # The value of the current optical power has crossed above the high # warning threshold. HIGH_WARNING = 220_984_799 # The value of the current optical power has crossed below the low alarm # threshold. LOW_ALARM = 316_659_046 # The value of the current optical power has crossed below the low # warning threshold. LOW_WARNING = 338_793_841 # The value of the current optical power has not crossed a warning # threshold. OK = 2524 end end |