Class: Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkOpticalPower
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkOpticalPower
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::String
The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver.
-
#value ⇒ ::Float
Value of the current receiving or transmitting optical power, read in dBm.
Instance Attribute Details
#state ⇒ ::String
Returns The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include:
- OK: The value has not crossed a warning threshold.
- LOW_WARNING: The value has crossed below the low
warning threshold.
- HIGH_WARNING: The value has
crossed above the high warning threshold.
- LOW_ALARM: The value has crossed below the low alarm threshold.
- HIGH_ALARM: The value has crossed above the high alarm threshold. Check the State enum for the list of possible values.
38469 38470 38471 38472 38473 38474 38475 38476 38477 38478 38479 38480 38481 38482 38483 38484 38485 38486 38487 38488 38489 38490 38491 38492 38493 38494 38495 38496 38497 38498 38499 38500 38501 38502 38503 38504 38505 38506 38507 38508 38509 38510 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38469 class InterconnectDiagnosticsLinkOpticalPower include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of the current value when compared to the warning and alarm # levels for the receiving or transmitting transceiver. Possible states # include: # # # - OK: The value has not crossed a warning threshold. # - LOW_WARNING: The value has crossed below the low # warning threshold. # - HIGH_WARNING: The value has # crossed above the high warning threshold. # - LOW_ALARM: The value has crossed below the low alarm # threshold. # - HIGH_ALARM: The value has crossed above the high alarm # threshold. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The value has crossed above the high alarm threshold. HIGH_ALARM = 305_363_284 # The value of the current optical power has crossed above the high # warning threshold. HIGH_WARNING = 220_984_799 # The value of the current optical power has crossed below the low alarm # threshold. LOW_ALARM = 316_659_046 # The value of the current optical power has crossed below the low # warning threshold. LOW_WARNING = 338_793_841 # The value of the current optical power has not crossed a warning # threshold. OK = 2524 end end |
#value ⇒ ::Float
Returns Value of the current receiving or transmitting optical power, read in dBm. Take a known good optical value, give it a 10% margin and trigger warnings relative to that value. In general, a -7dBm warning and a -11dBm alarm are good optical value estimates for most links.
38469 38470 38471 38472 38473 38474 38475 38476 38477 38478 38479 38480 38481 38482 38483 38484 38485 38486 38487 38488 38489 38490 38491 38492 38493 38494 38495 38496 38497 38498 38499 38500 38501 38502 38503 38504 38505 38506 38507 38508 38509 38510 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38469 class InterconnectDiagnosticsLinkOpticalPower include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of the current value when compared to the warning and alarm # levels for the receiving or transmitting transceiver. Possible states # include: # # # - OK: The value has not crossed a warning threshold. # - LOW_WARNING: The value has crossed below the low # warning threshold. # - HIGH_WARNING: The value has # crossed above the high warning threshold. # - LOW_ALARM: The value has crossed below the low alarm # threshold. # - HIGH_ALARM: The value has crossed above the high alarm # threshold. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The value has crossed above the high alarm threshold. HIGH_ALARM = 305_363_284 # The value of the current optical power has crossed above the high # warning threshold. HIGH_WARNING = 220_984_799 # The value of the current optical power has crossed below the low alarm # threshold. LOW_ALARM = 316_659_046 # The value of the current optical power has crossed below the low # warning threshold. LOW_WARNING = 338_793_841 # The value of the current optical power has not crossed a warning # threshold. OK = 2524 end end |