Module: Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkOpticalPower::State
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include:
- OK: The value has not crossed a warning threshold.
- LOW_WARNING: The value has crossed below the low
warning threshold.
- HIGH_WARNING: The value has
crossed above the high warning threshold.
- LOW_ALARM: The value has crossed below the low alarm threshold.
- HIGH_ALARM: The value has crossed above the high alarm threshold.
Constant Summary collapse
- UNDEFINED_STATE =
A value indicating that the enum field is not set.
0- HIGH_ALARM =
The value has crossed above the high alarm threshold.
305_363_284- HIGH_WARNING =
The value of the current optical power has crossed above the high warning threshold.
220_984_799- LOW_ALARM =
The value of the current optical power has crossed below the low alarm threshold.
316_659_046- LOW_WARNING =
The value of the current optical power has crossed below the low warning threshold.
338_793_841- OK =
The value of the current optical power has not crossed a warning threshold.
2524