Class: Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: OperationalStatus

Instance Attribute Summary collapse

Instance Attribute Details

#arp_caches::Array<::Google::Cloud::Compute::V1::InterconnectDiagnosticsARPEntry>

Returns A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled.

Returns:



36367
36368
36369
36370
36371
36372
36373
36374
36375
36376
36377
36378
36379
36380
36381
36382
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36367

class InterconnectDiagnosticsLinkStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operational status of the link.
  module OperationalStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATIONAL_STATUS = 0

    # The interface is unable to communicate with the remote end.
    LINK_OPERATIONAL_STATUS_DOWN = 281_653_885

    # The interface has low level communication with the remote end.
    LINK_OPERATIONAL_STATUS_UP = 305_879_862
  end
end

#circuit_id::String

Returns The unique ID for this link assigned during turn up by Google.

Returns:

  • (::String)

    The unique ID for this link assigned during turn up by Google.



36367
36368
36369
36370
36371
36372
36373
36374
36375
36376
36377
36378
36379
36380
36381
36382
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36367

class InterconnectDiagnosticsLinkStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operational status of the link.
  module OperationalStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATIONAL_STATUS = 0

    # The interface is unable to communicate with the remote end.
    LINK_OPERATIONAL_STATUS_DOWN = 281_653_885

    # The interface has low level communication with the remote end.
    LINK_OPERATIONAL_STATUS_UP = 305_879_862
  end
end

#google_demarc::String

Returns The Demarc address assigned by Google and provided in the LoA.

Returns:

  • (::String)

    The Demarc address assigned by Google and provided in the LoA.



36367
36368
36369
36370
36371
36372
36373
36374
36375
36376
36377
36378
36379
36380
36381
36382
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36367

class InterconnectDiagnosticsLinkStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operational status of the link.
  module OperationalStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATIONAL_STATUS = 0

    # The interface is unable to communicate with the remote end.
    LINK_OPERATIONAL_STATUS_DOWN = 281_653_885

    # The interface has low level communication with the remote end.
    LINK_OPERATIONAL_STATUS_UP = 305_879_862
  end
end

#lacp_status::Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkLACPStatus



36367
36368
36369
36370
36371
36372
36373
36374
36375
36376
36377
36378
36379
36380
36381
36382
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36367

class InterconnectDiagnosticsLinkStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operational status of the link.
  module OperationalStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATIONAL_STATUS = 0

    # The interface is unable to communicate with the remote end.
    LINK_OPERATIONAL_STATUS_DOWN = 281_653_885

    # The interface has low level communication with the remote end.
    LINK_OPERATIONAL_STATUS_UP = 305_879_862
  end
end

#macsec::Google::Cloud::Compute::V1::InterconnectDiagnosticsMacsecStatus

Returns Describes the status of MACsec encryption on this link.

Returns:



36367
36368
36369
36370
36371
36372
36373
36374
36375
36376
36377
36378
36379
36380
36381
36382
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36367

class InterconnectDiagnosticsLinkStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operational status of the link.
  module OperationalStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATIONAL_STATUS = 0

    # The interface is unable to communicate with the remote end.
    LINK_OPERATIONAL_STATUS_DOWN = 281_653_885

    # The interface has low level communication with the remote end.
    LINK_OPERATIONAL_STATUS_UP = 305_879_862
  end
end

#operational_status::String

Returns The operational status of the link. Check the OperationalStatus enum for the list of possible values.

Returns:

  • (::String)

    The operational status of the link. Check the OperationalStatus enum for the list of possible values.



36367
36368
36369
36370
36371
36372
36373
36374
36375
36376
36377
36378
36379
36380
36381
36382
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36367

class InterconnectDiagnosticsLinkStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operational status of the link.
  module OperationalStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATIONAL_STATUS = 0

    # The interface is unable to communicate with the remote end.
    LINK_OPERATIONAL_STATUS_DOWN = 281_653_885

    # The interface has low level communication with the remote end.
    LINK_OPERATIONAL_STATUS_UP = 305_879_862
  end
end

#receiving_optical_power::Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkOpticalPower

Returns An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.

Returns:



36367
36368
36369
36370
36371
36372
36373
36374
36375
36376
36377
36378
36379
36380
36381
36382
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36367

class InterconnectDiagnosticsLinkStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operational status of the link.
  module OperationalStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATIONAL_STATUS = 0

    # The interface is unable to communicate with the remote end.
    LINK_OPERATIONAL_STATUS_DOWN = 281_653_885

    # The interface has low level communication with the remote end.
    LINK_OPERATIONAL_STATUS_UP = 305_879_862
  end
end

#transmitting_optical_power::Google::Cloud::Compute::V1::InterconnectDiagnosticsLinkOpticalPower

Returns An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.

Returns:



36367
36368
36369
36370
36371
36372
36373
36374
36375
36376
36377
36378
36379
36380
36381
36382
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36367

class InterconnectDiagnosticsLinkStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operational status of the link.
  module OperationalStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_OPERATIONAL_STATUS = 0

    # The interface is unable to communicate with the remote end.
    LINK_OPERATIONAL_STATUS_DOWN = 281_653_885

    # The interface has low level communication with the remote end.
    LINK_OPERATIONAL_STATUS_UP = 305_879_862
  end
end