Class: Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapability
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapability
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.
Defined Under Namespace
Modules: SupportedSla
Instance Attribute Summary collapse
- #intended_capability_blockers ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>
-
#supported_sla ⇒ ::String
Check the SupportedSla enum for the list of possible values.
Instance Attribute Details
#intended_capability_blockers ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>
37553 37554 37555 37556 37557 37558 37559 37560 37561 37562 37563 37564 37565 37566 37567 37568 37569 37570 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37553 class InterconnectGroupConfiguredTopologyCapability include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module SupportedSla # A value indicating that the enum field is not set. UNDEFINED_SUPPORTED_SLA = 0 NO_SLA = 161_460_618 PRODUCTION_CRITICAL = 470_416_485 PRODUCTION_NON_CRITICAL = 117_399_223 UNSPECIFIED = 526_786_327 end end |
#supported_sla ⇒ ::String
Returns Check the SupportedSla enum for the list of possible values.
37553 37554 37555 37556 37557 37558 37559 37560 37561 37562 37563 37564 37565 37566 37567 37568 37569 37570 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37553 class InterconnectGroupConfiguredTopologyCapability include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module SupportedSla # A value indicating that the enum field is not set. UNDEFINED_SUPPORTED_SLA = 0 NO_SLA = 161_460_618 PRODUCTION_CRITICAL = 470_416_485 PRODUCTION_NON_CRITICAL = 117_399_223 UNSPECIFIED = 526_786_327 end end |