Class: Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapability

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.

Defined Under Namespace

Modules: SupportedSla

Instance Attribute Summary collapse

Instance Attribute Details

#intended_capability_blockers::Array<::Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>



36479
36480
36481
36482
36483
36484
36485
36486
36487
36488
36489
36490
36491
36492
36493
36494
36495
36496
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36479

class InterconnectGroupConfiguredTopologyCapability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module SupportedSla
    # A value indicating that the enum field is not set.
    UNDEFINED_SUPPORTED_SLA = 0

    NO_SLA = 161_460_618

    PRODUCTION_CRITICAL = 470_416_485

    PRODUCTION_NON_CRITICAL = 117_399_223

    UNSPECIFIED = 526_786_327
  end
end

#supported_sla::String

Returns Check the SupportedSla enum for the list of possible values.

Returns:

  • (::String)

    Check the SupportedSla enum for the list of possible values.



36479
36480
36481
36482
36483
36484
36485
36486
36487
36488
36489
36490
36491
36492
36493
36494
36495
36496
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36479

class InterconnectGroupConfiguredTopologyCapability
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module SupportedSla
    # A value indicating that the enum field is not set.
    UNDEFINED_SUPPORTED_SLA = 0

    NO_SLA = 161_460_618

    PRODUCTION_CRITICAL = 470_416_485

    PRODUCTION_NON_CRITICAL = 117_399_223

    UNSPECIFIED = 526_786_327
  end
end