Class: Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.

Defined Under Namespace

Modules: BlockerType

Instance Attribute Summary collapse

Instance Attribute Details

#blocker_type::String

Returns Check the BlockerType enum for the list of possible values.

Returns:

  • (::String)

    Check the BlockerType enum for the list of possible values.



37254
37255
37256
37257
37258
37259
37260
37261
37262
37263
37264
37265
37266
37267
37268
37269
37270
37271
37272
37273
37274
37275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37254

class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    INCOMPATIBLE_METROS = 290_410_432

    NOT_AVAILABLE = 140_722_205

    NO_INTERCONNECTS = 523_549_575

    NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492

    OTHER = 75_532_016

    UNSPECIFIED = 526_786_327
  end
end

Returns Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement.

Returns:

  • (::String)

    Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement.



37254
37255
37256
37257
37258
37259
37260
37261
37262
37263
37264
37265
37266
37267
37268
37269
37270
37271
37272
37273
37274
37275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37254

class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    INCOMPATIBLE_METROS = 290_410_432

    NOT_AVAILABLE = 140_722_205

    NO_INTERCONNECTS = 523_549_575

    NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492

    OTHER = 75_532_016

    UNSPECIFIED = 526_786_327
  end
end

#explanation::String

Returns Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement.

Returns:

  • (::String)

    Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement.



37254
37255
37256
37257
37258
37259
37260
37261
37262
37263
37264
37265
37266
37267
37268
37269
37270
37271
37272
37273
37274
37275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37254

class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    INCOMPATIBLE_METROS = 290_410_432

    NOT_AVAILABLE = 140_722_205

    NO_INTERCONNECTS = 523_549_575

    NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492

    OTHER = 75_532_016

    UNSPECIFIED = 526_786_327
  end
end

#facilities::Array<::String>

Returns Output only. [Output Only] Facilities used to explain this blocker in more detail. Like physicalStructure.metros.facilities.facility, this is a numeric string like "5467".

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Facilities used to explain this blocker in more detail. Like physicalStructure.metros.facilities.facility, this is a numeric string like "5467".



37254
37255
37256
37257
37258
37259
37260
37261
37262
37263
37264
37265
37266
37267
37268
37269
37270
37271
37272
37273
37274
37275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37254

class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    INCOMPATIBLE_METROS = 290_410_432

    NOT_AVAILABLE = 140_722_205

    NO_INTERCONNECTS = 523_549_575

    NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492

    OTHER = 75_532_016

    UNSPECIFIED = 526_786_327
  end
end

#interconnects::Array<::String>

Returns Output only. [Output Only] Interconnects used to explain this blocker in more detail.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Interconnects used to explain this blocker in more detail.



37254
37255
37256
37257
37258
37259
37260
37261
37262
37263
37264
37265
37266
37267
37268
37269
37270
37271
37272
37273
37274
37275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37254

class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    INCOMPATIBLE_METROS = 290_410_432

    NOT_AVAILABLE = 140_722_205

    NO_INTERCONNECTS = 523_549_575

    NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492

    OTHER = 75_532_016

    UNSPECIFIED = 526_786_327
  end
end

#metros::Array<::String>

Returns Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field.



37254
37255
37256
37257
37258
37259
37260
37261
37262
37263
37264
37265
37266
37267
37268
37269
37270
37271
37272
37273
37274
37275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37254

class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    INCOMPATIBLE_METROS = 290_410_432

    NOT_AVAILABLE = 140_722_205

    NO_INTERCONNECTS = 523_549_575

    NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492

    OTHER = 75_532_016

    UNSPECIFIED = 526_786_327
  end
end

#zones::Array<::String>

Returns Output only. [Output Only] Zones used to explain this blocker in more detail. Zone names are "zone1" and/or "zone2".

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Zones used to explain this blocker in more detail. Zone names are "zone1" and/or "zone2".



37254
37255
37256
37257
37258
37259
37260
37261
37262
37263
37264
37265
37266
37267
37268
37269
37270
37271
37272
37273
37274
37275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37254

class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module BlockerType
    # A value indicating that the enum field is not set.
    UNDEFINED_BLOCKER_TYPE = 0

    INCOMPATIBLE_METROS = 290_410_432

    NOT_AVAILABLE = 140_722_205

    NO_INTERCONNECTS = 523_549_575

    NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492

    OTHER = 75_532_016

    UNSPECIFIED = 526_786_327
  end
end