Class: Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.
Defined Under Namespace
Modules: BlockerType
Instance Attribute Summary collapse
-
#blocker_type ⇒ ::String
Check the BlockerType enum for the list of possible values.
-
#documentation_link ⇒ ::String
Output only.
-
#explanation ⇒ ::String
Output only.
-
#facilities ⇒ ::Array<::String>
Output only.
-
#interconnects ⇒ ::Array<::String>
Output only.
-
#metros ⇒ ::Array<::String>
Output only.
-
#zones ⇒ ::Array<::String>
Output only.
Instance Attribute Details
#blocker_type ⇒ ::String
Returns Check the BlockerType enum for the list of possible values.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 36544 36545 36546 36547 36548 36549 36550 36551 36552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36531 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#documentation_link ⇒ ::String
Returns Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 36544 36545 36546 36547 36548 36549 36550 36551 36552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36531 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#explanation ⇒ ::String
Returns Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 36544 36545 36546 36547 36548 36549 36550 36551 36552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36531 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#facilities ⇒ ::Array<::String>
Returns Output only. [Output Only] Facilities used to explain this blocker in more detail. Like physicalStructure.metros.facilities.facility, this is a numeric string like "5467".
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 36544 36545 36546 36547 36548 36549 36550 36551 36552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36531 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#interconnects ⇒ ::Array<::String>
Returns Output only. [Output Only] Interconnects used to explain this blocker in more detail.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 36544 36545 36546 36547 36548 36549 36550 36551 36552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36531 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#metros ⇒ ::Array<::String>
Returns Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field.
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 36544 36545 36546 36547 36548 36549 36550 36551 36552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36531 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#zones ⇒ ::Array<::String>
Returns Output only. [Output Only] Zones used to explain this blocker in more detail. Zone names are "zone1" and/or "zone2".
36531 36532 36533 36534 36535 36536 36537 36538 36539 36540 36541 36542 36543 36544 36545 36546 36547 36548 36549 36550 36551 36552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36531 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |