Class: Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.
Defined Under Namespace
Modules: BlockerType
Instance Attribute Summary collapse
-
#blocker_type ⇒ ::String
Check the BlockerType enum for the list of possible values.
-
#documentation_link ⇒ ::String
[Output Only] The url of Google Cloud public documentation explaining this requirement.
-
#explanation ⇒ ::String
[Output Only] A human-readable explanation of this requirement and why it's not met.
-
#facilities ⇒ ::Array<::String>
[Output Only] Facilities used to explain this blocker in more detail.
-
#interconnects ⇒ ::Array<::String>
[Output Only] Interconnects used to explain this blocker in more detail.
-
#metros ⇒ ::Array<::String>
[Output Only] Metros used to explain this blocker in more detail.
-
#zones ⇒ ::Array<::String>
[Output Only] Zones used to explain this blocker in more detail.
Instance Attribute Details
#blocker_type ⇒ ::String
17796 17797 17798 17799 17800 17801 17802 17803 17804 17805 17806 17807 17808 17809 17810 17811 17812 17813 17814 17815 17816 17817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17796 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#documentation_link ⇒ ::String
17796 17797 17798 17799 17800 17801 17802 17803 17804 17805 17806 17807 17808 17809 17810 17811 17812 17813 17814 17815 17816 17817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17796 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#explanation ⇒ ::String
17796 17797 17798 17799 17800 17801 17802 17803 17804 17805 17806 17807 17808 17809 17810 17811 17812 17813 17814 17815 17816 17817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17796 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#facilities ⇒ ::Array<::String>
17796 17797 17798 17799 17800 17801 17802 17803 17804 17805 17806 17807 17808 17809 17810 17811 17812 17813 17814 17815 17816 17817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17796 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#interconnects ⇒ ::Array<::String>
17796 17797 17798 17799 17800 17801 17802 17803 17804 17805 17806 17807 17808 17809 17810 17811 17812 17813 17814 17815 17816 17817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17796 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#metros ⇒ ::Array<::String>
17796 17797 17798 17799 17800 17801 17802 17803 17804 17805 17806 17807 17808 17809 17810 17811 17812 17813 17814 17815 17816 17817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17796 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |
#zones ⇒ ::Array<::String>
17796 17797 17798 17799 17800 17801 17802 17803 17804 17805 17806 17807 17808 17809 17810 17811 17812 17813 17814 17815 17816 17817 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17796 class InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module BlockerType # A value indicating that the enum field is not set. UNDEFINED_BLOCKER_TYPE = 0 INCOMPATIBLE_METROS = 290_410_432 NOT_AVAILABLE = 140_722_205 NO_INTERCONNECTS = 523_549_575 NO_INTERCONNECTS_IN_METRO_AND_ZONE = 440_966_492 OTHER = 75_532_016 UNSPECIFIED = 526_786_327 end end |