Class: Google::Cloud::Compute::V1::InterconnectGroupIntent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The user's intent for this group. This is the only required field besides the name that must be specified on group creation.

Defined Under Namespace

Modules: TopologyCapability

Instance Attribute Summary collapse

Instance Attribute Details

#topology_capability::String

Returns Check the TopologyCapability enum for the list of possible values.

Returns:

  • (::String)

    Check the TopologyCapability enum for the list of possible values.



37282
37283
37284
37285
37286
37287
37288
37289
37290
37291
37292
37293
37294
37295
37296
37297
37298
37299
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37282

class InterconnectGroupIntent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module TopologyCapability
    # A value indicating that the enum field is not set.
    UNDEFINED_TOPOLOGY_CAPABILITY = 0

    NO_SLA = 161_460_618

    PRODUCTION_CRITICAL = 470_416_485

    PRODUCTION_NON_CRITICAL = 117_399_223

    UNSPECIFIED = 526_786_327
  end
end