Class: Google::Cloud::Compute::V1::InterconnectGroupIntent
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupIntent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The user's intent for this group. This is the only required field besides the name that must be specified on group creation.
Defined Under Namespace
Modules: TopologyCapability
Instance Attribute Summary collapse
-
#topology_capability ⇒ ::String
Check the TopologyCapability enum for the list of possible values.
Instance Attribute Details
#topology_capability ⇒ ::String
Returns Check the TopologyCapability enum for the list of possible values.
36559 36560 36561 36562 36563 36564 36565 36566 36567 36568 36569 36570 36571 36572 36573 36574 36575 36576 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36559 class InterconnectGroupIntent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module TopologyCapability # A value indicating that the enum field is not set. UNDEFINED_TOPOLOGY_CAPABILITY = 0 NO_SLA = 161_460_618 PRODUCTION_CRITICAL = 470_416_485 PRODUCTION_NON_CRITICAL = 117_399_223 UNSPECIFIED = 526_786_327 end end |