Class: Google::Cloud::Compute::V1::InterconnectGroupsCreateMembers
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupsCreateMembers
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: IntentMismatchBehavior
Instance Attribute Summary collapse
-
#intent_mismatch_behavior ⇒ ::String
How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call.
- #interconnects ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput>
-
#template_interconnect ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput
Parameters for the Interconnects to create.
Instance Attribute Details
#intent_mismatch_behavior ⇒ ::String
Returns How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call. Check the IntentMismatchBehavior enum for the list of possible values.
37724 37725 37726 37727 37728 37729 37730 37731 37732 37733 37734 37735 37736 37737 37738 37739 37740 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37724 class InterconnectGroupsCreateMembers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How to behave when configured.topologyCapability.supportedSLA would not # equal intent.topologyCapability after this call. module IntentMismatchBehavior # A value indicating that the enum field is not set. UNDEFINED_INTENT_MISMATCH_BEHAVIOR = 0 CREATE = 385_389_820 REJECT = 266_102_687 UNSPECIFIED = 526_786_327 end end |
#interconnects ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput>
37724 37725 37726 37727 37728 37729 37730 37731 37732 37733 37734 37735 37736 37737 37738 37739 37740 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37724 class InterconnectGroupsCreateMembers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How to behave when configured.topologyCapability.supportedSLA would not # equal intent.topologyCapability after this call. module IntentMismatchBehavior # A value indicating that the enum field is not set. UNDEFINED_INTENT_MISMATCH_BEHAVIOR = 0 CREATE = 385_389_820 REJECT = 266_102_687 UNSPECIFIED = 526_786_327 end end |
#template_interconnect ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput
Returns Parameters for the Interconnects to create.
37724 37725 37726 37727 37728 37729 37730 37731 37732 37733 37734 37735 37736 37737 37738 37739 37740 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37724 class InterconnectGroupsCreateMembers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How to behave when configured.topologyCapability.supportedSLA would not # equal intent.topologyCapability after this call. module IntentMismatchBehavior # A value indicating that the enum field is not set. UNDEFINED_INTENT_MISMATCH_BEHAVIOR = 0 CREATE = 385_389_820 REJECT = 266_102_687 UNSPECIFIED = 526_786_327 end end |