Class: Google::Cloud::Compute::V1::InterconnectGroupsCreateMembers

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: IntentMismatchBehavior

Instance Attribute Summary collapse

Instance Attribute Details

#intent_mismatch_behavior::String

Returns How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call. Check the IntentMismatchBehavior enum for the list of possible values.

Returns:

  • (::String)

    How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call. Check the IntentMismatchBehavior enum for the list of possible values.



36650
36651
36652
36653
36654
36655
36656
36657
36658
36659
36660
36661
36662
36663
36664
36665
36666
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36650

class InterconnectGroupsCreateMembers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # How to behave when configured.topologyCapability.supportedSLA would not
  # equal intent.topologyCapability after this call.
  module IntentMismatchBehavior
    # A value indicating that the enum field is not set.
    UNDEFINED_INTENT_MISMATCH_BEHAVIOR = 0

    CREATE = 385_389_820

    REJECT = 266_102_687

    UNSPECIFIED = 526_786_327
  end
end

#interconnects::Array<::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput>



36650
36651
36652
36653
36654
36655
36656
36657
36658
36659
36660
36661
36662
36663
36664
36665
36666
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36650

class InterconnectGroupsCreateMembers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # How to behave when configured.topologyCapability.supportedSLA would not
  # equal intent.topologyCapability after this call.
  module IntentMismatchBehavior
    # A value indicating that the enum field is not set.
    UNDEFINED_INTENT_MISMATCH_BEHAVIOR = 0

    CREATE = 385_389_820

    REJECT = 266_102_687

    UNSPECIFIED = 526_786_327
  end
end

#template_interconnect::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput

Returns Parameters for the Interconnects to create.

Returns:



36650
36651
36652
36653
36654
36655
36656
36657
36658
36659
36660
36661
36662
36663
36664
36665
36666
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36650

class InterconnectGroupsCreateMembers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # How to behave when configured.topologyCapability.supportedSLA would not
  # equal intent.topologyCapability after this call.
  module IntentMismatchBehavior
    # A value indicating that the enum field is not set.
    UNDEFINED_INTENT_MISMATCH_BEHAVIOR = 0

    CREATE = 385_389_820

    REJECT = 266_102_687

    UNSPECIFIED = 526_786_327
  end
end