Class: Google::Cloud::Compute::V1::InterconnectGroupsCreateMembers
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupsCreateMembers
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: IntentMismatchBehavior
Instance Attribute Summary collapse
-
#intent_mismatch_behavior ⇒ ::String
How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call.
- #interconnects ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput>
-
#template_interconnect ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput
Parameters for the Interconnects to create.
Instance Attribute Details
#intent_mismatch_behavior ⇒ ::String
17902 17903 17904 17905 17906 17907 17908 17909 17910 17911 17912 17913 17914 17915 17916 17917 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17902 class InterconnectGroupsCreateMembers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call. module IntentMismatchBehavior # A value indicating that the enum field is not set. UNDEFINED_INTENT_MISMATCH_BEHAVIOR = 0 CREATE = 385_389_820 REJECT = 266_102_687 UNSPECIFIED = 526_786_327 end end |
#interconnects ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput>
17902 17903 17904 17905 17906 17907 17908 17909 17910 17911 17912 17913 17914 17915 17916 17917 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17902 class InterconnectGroupsCreateMembers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call. module IntentMismatchBehavior # A value indicating that the enum field is not set. UNDEFINED_INTENT_MISMATCH_BEHAVIOR = 0 CREATE = 385_389_820 REJECT = 266_102_687 UNSPECIFIED = 526_786_327 end end |
#template_interconnect ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput
17902 17903 17904 17905 17906 17907 17908 17909 17910 17911 17912 17913 17914 17915 17916 17917 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17902 class InterconnectGroupsCreateMembers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call. module IntentMismatchBehavior # A value indicating that the enum field is not set. UNDEFINED_INTENT_MISMATCH_BEHAVIOR = 0 CREATE = 385_389_820 REJECT = 266_102_687 UNSPECIFIED = 526_786_327 end end |