Class: Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupsCreateMembersInterconnectInput
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
LINT.IfChange
Defined Under Namespace
Modules: InterconnectType, LinkType, RequestedFeatures
Instance Attribute Summary collapse
-
#admin_enabled ⇒ ::Boolean
Administrative status of the interconnect.
-
#customer_name ⇒ ::String
Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
-
#description ⇒ ::String
An optional description of this resource.
-
#facility ⇒ ::String
A zone-free location to use for all Interconnects created in this call, like "iad-1234".
-
#interconnect_type ⇒ ::String
Type of interconnect, which can take one of the following values:.
-
#link_type ⇒ ::String
Type of link requested, which can take one of the following values:.
-
#name ⇒ ::String
Name of the Interconnects to be created.
-
#noc_contact_email ⇒ ::String
Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect.
-
#remote_location ⇒ ::String
Indicates that this is a Cross-Cloud Interconnect.
-
#requested_features ⇒ ::Array<::String>
Optional.
-
#requested_link_count ⇒ ::Integer
Target number of physical links in the link bundle, as requested by the customer.
Instance Attribute Details
#admin_enabled ⇒ ::Boolean
Returns Administrative status of the interconnect. When this is set to true, the Interconnect is functional and can carry traffic. When set to false, no packets can be carried over the interconnect and no BGP routes are exchanged over it. By default, the status is set to true.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#customer_name ⇒ ::String
Returns Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#facility ⇒ ::String
Returns A zone-free location to use for all Interconnects created in this call, like "iad-1234".
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#interconnect_type ⇒ ::String
Returns Type of interconnect, which can take one of the following values:
- PARTNER: A partner-managed interconnection shared between customers though a partner.
- DEDICATED: A dedicated physical interconnection with the customer.
Note that a value IT_PRIVATE has been deprecated in favor of DEDICATED. Check the InterconnectType enum for the list of possible values.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#link_type ⇒ ::String
Returns Type of link requested, which can take one of the following values:
- LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics
- LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics.
- LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics.
Note that this field indicates the speed of each of the links in the bundle, not the speed of the entire bundle. Check the LinkType enum for the list of possible values.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#name ⇒ ::String
Returns Name of the Interconnects to be created. This must be specified on the
template and/or on each individual interconnect. The name, if not empty,
must be 1-63 characters long, and comply with RFC1035.
Specifically, any nonempty name must be 1-63 characters long and match
the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#noc_contact_email ⇒ ::String
Returns Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect. If specified, this will be used for notifications in addition to all other forms described, such as Cloud Monitoring logs alerting and Cloud Notifications. This field is required for users who sign up for Cloud Interconnect using workforce identity federation.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#remote_location ⇒ ::String
Returns Indicates that this is a Cross-Cloud Interconnect. This field specifies the location outside of Google's network that the interconnect is connected to.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#requested_features ⇒ ::Array<::String>
Returns Optional. List of features requested for this Interconnect connection, which can take one of the following values:
- IF_MACSEC: If specified, then the connection is created on MACsec capable hardware ports. If not specified, non-MACsec capable ports will also be considered.
- IF_CROSS_SITE_NETWORK: If specified, then the connection is created exclusively for Cross-Site Networking. The connection can not be used for Cross-Site Networking unless this feature is specified. Check the RequestedFeatures enum for the list of possible values.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |
#requested_link_count ⇒ ::Integer
Returns Target number of physical links in the link bundle, as requested by the customer.
36751 36752 36753 36754 36755 36756 36757 36758 36759 36760 36761 36762 36763 36764 36765 36766 36767 36768 36769 36770 36771 36772 36773 36774 36775 36776 36777 36778 36779 36780 36781 36782 36783 36784 36785 36786 36787 36788 36789 36790 36791 36792 36793 36794 36795 36796 36797 36798 36799 36800 36801 36802 36803 36804 36805 36806 36807 36808 36809 36810 36811 36812 36813 36814 36815 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36751 class InterconnectGroupsCreateMembersInterconnectInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of interconnect, which can take one of the following values: # # - PARTNER: A partner-managed interconnection shared between # customers though a partner. # - DEDICATED: A dedicated physical # interconnection with the customer. # # Note that a value IT_PRIVATE # has been deprecated in favor of DEDICATED. module InterconnectType # A value indicating that the enum field is not set. UNDEFINED_INTERCONNECT_TYPE = 0 # A dedicated physical interconnection with the customer. DEDICATED = 258_411_983 # [Deprecated] A private, physical interconnection with the customer. IT_PRIVATE = 335_677_007 # A partner-managed interconnection shared between customers via partner. PARTNER = 461_924_520 end # Type of link requested, which can take one of the following values: # # - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics # - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. # - LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 # optics. # # Note that this field indicates the speed of each of the # links in the bundle, not the speed of the entire bundle. module LinkType # A value indicating that the enum field is not set. UNDEFINED_LINK_TYPE = 0 # 100G Ethernet, LR Optics. LINK_TYPE_ETHERNET_100G_LR = 337_672_551 # 10G Ethernet, LR Optics. # [(rate_bps) = 10000000000]; LINK_TYPE_ETHERNET_10G_LR = 236_739_749 # 400G Ethernet, LR4 Optics. LINK_TYPE_ETHERNET_400G_LR4 = 127_023_690 end module RequestedFeatures # A value indicating that the enum field is not set. UNDEFINED_REQUESTED_FEATURES = 0 # Cross-Site Networking IF_CROSS_SITE_NETWORK = 469_111_095 # L2 Interconnect Attachment Forwarding IF_L2_FORWARDING = 125_563_860 # Media Access Control security (MACsec) IF_MACSEC = 396_279_300 end end |