Class: Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Request to get the status of the interconnect group with extra detail.
Defined Under Namespace
Modules: GroupStatus
Instance Attribute Summary collapse
-
#configured ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
Output only.
-
#group_status ⇒ ::String
Output only.
-
#intent ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupIntent
Output only.
- #interconnect_statuses ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatusInterconnectStatus>
-
#operational ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
Output only.
Instance Attribute Details
#configured ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
Returns Output only. The configuration analysis, as returned by Get.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 37618 37619 37620 37621 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37604 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |
#group_status ⇒ ::String
Returns Output only. Summarizes the status of the group. Check the GroupStatus enum for the list of possible values.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 37618 37619 37620 37621 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37604 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |
#intent ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupIntent
Returns Output only. The intent of the resource, as returned by Get.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 37618 37619 37620 37621 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37604 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |
#interconnect_statuses ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatusInterconnectStatus>
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 37618 37619 37620 37621 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37604 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |
#operational ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
Returns Output only. The operational state of the group, including only active Interconnects.
37604 37605 37606 37607 37608 37609 37610 37611 37612 37613 37614 37615 37616 37617 37618 37619 37620 37621 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37604 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |