Class: Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Request to get the status of the interconnect group with extra detail.
Defined Under Namespace
Modules: GroupStatus
Instance Attribute Summary collapse
-
#configured ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
Output only.
-
#group_status ⇒ ::String
Output only.
-
#intent ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupIntent
Output only.
- #interconnect_statuses ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatusInterconnectStatus>
-
#operational ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
Output only.
Instance Attribute Details
#configured ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
Returns Output only. The configuration analysis, as returned by Get.
36882 36883 36884 36885 36886 36887 36888 36889 36890 36891 36892 36893 36894 36895 36896 36897 36898 36899 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36882 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |
#group_status ⇒ ::String
Returns Output only. Summarizes the status of the group. Check the GroupStatus enum for the list of possible values.
36882 36883 36884 36885 36886 36887 36888 36889 36890 36891 36892 36893 36894 36895 36896 36897 36898 36899 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36882 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |
#intent ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupIntent
Returns Output only. The intent of the resource, as returned by Get.
36882 36883 36884 36885 36886 36887 36888 36889 36890 36891 36892 36893 36894 36895 36896 36897 36898 36899 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36882 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |
#interconnect_statuses ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatusInterconnectStatus>
36882 36883 36884 36885 36886 36887 36888 36889 36890 36891 36892 36893 36894 36895 36896 36897 36898 36899 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36882 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |
#operational ⇒ ::Google::Cloud::Compute::V1::InterconnectGroupConfigured
Returns Output only. The operational state of the group, including only active Interconnects.
36882 36883 36884 36885 36886 36887 36888 36889 36890 36891 36892 36893 36894 36895 36896 36897 36898 36899 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36882 class InterconnectGroupsOperationalStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Summarizes the status of the group. module GroupStatus # A value indicating that the enum field is not set. UNDEFINED_GROUP_STATUS = 0 DEGRADED = 396_890_926 FULLY_DOWN = 255_514_647 FULLY_UP = 504_176_464 GROUPS_STATUS_UNSPECIFIED = 261_932_693 end end |