Class: Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatusInterconnectStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The status of one Interconnect in the group. The order is arbitrary.

Defined Under Namespace

Modules: IsActive

Instance Attribute Summary collapse

Instance Attribute Details

#admin_enabled::Boolean

Returns Output only. Whether the Interconnect is enabled.

Returns:

  • (::Boolean)

    Output only. Whether the Interconnect is enabled.



37990
37991
37992
37993
37994
37995
37996
37997
37998
37999
38000
38001
38002
38003
38004
38005
38006
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37990

class InterconnectGroupsOperationalStatusInterconnectStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Whether this interconnect is participating in the redundant
  # configuration.
  module IsActive
    # A value indicating that the enum field is not set.
    UNDEFINED_IS_ACTIVE = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099

    IS_ACTIVE_UNSPECIFIED = 274_948_243
  end
end

#diagnostics::Google::Cloud::Compute::V1::InterconnectDiagnostics

Returns Output only. The diagnostics of the Interconnect, as returned by the existing get-diagnostics method.

Returns:



37990
37991
37992
37993
37994
37995
37996
37997
37998
37999
38000
38001
38002
38003
38004
38005
38006
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37990

class InterconnectGroupsOperationalStatusInterconnectStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Whether this interconnect is participating in the redundant
  # configuration.
  module IsActive
    # A value indicating that the enum field is not set.
    UNDEFINED_IS_ACTIVE = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099

    IS_ACTIVE_UNSPECIFIED = 274_948_243
  end
end

#interconnect::String

Returns Output only. The URL of the Interconnect being described.

Returns:

  • (::String)

    Output only. The URL of the Interconnect being described.



37990
37991
37992
37993
37994
37995
37996
37997
37998
37999
38000
38001
38002
38003
38004
38005
38006
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37990

class InterconnectGroupsOperationalStatusInterconnectStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Whether this interconnect is participating in the redundant
  # configuration.
  module IsActive
    # A value indicating that the enum field is not set.
    UNDEFINED_IS_ACTIVE = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099

    IS_ACTIVE_UNSPECIFIED = 274_948_243
  end
end

#is_active::String

Returns Output only. Whether this interconnect is participating in the redundant configuration. Check the IsActive enum for the list of possible values.

Returns:

  • (::String)

    Output only. Whether this interconnect is participating in the redundant configuration. Check the IsActive enum for the list of possible values.



37990
37991
37992
37993
37994
37995
37996
37997
37998
37999
38000
38001
38002
38003
38004
38005
38006
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37990

class InterconnectGroupsOperationalStatusInterconnectStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Whether this interconnect is participating in the redundant
  # configuration.
  module IsActive
    # A value indicating that the enum field is not set.
    UNDEFINED_IS_ACTIVE = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099

    IS_ACTIVE_UNSPECIFIED = 274_948_243
  end
end