Class: Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatusInterconnectStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectGroupsOperationalStatusInterconnectStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The status of one Interconnect in the group. The order is arbitrary.
Defined Under Namespace
Modules: IsActive
Instance Attribute Summary collapse
-
#admin_enabled ⇒ ::Boolean
Output only.
-
#diagnostics ⇒ ::Google::Cloud::Compute::V1::InterconnectDiagnostics
Output only.
-
#interconnect ⇒ ::String
Output only.
-
#is_active ⇒ ::String
Output only.
Instance Attribute Details
#admin_enabled ⇒ ::Boolean
Returns Output only. Whether the Interconnect is enabled.
37639 37640 37641 37642 37643 37644 37645 37646 37647 37648 37649 37650 37651 37652 37653 37654 37655 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37639 class InterconnectGroupsOperationalStatusInterconnectStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Whether this interconnect is participating in the redundant # configuration. module IsActive # A value indicating that the enum field is not set. UNDEFINED_IS_ACTIVE = 0 ACTIVE = 314_733_318 INACTIVE = 270_421_099 IS_ACTIVE_UNSPECIFIED = 274_948_243 end end |
#diagnostics ⇒ ::Google::Cloud::Compute::V1::InterconnectDiagnostics
Returns Output only. The diagnostics of the Interconnect, as returned by the existing get-diagnostics method.
37639 37640 37641 37642 37643 37644 37645 37646 37647 37648 37649 37650 37651 37652 37653 37654 37655 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37639 class InterconnectGroupsOperationalStatusInterconnectStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Whether this interconnect is participating in the redundant # configuration. module IsActive # A value indicating that the enum field is not set. UNDEFINED_IS_ACTIVE = 0 ACTIVE = 314_733_318 INACTIVE = 270_421_099 IS_ACTIVE_UNSPECIFIED = 274_948_243 end end |
#interconnect ⇒ ::String
Returns Output only. The URL of the Interconnect being described.
37639 37640 37641 37642 37643 37644 37645 37646 37647 37648 37649 37650 37651 37652 37653 37654 37655 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37639 class InterconnectGroupsOperationalStatusInterconnectStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Whether this interconnect is participating in the redundant # configuration. module IsActive # A value indicating that the enum field is not set. UNDEFINED_IS_ACTIVE = 0 ACTIVE = 314_733_318 INACTIVE = 270_421_099 IS_ACTIVE_UNSPECIFIED = 274_948_243 end end |
#is_active ⇒ ::String
Returns Output only. Whether this interconnect is participating in the redundant configuration. Check the IsActive enum for the list of possible values.
37639 37640 37641 37642 37643 37644 37645 37646 37647 37648 37649 37650 37651 37652 37653 37654 37655 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37639 class InterconnectGroupsOperationalStatusInterconnectStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Whether this interconnect is participating in the redundant # configuration. module IsActive # A value indicating that the enum field is not set. UNDEFINED_IS_ACTIVE = 0 ACTIVE = 314_733_318 INACTIVE = 270_421_099 IS_ACTIVE_UNSPECIFIED = 274_948_243 end end |