Class: Google::Cloud::Compute::V1::InterconnectLocationRegionInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectLocationRegionInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Information about any potential InterconnectAttachments between an Interconnect at a specific InterconnectLocation, and a specific Cloud Region.
Defined Under Namespace
Modules: LocationPresence
Instance Attribute Summary collapse
-
#expected_rtt_ms ⇒ ::Integer
Output only.
-
#l2_forwarding_enabled ⇒ ::Boolean
Output only.
-
#location_presence ⇒ ::String
Output only.
-
#region ⇒ ::String
Output only.
Instance Attribute Details
#expected_rtt_ms ⇒ ::Integer
Returns Output only. Expected round-trip time in milliseconds, from this InterconnectLocation to a VM in this region.
37215 37216 37217 37218 37219 37220 37221 37222 37223 37224 37225 37226 37227 37228 37229 37230 37231 37232 37233 37234 37235 37236 37237 37238 37239 37240 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37215 class InterconnectLocationRegionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Identifies the network presence of this location. module LocationPresence # A value indicating that the enum field is not set. UNDEFINED_LOCATION_PRESENCE = 0 # This region is not in any common network presence with this # InterconnectLocation. GLOBAL = 494_663_587 # This region shares the same regional network presence as this # InterconnectLocation. LOCAL_REGION = 403_535_464 # [Deprecated] This region is not in any common network presence with # this InterconnectLocation. LP_GLOBAL = 429_584_062 # [Deprecated] This region shares the same regional network presence as # this InterconnectLocation. LP_LOCAL_REGION = 488_598_851 end end |
#l2_forwarding_enabled ⇒ ::Boolean
Returns Output only. Identifies whether L2 Interconnect Attachments can be created in this region for interconnects that are in this location.
37215 37216 37217 37218 37219 37220 37221 37222 37223 37224 37225 37226 37227 37228 37229 37230 37231 37232 37233 37234 37235 37236 37237 37238 37239 37240 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37215 class InterconnectLocationRegionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Identifies the network presence of this location. module LocationPresence # A value indicating that the enum field is not set. UNDEFINED_LOCATION_PRESENCE = 0 # This region is not in any common network presence with this # InterconnectLocation. GLOBAL = 494_663_587 # This region shares the same regional network presence as this # InterconnectLocation. LOCAL_REGION = 403_535_464 # [Deprecated] This region is not in any common network presence with # this InterconnectLocation. LP_GLOBAL = 429_584_062 # [Deprecated] This region shares the same regional network presence as # this InterconnectLocation. LP_LOCAL_REGION = 488_598_851 end end |
#location_presence ⇒ ::String
Returns Output only. Identifies the network presence of this location. Check the LocationPresence enum for the list of possible values.
37215 37216 37217 37218 37219 37220 37221 37222 37223 37224 37225 37226 37227 37228 37229 37230 37231 37232 37233 37234 37235 37236 37237 37238 37239 37240 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37215 class InterconnectLocationRegionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Identifies the network presence of this location. module LocationPresence # A value indicating that the enum field is not set. UNDEFINED_LOCATION_PRESENCE = 0 # This region is not in any common network presence with this # InterconnectLocation. GLOBAL = 494_663_587 # This region shares the same regional network presence as this # InterconnectLocation. LOCAL_REGION = 403_535_464 # [Deprecated] This region is not in any common network presence with # this InterconnectLocation. LP_GLOBAL = 429_584_062 # [Deprecated] This region shares the same regional network presence as # this InterconnectLocation. LP_LOCAL_REGION = 488_598_851 end end |
#region ⇒ ::String
Returns Output only. URL for the region of this location.
37215 37216 37217 37218 37219 37220 37221 37222 37223 37224 37225 37226 37227 37228 37229 37230 37231 37232 37233 37234 37235 37236 37237 37238 37239 37240 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37215 class InterconnectLocationRegionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Identifies the network presence of this location. module LocationPresence # A value indicating that the enum field is not set. UNDEFINED_LOCATION_PRESENCE = 0 # This region is not in any common network presence with this # InterconnectLocation. GLOBAL = 494_663_587 # This region shares the same regional network presence as this # InterconnectLocation. LOCAL_REGION = 403_535_464 # [Deprecated] This region is not in any common network presence with # this InterconnectLocation. LP_GLOBAL = 429_584_062 # [Deprecated] This region shares the same regional network presence as # this InterconnectLocation. LP_LOCAL_REGION = 488_598_851 end end |