Class: Google::Cloud::Compute::V1::InterconnectOutageNotification

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Description of a planned outage on this Interconnect.

Defined Under Namespace

Modules: IssueType, Source, State

Instance Attribute Summary collapse

Instance Attribute Details

#affected_circuits::Array<::String>

Returns If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.

Returns:

  • (::Array<::String>)

    If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.



38101
38102
38103
38104
38105
38106
38107
38108
38109
38110
38111
38112
38113
38114
38115
38116
38117
38118
38119
38120
38121
38122
38123
38124
38125
38126
38127
38128
38129
38130
38131
38132
38133
38134
38135
38136
38137
38138
38139
38140
38141
38142
38143
38144
38145
38146
38147
38148
38149
38150
38151
38152
38153
38154
38155
38156
38157
38158
38159
38160
38161
38162
38163
38164
38165
38166
38167
38168
38169
38170
38171
38172
38173
38174
38175
38176
38177
38178
38179
38180
38181
38182
38183
38184
38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38101

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#description::String

Returns A description about the purpose of the outage.

Returns:

  • (::String)

    A description about the purpose of the outage.



38101
38102
38103
38104
38105
38106
38107
38108
38109
38110
38111
38112
38113
38114
38115
38116
38117
38118
38119
38120
38121
38122
38123
38124
38125
38126
38127
38128
38129
38130
38131
38132
38133
38134
38135
38136
38137
38138
38139
38140
38141
38142
38143
38144
38145
38146
38147
38148
38149
38150
38151
38152
38153
38154
38155
38156
38157
38158
38159
38160
38161
38162
38163
38164
38165
38166
38167
38168
38169
38170
38171
38172
38173
38174
38175
38176
38177
38178
38179
38180
38181
38182
38183
38184
38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38101

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#end_time::Integer

Returns Scheduled end time for the outage (milliseconds since Unix epoch).

Returns:

  • (::Integer)

    Scheduled end time for the outage (milliseconds since Unix epoch).



38101
38102
38103
38104
38105
38106
38107
38108
38109
38110
38111
38112
38113
38114
38115
38116
38117
38118
38119
38120
38121
38122
38123
38124
38125
38126
38127
38128
38129
38130
38131
38132
38133
38134
38135
38136
38137
38138
38139
38140
38141
38142
38143
38144
38145
38146
38147
38148
38149
38150
38151
38152
38153
38154
38155
38156
38157
38158
38159
38160
38161
38162
38163
38164
38165
38166
38167
38168
38169
38170
38171
38172
38173
38174
38175
38176
38177
38178
38179
38180
38181
38182
38183
38184
38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38101

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#issue_type::String

Returns Form this outage is expected to take, which can take one of the following values:

  • OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
  • PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth.

Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values. Check the IssueType enum for the list of possible values.

Returns:

  • (::String)

    Form this outage is expected to take, which can take one of the following values:

    • OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
    • PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth.

    Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values. Check the IssueType enum for the list of possible values.



38101
38102
38103
38104
38105
38106
38107
38108
38109
38110
38111
38112
38113
38114
38115
38116
38117
38118
38119
38120
38121
38122
38123
38124
38125
38126
38127
38128
38129
38130
38131
38132
38133
38134
38135
38136
38137
38138
38139
38140
38141
38142
38143
38144
38145
38146
38147
38148
38149
38150
38151
38152
38153
38154
38155
38156
38157
38158
38159
38160
38161
38162
38163
38164
38165
38166
38167
38168
38169
38170
38171
38172
38173
38174
38175
38176
38177
38178
38179
38180
38181
38182
38183
38184
38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38101

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#name::String

Returns Unique identifier for this outage notification.

Returns:

  • (::String)

    Unique identifier for this outage notification.



38101
38102
38103
38104
38105
38106
38107
38108
38109
38110
38111
38112
38113
38114
38115
38116
38117
38118
38119
38120
38121
38122
38123
38124
38125
38126
38127
38128
38129
38130
38131
38132
38133
38134
38135
38136
38137
38138
38139
38140
38141
38142
38143
38144
38145
38146
38147
38148
38149
38150
38151
38152
38153
38154
38155
38156
38157
38158
38159
38160
38161
38162
38163
38164
38165
38166
38167
38168
38169
38170
38171
38172
38173
38174
38175
38176
38177
38178
38179
38180
38181
38182
38183
38184
38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38101

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#source::String

Returns The party that generated this notification, which can take the following value:

  • GOOGLE: this notification as generated by Google.

Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE. Check the Source enum for the list of possible values.

Returns:

  • (::String)

    The party that generated this notification, which can take the following value:

    • GOOGLE: this notification as generated by Google.

    Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE. Check the Source enum for the list of possible values.



38101
38102
38103
38104
38105
38106
38107
38108
38109
38110
38111
38112
38113
38114
38115
38116
38117
38118
38119
38120
38121
38122
38123
38124
38125
38126
38127
38128
38129
38130
38131
38132
38133
38134
38135
38136
38137
38138
38139
38140
38141
38142
38143
38144
38145
38146
38147
38148
38149
38150
38151
38152
38153
38154
38155
38156
38157
38158
38159
38160
38161
38162
38163
38164
38165
38166
38167
38168
38169
38170
38171
38172
38173
38174
38175
38176
38177
38178
38179
38180
38181
38182
38183
38184
38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38101

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#start_time::Integer

Returns Scheduled start time for the outage (milliseconds since Unix epoch).

Returns:

  • (::Integer)

    Scheduled start time for the outage (milliseconds since Unix epoch).



38101
38102
38103
38104
38105
38106
38107
38108
38109
38110
38111
38112
38113
38114
38115
38116
38117
38118
38119
38120
38121
38122
38123
38124
38125
38126
38127
38128
38129
38130
38131
38132
38133
38134
38135
38136
38137
38138
38139
38140
38141
38142
38143
38144
38145
38146
38147
38148
38149
38150
38151
38152
38153
38154
38155
38156
38157
38158
38159
38160
38161
38162
38163
38164
38165
38166
38167
38168
38169
38170
38171
38172
38173
38174
38175
38176
38177
38178
38179
38180
38181
38182
38183
38184
38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38101

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#state::String

Returns State of this notification, which can take one of the following values:

  • ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
  • CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
  • COMPLETED: The outage associated with this notification is complete.

Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values. Check the State enum for the list of possible values.

Returns:

  • (::String)

    State of this notification, which can take one of the following values:

    • ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
    • CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
    • COMPLETED: The outage associated with this notification is complete.

    Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values. Check the State enum for the list of possible values.



38101
38102
38103
38104
38105
38106
38107
38108
38109
38110
38111
38112
38113
38114
38115
38116
38117
38118
38119
38120
38121
38122
38123
38124
38125
38126
38127
38128
38129
38130
38131
38132
38133
38134
38135
38136
38137
38138
38139
38140
38141
38142
38143
38144
38145
38146
38147
38148
38149
38150
38151
38152
38153
38154
38155
38156
38157
38158
38159
38160
38161
38162
38163
38164
38165
38166
38167
38168
38169
38170
38171
38172
38173
38174
38175
38176
38177
38178
38179
38180
38181
38182
38183
38184
38185
38186
38187
38188
38189
38190
38191
38192
38193
38194
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38101

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end