Class: Google::Cloud::Compute::V1::InterconnectOutageNotification

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Description of a planned outage on this Interconnect.

Defined Under Namespace

Modules: IssueType, Source, State

Instance Attribute Summary collapse

Instance Attribute Details

#affected_circuits::Array<::String>

Returns If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.

Returns:

  • (::Array<::String>)

    If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.



37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
37417
37418
37419
37420
37421
37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
37434
37435
37436
37437
37438
37439
37440
37441
37442
37443
37444
37445
37446
37447
37448
37449
37450
37451
37452
37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
37463
37464
37465
37466
37467
37468
37469
37470
37471
37472
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37379

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#description::String

Returns A description about the purpose of the outage.

Returns:

  • (::String)

    A description about the purpose of the outage.



37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
37417
37418
37419
37420
37421
37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
37434
37435
37436
37437
37438
37439
37440
37441
37442
37443
37444
37445
37446
37447
37448
37449
37450
37451
37452
37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
37463
37464
37465
37466
37467
37468
37469
37470
37471
37472
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37379

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#end_time::Integer

Returns Scheduled end time for the outage (milliseconds since Unix epoch).

Returns:

  • (::Integer)

    Scheduled end time for the outage (milliseconds since Unix epoch).



37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
37417
37418
37419
37420
37421
37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
37434
37435
37436
37437
37438
37439
37440
37441
37442
37443
37444
37445
37446
37447
37448
37449
37450
37451
37452
37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
37463
37464
37465
37466
37467
37468
37469
37470
37471
37472
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37379

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#issue_type::String

Returns Form this outage is expected to take, which can take one of the following values:

  • OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
  • PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth.

Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values. Check the IssueType enum for the list of possible values.

Returns:

  • (::String)

    Form this outage is expected to take, which can take one of the following values:

    • OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
    • PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole should remain up, but with reduced bandwidth.

    Note that the versions of this enum prefixed with "IT_" have been deprecated in favor of the unprefixed values. Check the IssueType enum for the list of possible values.



37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
37417
37418
37419
37420
37421
37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
37434
37435
37436
37437
37438
37439
37440
37441
37442
37443
37444
37445
37446
37447
37448
37449
37450
37451
37452
37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
37463
37464
37465
37466
37467
37468
37469
37470
37471
37472
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37379

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#name::String

Returns Unique identifier for this outage notification.

Returns:

  • (::String)

    Unique identifier for this outage notification.



37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
37417
37418
37419
37420
37421
37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
37434
37435
37436
37437
37438
37439
37440
37441
37442
37443
37444
37445
37446
37447
37448
37449
37450
37451
37452
37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
37463
37464
37465
37466
37467
37468
37469
37470
37471
37472
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37379

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#source::String

Returns The party that generated this notification, which can take the following value:

  • GOOGLE: this notification as generated by Google.

Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE. Check the Source enum for the list of possible values.

Returns:

  • (::String)

    The party that generated this notification, which can take the following value:

    • GOOGLE: this notification as generated by Google.

    Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE. Check the Source enum for the list of possible values.



37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
37417
37418
37419
37420
37421
37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
37434
37435
37436
37437
37438
37439
37440
37441
37442
37443
37444
37445
37446
37447
37448
37449
37450
37451
37452
37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
37463
37464
37465
37466
37467
37468
37469
37470
37471
37472
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37379

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#start_time::Integer

Returns Scheduled start time for the outage (milliseconds since Unix epoch).

Returns:

  • (::Integer)

    Scheduled start time for the outage (milliseconds since Unix epoch).



37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
37417
37418
37419
37420
37421
37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
37434
37435
37436
37437
37438
37439
37440
37441
37442
37443
37444
37445
37446
37447
37448
37449
37450
37451
37452
37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
37463
37464
37465
37466
37467
37468
37469
37470
37471
37472
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37379

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end

#state::String

Returns State of this notification, which can take one of the following values:

  • ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
  • CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
  • COMPLETED: The outage associated with this notification is complete.

Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values. Check the State enum for the list of possible values.

Returns:

  • (::String)

    State of this notification, which can take one of the following values:

    • ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
    • CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
    • COMPLETED: The outage associated with this notification is complete.

    Note that the versions of this enum prefixed with "NS_" have been deprecated in favor of the unprefixed values. Check the State enum for the list of possible values.



37379
37380
37381
37382
37383
37384
37385
37386
37387
37388
37389
37390
37391
37392
37393
37394
37395
37396
37397
37398
37399
37400
37401
37402
37403
37404
37405
37406
37407
37408
37409
37410
37411
37412
37413
37414
37415
37416
37417
37418
37419
37420
37421
37422
37423
37424
37425
37426
37427
37428
37429
37430
37431
37432
37433
37434
37435
37436
37437
37438
37439
37440
37441
37442
37443
37444
37445
37446
37447
37448
37449
37450
37451
37452
37453
37454
37455
37456
37457
37458
37459
37460
37461
37462
37463
37464
37465
37466
37467
37468
37469
37470
37471
37472
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37379

class InterconnectOutageNotification
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Form this outage is expected to take, which can take one of the following
  # values:
  #
  #    - OUTAGE: The Interconnect may be completely out of service for
  #    some or all of the specified window.
  #    - PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
  #    should remain up, but with reduced bandwidth.
  #
  #
  # Note that the versions of this enum prefixed with "IT_" have been
  # deprecated in favor of the unprefixed values.
  module IssueType
    # A value indicating that the enum field is not set.
    UNDEFINED_ISSUE_TYPE = 0

    # [Deprecated] The Interconnect may be completely out of service for some
    # or all of the specified window.
    IT_OUTAGE = 175_779_973

    # [Deprecated] Some circuits comprising the Interconnect will be out of
    # service during the expected window. The interconnect as a whole should
    # remain up, albeit with reduced bandwidth.
    IT_PARTIAL_OUTAGE = 92_103_971

    # The Interconnect may be completely out of service for some or all of
    # the specified window.
    OUTAGE = 195_285_745

    # Some circuits comprising the Interconnect will be out of service during
    # the expected window. The interconnect as a whole should remain
    # up, albeit with reduced bandwidth.
    PARTIAL_OUTAGE = 147_053_455
  end

  # The party that generated this notification, which can take the following
  # value:
  #
  #    - GOOGLE: this notification as generated by Google.
  #
  #
  # Note that the value of NSRC_GOOGLE has been deprecated in favor of
  # GOOGLE.
  module Source
    # A value indicating that the enum field is not set.
    UNDEFINED_SOURCE = 0

    # This notification was generated by Google.
    GOOGLE = 497_439_289

    # [Deprecated] This notification was generated by Google.
    NSRC_GOOGLE = 510_574_562
  end

  # State of this notification, which can take one of the following values:
  #
  #    - ACTIVE: This outage notification is active. The event could be in
  #    the past, present, or future. See start_time and end_time for
  #    scheduling.
  #    - CANCELLED: The outage associated with this notification was cancelled
  #    before the outage was due to start.
  #    - COMPLETED: The outage associated with this notification is complete.
  #
  #
  # Note that the versions of this enum prefixed with "NS_" have been
  # deprecated in favor of the unprefixed values.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # This outage notification is active. The event could be in the future,
    # present, or past. See start_time and end_time for scheduling.
    ACTIVE = 314_733_318

    # The outage associated with this notification was cancelled before the
    # outage was due to start.
    CANCELLED = 41_957_681

    # The outage associated with this notification is complete.
    COMPLETED = 309_921_323

    # [Deprecated] This outage notification is active. The event could be in
    # the future, present, or past. See start_time and end_time for
    # scheduling.
    NS_ACTIVE = 252_563_136

    # [Deprecated] The outage associated with this notification was canceled
    # before the outage was due to start.
    NS_CANCELED = 506_579_411
  end
end