Module: Google::Cloud::Compute::V1::InterconnectOutageNotification::Source
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The party that generated this notification, which can take the following value: - GOOGLE: this notification as generated by Google. Note that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
Constant Summary collapse
- UNDEFINED_SOURCE =
A value indicating that the enum field is not set.
0- GOOGLE =
This notification was generated by Google.
497_439_289- NSRC_GOOGLE =
[Deprecated] This notification was generated by Google.
510_574_562