Class: Google::Cloud::Compute::V1::InterconnectRemoteLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectRemoteLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Cross-Cloud Interconnect Remote Location resource.
You can use this resource to find remote location details about an Interconnect attachment (VLAN).
Defined Under Namespace
Modules: Continent, Lacp, Status
Instance Attribute Summary collapse
-
#address ⇒ ::String
Output only.
-
#attachment_configuration_constraints ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentConfigurationConstraints
Output only.
-
#city ⇒ ::String
Output only.
-
#constraints ⇒ ::Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraints
Output only.
-
#continent ⇒ ::String
Output only.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
Output only.
-
#facility_provider ⇒ ::String
Output only.
-
#facility_provider_facility_id ⇒ ::String
Output only.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#lacp ⇒ ::String
Output only.
-
#max_lag_size100_gbps ⇒ ::Integer
Output only.
-
#max_lag_size10_gbps ⇒ ::Integer
Output only.
-
#max_lag_size400_gbps ⇒ ::Integer
Output only.
-
#name ⇒ ::String
Output only.
-
#peeringdb_facility_id ⇒ ::String
Output only.
-
#permitted_connections ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectRemoteLocationPermittedConnections>
Output only.
-
#remote_service ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#status ⇒ ::String
Output only.
Instance Attribute Details
#address ⇒ ::String
Returns Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#attachment_configuration_constraints ⇒ ::Google::Cloud::Compute::V1::InterconnectAttachmentConfigurationConstraints
Returns Output only. [Output Only] Subset of fields from InterconnectAttachment's |configurationConstraints| field that apply to all attachments for this remote location.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#city ⇒ ::String
Returns Output only. [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#constraints ⇒ ::Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraints
Returns Output only. [Output Only] Constraints on the parameters for creating Cross-Cloud Interconnect and associated InterconnectAttachments.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#continent ⇒ ::String
Returns Output only. [Output Only] Continent for this location, which can take one of the following values:
- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA Check the Continent enum for the list of possible values.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#description ⇒ ::String
Returns Output only. [Output Only] An optional description of the resource.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#facility_provider ⇒ ::String
Returns Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX).
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#facility_provider_facility_id ⇒ ::String
Returns Output only. [Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#interconnectRemoteLocation for interconnect remote locations.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#lacp ⇒ ::String
Returns Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED Check the Lacp enum for the list of possible values.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#max_lag_size100_gbps ⇒ ::Integer
Returns Output only. [Output Only] The maximum number of 100 Gbps ports supported in a link aggregation group (LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed max_lag_size_100_gbps.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#max_lag_size10_gbps ⇒ ::Integer
Returns Output only. [Output Only] The maximum number of 10 Gbps ports supported in a link aggregation group (LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed max_lag_size_10_gbps.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#max_lag_size400_gbps ⇒ ::Integer
Returns Output only. [Output Only] The maximum number of 400 Gbps ports supported in a link aggregation group (LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed max_lag_size_400_gbps.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#name ⇒ ::String
Returns Output only. [Output Only] Name of the resource.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#peeringdb_facility_id ⇒ ::String
Returns Output only. [Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#permitted_connections ⇒ ::Array<::Google::Cloud::Compute::V1::InterconnectRemoteLocationPermittedConnections>
Returns Output only. [Output Only] Permitted connections.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#remote_service ⇒ ::String
Returns Output only. [Output Only] Indicates the service provider present at the remote location. Example values: "Amazon Web Services", "Microsoft Azure".
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |
#status ⇒ ::String
Returns Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:
- CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects.
- AVAILABLE: The InterconnectRemoteLocation is available for provisioning new Cross-Cloud Interconnects. Check the Status enum for the list of possible values.
38333 38334 38335 38336 38337 38338 38339 38340 38341 38342 38343 38344 38345 38346 38347 38348 38349 38350 38351 38352 38353 38354 38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 38365 38366 38367 38368 38369 38370 38371 38372 38373 38374 38375 38376 38377 38378 38379 38380 38381 38382 38383 38384 38385 38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38333 class InterconnectRemoteLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Continent for this location, which can take one of the # following values: # # - AFRICA # - ASIA_PAC # - EUROPE # - NORTH_AMERICA # - SOUTH_AMERICA module Continent # A value indicating that the enum field is not set. UNDEFINED_CONTINENT = 0 AFRICA = 317_443_706 ASIA_PAC = 119_782_269 EUROPE = 445_819_298 NORTH_AMERICA = 448_015_508 SOUTH_AMERICA = 32_597_340 end # Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which # can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED module Lacp # A value indicating that the enum field is not set. UNDEFINED_LACP = 0 # LACP_SUPPORTED: LACP is supported, and enabled by default on # the Cross-Cloud Interconnect. LACP_SUPPORTED = 339_576_113 # LACP_UNSUPPORTED: LACP is not supported and is not be enabled on this # port. GetDiagnostics shows bundleAggregationType as "static". GCP does # not support LAGs without LACP, so requestedLinkCount must be 1. LACP_UNSUPPORTED = 203_930_104 end # Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take # one of the following values: # # - CLOSED: The InterconnectRemoteLocation is closed and is unavailable # for provisioning new Cross-Cloud Interconnects. # - AVAILABLE: The # InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The InterconnectRemoteLocation is available for provisioning new # Cross-Cloud Interconnects. AVAILABLE = 442_079_913 # The InterconnectRemoteLocation is closed for provisioning new # Cross-Cloud Interconnects. CLOSED = 380_163_436 end end |