Class: Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraints

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: PortPairRemoteLocation, PortPairVlan

Instance Attribute Summary collapse

Instance Attribute Details

#port_pair_remote_location::String

Returns Output only. [Output Only] Port pair remote location constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, PORT_PAIR_MATCHING_REMOTE_LOCATION.

Google Cloud API refers only to individual ports, but the UI uses this field when ordering a pair of ports, to prevent users from accidentally ordering something that is incompatible with their cloud provider. Specifically, when ordering a redundant pair of Cross-Cloud Interconnect ports, and one of them uses a remote location with portPairMatchingRemoteLocation set to matching, the UI requires that both ports use the same remote location. Check the PortPairRemoteLocation enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] Port pair remote location constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, PORT_PAIR_MATCHING_REMOTE_LOCATION.

    Google Cloud API refers only to individual ports, but the UI uses this field when ordering a pair of ports, to prevent users from accidentally ordering something that is incompatible with their cloud provider. Specifically, when ordering a redundant pair of Cross-Cloud Interconnect ports, and one of them uses a remote location with portPairMatchingRemoteLocation set to matching, the UI requires that both ports use the same remote location. Check the PortPairRemoteLocation enum for the list of possible values.



38434
38435
38436
38437
38438
38439
38440
38441
38442
38443
38444
38445
38446
38447
38448
38449
38450
38451
38452
38453
38454
38455
38456
38457
38458
38459
38460
38461
38462
38463
38464
38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
38476
38477
38478
38479
38480
38481
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38434

class InterconnectRemoteLocationConstraints
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Port pair remote location constraints, which can take one
  # of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
  # PORT_PAIR_MATCHING_REMOTE_LOCATION.
  #
  # Google Cloud API refers only to individual ports, but the UI uses this
  # field when ordering a pair of ports, to prevent users from accidentally
  # ordering something that is incompatible with their cloud provider.
  # Specifically, when ordering a redundant pair of Cross-Cloud Interconnect
  # ports, and one of them uses a remote location with
  # portPairMatchingRemoteLocation set to matching, the UI requires that
  # both ports use the same remote location.
  module PortPairRemoteLocation
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_REMOTE_LOCATION = 0

    # If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider
    # allocates ports in pairs, and the user should choose the same remote
    # location for both ports.
    PORT_PAIR_MATCHING_REMOTE_LOCATION = 207_291_859

    # If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision
    # a redundant pair of Cross-Cloud Interconnects using two different
    # remote locations in the same city.
    PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 60_609_829
  end

  # Output only. [Output Only] Port pair VLAN constraints, which can take one of the
  # following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN
  module PortPairVlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_VLAN = 0

    # If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is
    # part of a pair of ports that should have matching VLAN allocations.
    # This occurs with Cross-Cloud Interconnect to Azure remote locations.
    # While GCP's API does not explicitly group pairs of ports, the UI uses
    # this field to ensure matching VLAN ids when configuring a redundant
    # VLAN pair.
    PORT_PAIR_MATCHING_VLAN = 250_295_358

    # PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint.
    PORT_PAIR_UNCONSTRAINED_VLAN = 175_227_948
  end
end

#port_pair_vlan::String

Returns Output only. [Output Only] Port pair VLAN constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN Check the PortPairVlan enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] Port pair VLAN constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN Check the PortPairVlan enum for the list of possible values.



38434
38435
38436
38437
38438
38439
38440
38441
38442
38443
38444
38445
38446
38447
38448
38449
38450
38451
38452
38453
38454
38455
38456
38457
38458
38459
38460
38461
38462
38463
38464
38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
38476
38477
38478
38479
38480
38481
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38434

class InterconnectRemoteLocationConstraints
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Port pair remote location constraints, which can take one
  # of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
  # PORT_PAIR_MATCHING_REMOTE_LOCATION.
  #
  # Google Cloud API refers only to individual ports, but the UI uses this
  # field when ordering a pair of ports, to prevent users from accidentally
  # ordering something that is incompatible with their cloud provider.
  # Specifically, when ordering a redundant pair of Cross-Cloud Interconnect
  # ports, and one of them uses a remote location with
  # portPairMatchingRemoteLocation set to matching, the UI requires that
  # both ports use the same remote location.
  module PortPairRemoteLocation
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_REMOTE_LOCATION = 0

    # If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider
    # allocates ports in pairs, and the user should choose the same remote
    # location for both ports.
    PORT_PAIR_MATCHING_REMOTE_LOCATION = 207_291_859

    # If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision
    # a redundant pair of Cross-Cloud Interconnects using two different
    # remote locations in the same city.
    PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 60_609_829
  end

  # Output only. [Output Only] Port pair VLAN constraints, which can take one of the
  # following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN
  module PortPairVlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_VLAN = 0

    # If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is
    # part of a pair of ports that should have matching VLAN allocations.
    # This occurs with Cross-Cloud Interconnect to Azure remote locations.
    # While GCP's API does not explicitly group pairs of ports, the UI uses
    # this field to ensure matching VLAN ids when configuring a redundant
    # VLAN pair.
    PORT_PAIR_MATCHING_VLAN = 250_295_358

    # PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint.
    PORT_PAIR_UNCONSTRAINED_VLAN = 175_227_948
  end
end

#subnet_length_range::Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraintsSubnetLengthRange

Returns Output only. [Output Only]

[min-length, max-length]

The minimum and maximum value (inclusive) for the IPv4 subnet length.

For example, an interconnectRemoteLocation for Azure has {min: 30, max: 30} because Azure requires /30 subnets.

This range specifies the values supported by both cloud providers. Interconnect currently supports /29 and /30 IPv4 subnet lengths. If a remote cloud has no constraint on IPv4 subnet length, the range would thus be {min: 29, max: 30}.

Returns:

  • (::Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraintsSubnetLengthRange)

    Output only. [Output Only]

    [min-length, max-length]

    The minimum and maximum value (inclusive) for the IPv4 subnet length.

    For example, an interconnectRemoteLocation for Azure has {min: 30, max: 30} because Azure requires /30 subnets.

    This range specifies the values supported by both cloud providers. Interconnect currently supports /29 and /30 IPv4 subnet lengths. If a remote cloud has no constraint on IPv4 subnet length, the range would thus be {min: 29, max: 30}.



38434
38435
38436
38437
38438
38439
38440
38441
38442
38443
38444
38445
38446
38447
38448
38449
38450
38451
38452
38453
38454
38455
38456
38457
38458
38459
38460
38461
38462
38463
38464
38465
38466
38467
38468
38469
38470
38471
38472
38473
38474
38475
38476
38477
38478
38479
38480
38481
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38434

class InterconnectRemoteLocationConstraints
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Port pair remote location constraints, which can take one
  # of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
  # PORT_PAIR_MATCHING_REMOTE_LOCATION.
  #
  # Google Cloud API refers only to individual ports, but the UI uses this
  # field when ordering a pair of ports, to prevent users from accidentally
  # ordering something that is incompatible with their cloud provider.
  # Specifically, when ordering a redundant pair of Cross-Cloud Interconnect
  # ports, and one of them uses a remote location with
  # portPairMatchingRemoteLocation set to matching, the UI requires that
  # both ports use the same remote location.
  module PortPairRemoteLocation
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_REMOTE_LOCATION = 0

    # If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider
    # allocates ports in pairs, and the user should choose the same remote
    # location for both ports.
    PORT_PAIR_MATCHING_REMOTE_LOCATION = 207_291_859

    # If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision
    # a redundant pair of Cross-Cloud Interconnects using two different
    # remote locations in the same city.
    PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 60_609_829
  end

  # Output only. [Output Only] Port pair VLAN constraints, which can take one of the
  # following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN
  module PortPairVlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PORT_PAIR_VLAN = 0

    # If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is
    # part of a pair of ports that should have matching VLAN allocations.
    # This occurs with Cross-Cloud Interconnect to Azure remote locations.
    # While GCP's API does not explicitly group pairs of ports, the UI uses
    # this field to ensure matching VLAN ids when configuring a redundant
    # VLAN pair.
    PORT_PAIR_MATCHING_VLAN = 250_295_358

    # PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint.
    PORT_PAIR_UNCONSTRAINED_VLAN = 175_227_948
  end
end