Class: Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraints
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraints
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: PortPairRemoteLocation, PortPairVlan
Instance Attribute Summary collapse
-
#port_pair_remote_location ⇒ ::String
Output only.
-
#port_pair_vlan ⇒ ::String
Output only.
-
#subnet_length_range ⇒ ::Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraintsSubnetLengthRange
Output only.
Instance Attribute Details
#port_pair_remote_location ⇒ ::String
Returns Output only. [Output Only] Port pair remote location constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, PORT_PAIR_MATCHING_REMOTE_LOCATION.
Google Cloud API refers only to individual ports, but the UI uses this field when ordering a pair of ports, to prevent users from accidentally ordering something that is incompatible with their cloud provider. Specifically, when ordering a redundant pair of Cross-Cloud Interconnect ports, and one of them uses a remote location with portPairMatchingRemoteLocation set to matching, the UI requires that both ports use the same remote location. Check the PortPairRemoteLocation enum for the list of possible values.
37712 37713 37714 37715 37716 37717 37718 37719 37720 37721 37722 37723 37724 37725 37726 37727 37728 37729 37730 37731 37732 37733 37734 37735 37736 37737 37738 37739 37740 37741 37742 37743 37744 37745 37746 37747 37748 37749 37750 37751 37752 37753 37754 37755 37756 37757 37758 37759 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37712 class InterconnectRemoteLocationConstraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Port pair remote location constraints, which can take one # of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, # PORT_PAIR_MATCHING_REMOTE_LOCATION. # # Google Cloud API refers only to individual ports, but the UI uses this # field when ordering a pair of ports, to prevent users from accidentally # ordering something that is incompatible with their cloud provider. # Specifically, when ordering a redundant pair of Cross-Cloud Interconnect # ports, and one of them uses a remote location with # portPairMatchingRemoteLocation set to matching, the UI requires that # both ports use the same remote location. module PortPairRemoteLocation # A value indicating that the enum field is not set. UNDEFINED_PORT_PAIR_REMOTE_LOCATION = 0 # If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider # allocates ports in pairs, and the user should choose the same remote # location for both ports. PORT_PAIR_MATCHING_REMOTE_LOCATION = 207_291_859 # If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision # a redundant pair of Cross-Cloud Interconnects using two different # remote locations in the same city. PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 60_609_829 end # Output only. [Output Only] Port pair VLAN constraints, which can take one of the # following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN module PortPairVlan # A value indicating that the enum field is not set. UNDEFINED_PORT_PAIR_VLAN = 0 # If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is # part of a pair of ports that should have matching VLAN allocations. # This occurs with Cross-Cloud Interconnect to Azure remote locations. # While GCP's API does not explicitly group pairs of ports, the UI uses # this field to ensure matching VLAN ids when configuring a redundant # VLAN pair. PORT_PAIR_MATCHING_VLAN = 250_295_358 # PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint. PORT_PAIR_UNCONSTRAINED_VLAN = 175_227_948 end end |
#port_pair_vlan ⇒ ::String
Returns Output only. [Output Only] Port pair VLAN constraints, which can take one of the following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN Check the PortPairVlan enum for the list of possible values.
37712 37713 37714 37715 37716 37717 37718 37719 37720 37721 37722 37723 37724 37725 37726 37727 37728 37729 37730 37731 37732 37733 37734 37735 37736 37737 37738 37739 37740 37741 37742 37743 37744 37745 37746 37747 37748 37749 37750 37751 37752 37753 37754 37755 37756 37757 37758 37759 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37712 class InterconnectRemoteLocationConstraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Port pair remote location constraints, which can take one # of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, # PORT_PAIR_MATCHING_REMOTE_LOCATION. # # Google Cloud API refers only to individual ports, but the UI uses this # field when ordering a pair of ports, to prevent users from accidentally # ordering something that is incompatible with their cloud provider. # Specifically, when ordering a redundant pair of Cross-Cloud Interconnect # ports, and one of them uses a remote location with # portPairMatchingRemoteLocation set to matching, the UI requires that # both ports use the same remote location. module PortPairRemoteLocation # A value indicating that the enum field is not set. UNDEFINED_PORT_PAIR_REMOTE_LOCATION = 0 # If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider # allocates ports in pairs, and the user should choose the same remote # location for both ports. PORT_PAIR_MATCHING_REMOTE_LOCATION = 207_291_859 # If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision # a redundant pair of Cross-Cloud Interconnects using two different # remote locations in the same city. PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 60_609_829 end # Output only. [Output Only] Port pair VLAN constraints, which can take one of the # following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN module PortPairVlan # A value indicating that the enum field is not set. UNDEFINED_PORT_PAIR_VLAN = 0 # If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is # part of a pair of ports that should have matching VLAN allocations. # This occurs with Cross-Cloud Interconnect to Azure remote locations. # While GCP's API does not explicitly group pairs of ports, the UI uses # this field to ensure matching VLAN ids when configuring a redundant # VLAN pair. PORT_PAIR_MATCHING_VLAN = 250_295_358 # PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint. PORT_PAIR_UNCONSTRAINED_VLAN = 175_227_948 end end |
#subnet_length_range ⇒ ::Google::Cloud::Compute::V1::InterconnectRemoteLocationConstraintsSubnetLengthRange
Returns Output only. [Output Only]
[min-length, max-length]
The minimum and maximum value (inclusive) for the IPv4 subnet length.
For example, an interconnectRemoteLocation for Azure has {min: 30, max: 30} because Azure requires /30 subnets.
This range specifies the values supported by both cloud providers. Interconnect currently supports /29 and /30 IPv4 subnet lengths. If a remote cloud has no constraint on IPv4 subnet length, the range would thus be {min: 29, max: 30}.
37712 37713 37714 37715 37716 37717 37718 37719 37720 37721 37722 37723 37724 37725 37726 37727 37728 37729 37730 37731 37732 37733 37734 37735 37736 37737 37738 37739 37740 37741 37742 37743 37744 37745 37746 37747 37748 37749 37750 37751 37752 37753 37754 37755 37756 37757 37758 37759 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37712 class InterconnectRemoteLocationConstraints include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Port pair remote location constraints, which can take one # of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, # PORT_PAIR_MATCHING_REMOTE_LOCATION. # # Google Cloud API refers only to individual ports, but the UI uses this # field when ordering a pair of ports, to prevent users from accidentally # ordering something that is incompatible with their cloud provider. # Specifically, when ordering a redundant pair of Cross-Cloud Interconnect # ports, and one of them uses a remote location with # portPairMatchingRemoteLocation set to matching, the UI requires that # both ports use the same remote location. module PortPairRemoteLocation # A value indicating that the enum field is not set. UNDEFINED_PORT_PAIR_REMOTE_LOCATION = 0 # If PORT_PAIR_MATCHING_REMOTE_LOCATION, the remote cloud provider # allocates ports in pairs, and the user should choose the same remote # location for both ports. PORT_PAIR_MATCHING_REMOTE_LOCATION = 207_291_859 # If PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION, a user may opt to provision # a redundant pair of Cross-Cloud Interconnects using two different # remote locations in the same city. PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION = 60_609_829 end # Output only. [Output Only] Port pair VLAN constraints, which can take one of the # following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN module PortPairVlan # A value indicating that the enum field is not set. UNDEFINED_PORT_PAIR_VLAN = 0 # If PORT_PAIR_MATCHING_VLAN, the Interconnect for this attachment is # part of a pair of ports that should have matching VLAN allocations. # This occurs with Cross-Cloud Interconnect to Azure remote locations. # While GCP's API does not explicitly group pairs of ports, the UI uses # this field to ensure matching VLAN ids when configuring a redundant # VLAN pair. PORT_PAIR_MATCHING_VLAN = 250_295_358 # PORT_PAIR_UNCONSTRAINED_VLAN means there is no constraint. PORT_PAIR_UNCONSTRAINED_VLAN = 175_227_948 end end |