Class: Google::Cloud::Compute::V1::License
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::License
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a License resource.
A License represents billing and aggregate usage data forpublic andmarketplace images. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Instance Attribute Summary collapse
-
#allowed_replacement_licenses ⇒ ::Array<::String>
Specifies licenseCodes of licenses that can replace this license.
-
#appendable_to_disk ⇒ ::Boolean
If true, this license can be appended to an existing disk's set of licenses.
-
#charges_use_fee ⇒ ::Boolean
[Output Only] Deprecated.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional textual description of the resource; provided by the client when the resource is created.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#incompatible_licenses ⇒ ::Array<::String>
Specifies licenseCodes of licenses that are incompatible with this license.
-
#kind ⇒ ::String
Output only.
-
#license_code ⇒ ::Integer
[Output Only] The unique code used to attach this license to images, snapshots, and disks.
-
#minimum_retention ⇒ ::Google::Cloud::Compute::V1::Duration
If set, this license will be unable to be removed or replaced once attached to a disk until the minimum_retention period has passed.
-
#multi_tenant_only ⇒ ::Boolean
If true, this license can only be used on VMs on multi tenant nodes.
-
#name ⇒ ::String
Name of the resource.
-
#os_license ⇒ ::Boolean
If true, indicates this is an OS license.
-
#params ⇒ ::Google::Cloud::Compute::V1::LicenseParams
Input only.
-
#removable_from_disk ⇒ ::Boolean
If true, this license can be removed from a disk's set of licenses, with no replacement license needed.
-
#required_coattached_licenses ⇒ ::Array<::String>
Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license.
-
#resource_requirements ⇒ ::Google::Cloud::Compute::V1::LicenseResourceRequirements
[Input Only] Deprecated.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#sole_tenant_only ⇒ ::Boolean
If true, this license can only be used on VMs on sole tenant nodes.
-
#transferable ⇒ ::Boolean
If false, licenses will not be copied from the source resource when creating an image from a disk, disk from snapshot, or snapshot from disk.
-
#update_timestamp ⇒ ::String
Output only.
Instance Attribute Details
#allowed_replacement_licenses ⇒ ::Array<::String>
Returns Specifies licenseCodes of licenses that can replace this license. Note: such replacements are allowed even if removable_from_disk is false.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#appendable_to_disk ⇒ ::Boolean
Returns If true, this license can be appended to an existing disk's set of licenses.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#charges_use_fee ⇒ ::Boolean
Returns [Output Only] Deprecated. This field no longer reflects whether a license charges a usage fee.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns An optional textual description of the resource; provided by the client when the resource is created.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#incompatible_licenses ⇒ ::Array<::String>
Returns Specifies licenseCodes of licenses that are incompatible with this license. If a license is incompatible with this license, it cannot be attached to the same disk or image.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Always compute#license for licenses.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#license_code ⇒ ::Integer
Returns [Output Only] The unique code used to attach this license to images, snapshots, and disks.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#minimum_retention ⇒ ::Google::Cloud::Compute::V1::Duration
Returns If set, this license will be unable to be removed or replaced once attached to a disk until the minimum_retention period has passed.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#multi_tenant_only ⇒ ::Boolean
Returns If true, this license can only be used on VMs on multi tenant nodes.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Name of the resource. The name must be 1-63 characters long and comply withRFC1035.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#os_license ⇒ ::Boolean
Returns If true, indicates this is an OS license. Only one OS license can be attached to a disk or image at a time.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#params ⇒ ::Google::Cloud::Compute::V1::LicenseParams
Returns Input only. Additional params passed with the request, but not persisted as part of resource payload.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#removable_from_disk ⇒ ::Boolean
Returns If true, this license can be removed from a disk's set of licenses, with no replacement license needed.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#required_coattached_licenses ⇒ ::Array<::String>
Returns Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license. At least one license from the set must be attached to the same disk or image as this license.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_requirements ⇒ ::Google::Cloud::Compute::V1::LicenseResourceRequirements
Returns [Input Only] Deprecated.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource with the resource id.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sole_tenant_only ⇒ ::Boolean
Returns If true, this license can only be used on VMs on sole tenant nodes.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transferable ⇒ ::Boolean
Returns If false, licenses will not be copied from the source resource when creating an image from a disk, disk from snapshot, or snapshot from disk.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_timestamp ⇒ ::String
Returns Output only. [Output Only] Last update timestamp inRFC3339 text format.
37968 37969 37970 37971 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 37968 class License include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |