Class: Google::Cloud::Compute::V1::LicenseCode

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a License Code resource.

A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_replacement_licenses::Array<::String>

Returns Specifies licenseCodes of licenses that can replace this license. Note: such replacements are allowed even if removable_from_disk is false.

Returns:

  • (::Array<::String>)

    Specifies licenseCodes of licenses that can replace this license. Note: such replacements are allowed even if removable_from_disk is false.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#appendable_to_disk::Boolean

Returns If true, this license can be appended to an existing disk's set of licenses.

Returns:

  • (::Boolean)

    If true, this license can be appended to an existing disk's set of licenses.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#description::String

Returns Output only. [Output Only] Description of this License Code.

Returns:

  • (::String)

    Output only. [Output Only] Description of this License Code.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#incompatible_licenses::Array<::String>

Returns Specifies licenseCodes of licenses that are incompatible with this license. If a license is incompatible with this license, it cannot be attached to the same disk or image.

Returns:

  • (::Array<::String>)

    Specifies licenseCodes of licenses that are incompatible with this license. If a license is incompatible with this license, it cannot be attached to the same disk or image.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#kind::String

Returns Output only. [Output Only] Type of resource. Always compute#licenseCode for licenses.

Returns:

  • (::String)

    Output only. [Output Only] Type of resource. Always compute#licenseCode for licenses.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#license_alias::Array<::Google::Cloud::Compute::V1::LicenseCodeLicenseAlias>

Returns [Output Only] URL and description aliases of Licenses with the same License Code.

Returns:



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#minimum_retention::Google::Cloud::Compute::V1::Duration

Returns If set, this license will be unable to be removed or replaced once attached to a disk until the minimum_retention period has passed.

Returns:



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#multi_tenant_only::Boolean

Returns If true, this license can only be used on VMs on multi tenant nodes.

Returns:

  • (::Boolean)

    If true, this license can only be used on VMs on multi tenant nodes.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#name::String

Returns Output only. [Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer.

Returns:

  • (::String)

    Output only. [Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#os_license::Boolean

Returns If true, indicates this is an OS license. Only one OS license can be attached to a disk or image at a time.

Returns:

  • (::Boolean)

    If true, indicates this is an OS license. Only one OS license can be attached to a disk or image at a time.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#removable_from_disk::Boolean

Returns If true, this license can be removed from a disk's set of licenses, with no replacement license needed.

Returns:

  • (::Boolean)

    If true, this license can be removed from a disk's set of licenses, with no replacement license needed.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#required_coattached_licenses::Array<::String>

Returns Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license. At least one license from the set must be attached to the same disk or image as this license.

Returns:

  • (::Array<::String>)

    Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license. At least one license from the set must be attached to the same disk or image as this license.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for the resource.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#sole_tenant_only::Boolean

Returns If true, this license can only be used on VMs on sole tenant nodes.

Returns:

  • (::Boolean)

    If true, this license can only be used on VMs on sole tenant nodes.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#state::String

Returns Output only. [Output Only] Current state of this License Code. Check the State enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] Current state of this License Code. Check the State enum for the list of possible values.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#transferable::Boolean

Returns Output only. [Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred.

Returns:

  • (::Boolean)

    Output only. [Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end

#update_timestamp::String

Returns Output only. [Output Only] Last update timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Last update timestamp inRFC3339 text format.



38776
38777
38778
38779
38780
38781
38782
38783
38784
38785
38786
38787
38788
38789
38790
38791
38792
38793
38794
38795
38796
38797
38798
38799
38800
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38776

class LicenseCode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Current state of this License Code.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Machines are not allowed to attach boot disks with this License Code.
    # Requests to create new resources with this license will be rejected.
    DISABLED = 516_696_700

    # Use is allowed for anyone with USE_READ_ONLY access to this License Code.
    ENABLED = 182_130_465

    # Use of this license is limited to a project whitelist.
    RESTRICTED = 261_551_195

    STATE_UNSPECIFIED = 470_755_401

    # Reserved state.
    TERMINATED = 250_018_339
  end
end