Class: Google::Cloud::Compute::V1::LicenseCode
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::LicenseCode
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a License Code resource.
A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
Output only.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#license_alias ⇒ ::Array<::Google::Cloud::Compute::V1::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same License Code.
-
#name ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#state ⇒ ::String
Output only.
-
#transferable ⇒ ::Boolean
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
38014 38015 38016 38017 38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 38037 38038 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38014 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. # Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#description ⇒ ::String
Returns Output only. [Output Only] Description of this License Code.
38014 38015 38016 38017 38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 38037 38038 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38014 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. # Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
38014 38015 38016 38017 38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 38037 38038 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38014 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. # Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Always compute#licenseCode for licenses.
38014 38015 38016 38017 38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 38037 38038 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38014 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. # Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#license_alias ⇒ ::Array<::Google::Cloud::Compute::V1::LicenseCodeLicenseAlias>
Returns [Output Only] URL and description aliases of Licenses with the same License Code.
38014 38015 38016 38017 38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 38037 38038 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38014 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. # Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#name ⇒ ::String
Returns Output only. [Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer.
38014 38015 38016 38017 38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 38037 38038 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38014 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. # Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
38014 38015 38016 38017 38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 38037 38038 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38014 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. # Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#state ⇒ ::String
Returns Output only. [Output Only] Current state of this License Code. Check the State enum for the list of possible values.
38014 38015 38016 38017 38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 38037 38038 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38014 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. # Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#transferable ⇒ ::Boolean
Returns Output only. [Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred.
38014 38015 38016 38017 38018 38019 38020 38021 38022 38023 38024 38025 38026 38027 38028 38029 38030 38031 38032 38033 38034 38035 38036 38037 38038 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38014 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. # Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |