Class: Google::Cloud::Compute::V1::LicenseCode
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::LicenseCode
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a License Code resource. A License Code is a unique identifier used to represent a license resource. Caution This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ ::String
[Output Only] Description of this License Code.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
[Output Only] Type of resource.
-
#license_alias ⇒ ::Array<::Google::Cloud::Compute::V1::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same License Code.
-
#name ⇒ ::String
[Output Only] Name of the resource.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#state ⇒ ::String
[Output Only] Current state of this License Code.
-
#transferable ⇒ ::Boolean
[Output Only] If true, the license will remain attached when creating images or snapshots from disks.
Instance Attribute Details
#creation_timestamp ⇒ ::String
17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 17283 17284 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17261 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#description ⇒ ::String
17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 17283 17284 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17261 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#id ⇒ ::Integer
17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 17283 17284 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17261 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#kind ⇒ ::String
17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 17283 17284 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17261 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#license_alias ⇒ ::Array<::Google::Cloud::Compute::V1::LicenseCodeLicenseAlias>
17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 17283 17284 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17261 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#name ⇒ ::String
17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 17283 17284 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17261 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#self_link ⇒ ::String
17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 17283 17284 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17261 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#state ⇒ ::String
17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 17283 17284 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17261 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |
#transferable ⇒ ::Boolean
17261 17262 17263 17264 17265 17266 17267 17268 17269 17270 17271 17272 17273 17274 17275 17276 17277 17278 17279 17280 17281 17282 17283 17284 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 17261 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516_696_700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182_130_465 # Use of this license is limited to a project whitelist. RESTRICTED = 261_551_195 STATE_UNSPECIFIED = 470_755_401 # Reserved state. TERMINATED = 250_018_339 end end |