Class: Google::Cloud::Compute::V1::LicenseCode
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::LicenseCode
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a License Code resource. A License Code is a unique identifier used to represent a license resource. Caution This resource is intended for use only by third-party partners who are creating Cloud Marketplace images.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ ::String
[Output Only] Description of this License Code.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
[Output Only] Type of resource.
-
#license_alias ⇒ ::Array<::Google::Cloud::Compute::V1::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same License Code.
-
#name ⇒ ::String
[Output Only] Name of the resource.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#state ⇒ ::String
[Output Only] Current state of this License Code.
-
#transferable ⇒ ::Boolean
[Output Only] If true, the license will remain attached when creating images or snapshots from disks.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns [Output Only] Creation timestamp in RFC3339 text format.
14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14425 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516696700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182130465 # Use of this license is limited to a project whitelist. RESTRICTED = 261551195 STATE_UNSPECIFIED = 470755401 # Reserved state. TERMINATED = 250018339 end end |
#description ⇒ ::String
Returns [Output Only] Description of this License Code.
14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14425 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516696700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182130465 # Use of this license is limited to a project whitelist. RESTRICTED = 261551195 STATE_UNSPECIFIED = 470755401 # Reserved state. TERMINATED = 250018339 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14425 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516696700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182130465 # Use of this license is limited to a project whitelist. RESTRICTED = 261551195 STATE_UNSPECIFIED = 470755401 # Reserved state. TERMINATED = 250018339 end end |
#kind ⇒ ::String
Returns [Output Only] Type of resource. Always compute#licenseCode for licenses.
14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14425 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516696700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182130465 # Use of this license is limited to a project whitelist. RESTRICTED = 261551195 STATE_UNSPECIFIED = 470755401 # Reserved state. TERMINATED = 250018339 end end |
#license_alias ⇒ ::Array<::Google::Cloud::Compute::V1::LicenseCodeLicenseAlias>
Returns [Output Only] URL and description aliases of Licenses with the same License Code.
14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14425 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516696700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182130465 # Use of this license is limited to a project whitelist. RESTRICTED = 261551195 STATE_UNSPECIFIED = 470755401 # Reserved state. TERMINATED = 250018339 end end |
#name ⇒ ::String
Returns [Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer.
14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14425 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516696700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182130465 # Use of this license is limited to a project whitelist. RESTRICTED = 261551195 STATE_UNSPECIFIED = 470755401 # Reserved state. TERMINATED = 250018339 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14425 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516696700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182130465 # Use of this license is limited to a project whitelist. RESTRICTED = 261551195 STATE_UNSPECIFIED = 470755401 # Reserved state. TERMINATED = 250018339 end end |
#state ⇒ ::String
Returns [Output Only] Current state of this License Code. Check the State enum for the list of possible values.
14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14425 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516696700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182130465 # Use of this license is limited to a project whitelist. RESTRICTED = 261551195 STATE_UNSPECIFIED = 470755401 # Reserved state. TERMINATED = 250018339 end end |
#transferable ⇒ ::Boolean
Returns [Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred.
14425 14426 14427 14428 14429 14430 14431 14432 14433 14434 14435 14436 14437 14438 14439 14440 14441 14442 14443 14444 14445 14446 14447 14448 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 14425 class LicenseCode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Current state of this License Code. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Machines are not allowed to attach boot disks with this License Code. Requests to create new resources with this license will be rejected. DISABLED = 516696700 # Use is allowed for anyone with USE_READ_ONLY access to this License Code. ENABLED = 182130465 # Use of this license is limited to a project whitelist. RESTRICTED = 261551195 STATE_UNSPECIFIED = 470755401 # Reserved state. TERMINATED = 250018339 end end |