Class: Google::Cloud::Compute::V1::LicenseParams
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::LicenseParams
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Additional license params.
Defined Under Namespace
Classes: ResourceManagerTagsEntry
Instance Attribute Summary collapse
Instance Attribute Details
#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Input only. Resource manager tags to be bound to the license. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in
namespaced format such as {org_id|project_id}/{tag_key_short_name} and
{tag_value_short_name}. The field is ignored (both PUT &
PATCH) when empty.
38823 38824 38825 38826 38827 38828 38829 38830 38831 38832 38833 38834 38835 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38823 class LicenseParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |