Class: Google::Cloud::Compute::V1::ListAssociationsFirewallPolicyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ListAssociationsFirewallPolicyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for FirewallPolicies.ListAssociations. See the method description for details.
Instance Attribute Summary collapse
-
#include_inherited_policies ⇒ ::Boolean
If set to "true", the response will contain a list of all associations for the containing folders and the containing organization of the target.
-
#target_resource ⇒ ::String
The target resource to list associations.
Instance Attribute Details
#include_inherited_policies ⇒ ::Boolean
Returns If set to "true", the response will contain a list of all associations for the containing folders and the containing organization of the target. The parameter has no effect if the target is an organization.
38347 38348 38349 38350 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38347 class ListAssociationsFirewallPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#target_resource ⇒ ::String
Returns The target resource to list associations. It is an organization, or a folder.
38347 38348 38349 38350 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 38347 class ListAssociationsFirewallPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |