Class: Google::Cloud::Compute::V1::LocationPolicyLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Preference

Instance Attribute Summary collapse

Instance Attribute Details

#constraints::Google::Cloud::Compute::V1::LocationPolicyLocationConstraints

Returns Constraints that the caller requires on the result distribution in this zone.

Returns:



53904
53905
53906
53907
53908
53909
53910
53911
53912
53913
53914
53915
53916
53917
53918
53919
53920
53921
53922
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53904

class LocationPolicyLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Preference for a given location. Set to either ALLOW orDENY.
  module Preference
    # A value indicating that the enum field is not set.
    UNDEFINED_PREFERENCE = 0

    # Location is allowed for use.
    ALLOW = 62_368_553

    # Location is prohibited.
    DENY = 2_094_604

    # Default value, unused.
    PREFERENCE_UNSPECIFIED = 496_219_571
  end
end

#preference::String

Returns Preference for a given location. Set to either ALLOW orDENY. Check the Preference enum for the list of possible values.

Returns:

  • (::String)

    Preference for a given location. Set to either ALLOW orDENY. Check the Preference enum for the list of possible values.



53904
53905
53906
53907
53908
53909
53910
53911
53912
53913
53914
53915
53916
53917
53918
53919
53920
53921
53922
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53904

class LocationPolicyLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Preference for a given location. Set to either ALLOW orDENY.
  module Preference
    # A value indicating that the enum field is not set.
    UNDEFINED_PREFERENCE = 0

    # Location is allowed for use.
    ALLOW = 62_368_553

    # Location is prohibited.
    DENY = 2_094_604

    # Default value, unused.
    PREFERENCE_UNSPECIFIED = 496_219_571
  end
end