Class: Google::Cloud::Compute::V1::LocationPolicyLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::LocationPolicyLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Preference
Instance Attribute Summary collapse
-
#constraints ⇒ ::Google::Cloud::Compute::V1::LocationPolicyLocationConstraints
Constraints that the caller requires on the result distribution in this zone.
-
#preference ⇒ ::String
Preference for a given location.
Instance Attribute Details
#constraints ⇒ ::Google::Cloud::Compute::V1::LocationPolicyLocationConstraints
Returns Constraints that the caller requires on the result distribution in this zone.
52836 52837 52838 52839 52840 52841 52842 52843 52844 52845 52846 52847 52848 52849 52850 52851 52852 52853 52854 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52836 class LocationPolicyLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preference for a given location. Set to either ALLOW orDENY. module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # Location is allowed for use. ALLOW = 62_368_553 # Location is prohibited. DENY = 2_094_604 # Default value, unused. PREFERENCE_UNSPECIFIED = 496_219_571 end end |
#preference ⇒ ::String
Returns Preference for a given location. Set to either ALLOW orDENY. Check the Preference enum for the list of possible values.
52836 52837 52838 52839 52840 52841 52842 52843 52844 52845 52846 52847 52848 52849 52850 52851 52852 52853 52854 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52836 class LocationPolicyLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preference for a given location. Set to either ALLOW orDENY. module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # Location is allowed for use. ALLOW = 62_368_553 # Location is prohibited. DENY = 2_094_604 # Default value, unused. PREFERENCE_UNSPECIFIED = 496_219_571 end end |