Class: Google::Cloud::Compute::V1::LocationPolicyLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::LocationPolicyLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Preference
Instance Attribute Summary collapse
-
#constraints ⇒ ::Google::Cloud::Compute::V1::LocationPolicyLocationConstraints
Constraints that the caller requires on the result distribution in this zone.
-
#preference ⇒ ::String
Preference for a given location.
Instance Attribute Details
#constraints ⇒ ::Google::Cloud::Compute::V1::LocationPolicyLocationConstraints
Returns Constraints that the caller requires on the result distribution in this zone.
55708 55709 55710 55711 55712 55713 55714 55715 55716 55717 55718 55719 55720 55721 55722 55723 55724 55725 55726 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55708 class LocationPolicyLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preference for a given location. Set to either ALLOW orDENY. module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # Location is allowed for use. ALLOW = 62_368_553 # Location is prohibited. DENY = 2_094_604 # Default value, unused. PREFERENCE_UNSPECIFIED = 496_219_571 end end |
#preference ⇒ ::String
Returns Preference for a given location. Set to either ALLOW orDENY. Check the Preference enum for the list of possible values.
55708 55709 55710 55711 55712 55713 55714 55715 55716 55717 55718 55719 55720 55721 55722 55723 55724 55725 55726 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55708 class LocationPolicyLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preference for a given location. Set to either ALLOW orDENY. module Preference # A value indicating that the enum field is not set. UNDEFINED_PREFERENCE = 0 # Location is allowed for use. ALLOW = 62_368_553 # Location is prohibited. DENY = 2_094_604 # Default value, unused. PREFERENCE_UNSPECIFIED = 496_219_571 end end |