Class: Google::Cloud::Compute::V1::MachineImage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a machine image resource.

A machine image is a Compute Engine resource that stores all the configuration, metadata, permissions, and data from one or more disks required to create a Virtual machine (VM) instance. For more information, seeMachine images.

Defined Under Namespace

Modules: Status Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns Output only. [Output Only] The creation timestamp for this machine image inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] The creation timestamp for this machine image inRFC3339 text format.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#guest_flush::Boolean

Returns [Input Only] Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process.

Returns:

  • (::Boolean)

    [Input Only] Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#id::Integer

Returns Output only. [Output Only] A unique identifier for this machine image. The server defines this identifier.

Returns:

  • (::Integer)

    Output only. [Output Only] A unique identifier for this machine image. The server defines this identifier.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#instance_properties::Google::Cloud::Compute::V1::InstanceProperties

Returns [Output Only] Properties of source instance.

Returns:



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#kind::String

Returns Output only. [Output Only] The resource type, which is alwayscompute#machineImage for machine image.

Returns:

  • (::String)

    Output only. [Output Only] The resource type, which is alwayscompute#machineImage for machine image.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#label_fingerprint::String

Returns A fingerprint for the labels being applied to this machine image, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels.

To see the latest fingerprint, make get() request to the machine image.

Returns:

  • (::String)

    A fingerprint for the labels being applied to this machine image, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels.

    To see the latest fingerprint, make get() request to the machine image.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Labels to apply to this machine image. These can be later modified by the setLabels method.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Labels to apply to this machine image. These can be later modified by the setLabels method.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#machine_image_encryption_key::Google::Cloud::Compute::V1::CustomerEncryptionKey

Returns Encrypts the machine image using acustomer-supplied encryption key.

After you encrypt a machine image using a customer-supplied key, you must provide the same key if you use the machine image later. For example, you must provide the encryption key when you create an instance from the encrypted machine image in a future request.

Customer-supplied encryption keys do not protect access to metadata of the machine image.

If you do not provide an encryption key when creating the machine image, then the machine image will be encrypted using an automatically generated key and you do not need to provide a key to use the machine image later.

Returns:

  • (::Google::Cloud::Compute::V1::CustomerEncryptionKey)

    Encrypts the machine image using acustomer-supplied encryption key.

    After you encrypt a machine image using a customer-supplied key, you must provide the same key if you use the machine image later. For example, you must provide the encryption key when you create an instance from the encrypted machine image in a future request.

    Customer-supplied encryption keys do not protect access to metadata of the machine image.

    If you do not provide an encryption key when creating the machine image, then the machine image will be encrypted using an automatically generated key and you do not need to provide a key to use the machine image later.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#name::String

Returns Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#params::Google::Cloud::Compute::V1::MachineImageParams

Returns Input only. [Input Only] Additional parameters that are passed in the request, but are not persisted in the resource.

Returns:



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#satisfies_pzi::Boolean

Returns Output only. Reserved for future use.

Returns:

  • (::Boolean)

    Output only. Reserved for future use.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#satisfies_pzs::Boolean

Returns Output only. [Output Only] Reserved for future use.

Returns:

  • (::Boolean)

    Output only. [Output Only] Reserved for future use.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#saved_disks::Array<::Google::Cloud::Compute::V1::SavedDisk>

Returns Output only. An array of Machine Image specific properties for disks attached to the source instance.

Returns:



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

Returns Output only. [Output Only] The URL for this machine image. The server defines this URL.

Returns:

  • (::String)

    Output only. [Output Only] The URL for this machine image. The server defines this URL.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#source_disk_encryption_keys::Array<::Google::Cloud::Compute::V1::SourceDiskEncryptionKey>

Returns [Input Only] Thecustomer-supplied encryption key of the disks attached to the source instance. Required if the source disk is protected by a customer-supplied encryption key.

Returns:



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#source_instance::String

Returns The source instance used to create the machine image. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

 - https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
  • projects/project/zones/zone/instances/instance.

Returns:

  • (::String)

    The source instance used to create the machine image. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

     - https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
    
    • projects/project/zones/zone/instances/instance


52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#source_instance_properties::Google::Cloud::Compute::V1::SourceInstanceProperties

Returns Output only. [Output Only] DEPRECATED: Please use instance_properties instead for source instance related properties. New properties will not be added to this field.

Returns:



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#status::String

Returns Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING. Check the Status enum for the list of possible values.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#storage_locations::Array<::String>

Returns The regional or multi-regional Cloud Storage bucket location where themachine image is stored.

Returns:

  • (::Array<::String>)

    The regional or multi-regional Cloud Storage bucket location where themachine image is stored.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#total_storage_bytes::Integer

Returns Output only. [Output Only] Total size of the storage used by the machine image.

Returns:

  • (::Integer)

    Output only. [Output Only] Total size of the storage used by the machine image.



52990
52991
52992
52993
52994
52995
52996
52997
52998
52999
53000
53001
53002
53003
53004
53005
53006
53007
53008
53009
53010
53011
53012
53013
53014
53015
53016
53017
53018
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 52990

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end