Class: Google::Cloud::Compute::V1::MachineImage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a machine image resource. A machine image is a Compute Engine resource that stores all the configuration, metadata, permissions, and data from one or more disks required to create a Virtual machine (VM) instance. For more information, see Machine images.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#description::String



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#guest_flush::Boolean



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#id::Integer



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#instance_properties::Google::Cloud::Compute::V1::InstanceProperties



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#kind::String



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#machine_image_encryption_key::Google::Cloud::Compute::V1::CustomerEncryptionKey



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#name::String



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#satisfies_pzi::Boolean



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#satisfies_pzs::Boolean



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#saved_disks::Array<::Google::Cloud::Compute::V1::SavedDisk>



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end


20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#source_disk_encryption_keys::Array<::Google::Cloud::Compute::V1::SourceDiskEncryptionKey>



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#source_instance::String



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#source_instance_properties::Google::Cloud::Compute::V1::SourceInstanceProperties



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#status::String



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#storage_locations::Array<::String>



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end

#total_storage_bytes::Integer



20639
20640
20641
20642
20643
20644
20645
20646
20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639

class MachineImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    UPLOADING = 267_603_489
  end
end