Class: Google::Cloud::Compute::V1::MachineImage
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::MachineImage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a machine image resource. A machine image is a Compute Engine resource that stores all the configuration, metadata, permissions, and data from one or more disks required to create a Virtual machine (VM) instance. For more information, see Machine images.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
[Output Only] The creation timestamp for this machine image in RFC3339 text format.
-
#description ⇒ ::String
An optional description of this resource.
-
#guest_flush ⇒ ::Boolean
[Input Only] Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process.
-
#id ⇒ ::Integer
[Output Only] A unique identifier for this machine image.
-
#instance_properties ⇒ ::Google::Cloud::Compute::V1::InstanceProperties
[Output Only] Properties of source instance.
-
#kind ⇒ ::String
[Output Only] The resource type, which is always compute#machineImage for machine image.
-
#machine_image_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Encrypts the machine image using a customer-supplied encryption key.
-
#name ⇒ ::String
Name of the resource; provided by the client when the resource is created.
-
#satisfies_pzi ⇒ ::Boolean
Output only.
-
#satisfies_pzs ⇒ ::Boolean
[Output Only] Reserved for future use.
-
#saved_disks ⇒ ::Array<::Google::Cloud::Compute::V1::SavedDisk>
An array of Machine Image specific properties for disks attached to the source instance.
-
#self_link ⇒ ::String
[Output Only] The URL for this machine image.
-
#source_disk_encryption_keys ⇒ ::Array<::Google::Cloud::Compute::V1::SourceDiskEncryptionKey>
[Input Only] The customer-supplied encryption key of the disks attached to the source instance.
-
#source_instance ⇒ ::String
The source instance used to create the machine image.
-
#source_instance_properties ⇒ ::Google::Cloud::Compute::V1::SourceInstanceProperties
[Output Only] DEPRECATED: Please use instance_properties instead for source instance related properties.
-
#status ⇒ ::String
[Output Only] The status of the machine image.
-
#storage_locations ⇒ ::Array<::String>
The regional or multi-regional Cloud Storage bucket location where the machine image is stored.
-
#total_storage_bytes ⇒ ::Integer
[Output Only] Total size of the storage used by the machine image.
Instance Attribute Details
#creation_timestamp ⇒ ::String
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#description ⇒ ::String
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#guest_flush ⇒ ::Boolean
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#id ⇒ ::Integer
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#instance_properties ⇒ ::Google::Cloud::Compute::V1::InstanceProperties
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#kind ⇒ ::String
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#machine_image_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#name ⇒ ::String
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#satisfies_pzi ⇒ ::Boolean
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#satisfies_pzs ⇒ ::Boolean
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#saved_disks ⇒ ::Array<::Google::Cloud::Compute::V1::SavedDisk>
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#self_link ⇒ ::String
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#source_disk_encryption_keys ⇒ ::Array<::Google::Cloud::Compute::V1::SourceDiskEncryptionKey>
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#source_instance ⇒ ::String
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#source_instance_properties ⇒ ::Google::Cloud::Compute::V1::SourceInstanceProperties
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#status ⇒ ::String
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#storage_locations ⇒ ::Array<::String>
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |
#total_storage_bytes ⇒ ::Integer
20639 20640 20641 20642 20643 20644 20645 20646 20647 20648 20649 20650 20651 20652 20653 20654 20655 20656 20657 20658 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20639 class MachineImage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the machine image. One of the following values: INVALID, CREATING, READY, DELETING, and UPLOADING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 UPLOADING = 267_603_489 end end |