Class: Google::Cloud::Compute::V1::MachineImageParams
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::MachineImageParams
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Machine Image parameters
Defined Under Namespace
Classes: ResourceManagerTagsEntry
Instance Attribute Summary collapse
Instance Attribute Details
#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Input only. Resource manager tags to be bound to the machine image. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in
namespaced format such as {org_id|project_id}/{tag_key_short_name} and
{tag_value_short_name}. The field is ignored (both PUT &
PATCH) when empty.
53058 53059 53060 53061 53062 53063 53064 53065 53066 53067 53068 53069 53070 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53058 class MachineImageParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |