Class: Google::Cloud::Compute::V1::MachineType

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, read Machine Types.

Defined Under Namespace

Modules: Architecture

Instance Attribute Summary collapse

Instance Attribute Details

#accelerators::Array<::Google::Cloud::Compute::V1::Accelerators>

Returns [Output Only] A list of accelerator configurations assigned to this machine type.

Returns:



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#architecture::String

Returns [Output Only] The architecture of the machine type. Check the Architecture enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] The architecture of the machine type. Check the Architecture enum for the list of possible values.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#creation_timestamp::String

Returns [Output Only] Creation timestamp in RFC3339 text format.

Returns:

  • (::String)

    [Output Only] Creation timestamp in RFC3339 text format.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#deprecated::Google::Cloud::Compute::V1::DeprecationStatus

Returns [Output Only] The deprecation status associated with this machine type. Only applicable if the machine type is unavailable.

Returns:



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#description::String

Returns [Output Only] An optional textual description of the resource.

Returns:

  • (::String)

    [Output Only] An optional textual description of the resource.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#guest_cpus::Integer

Returns [Output Only] The number of virtual CPUs that are available to the instance.

Returns:

  • (::Integer)

    [Output Only] The number of virtual CPUs that are available to the instance.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#id::Integer

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    [Output Only] The unique identifier for the resource. This identifier is defined by the server.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#image_space_gb::Integer

Returns [Deprecated] This property is deprecated and will never be populated with any relevant values.

Returns:

  • (::Integer)

    [Deprecated] This property is deprecated and will never be populated with any relevant values.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#is_shared_cpu::Boolean

Returns [Output Only] Whether this machine type has a shared CPU. See Shared-core machine types for more information.

Returns:

  • (::Boolean)

    [Output Only] Whether this machine type has a shared CPU. See Shared-core machine types for more information.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#kind::String

Returns [Output Only] The type of the resource. Always compute#machineType for machine types.

Returns:

  • (::String)

    [Output Only] The type of the resource. Always compute#machineType for machine types.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#maximum_persistent_disks::Integer

Returns [Output Only] Maximum persistent disks allowed.

Returns:

  • (::Integer)

    [Output Only] Maximum persistent disks allowed.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#maximum_persistent_disks_size_gb::Integer

Returns [Output Only] Maximum total persistent disks size (GB) allowed.

Returns:

  • (::Integer)

    [Output Only] Maximum total persistent disks size (GB) allowed.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#memory_mb::Integer

Returns [Output Only] The amount of physical memory available to the instance, defined in MB.

Returns:

  • (::Integer)

    [Output Only] The amount of physical memory available to the instance, defined in MB.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#name::String

Returns [Output Only] Name of the resource.

Returns:

  • (::String)

    [Output Only] Name of the resource.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#scratch_disks::Array<::Google::Cloud::Compute::V1::ScratchDisks>

Returns [Output Only] A list of extended scratch disks assigned to the instance.

Returns:



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for the resource.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end

#zone::String

Returns [Output Only] The name of the zone where the machine type resides, such as us-central1-a.

Returns:

  • (::String)

    [Output Only] The name of the zone where the machine type resides, such as us-central1-a.



20767
20768
20769
20770
20771
20772
20773
20774
20775
20776
20777
20778
20779
20780
20781
20782
20783
20784
20785
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 20767

class MachineType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The architecture of the machine type.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end
end