Class: Google::Cloud::Compute::V1::ManagedInstanceInstanceHealth

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DetailedHealthState

Instance Attribute Summary collapse

Instance Attribute Details

#detailed_health_state::String

Returns Output only. [Output Only] The current detailed instance health state. Check the DetailedHealthState enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The current detailed instance health state. Check the DetailedHealthState enum for the list of possible values.



54984
54985
54986
54987
54988
54989
54990
54991
54992
54993
54994
54995
54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54984

class ManagedInstanceInstanceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current detailed instance health state.
  module DetailedHealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_DETAILED_HEALTH_STATE = 0

    # The instance is being drained. The existing connections to the instance
    # have time to complete, but the new ones are being refused.
    DRAINING = 480_455_402

    # The instance is reachable i.e. a connection to the application health
    # checking endpoint can be established, and conforms to the requirements
    # defined by the health check.
    HEALTHY = 439_801_213

    # The instance is unreachable i.e. a connection to the application health
    # checking endpoint cannot be established, or the server does not respond
    # within the specified timeout.
    TIMEOUT = 477_813_057

    # The instance is reachable, but does not conform to the requirements
    # defined by the health check.
    UNHEALTHY = 462_118_084

    # The health checking system is aware of the instance but its health is
    # not known at the moment.
    UNKNOWN = 433_141_802
  end
end

#health_check::String

Returns Output only. [Output Only] The URL for the health check that verifies whether the instance is healthy.

Returns:

  • (::String)

    Output only. [Output Only] The URL for the health check that verifies whether the instance is healthy.



54984
54985
54986
54987
54988
54989
54990
54991
54992
54993
54994
54995
54996
54997
54998
54999
55000
55001
55002
55003
55004
55005
55006
55007
55008
55009
55010
55011
55012
55013
55014
55015
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54984

class ManagedInstanceInstanceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current detailed instance health state.
  module DetailedHealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_DETAILED_HEALTH_STATE = 0

    # The instance is being drained. The existing connections to the instance
    # have time to complete, but the new ones are being refused.
    DRAINING = 480_455_402

    # The instance is reachable i.e. a connection to the application health
    # checking endpoint can be established, and conforms to the requirements
    # defined by the health check.
    HEALTHY = 439_801_213

    # The instance is unreachable i.e. a connection to the application health
    # checking endpoint cannot be established, or the server does not respond
    # within the specified timeout.
    TIMEOUT = 477_813_057

    # The instance is reachable, but does not conform to the requirements
    # defined by the health check.
    UNHEALTHY = 462_118_084

    # The health checking system is aware of the instance but its health is
    # not known at the moment.
    UNKNOWN = 433_141_802
  end
end