Class: Google::Cloud::Compute::V1::ManagedInstanceInstanceHealth

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DetailedHealthState

Instance Attribute Summary collapse

Instance Attribute Details

#detailed_health_state::String

Returns Output only. [Output Only] The current detailed instance health state. Check the DetailedHealthState enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The current detailed instance health state. Check the DetailedHealthState enum for the list of possible values.



54517
54518
54519
54520
54521
54522
54523
54524
54525
54526
54527
54528
54529
54530
54531
54532
54533
54534
54535
54536
54537
54538
54539
54540
54541
54542
54543
54544
54545
54546
54547
54548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54517

class ManagedInstanceInstanceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current detailed instance health state.
  module DetailedHealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_DETAILED_HEALTH_STATE = 0

    # The instance is being drained. The existing connections to the instance
    # have time to complete, but the new ones are being refused.
    DRAINING = 480_455_402

    # The instance is reachable i.e. a connection to the application health
    # checking endpoint can be established, and conforms to the requirements
    # defined by the health check.
    HEALTHY = 439_801_213

    # The instance is unreachable i.e. a connection to the application health
    # checking endpoint cannot be established, or the server does not respond
    # within the specified timeout.
    TIMEOUT = 477_813_057

    # The instance is reachable, but does not conform to the requirements
    # defined by the health check.
    UNHEALTHY = 462_118_084

    # The health checking system is aware of the instance but its health is
    # not known at the moment.
    UNKNOWN = 433_141_802
  end
end

#health_check::String

Returns Output only. [Output Only] The URL for the health check that verifies whether the instance is healthy.

Returns:

  • (::String)

    Output only. [Output Only] The URL for the health check that verifies whether the instance is healthy.



54517
54518
54519
54520
54521
54522
54523
54524
54525
54526
54527
54528
54529
54530
54531
54532
54533
54534
54535
54536
54537
54538
54539
54540
54541
54542
54543
54544
54545
54546
54547
54548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54517

class ManagedInstanceInstanceHealth
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The current detailed instance health state.
  module DetailedHealthState
    # A value indicating that the enum field is not set.
    UNDEFINED_DETAILED_HEALTH_STATE = 0

    # The instance is being drained. The existing connections to the instance
    # have time to complete, but the new ones are being refused.
    DRAINING = 480_455_402

    # The instance is reachable i.e. a connection to the application health
    # checking endpoint can be established, and conforms to the requirements
    # defined by the health check.
    HEALTHY = 439_801_213

    # The instance is unreachable i.e. a connection to the application health
    # checking endpoint cannot be established, or the server does not respond
    # within the specified timeout.
    TIMEOUT = 477_813_057

    # The instance is reachable, but does not conform to the requirements
    # defined by the health check.
    UNHEALTHY = 462_118_084

    # The health checking system is aware of the instance but its health is
    # not known at the moment.
    UNKNOWN = 433_141_802
  end
end