Class: Google::Cloud::Compute::V1::ManagedInstanceInstanceHealth
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ManagedInstanceInstanceHealth
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: DetailedHealthState
Instance Attribute Summary collapse
-
#detailed_health_state ⇒ ::String
Output only.
-
#health_check ⇒ ::String
Output only.
Instance Attribute Details
#detailed_health_state ⇒ ::String
Returns Output only. [Output Only] The current detailed instance health state. Check the DetailedHealthState enum for the list of possible values.
53449 53450 53451 53452 53453 53454 53455 53456 53457 53458 53459 53460 53461 53462 53463 53464 53465 53466 53467 53468 53469 53470 53471 53472 53473 53474 53475 53476 53477 53478 53479 53480 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53449 class ManagedInstanceInstanceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The current detailed instance health state. module DetailedHealthState # A value indicating that the enum field is not set. UNDEFINED_DETAILED_HEALTH_STATE = 0 # The instance is being drained. The existing connections to the instance # have time to complete, but the new ones are being refused. DRAINING = 480_455_402 # The instance is reachable i.e. a connection to the application health # checking endpoint can be established, and conforms to the requirements # defined by the health check. HEALTHY = 439_801_213 # The instance is unreachable i.e. a connection to the application health # checking endpoint cannot be established, or the server does not respond # within the specified timeout. TIMEOUT = 477_813_057 # The instance is reachable, but does not conform to the requirements # defined by the health check. UNHEALTHY = 462_118_084 # The health checking system is aware of the instance but its health is # not known at the moment. UNKNOWN = 433_141_802 end end |
#health_check ⇒ ::String
Returns Output only. [Output Only] The URL for the health check that verifies whether the instance is healthy.
53449 53450 53451 53452 53453 53454 53455 53456 53457 53458 53459 53460 53461 53462 53463 53464 53465 53466 53467 53468 53469 53470 53471 53472 53473 53474 53475 53476 53477 53478 53479 53480 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53449 class ManagedInstanceInstanceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The current detailed instance health state. module DetailedHealthState # A value indicating that the enum field is not set. UNDEFINED_DETAILED_HEALTH_STATE = 0 # The instance is being drained. The existing connections to the instance # have time to complete, but the new ones are being refused. DRAINING = 480_455_402 # The instance is reachable i.e. a connection to the application health # checking endpoint can be established, and conforms to the requirements # defined by the health check. HEALTHY = 439_801_213 # The instance is unreachable i.e. a connection to the application health # checking endpoint cannot be established, or the server does not respond # within the specified timeout. TIMEOUT = 477_813_057 # The instance is reachable, but does not conform to the requirements # defined by the health check. UNHEALTHY = 462_118_084 # The health checking system is aware of the instance but its health is # not known at the moment. UNKNOWN = 433_141_802 end end |