Class: Google::Cloud::Compute::V1::ManagedInstanceInstanceHealth
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ManagedInstanceInstanceHealth
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: DetailedHealthState
Instance Attribute Summary collapse
-
#detailed_health_state ⇒ ::String
Output only.
-
#health_check ⇒ ::String
Output only.
Instance Attribute Details
#detailed_health_state ⇒ ::String
Returns Output only. [Output Only] The current detailed instance health state. Check the DetailedHealthState enum for the list of possible values.
56358 56359 56360 56361 56362 56363 56364 56365 56366 56367 56368 56369 56370 56371 56372 56373 56374 56375 56376 56377 56378 56379 56380 56381 56382 56383 56384 56385 56386 56387 56388 56389 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56358 class ManagedInstanceInstanceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The current detailed instance health state. module DetailedHealthState # A value indicating that the enum field is not set. UNDEFINED_DETAILED_HEALTH_STATE = 0 # The instance is being drained. The existing connections to the instance # have time to complete, but the new ones are being refused. DRAINING = 480_455_402 # The instance is reachable i.e. a connection to the application health # checking endpoint can be established, and conforms to the requirements # defined by the health check. HEALTHY = 439_801_213 # The instance is unreachable i.e. a connection to the application health # checking endpoint cannot be established, or the server does not respond # within the specified timeout. TIMEOUT = 477_813_057 # The instance is reachable, but does not conform to the requirements # defined by the health check. UNHEALTHY = 462_118_084 # The health checking system is aware of the instance but its health is # not known at the moment. UNKNOWN = 433_141_802 end end |
#health_check ⇒ ::String
Returns Output only. [Output Only] The URL for the health check that verifies whether the instance is healthy.
56358 56359 56360 56361 56362 56363 56364 56365 56366 56367 56368 56369 56370 56371 56372 56373 56374 56375 56376 56377 56378 56379 56380 56381 56382 56383 56384 56385 56386 56387 56388 56389 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56358 class ManagedInstanceInstanceHealth include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The current detailed instance health state. module DetailedHealthState # A value indicating that the enum field is not set. UNDEFINED_DETAILED_HEALTH_STATE = 0 # The instance is being drained. The existing connections to the instance # have time to complete, but the new ones are being refused. DRAINING = 480_455_402 # The instance is reachable i.e. a connection to the application health # checking endpoint can be established, and conforms to the requirements # defined by the health check. HEALTHY = 439_801_213 # The instance is unreachable i.e. a connection to the application health # checking endpoint cannot be established, or the server does not respond # within the specified timeout. TIMEOUT = 477_813_057 # The instance is reachable, but does not conform to the requirements # defined by the health check. UNHEALTHY = 462_118_084 # The health checking system is aware of the instance but its health is # not known at the moment. UNKNOWN = 433_141_802 end end |