Class: Google::Cloud::Compute::V1::ManagedInstanceScheduling
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ManagedInstanceScheduling
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#graceful_shutdown_timestamp ⇒ ::String
Output only.
-
#termination_timestamp ⇒ ::String
Output only.
Instance Attribute Details
#graceful_shutdown_timestamp ⇒ ::String
Returns Output only. The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured. This is in RFC3339 text format.
55054 55055 55056 55057 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55054 class ManagedInstanceScheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#termination_timestamp ⇒ ::String
Returns Output only. The timestamp at which the managed instance will be terminated. This is in RFC3339 text format.
55054 55055 55056 55057 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55054 class ManagedInstanceScheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |