Class: Google::Cloud::Compute::V1::MetadataFilter

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Opaque filter criteria used by load balancers to restrict routing configuration to a limited set of load balancing proxies. Proxies and sidecars involved in load balancing would typically present metadata to the load balancers that need to match criteria specified here. If a match takes place, the relevant configuration is made available to those proxies.

For each metadataFilter in this list, if itsfilterMatchCriteria is set to MATCH_ANY, at least one of thefilterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata.

An example for using metadataFilters would be: if load balancing involves Envoys, they receive routing configuration when values inmetadataFilters match values supplied in of their XDS requests to loadbalancers.

Defined Under Namespace

Modules: FilterMatchCriteria

Instance Attribute Summary collapse

Instance Attribute Details

#filter_labels::Array<::Google::Cloud::Compute::V1::MetadataFilterLabelMatch>

Returns The list of label value pairs that must match labels in the provided metadata based on filterMatchCriteria

This list must not be empty and can have at the most 64 entries.

Returns:



54650
54651
54652
54653
54654
54655
54656
54657
54658
54659
54660
54661
54662
54663
54664
54665
54666
54667
54668
54669
54670
54671
54672
54673
54674
54675
54676
54677
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54650

class MetadataFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how individual filter label matches
  # within the list of filterLabels and contributes toward the
  # overall metadataFilter match.
  #
  #  Supported values are:
  #
  #    - MATCH_ANY: at least one of the filterLabels
  #    must have a matching label in the provided metadata.
  #    - MATCH_ALL: all filterLabels must have
  #    matching labels in the provided metadata.
  module FilterMatchCriteria
    # A value indicating that the enum field is not set.
    UNDEFINED_FILTER_MATCH_CRITERIA = 0

    # Specifies that all filterLabels must match for themetadataFilter to be considered a match.
    MATCH_ALL = 180_663_271

    # Specifies that any filterLabel must match for themetadataFilter to be considered a match.
    MATCH_ANY = 180_663_346

    # Indicates that the match criteria was not set. AmetadataFilter must never be created with this value.
    NOT_SET = 163_646_646
  end
end

#filter_match_criteria::String

Returns Specifies how individual filter label matches within the list of filterLabels and contributes toward the overall metadataFilter match.

Supported values are:

  • MATCH_ANY: at least one of the filterLabels must have a matching label in the provided metadata.
  • MATCH_ALL: all filterLabels must have matching labels in the provided metadata. Check the FilterMatchCriteria enum for the list of possible values.

Returns:

  • (::String)

    Specifies how individual filter label matches within the list of filterLabels and contributes toward the overall metadataFilter match.

    Supported values are:

    • MATCH_ANY: at least one of the filterLabels must have a matching label in the provided metadata.
    • MATCH_ALL: all filterLabels must have matching labels in the provided metadata. Check the FilterMatchCriteria enum for the list of possible values.


54650
54651
54652
54653
54654
54655
54656
54657
54658
54659
54660
54661
54662
54663
54664
54665
54666
54667
54668
54669
54670
54671
54672
54673
54674
54675
54676
54677
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54650

class MetadataFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies how individual filter label matches
  # within the list of filterLabels and contributes toward the
  # overall metadataFilter match.
  #
  #  Supported values are:
  #
  #    - MATCH_ANY: at least one of the filterLabels
  #    must have a matching label in the provided metadata.
  #    - MATCH_ALL: all filterLabels must have
  #    matching labels in the provided metadata.
  module FilterMatchCriteria
    # A value indicating that the enum field is not set.
    UNDEFINED_FILTER_MATCH_CRITERIA = 0

    # Specifies that all filterLabels must match for themetadataFilter to be considered a match.
    MATCH_ALL = 180_663_271

    # Specifies that any filterLabel must match for themetadataFilter to be considered a match.
    MATCH_ANY = 180_663_346

    # Indicates that the match criteria was not set. AmetadataFilter must never be created with this value.
    NOT_SET = 163_646_646
  end
end