Module: Google::Cloud::Compute::V1::MetadataFilter::FilterMatchCriteria
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies how individual filter label matches within the list of filterLabels and contributes toward the overall metadataFilter match. Supported values are: - MATCH_ANY: at least one of the filterLabels must have a matching label in the provided metadata. - MATCH_ALL: all filterLabels must have matching labels in the provided metadata.
Constant Summary collapse
- UNDEFINED_FILTER_MATCH_CRITERIA =
A value indicating that the enum field is not set.
0- MATCH_ALL =
Specifies that all filterLabels must match for the metadataFilter to be considered a match.
180_663_271- MATCH_ANY =
Specifies that any filterLabel must match for the metadataFilter to be considered a match.
180_663_346- NOT_SET =
Indicates that the match criteria was not set. A metadataFilter must never be created with this value.
163_646_646