Class: Google::Cloud::Compute::V1::NamedSet
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NamedSet
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#description ⇒ ::String
An optional description of named set.
-
#elements ⇒ ::Array<::Google::Cloud::Compute::V1::Expr>
CEL expressions that are comparable to constructs of this set's type (see Policy Language).
-
#fingerprint ⇒ ::String
A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking.
-
#name ⇒ ::String
This set's name, which must be a resource ID segment and unique within all named sets owned by the Router.
-
#type ⇒ ::String
This named set's type Check the Type enum for the list of possible values.
Instance Attribute Details
#description ⇒ ::String
Returns An optional description of named set.
56799 56800 56801 56802 56803 56804 56805 56806 56807 56808 56809 56810 56811 56812 56813 56814 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56799 class NamedSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This named set's type module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # The Named Set is a Community Named Set. NAMED_SET_TYPE_COMMUNITY = 263_444_871 # The Named Set is a Prefix Named Set. NAMED_SET_TYPE_PREFIX = 228_038_036 end end |
#elements ⇒ ::Array<::Google::Cloud::Compute::V1::Expr>
Returns CEL expressions that are comparable to constructs of this set's type (see Policy Language).
56799 56800 56801 56802 56803 56804 56805 56806 56807 56808 56809 56810 56811 56812 56813 56814 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56799 class NamedSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This named set's type module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # The Named Set is a Community Named Set. NAMED_SET_TYPE_COMMUNITY = 263_444_871 # The Named Set is a Prefix Named Set. NAMED_SET_TYPE_PREFIX = 228_038_036 end end |
#fingerprint ⇒ ::String
Returns A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels.
To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set.
56799 56800 56801 56802 56803 56804 56805 56806 56807 56808 56809 56810 56811 56812 56813 56814 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56799 class NamedSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This named set's type module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # The Named Set is a Community Named Set. NAMED_SET_TYPE_COMMUNITY = 263_444_871 # The Named Set is a Prefix Named Set. NAMED_SET_TYPE_PREFIX = 228_038_036 end end |
#name ⇒ ::String
Returns This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035.
56799 56800 56801 56802 56803 56804 56805 56806 56807 56808 56809 56810 56811 56812 56813 56814 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56799 class NamedSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This named set's type module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # The Named Set is a Community Named Set. NAMED_SET_TYPE_COMMUNITY = 263_444_871 # The Named Set is a Prefix Named Set. NAMED_SET_TYPE_PREFIX = 228_038_036 end end |
#type ⇒ ::String
Returns This named set's type Check the Type enum for the list of possible values.
56799 56800 56801 56802 56803 56804 56805 56806 56807 56808 56809 56810 56811 56812 56813 56814 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56799 class NamedSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This named set's type module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # The Named Set is a Community Named Set. NAMED_SET_TYPE_COMMUNITY = 263_444_871 # The Named Set is a Prefix Named Set. NAMED_SET_TYPE_PREFIX = 228_038_036 end end |