Class: Google::Cloud::Compute::V1::NatIpInfoNatIpInfoMapping

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains information of a NAT IP.

Defined Under Namespace

Modules: Mode, Usage

Instance Attribute Summary collapse

Instance Attribute Details

#mode::String

Returns Output only. Specifies whether NAT IP is auto or manual. Check the Mode enum for the list of possible values.

Returns:

  • (::String)

    Output only. Specifies whether NAT IP is auto or manual. Check the Mode enum for the list of possible values.



54908
54909
54910
54911
54912
54913
54914
54915
54916
54917
54918
54919
54920
54921
54922
54923
54924
54925
54926
54927
54928
54929
54930
54931
54932
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54908

class NatIpInfoNatIpInfoMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Specifies whether NAT IP is auto or manual.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    AUTO = 2_020_783

    MANUAL = 119_397_318
  end

  # Output only. Specifies whether NAT IP is currently serving at least one endpoint or
  # not.
  module Usage
    # A value indicating that the enum field is not set.
    UNDEFINED_USAGE = 0

    IN_USE = 17_393_485

    UNUSED = 360_643_030
  end
end

#nat_ip::String

Returns Output only. NAT IP address. For example: 203.0.113.11.

Returns:

  • (::String)

    Output only. NAT IP address. For example: 203.0.113.11.



54908
54909
54910
54911
54912
54913
54914
54915
54916
54917
54918
54919
54920
54921
54922
54923
54924
54925
54926
54927
54928
54929
54930
54931
54932
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54908

class NatIpInfoNatIpInfoMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Specifies whether NAT IP is auto or manual.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    AUTO = 2_020_783

    MANUAL = 119_397_318
  end

  # Output only. Specifies whether NAT IP is currently serving at least one endpoint or
  # not.
  module Usage
    # A value indicating that the enum field is not set.
    UNDEFINED_USAGE = 0

    IN_USE = 17_393_485

    UNUSED = 360_643_030
  end
end

#usage::String

Returns Output only. Specifies whether NAT IP is currently serving at least one endpoint or not. Check the Usage enum for the list of possible values.

Returns:

  • (::String)

    Output only. Specifies whether NAT IP is currently serving at least one endpoint or not. Check the Usage enum for the list of possible values.



54908
54909
54910
54911
54912
54913
54914
54915
54916
54917
54918
54919
54920
54921
54922
54923
54924
54925
54926
54927
54928
54929
54930
54931
54932
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54908

class NatIpInfoNatIpInfoMapping
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Specifies whether NAT IP is auto or manual.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    AUTO = 2_020_783

    MANUAL = 119_397_318
  end

  # Output only. Specifies whether NAT IP is currently serving at least one endpoint or
  # not.
  module Usage
    # A value indicating that the enum field is not set.
    UNDEFINED_USAGE = 0

    IN_USE = 17_393_485

    UNUSED = 360_643_030
  end
end