Class: Google::Cloud::Compute::V1::NatIpInfoNatIpInfoMapping
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NatIpInfoNatIpInfoMapping
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Contains information of a NAT IP.
Defined Under Namespace
Instance Attribute Summary collapse
-
#mode ⇒ ::String
Output only.
-
#nat_ip ⇒ ::String
Output only.
-
#usage ⇒ ::String
Output only.
Instance Attribute Details
#mode ⇒ ::String
Returns Output only. Specifies whether NAT IP is auto or manual. Check the Mode enum for the list of possible values.
53840 53841 53842 53843 53844 53845 53846 53847 53848 53849 53850 53851 53852 53853 53854 53855 53856 53857 53858 53859 53860 53861 53862 53863 53864 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53840 class NatIpInfoNatIpInfoMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Specifies whether NAT IP is auto or manual. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 AUTO = 2_020_783 MANUAL = 119_397_318 end # Output only. Specifies whether NAT IP is currently serving at least one endpoint or # not. module Usage # A value indicating that the enum field is not set. UNDEFINED_USAGE = 0 IN_USE = 17_393_485 UNUSED = 360_643_030 end end |
#nat_ip ⇒ ::String
Returns Output only. NAT IP address. For example: 203.0.113.11.
53840 53841 53842 53843 53844 53845 53846 53847 53848 53849 53850 53851 53852 53853 53854 53855 53856 53857 53858 53859 53860 53861 53862 53863 53864 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53840 class NatIpInfoNatIpInfoMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Specifies whether NAT IP is auto or manual. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 AUTO = 2_020_783 MANUAL = 119_397_318 end # Output only. Specifies whether NAT IP is currently serving at least one endpoint or # not. module Usage # A value indicating that the enum field is not set. UNDEFINED_USAGE = 0 IN_USE = 17_393_485 UNUSED = 360_643_030 end end |
#usage ⇒ ::String
Returns Output only. Specifies whether NAT IP is currently serving at least one endpoint or not. Check the Usage enum for the list of possible values.
53840 53841 53842 53843 53844 53845 53846 53847 53848 53849 53850 53851 53852 53853 53854 53855 53856 53857 53858 53859 53860 53861 53862 53863 53864 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 53840 class NatIpInfoNatIpInfoMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Specifies whether NAT IP is auto or manual. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 AUTO = 2_020_783 MANUAL = 119_397_318 end # Output only. Specifies whether NAT IP is currently serving at least one endpoint or # not. module Usage # A value indicating that the enum field is not set. UNDEFINED_USAGE = 0 IN_USE = 17_393_485 UNUSED = 360_643_030 end end |