Class: Google::Cloud::Compute::V1::NetworkAttachment
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkAttachment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
NetworkAttachments A network attachment resource ...
Defined Under Namespace
Modules: ConnectionPreference
Instance Attribute Summary collapse
-
#connection_endpoints ⇒ ::Array<::Google::Cloud::Compute::V1::NetworkAttachmentConnectedEndpoint>
Output only.
-
#connection_preference ⇒ ::String
Check the ConnectionPreference enum for the list of possible values.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#network ⇒ ::String
Output only.
-
#producer_accept_lists ⇒ ::Array<::String>
Projects that are allowed to connect to this network attachment.
-
#producer_reject_lists ⇒ ::Array<::String>
Projects that are not allowed to connect to this network attachment.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#subnetworks ⇒ ::Array<::String>
An array of URLs where each entry is the URL of a subnet provided by the service consumer to use for endpoints in the producers that connect to this network attachment.
Instance Attribute Details
#connection_endpoints ⇒ ::Array<::Google::Cloud::Compute::V1::NetworkAttachmentConnectedEndpoint>
Returns Output only. [Output Only] An array of connections for all the producers connected to this network attachment.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#connection_preference ⇒ ::String
Returns Check the ConnectionPreference enum for the list of possible values.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#fingerprint ⇒ ::String
Returns Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. An up-to-date fingerprint must be provided in order to patch.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#network ⇒ ::String
Returns Output only. [Output Only] The URL of the network which the Network Attachment belongs to. Practically it is inferred by fetching the network of the first subnetwork associated. Because it is required that all the subnetworks must be from the same network, it is assured that the Network Attachment belongs to the same network as all the subnetworks.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#producer_accept_lists ⇒ ::Array<::String>
Returns Projects that are allowed to connect to this network attachment. The project can be specified using its id or number.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#producer_reject_lists ⇒ ::Array<::String>
Returns Projects that are not allowed to connect to this network attachment. The project can be specified using its id or number.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the network attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource's resource id.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |
#subnetworks ⇒ ::Array<::String>
Returns An array of URLs where each entry is the URL of a subnet provided by the service consumer to use for endpoints in the producers that connect to this network attachment.
54072 54073 54074 54075 54076 54077 54078 54079 54080 54081 54082 54083 54084 54085 54086 54087 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54072 class NetworkAttachment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module ConnectionPreference # A value indicating that the enum field is not set. UNDEFINED_CONNECTION_PREFERENCE = 0 ACCEPT_AUTOMATIC = 75_250_580 ACCEPT_MANUAL = 373_061_341 INVALID = 530_283_991 end end |