Class: Google::Cloud::Compute::V1::NetworkAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkAttachmentConnectedEndpoint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] A connection connected to this network attachment.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#ip_address ⇒ ::String
The IPv4 address assigned to the producer instance network interface.
-
#ipv6_address ⇒ ::String
The IPv6 address assigned to the producer instance network interface.
-
#project_id_or_num ⇒ ::String
The project id or number of the interface to which the IP was assigned.
-
#secondary_ip_cidr_ranges ⇒ ::Array<::String>
Alias IP ranges from the same subnetwork.
-
#service_class_id ⇒ ::String
The service class id of the producer service to which the IP was assigned.
-
#status ⇒ ::String
The status of a connected endpoint to this network attachment.
-
#subnetwork ⇒ ::String
The subnetwork used to assign the IP to the producer instance network interface.
-
#subnetwork_cidr_range ⇒ ::String
Output only.
Instance Attribute Details
#ip_address ⇒ ::String
Returns The IPv4 address assigned to the producer instance network interface. This value will be a range in case of Serverless.
55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 55245 55246 55247 55248 55249 55250 55251 55252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55225 class NetworkAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this network attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The consumer allows traffic from the producer to reach its VPC. ACCEPTED = 246_714_279 # The consumer network attachment no longer exists. CLOSED = 380_163_436 # The consumer needs to take further action before traffic can be served. NEEDS_ATTENTION = 344_491_452 # The consumer neither allows nor prohibits traffic # from the producer to reach its VPC. PENDING = 35_394_935 # The consumer prohibits traffic from the producer to reach its VPC. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#ipv6_address ⇒ ::String
Returns The IPv6 address assigned to the producer instance network interface. This is only assigned when the stack types of both the instance network interface and the consumer subnet are IPv4_IPv6.
55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 55245 55246 55247 55248 55249 55250 55251 55252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55225 class NetworkAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this network attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The consumer allows traffic from the producer to reach its VPC. ACCEPTED = 246_714_279 # The consumer network attachment no longer exists. CLOSED = 380_163_436 # The consumer needs to take further action before traffic can be served. NEEDS_ATTENTION = 344_491_452 # The consumer neither allows nor prohibits traffic # from the producer to reach its VPC. PENDING = 35_394_935 # The consumer prohibits traffic from the producer to reach its VPC. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#project_id_or_num ⇒ ::String
Returns The project id or number of the interface to which the IP was assigned.
55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 55245 55246 55247 55248 55249 55250 55251 55252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55225 class NetworkAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this network attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The consumer allows traffic from the producer to reach its VPC. ACCEPTED = 246_714_279 # The consumer network attachment no longer exists. CLOSED = 380_163_436 # The consumer needs to take further action before traffic can be served. NEEDS_ATTENTION = 344_491_452 # The consumer neither allows nor prohibits traffic # from the producer to reach its VPC. PENDING = 35_394_935 # The consumer prohibits traffic from the producer to reach its VPC. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#secondary_ip_cidr_ranges ⇒ ::Array<::String>
Returns Alias IP ranges from the same subnetwork.
55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 55245 55246 55247 55248 55249 55250 55251 55252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55225 class NetworkAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this network attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The consumer allows traffic from the producer to reach its VPC. ACCEPTED = 246_714_279 # The consumer network attachment no longer exists. CLOSED = 380_163_436 # The consumer needs to take further action before traffic can be served. NEEDS_ATTENTION = 344_491_452 # The consumer neither allows nor prohibits traffic # from the producer to reach its VPC. PENDING = 35_394_935 # The consumer prohibits traffic from the producer to reach its VPC. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#service_class_id ⇒ ::String
Returns The service class id of the producer service to which the IP was assigned.
55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 55245 55246 55247 55248 55249 55250 55251 55252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55225 class NetworkAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this network attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The consumer allows traffic from the producer to reach its VPC. ACCEPTED = 246_714_279 # The consumer network attachment no longer exists. CLOSED = 380_163_436 # The consumer needs to take further action before traffic can be served. NEEDS_ATTENTION = 344_491_452 # The consumer neither allows nor prohibits traffic # from the producer to reach its VPC. PENDING = 35_394_935 # The consumer prohibits traffic from the producer to reach its VPC. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#status ⇒ ::String
Returns The status of a connected endpoint to this network attachment. Check the Status enum for the list of possible values.
55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 55245 55246 55247 55248 55249 55250 55251 55252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55225 class NetworkAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this network attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The consumer allows traffic from the producer to reach its VPC. ACCEPTED = 246_714_279 # The consumer network attachment no longer exists. CLOSED = 380_163_436 # The consumer needs to take further action before traffic can be served. NEEDS_ATTENTION = 344_491_452 # The consumer neither allows nor prohibits traffic # from the producer to reach its VPC. PENDING = 35_394_935 # The consumer prohibits traffic from the producer to reach its VPC. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#subnetwork ⇒ ::String
Returns The subnetwork used to assign the IP to the producer instance network interface.
55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 55245 55246 55247 55248 55249 55250 55251 55252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55225 class NetworkAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this network attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The consumer allows traffic from the producer to reach its VPC. ACCEPTED = 246_714_279 # The consumer network attachment no longer exists. CLOSED = 380_163_436 # The consumer needs to take further action before traffic can be served. NEEDS_ATTENTION = 344_491_452 # The consumer neither allows nor prohibits traffic # from the producer to reach its VPC. PENDING = 35_394_935 # The consumer prohibits traffic from the producer to reach its VPC. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#subnetwork_cidr_range ⇒ ::String
Returns Output only. [Output Only] The CIDR range of the subnet from which the IPv4 internal IP was allocated from.
55225 55226 55227 55228 55229 55230 55231 55232 55233 55234 55235 55236 55237 55238 55239 55240 55241 55242 55243 55244 55245 55246 55247 55248 55249 55250 55251 55252 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55225 class NetworkAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this network attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The consumer allows traffic from the producer to reach its VPC. ACCEPTED = 246_714_279 # The consumer network attachment no longer exists. CLOSED = 380_163_436 # The consumer needs to take further action before traffic can be served. NEEDS_ATTENTION = 344_491_452 # The consumer neither allows nor prohibits traffic # from the producer to reach its VPC. PENDING = 35_394_935 # The consumer prohibits traffic from the producer to reach its VPC. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |