Class: Google::Cloud::Compute::V1::NetworkEdgeSecurityServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkEdgeSecurityServiceAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
- #etag ⇒ ::String
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList}
A list of NetworkEdgeSecurityServicesScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#etag ⇒ ::String
54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54308 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54308 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList}
Returns A list of NetworkEdgeSecurityServicesScopedList resources.
54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54308 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Alwayscompute#networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services.
54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54308 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54308 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54308 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54308 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
54308 54309 54310 54311 54312 54313 54314 54315 54316 54317 54318 54319 54320 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54308 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |