Class: Google::Cloud::Compute::V1::NetworkEdgeSecurityServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkEdgeSecurityServiceAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
- #etag ⇒ ::String
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList}
A list of NetworkEdgeSecurityServicesScopedList resources.
-
#kind ⇒ ::String
[Output Only] Type of resource.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ ::Array<::String>
[Output Only] Unreachable resources.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#etag ⇒ ::String
21693 21694 21695 21696 21697 21698 21699 21700 21701 21702 21703 21704 21705 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
21693 21694 21695 21696 21697 21698 21699 21700 21701 21702 21703 21704 21705 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList}
Returns A list of NetworkEdgeSecurityServicesScopedList resources.
21693 21694 21695 21696 21697 21698 21699 21700 21701 21702 21703 21704 21705 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns [Output Only] Type of resource. Always compute#networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services.
21693 21694 21695 21696 21697 21698 21699 21700 21701 21702 21703 21704 21705 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
21693 21694 21695 21696 21697 21698 21699 21700 21701 21702 21703 21704 21705 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for this resource.
21693 21694 21695 21696 21697 21698 21699 21700 21701 21702 21703 21704 21705 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns [Output Only] Unreachable resources.
21693 21694 21695 21696 21697 21698 21699 21700 21701 21702 21703 21704 21705 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
21693 21694 21695 21696 21697 21698 21699 21700 21701 21702 21703 21704 21705 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21693 class NetworkEdgeSecurityServiceAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |