Class: Google::Cloud::Compute::V1::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns:

  • (::String)


21536
21537
21538
21539
21540
21541
21542
21543
21544
21545
21546
21547
21548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21536

class NetworkEdgeSecurityServiceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    [Output Only] Unique identifier for the resource; defined by the server.



21536
21537
21538
21539
21540
21541
21542
21543
21544
21545
21546
21547
21548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21536

class NetworkEdgeSecurityServiceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList}

Returns A list of NetworkEdgeSecurityServicesScopedList resources.

Returns:



21536
21537
21538
21539
21540
21541
21542
21543
21544
21545
21546
21547
21548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21536

class NetworkEdgeSecurityServiceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns [Output Only] Type of resource. Always compute#networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services.

Returns:

  • (::String)

    [Output Only] Type of resource. Always compute#networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services.



21536
21537
21538
21539
21540
21541
21542
21543
21544
21545
21546
21547
21548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21536

class NetworkEdgeSecurityServiceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



21536
21537
21538
21539
21540
21541
21542
21543
21544
21545
21546
21547
21548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21536

class NetworkEdgeSecurityServiceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns [Output Only] Server-defined URL for this resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for this resource.



21536
21537
21538
21539
21540
21541
21542
21543
21544
21545
21546
21547
21548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21536

class NetworkEdgeSecurityServiceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables::Array<::String>

Returns [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>)

    [Output Only] Unreachable resources.



21536
21537
21538
21539
21540
21541
21542
21543
21544
21545
21546
21547
21548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21536

class NetworkEdgeSecurityServiceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



21536
21537
21538
21539
21540
21541
21542
21543
21544
21545
21546
21547
21548
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21536

class NetworkEdgeSecurityServiceAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEdgeSecurityServicesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end