Class: Google::Cloud::Compute::V1::NetworkEndpointGroup
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkEndpointGroup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a collection of network endpoints.
A network endpoint group (NEG) defines how a set of endpoints should be reached, whether they are reachable, and where they are located. For more information about using NEGs for different use cases, seeNetwork endpoint groups overview.
Note: Use the following APIs to manage network endpoint groups:
-
To manage NEGs with zonal scope (such as zonal NEGs, hybrid connectivity
NEGs): zonal
API
-
To manage NEGs with regional scope (such as regional internet NEGs,
serverless NEGs, Private Service Connect NEGs): regional
API
-
To manage NEGs with global scope (such as global internet NEGs):global
API
Defined Under Namespace
Modules: NetworkEndpointType Classes: AnnotationsEntry
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#app_engine ⇒ ::Google::Cloud::Compute::V1::NetworkEndpointGroupAppEngine
Optional.
-
#cloud_function ⇒ ::Google::Cloud::Compute::V1::NetworkEndpointGroupCloudFunction
Optional.
-
#cloud_run ⇒ ::Google::Cloud::Compute::V1::NetworkEndpointGroupCloudRun
Optional.
-
#creation_timestamp ⇒ ::String
Output only.
-
#default_port ⇒ ::Integer
The default port used if the port number is not specified in the network endpoint.
-
#description ⇒ ::String
An optional description of this resource.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ ::String
The URL of the network to which all network endpoints in the NEG belong.
-
#network_endpoint_type ⇒ ::String
Type of network endpoints in this network endpoint group.
-
#psc_data ⇒ ::Google::Cloud::Compute::V1::NetworkEndpointGroupPscData
Optional.
-
#psc_target_service ⇒ ::String
The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#size ⇒ ::Integer
Output only.
-
#subnetwork ⇒ ::String
Optional URL of the subnetwork to which all network endpoints in the NEG belong.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Metadata defined as annotations on the network endpoint group.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#app_engine ⇒ ::Google::Cloud::Compute::V1::NetworkEndpointGroupAppEngine
Returns Optional. Only valid when networkEndpointType isSERVERLESS. Only one of cloudRun,appEngine or cloudFunction may be set.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#cloud_function ⇒ ::Google::Cloud::Compute::V1::NetworkEndpointGroupCloudFunction
Returns Optional. Only valid when networkEndpointType isSERVERLESS. Only one of cloudRun,appEngine or cloudFunction may be set.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#cloud_run ⇒ ::Google::Cloud::Compute::V1::NetworkEndpointGroupCloudRun
Returns Optional. Only valid when networkEndpointType isSERVERLESS. Only one of cloudRun,appEngine or cloudFunction may be set.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#default_port ⇒ ::Integer
Returns The default port used if the port number is not specified in the network endpoint.
Optional. If the network endpoint type is either GCE_VM_IP,SERVERLESS or PRIVATE_SERVICE_CONNECT, this field must not be specified.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#networkEndpointGroup for network endpoint group.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#name ⇒ ::String
Returns Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#network ⇒ ::String
Returns The URL of the network to which all network endpoints in the NEG belong. For networkEndpointType GCE_VM_IP_PORT,GCE_VM_IP_PORTMAP or NON_GCP_PRIVATE_IP_PORT, if this field is not specified, a default network will be used. This field cannot be set for NEGs with networkEndpointType set toSERVERLESS or PRIVATE_SERVICE_CONNECT and for global NEGs. For all other network endpoint types, this field is required.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#network_endpoint_type ⇒ ::String
Returns Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. Check the NetworkEndpointType enum for the list of possible values.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#psc_data ⇒ ::Google::Cloud::Compute::V1::NetworkEndpointGroupPscData
Returns Optional. Only valid when networkEndpointType isPRIVATE_SERVICE_CONNECT.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#psc_target_service ⇒ ::String
Returns The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment. An example value is: asia-northeast3-cloudkms.googleapis.com.
Optional. Only valid when networkEndpointType isPRIVATE_SERVICE_CONNECT.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#region ⇒ ::String
Returns Output only. [Output Only] The URL of theregion where the network endpoint group is located.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#size ⇒ ::Integer
Returns Output only. [Output only] Number of network endpoints in the network endpoint group.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#subnetwork ⇒ ::String
Returns Optional URL of the subnetwork to which all network endpoints in the NEG belong.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |
#zone ⇒ ::String
Returns Output only. [Output Only] The URL of thezone where the network endpoint group is located.
57500 57501 57502 57503 57504 57505 57506 57507 57508 57509 57510 57511 57512 57513 57514 57515 57516 57517 57518 57519 57520 57521 57522 57523 57524 57525 57526 57527 57528 57529 57530 57531 57532 57533 57534 57535 57536 57537 57538 57539 57540 57541 57542 57543 57544 57545 57546 57547 57548 57549 57550 57551 57552 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57500 class NetworkEndpointGroup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. module NetworkEndpointType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_ENDPOINT_TYPE = 0 # The network endpoint is represented by an IP address. GCE_VM_IP = 401_880_793 # The network endpoint for targeting a specific network interface of a # VM instance in configurations with multiple network interfaces on the # same network. GCE_VM_IP_DEDICATED_BACKEND = 321_618_974 # The network endpoint is represented by IP address and port pair. GCE_VM_IP_PORT = 501_838_375 # The network endpoint is represented by an IP, Port and Client Destination # Port. GCE_VM_IP_PORTMAP = 22_819_253 # The network endpoint is represented by fully qualified domain name and # port. INTERNET_FQDN_PORT = 404_154_477 # The network endpoint is represented by an internet IP address and port. INTERNET_IP_PORT = 477_719_963 # The network endpoint is represented by an IP address and port. The # endpoint belongs to a VM or pod running in a customer's on-premises. NON_GCP_PRIVATE_IP_PORT = 336_447_968 # The network endpoint is either public Google APIs or # services exposed by other GCP Project with a Service Attachment. # The connection is set up by private service connect PRIVATE_SERVICE_CONNECT = 48_134_724 # The network endpoint is handled by specified serverless infrastructure. SERVERLESS = 270_492_508 end end |