Class: Google::Cloud::Compute::V1::NetworkEndpointGroupAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#id::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    [Output Only] Unique identifier for the resource; defined by the server.



56180
56181
56182
56183
56184
56185
56186
56187
56188
56189
56190
56191
56192
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56180

class NetworkEndpointGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList}

Returns A list of NetworkEndpointGroupsScopedList resources.

Returns:



56180
56181
56182
56183
56184
56185
56186
56187
56188
56189
56190
56191
56192
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56180

class NetworkEndpointGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns Output only. [Output Only] The resource type, which is alwayscompute#networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups.

Returns:

  • (::String)

    Output only. [Output Only] The resource type, which is alwayscompute#networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups.



56180
56181
56182
56183
56184
56185
56186
56187
56188
56189
56190
56191
56192
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56180

class NetworkEndpointGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



56180
56181
56182
56183
56184
56185
56186
56187
56188
56189
56190
56191
56192
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56180

class NetworkEndpointGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource.



56180
56181
56182
56183
56184
56185
56186
56187
56188
56189
56190
56191
56192
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56180

class NetworkEndpointGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Unreachable resources.



56180
56181
56182
56183
56184
56185
56186
56187
56188
56189
56190
56191
56192
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56180

class NetworkEndpointGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



56180
56181
56182
56183
56184
56185
56186
56187
56188
56189
56190
56191
56192
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56180

class NetworkEndpointGroupAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end