Class: Google::Cloud::Compute::V1::NetworkEndpointGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkEndpointGroupAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList}
A list of NetworkEndpointGroupsScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
54568 54569 54570 54571 54572 54573 54574 54575 54576 54577 54578 54579 54580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54568 class NetworkEndpointGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList}
Returns A list of NetworkEndpointGroupsScopedList resources.
54568 54569 54570 54571 54572 54573 54574 54575 54576 54577 54578 54579 54580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54568 class NetworkEndpointGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] The resource type, which is alwayscompute#networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups.
54568 54569 54570 54571 54572 54573 54574 54575 54576 54577 54578 54579 54580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54568 class NetworkEndpointGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
54568 54569 54570 54571 54572 54573 54574 54575 54576 54577 54578 54579 54580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54568 class NetworkEndpointGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
54568 54569 54570 54571 54572 54573 54574 54575 54576 54577 54578 54579 54580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54568 class NetworkEndpointGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
54568 54569 54570 54571 54572 54573 54574 54575 54576 54577 54578 54579 54580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54568 class NetworkEndpointGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
54568 54569 54570 54571 54572 54573 54574 54575 54576 54577 54578 54579 54580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 54568 class NetworkEndpointGroupAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::NetworkEndpointGroupsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |