Class: Google::Cloud::Compute::V1::NetworkEndpointGroupAppEngine
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkEndpointGroupAppEngine
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present. Note: App Engine service must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#service ⇒ ::String
Optional serving service.
-
#url_mask ⇒ ::String
An URL mask is one of the main components of the Cloud Function.
-
#version ⇒ ::String
Optional serving version.
Instance Attribute Details
#service ⇒ ::String
21775 21776 21777 21778 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21775 class NetworkEndpointGroupAppEngine include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#url_mask ⇒ ::String
21775 21776 21777 21778 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21775 class NetworkEndpointGroupAppEngine include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#version ⇒ ::String
21775 21776 21777 21778 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21775 class NetworkEndpointGroupAppEngine include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |