Class: Google::Cloud::Compute::V1::NetworkEndpointGroupPscData

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.

Defined Under Namespace

Modules: PscConnectionStatus

Instance Attribute Summary collapse

Instance Attribute Details

#consumer_psc_address::String

Returns Output only. [Output Only] Address allocated from given subnetwork for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in L7 PSC-XLB.

Returns:

  • (::String)

    Output only. [Output Only] Address allocated from given subnetwork for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in L7 PSC-XLB.



55811
55812
55813
55814
55815
55816
55817
55818
55819
55820
55821
55822
55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
55839
55840
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55811

class NetworkEndpointGroupPscData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The connection status of the PSC Forwarding Rule.
  module PscConnectionStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PSC_CONNECTION_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer and will not serve
    # traffic going forward.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The connection has been rejected by the producer.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#producer_port::Integer

Returns The psc producer port is used to connect PSC NEG with specific port on the PSC Producer side; should only be used for the PRIVATE_SERVICE_CONNECT NEG type.

Returns:

  • (::Integer)

    The psc producer port is used to connect PSC NEG with specific port on the PSC Producer side; should only be used for the PRIVATE_SERVICE_CONNECT NEG type



55811
55812
55813
55814
55815
55816
55817
55818
55819
55820
55821
55822
55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
55839
55840
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55811

class NetworkEndpointGroupPscData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The connection status of the PSC Forwarding Rule.
  module PscConnectionStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PSC_CONNECTION_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer and will not serve
    # traffic going forward.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The connection has been rejected by the producer.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#psc_connection_id::Integer

Returns Output only. [Output Only] The PSC connection id of the PSC Network Endpoint Group Consumer.

Returns:

  • (::Integer)

    Output only. [Output Only] The PSC connection id of the PSC Network Endpoint Group Consumer.



55811
55812
55813
55814
55815
55816
55817
55818
55819
55820
55821
55822
55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
55839
55840
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55811

class NetworkEndpointGroupPscData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The connection status of the PSC Forwarding Rule.
  module PscConnectionStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PSC_CONNECTION_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer and will not serve
    # traffic going forward.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The connection has been rejected by the producer.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#psc_connection_status::String

Returns Output only. [Output Only] The connection status of the PSC Forwarding Rule. Check the PscConnectionStatus enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The connection status of the PSC Forwarding Rule. Check the PscConnectionStatus enum for the list of possible values.



55811
55812
55813
55814
55815
55816
55817
55818
55819
55820
55821
55822
55823
55824
55825
55826
55827
55828
55829
55830
55831
55832
55833
55834
55835
55836
55837
55838
55839
55840
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55811

class NetworkEndpointGroupPscData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The connection status of the PSC Forwarding Rule.
  module PscConnectionStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_PSC_CONNECTION_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer and will not serve
    # traffic going forward.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The connection has been rejected by the producer.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end