Class: Google::Cloud::Compute::V1::NetworkEndpointGroupPscData
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkEndpointGroupPscData
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.
Defined Under Namespace
Modules: PscConnectionStatus
Instance Attribute Summary collapse
-
#consumer_psc_address ⇒ ::String
Output only.
-
#producer_port ⇒ ::Integer
The psc producer port is used to connect PSC NEG with specific port on the PSC Producer side; should only be used for the PRIVATE_SERVICE_CONNECT NEG type.
-
#psc_connection_id ⇒ ::Integer
Output only.
-
#psc_connection_status ⇒ ::String
Output only.
Instance Attribute Details
#consumer_psc_address ⇒ ::String
Returns Output only. [Output Only] Address allocated from given subnetwork for PSC. This IP address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in L7 PSC-XLB.
57755 57756 57757 57758 57759 57760 57761 57762 57763 57764 57765 57766 57767 57768 57769 57770 57771 57772 57773 57774 57775 57776 57777 57778 57779 57780 57781 57782 57783 57784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57755 class NetworkEndpointGroupPscData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The connection status of the PSC Forwarding Rule. module PscConnectionStatus # A value indicating that the enum field is not set. UNDEFINED_PSC_CONNECTION_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer and will not serve # traffic going forward. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The connection has been rejected by the producer. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#producer_port ⇒ ::Integer
Returns The psc producer port is used to connect PSC NEG with specific port on the PSC Producer side; should only be used for the PRIVATE_SERVICE_CONNECT NEG type.
57755 57756 57757 57758 57759 57760 57761 57762 57763 57764 57765 57766 57767 57768 57769 57770 57771 57772 57773 57774 57775 57776 57777 57778 57779 57780 57781 57782 57783 57784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57755 class NetworkEndpointGroupPscData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The connection status of the PSC Forwarding Rule. module PscConnectionStatus # A value indicating that the enum field is not set. UNDEFINED_PSC_CONNECTION_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer and will not serve # traffic going forward. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The connection has been rejected by the producer. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#psc_connection_id ⇒ ::Integer
Returns Output only. [Output Only] The PSC connection id of the PSC Network Endpoint Group Consumer.
57755 57756 57757 57758 57759 57760 57761 57762 57763 57764 57765 57766 57767 57768 57769 57770 57771 57772 57773 57774 57775 57776 57777 57778 57779 57780 57781 57782 57783 57784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57755 class NetworkEndpointGroupPscData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The connection status of the PSC Forwarding Rule. module PscConnectionStatus # A value indicating that the enum field is not set. UNDEFINED_PSC_CONNECTION_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer and will not serve # traffic going forward. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The connection has been rejected by the producer. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#psc_connection_status ⇒ ::String
Returns Output only. [Output Only] The connection status of the PSC Forwarding Rule. Check the PscConnectionStatus enum for the list of possible values.
57755 57756 57757 57758 57759 57760 57761 57762 57763 57764 57765 57766 57767 57768 57769 57770 57771 57772 57773 57774 57775 57776 57777 57778 57779 57780 57781 57782 57783 57784 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57755 class NetworkEndpointGroupPscData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The connection status of the PSC Forwarding Rule. module PscConnectionStatus # A value indicating that the enum field is not set. UNDEFINED_PSC_CONNECTION_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer and will not serve # traffic going forward. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The connection has been rejected by the producer. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |