Class: Google::Cloud::Compute::V1::NetworkFirewallPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkFirewallPolicyAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::FirewallPoliciesScopedList}
A list of FirewallPoliciesScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
56508 56509 56510 56511 56512 56513 56514 56515 56516 56517 56518 56519 56520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56508 class NetworkFirewallPolicyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FirewallPoliciesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::FirewallPoliciesScopedList}
Returns A list of FirewallPoliciesScopedList resources.
56508 56509 56510 56511 56512 56513 56514 56515 56516 56517 56518 56519 56520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56508 class NetworkFirewallPolicyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FirewallPoliciesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Alwayscompute#networkFirewallPoliciesAggregatedList for lists of network firewall policies.
56508 56509 56510 56511 56512 56513 56514 56515 56516 56517 56518 56519 56520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56508 class NetworkFirewallPolicyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FirewallPoliciesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
56508 56509 56510 56511 56512 56513 56514 56515 56516 56517 56518 56519 56520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56508 class NetworkFirewallPolicyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FirewallPoliciesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
56508 56509 56510 56511 56512 56513 56514 56515 56516 56517 56518 56519 56520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56508 class NetworkFirewallPolicyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FirewallPoliciesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
56508 56509 56510 56511 56512 56513 56514 56515 56516 56517 56518 56519 56520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56508 class NetworkFirewallPolicyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FirewallPoliciesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
56508 56509 56510 56511 56512 56513 56514 56515 56516 56517 56518 56519 56520 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56508 class NetworkFirewallPolicyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::FirewallPoliciesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |