Class: Google::Cloud::Compute::V1::NetworkInterface
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkInterface
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A network interface resource attached to an instance.
Defined Under Namespace
Modules: Ipv6AccessType, NicType, StackType
Instance Attribute Summary collapse
-
#access_configs ⇒ ::Array<::Google::Cloud::Compute::V1::AccessConfig>
An array of configurations for this interface.
-
#alias_ip_ranges ⇒ ::Array<::Google::Cloud::Compute::V1::AliasIpRange>
An array of alias IP ranges for this network interface.
-
#fingerprint ⇒ ::String
Fingerprint hash of contents stored in this network interface.
-
#internal_ipv6_prefix_length ⇒ ::Integer
The prefix length of the primary internal IPv6 range.
-
#ipv6_access_configs ⇒ ::Array<::Google::Cloud::Compute::V1::AccessConfig>
An array of IPv6 access configurations for this interface.
-
#ipv6_access_type ⇒ ::String
[Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet.
-
#ipv6_address ⇒ ::String
An IPv6 internal network address for this network interface.
-
#kind ⇒ ::String
[Output Only] Type of the resource.
-
#name ⇒ ::String
[Output Only] The name of the network interface, which is generated by the server.
-
#network ⇒ ::String
URL of the VPC network resource for this instance.
-
#network_attachment ⇒ ::String
The URL of the network attachment that this interface should connect to in the following format: projects/{project_number}/regions/{region_name}/networkAttachments/{network_attachment_name}.
-
#network_i_p ⇒ ::String
An IPv4 internal IP address to assign to the instance for this network interface.
-
#nic_type ⇒ ::String
The type of vNIC to be used on this interface.
-
#queue_count ⇒ ::Integer
The networking queue count that's specified by users for the network interface.
-
#stack_type ⇒ ::String
The stack type for this network interface.
-
#subnetwork ⇒ ::String
The URL of the Subnetwork resource for this instance.
Instance Attribute Details
#access_configs ⇒ ::Array<::Google::Cloud::Compute::V1::AccessConfig>
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#alias_ip_ranges ⇒ ::Array<::Google::Cloud::Compute::V1::AliasIpRange>
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#fingerprint ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#internal_ipv6_prefix_length ⇒ ::Integer
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#ipv6_access_configs ⇒ ::Array<::Google::Cloud::Compute::V1::AccessConfig>
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#ipv6_access_type ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#ipv6_address ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#kind ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#name ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#network ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#network_attachment ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#network_i_p ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#nic_type ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#queue_count ⇒ ::Integer
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#stack_type ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |
#subnetwork ⇒ ::String
22165 22166 22167 22168 22169 22170 22171 22172 22173 22174 22175 22176 22177 22178 22179 22180 22181 22182 22183 22184 22185 22186 22187 22188 22189 22190 22191 22192 22193 22194 22195 22196 22197 22198 22199 22200 22201 22202 22203 22204 22205 22206 22207 22208 22209 22210 22211 22212 22213 22214 22215 22216 22217 22218 22219 22220 22221 22222 22223 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22165 class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # This network interface can have external IPv6. EXTERNAL = 35_607_499 # This network interface can have internal IPv6. INTERNAL = 279_295_677 UNSPECIFIED_IPV6_ACCESS_TYPE = 313_080_613 end # The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. module NicType # A value indicating that the enum field is not set. UNDEFINED_NIC_TYPE = 0 # GVNIC GVNIC = 68_209_305 # IDPF IDPF = 2_242_641 # IRDMA IRDMA = 69_927_695 # MRDMA MRDMA = 73_621_779 # No type specified. UNSPECIFIED_NIC_TYPE = 67_411_801 # VIRTIO VIRTIO_NET = 452_123_481 end # The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # The network interface can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # The network interface will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # The network interface will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 UNSPECIFIED_STACK_TYPE = 298_084_569 end end |