Module: Google::Cloud::Compute::V1::NetworkInterface::IgmpQuery
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Indicate whether igmp query is enabled on the network interface or not. If enabled, also indicates the version of IGMP supported.
Constant Summary collapse
- UNDEFINED_IGMP_QUERY =
A value indicating that the enum field is not set.
0- IGMP_QUERY_DISABLED =
The network interface has disabled IGMP query.
28_285_169- IGMP_QUERY_V2 =
The network interface has enabled IGMP query - v2.
333_493_457