Class: Google::Cloud::Compute::V1::NetworkPeering
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkPeering
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering.
Defined Under Namespace
Modules: StackType, State, UpdateStrategy
Instance Attribute Summary collapse
-
#auto_create_routes ⇒ ::Boolean
This field will be deprecated soon.
-
#connection_status ⇒ ::Google::Cloud::Compute::V1::NetworkPeeringConnectionStatus
Output only.
-
#exchange_subnet_routes ⇒ ::Boolean
Indicates whether full mesh connectivity is created and managed automatically between peered networks.
-
#export_custom_routes ⇒ ::Boolean
Whether to export the custom routes to peer network.
-
#export_subnet_routes_with_public_ip ⇒ ::Boolean
Whether subnet routes with public IP range are exported.
-
#import_custom_routes ⇒ ::Boolean
Whether to import the custom routes from peer network.
-
#import_subnet_routes_with_public_ip ⇒ ::Boolean
Whether subnet routes with public IP range are imported.
-
#name ⇒ ::String
Name of this peering.
-
#network ⇒ ::String
The URL of the peer network.
-
#peer_mtu ⇒ ::Integer
Output only.
-
#stack_type ⇒ ::String
Which IP version(s) of traffic and routes are allowed to be imported or exported between peer networks.
-
#state ⇒ ::String
Output only.
-
#state_details ⇒ ::String
Output only.
-
#update_strategy ⇒ ::String
The update strategy determines the semantics for updates and deletes to the peering connection configuration.
Instance Attribute Details
#auto_create_routes ⇒ ::Boolean
Returns This field will be deprecated soon. Use theexchange_subnet_routes field instead. Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state isACTIVE.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#connection_status ⇒ ::Google::Cloud::Compute::V1::NetworkPeeringConnectionStatus
Returns Output only. [Output Only] The effective state of the peering connection as a whole.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#exchange_subnet_routes ⇒ ::Boolean
Returns Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state isACTIVE.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#export_custom_routes ⇒ ::Boolean
Returns Whether to export the custom routes to peer network. The default value is false.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#export_subnet_routes_with_public_ip ⇒ ::Boolean
Returns Whether subnet routes with public IP range are exported. The default value is true, all subnet routes are exported.IPv4 special-use ranges are always exported to peers and are not controlled by this field.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#import_custom_routes ⇒ ::Boolean
Returns Whether to import the custom routes from peer network. The default value is false.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#import_subnet_routes_with_public_ip ⇒ ::Boolean
Returns Whether subnet routes with public IP range are imported. The default value is false.IPv4 special-use ranges are always imported from peers and are not controlled by this field.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#name ⇒ ::String
Returns Name of this peering. Provided by the client when the peering is created.
The name must comply withRFC1035.
Specifically, the name must be 1-63 characters long and match regular
expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a
lowercase letter, and all the following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#network ⇒ ::String
Returns The URL of the peer network. It can be either full URL or partial URL. The peer network may belong to a different project. If the partial URL does not contain project, it is assumed that the peer network is in the same project as the current network.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#peer_mtu ⇒ ::Integer
Returns Output only. [Output Only] Maximum Transmission Unit in bytes of the peer network.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#stack_type ⇒ ::String
Returns Which IP version(s) of traffic and routes are allowed to be imported or exported between peer networks. The default value is IPV4_ONLY. Check the StackType enum for the list of possible values.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#state ⇒ ::String
Returns Output only. [Output Only] State for the peering. Check the State enum for the list of possible values.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#state_details ⇒ ::String
Returns Output only. [Output Only] Details about the current state of the peering.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#update_strategy ⇒ ::String
Returns The update strategy determines the semantics for updates and deletes to the peering connection configuration. Check the UpdateStrategy enum for the list of possible values.
55251 55252 55253 55254 55255 55256 55257 55258 55259 55260 55261 55262 55263 55264 55265 55266 55267 55268 55269 55270 55271 55272 55273 55274 55275 55276 55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 55288 55289 55290 55291 55292 55293 55294 55295 55296 55297 55298 55299 55300 55301 55302 55303 55304 55305 55306 55307 55308 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55251 class NetworkPeering include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are allowed to be imported or # exported between peer networks. The default value is IPV4_ONLY. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end # Output only. [Output Only] State for the peering. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Matching configuration exists on the peer. ACTIVE = 314_733_318 # There is no matching configuration on the peer, including the case when # peer does not exist. INACTIVE = 270_421_099 end # The update strategy determines the semantics for updates and deletes to the # peering connection configuration. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |