Class: Google::Cloud::Compute::V1::NetworkPeeringConnectionStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkPeeringConnectionStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings.
Defined Under Namespace
Modules: UpdateStrategy
Instance Attribute Summary collapse
-
#consensus_state ⇒ ::Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusConsensusState
The consensus state contains information about the status of update and delete for a consensus peering connection.
-
#traffic_configuration ⇒ ::Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusTrafficConfiguration
The active connectivity settings for the peering connection based on the settings of the network peerings.
-
#update_strategy ⇒ ::String
The update strategy determines the update/delete semantics for this peering connection.
Instance Attribute Details
#consensus_state ⇒ ::Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusConsensusState
Returns The consensus state contains information about the status of update and delete for a consensus peering connection.
56395 56396 56397 56398 56399 56400 56401 56402 56403 56404 56405 56406 56407 56408 56409 56410 56411 56412 56413 56414 56415 56416 56417 56418 56419 56420 56421 56422 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56395 class NetworkPeeringConnectionStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The update strategy determines the update/delete semantics for this # peering connection. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#traffic_configuration ⇒ ::Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusTrafficConfiguration
Returns The active connectivity settings for the peering connection based on the settings of the network peerings.
56395 56396 56397 56398 56399 56400 56401 56402 56403 56404 56405 56406 56407 56408 56409 56410 56411 56412 56413 56414 56415 56416 56417 56418 56419 56420 56421 56422 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56395 class NetworkPeeringConnectionStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The update strategy determines the update/delete semantics for this # peering connection. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |
#update_strategy ⇒ ::String
Returns The update strategy determines the update/delete semantics for this peering connection. Check the UpdateStrategy enum for the list of possible values.
56395 56396 56397 56398 56399 56400 56401 56402 56403 56404 56405 56406 56407 56408 56409 56410 56411 56412 56413 56414 56415 56416 56417 56418 56419 56420 56421 56422 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56395 class NetworkPeeringConnectionStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The update strategy determines the update/delete semantics for this # peering connection. module UpdateStrategy # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STRATEGY = 0 # Updates are reflected in the local peering but aren't applied to the # peering connection until a complementary change is made to the # matching peering. # To delete a peering with the consensus update strategy, both the peerings # must request the deletion of the peering before the peering can be # deleted. CONSENSUS = 203_373_655 # In this mode, changes to the peering configuration can # be unilaterally altered by changing either side of the peering. # This is the default value if the field is unspecified. INDEPENDENT = 127_011_674 # Peerings with update strategy UNSPECIFIED are created with # update strategy INDEPENDENT. UNSPECIFIED = 526_786_327 end end |