Class: Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusConsensusState

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The status of update/delete for a consensus peering connection. Only set when connection_status.update_strategy isCONSENSUS or a network peering is proposing to update the strategy to CONSENSUS.

Defined Under Namespace

Modules: DeleteStatus, UpdateStatus

Instance Attribute Summary collapse

Instance Attribute Details

#delete_status::String

Returns The status of the delete request. Check the DeleteStatus enum for the list of possible values.

Returns:

  • (::String)

    The status of the delete request. Check the DeleteStatus enum for the list of possible values.



56435
56436
56437
56438
56439
56440
56441
56442
56443
56444
56445
56446
56447
56448
56449
56450
56451
56452
56453
56454
56455
56456
56457
56458
56459
56460
56461
56462
56463
56464
56465
56466
56467
56468
56469
56470
56471
56472
56473
56474
56475
56476
56477
56478
56479
56480
56481
56482
56483
56484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56435

class NetworkPeeringConnectionStatusConsensusState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the delete request.
  module DeleteStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_DELETE_STATUS = 0

    # Both network admins have agreed this consensus peering connection can
    # be deleted.
    DELETE_ACKNOWLEDGED = 325_293_916

    DELETE_STATUS_UNSPECIFIED = 395_396_446

    # The local network admin requested to cancel their delete request
    # after DELETE_ACKNOWLEDGED.
    LOCAL_CANCEL_REQUESTED = 169_545_277

    # Network admin has requested deletion of this peering connection.
    LOCAL_DELETE_REQUESTED = 227_335_214

    # The peer network admin requested to cancel their delete request after
    # DELETE_ACKNOWLEDGED.
    PEER_CANCEL_REQUESTED = 140_057_862

    # The peer network admin has requested deletion of this peering
    # connection.
    PEER_DELETE_REQUESTED = 197_847_799
  end

  # The status of the update request.
  module UpdateStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_UPDATE_STATUS = 0

    # No pending configuration update proposals to the  peering connection.
    IN_SYNC = 2_273_653

    # The peer network admin has made an updatePeering call. The change is
    # awaiting acknowledgment from this peering's network admin.
    PENDING_LOCAL_ACKNOWLEDMENT = 229_926_592

    # The local network admin has made an updatePeering call. The change
    # is awaiting acknowledgment from the peer network admin.
    PENDING_PEER_ACKNOWLEDGEMENT = 420_185_797

    UPDATE_STATUS_UNSPECIFIED = 120_836_480
  end
end

#update_status::String

Returns The status of the update request. Check the UpdateStatus enum for the list of possible values.

Returns:

  • (::String)

    The status of the update request. Check the UpdateStatus enum for the list of possible values.



56435
56436
56437
56438
56439
56440
56441
56442
56443
56444
56445
56446
56447
56448
56449
56450
56451
56452
56453
56454
56455
56456
56457
56458
56459
56460
56461
56462
56463
56464
56465
56466
56467
56468
56469
56470
56471
56472
56473
56474
56475
56476
56477
56478
56479
56480
56481
56482
56483
56484
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56435

class NetworkPeeringConnectionStatusConsensusState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the delete request.
  module DeleteStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_DELETE_STATUS = 0

    # Both network admins have agreed this consensus peering connection can
    # be deleted.
    DELETE_ACKNOWLEDGED = 325_293_916

    DELETE_STATUS_UNSPECIFIED = 395_396_446

    # The local network admin requested to cancel their delete request
    # after DELETE_ACKNOWLEDGED.
    LOCAL_CANCEL_REQUESTED = 169_545_277

    # Network admin has requested deletion of this peering connection.
    LOCAL_DELETE_REQUESTED = 227_335_214

    # The peer network admin requested to cancel their delete request after
    # DELETE_ACKNOWLEDGED.
    PEER_CANCEL_REQUESTED = 140_057_862

    # The peer network admin has requested deletion of this peering
    # connection.
    PEER_DELETE_REQUESTED = 197_847_799
  end

  # The status of the update request.
  module UpdateStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_UPDATE_STATUS = 0

    # No pending configuration update proposals to the  peering connection.
    IN_SYNC = 2_273_653

    # The peer network admin has made an updatePeering call. The change is
    # awaiting acknowledgment from this peering's network admin.
    PENDING_LOCAL_ACKNOWLEDMENT = 229_926_592

    # The local network admin has made an updatePeering call. The change
    # is awaiting acknowledgment from the peer network admin.
    PENDING_PEER_ACKNOWLEDGEMENT = 420_185_797

    UPDATE_STATUS_UNSPECIFIED = 120_836_480
  end
end