Class: Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusConsensusState
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusConsensusState
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The status of update/delete for a consensus peering connection. Only set when connection_status.update_strategy isCONSENSUS or a network peering is proposing to update the strategy to CONSENSUS.
Defined Under Namespace
Modules: DeleteStatus, UpdateStatus
Instance Attribute Summary collapse
-
#delete_status ⇒ ::String
The status of the delete request.
-
#update_status ⇒ ::String
The status of the update request.
Instance Attribute Details
#delete_status ⇒ ::String
Returns The status of the delete request. Check the DeleteStatus enum for the list of possible values.
55367 55368 55369 55370 55371 55372 55373 55374 55375 55376 55377 55378 55379 55380 55381 55382 55383 55384 55385 55386 55387 55388 55389 55390 55391 55392 55393 55394 55395 55396 55397 55398 55399 55400 55401 55402 55403 55404 55405 55406 55407 55408 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55367 class NetworkPeeringConnectionStatusConsensusState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of the delete request. module DeleteStatus # A value indicating that the enum field is not set. UNDEFINED_DELETE_STATUS = 0 # Both network admins have agreed this consensus peering connection can # be deleted. DELETE_ACKNOWLEDGED = 325_293_916 DELETE_STATUS_UNSPECIFIED = 395_396_446 # Network admin has requested deletion of this peering connection. LOCAL_DELETE_REQUESTED = 227_335_214 # The peer network admin has requested deletion of this peering # connection. PEER_DELETE_REQUESTED = 197_847_799 end # The status of the update request. module UpdateStatus # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STATUS = 0 # No pending configuration update proposals to the peering connection. IN_SYNC = 2_273_653 # The peer network admin has made an updatePeering call. The change is # awaiting acknowledgment from this peering's network admin. PENDING_LOCAL_ACKNOWLEDMENT = 229_926_592 # The local network admin has made an updatePeering call. The change # is awaiting acknowledgment from the peer network admin. PENDING_PEER_ACKNOWLEDGEMENT = 420_185_797 UPDATE_STATUS_UNSPECIFIED = 120_836_480 end end |
#update_status ⇒ ::String
Returns The status of the update request. Check the UpdateStatus enum for the list of possible values.
55367 55368 55369 55370 55371 55372 55373 55374 55375 55376 55377 55378 55379 55380 55381 55382 55383 55384 55385 55386 55387 55388 55389 55390 55391 55392 55393 55394 55395 55396 55397 55398 55399 55400 55401 55402 55403 55404 55405 55406 55407 55408 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55367 class NetworkPeeringConnectionStatusConsensusState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of the delete request. module DeleteStatus # A value indicating that the enum field is not set. UNDEFINED_DELETE_STATUS = 0 # Both network admins have agreed this consensus peering connection can # be deleted. DELETE_ACKNOWLEDGED = 325_293_916 DELETE_STATUS_UNSPECIFIED = 395_396_446 # Network admin has requested deletion of this peering connection. LOCAL_DELETE_REQUESTED = 227_335_214 # The peer network admin has requested deletion of this peering # connection. PEER_DELETE_REQUESTED = 197_847_799 end # The status of the update request. module UpdateStatus # A value indicating that the enum field is not set. UNDEFINED_UPDATE_STATUS = 0 # No pending configuration update proposals to the peering connection. IN_SYNC = 2_273_653 # The peer network admin has made an updatePeering call. The change is # awaiting acknowledgment from this peering's network admin. PENDING_LOCAL_ACKNOWLEDMENT = 229_926_592 # The local network admin has made an updatePeering call. The change # is awaiting acknowledgment from the peer network admin. PENDING_PEER_ACKNOWLEDGEMENT = 420_185_797 UPDATE_STATUS_UNSPECIFIED = 120_836_480 end end |