Class: Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusTrafficConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: StackType

Instance Attribute Summary collapse

Instance Attribute Details

#export_custom_routes_to_peer::Boolean

Returns Whether custom routes are being exported to the peer network.

Returns:

  • (::Boolean)

    Whether custom routes are being exported to the peer network.



55429
55430
55431
55432
55433
55434
55435
55436
55437
55438
55439
55440
55441
55442
55443
55444
55445
55446
55447
55448
55449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55429

class NetworkPeeringConnectionStatusTrafficConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Which IP version(s) of traffic and routes are being imported or
  # exported between peer networks.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # This Peering will allow IPv4 traffic and routes to be
    # exchanged. Additionally if the matching peering is
    # IPV4_IPV6, IPv6 traffic and routes will be exchanged as
    # well.
    IPV4_IPV6 = 22_197_249

    # This Peering will only allow IPv4 traffic and routes to be
    # exchanged, even if the matching peering is IPV4_IPV6.
    IPV4_ONLY = 22_373_798
  end
end

#export_subnet_routes_with_public_ip_to_peer::Boolean

Returns Whether subnet routes with public IP ranges are being exported to the peer network.

Returns:

  • (::Boolean)

    Whether subnet routes with public IP ranges are being exported to the peer network.



55429
55430
55431
55432
55433
55434
55435
55436
55437
55438
55439
55440
55441
55442
55443
55444
55445
55446
55447
55448
55449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55429

class NetworkPeeringConnectionStatusTrafficConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Which IP version(s) of traffic and routes are being imported or
  # exported between peer networks.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # This Peering will allow IPv4 traffic and routes to be
    # exchanged. Additionally if the matching peering is
    # IPV4_IPV6, IPv6 traffic and routes will be exchanged as
    # well.
    IPV4_IPV6 = 22_197_249

    # This Peering will only allow IPv4 traffic and routes to be
    # exchanged, even if the matching peering is IPV4_IPV6.
    IPV4_ONLY = 22_373_798
  end
end

#import_custom_routes_from_peer::Boolean

Returns Whether custom routes are being imported from the peer network.

Returns:

  • (::Boolean)

    Whether custom routes are being imported from the peer network.



55429
55430
55431
55432
55433
55434
55435
55436
55437
55438
55439
55440
55441
55442
55443
55444
55445
55446
55447
55448
55449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55429

class NetworkPeeringConnectionStatusTrafficConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Which IP version(s) of traffic and routes are being imported or
  # exported between peer networks.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # This Peering will allow IPv4 traffic and routes to be
    # exchanged. Additionally if the matching peering is
    # IPV4_IPV6, IPv6 traffic and routes will be exchanged as
    # well.
    IPV4_IPV6 = 22_197_249

    # This Peering will only allow IPv4 traffic and routes to be
    # exchanged, even if the matching peering is IPV4_IPV6.
    IPV4_ONLY = 22_373_798
  end
end

#import_subnet_routes_with_public_ip_from_peer::Boolean

Returns Whether subnet routes with public IP ranges are being imported from the peer network.

Returns:

  • (::Boolean)

    Whether subnet routes with public IP ranges are being imported from the peer network.



55429
55430
55431
55432
55433
55434
55435
55436
55437
55438
55439
55440
55441
55442
55443
55444
55445
55446
55447
55448
55449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55429

class NetworkPeeringConnectionStatusTrafficConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Which IP version(s) of traffic and routes are being imported or
  # exported between peer networks.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # This Peering will allow IPv4 traffic and routes to be
    # exchanged. Additionally if the matching peering is
    # IPV4_IPV6, IPv6 traffic and routes will be exchanged as
    # well.
    IPV4_IPV6 = 22_197_249

    # This Peering will only allow IPv4 traffic and routes to be
    # exchanged, even if the matching peering is IPV4_IPV6.
    IPV4_ONLY = 22_373_798
  end
end

#stack_type::String

Returns Which IP version(s) of traffic and routes are being imported or exported between peer networks. Check the StackType enum for the list of possible values.

Returns:

  • (::String)

    Which IP version(s) of traffic and routes are being imported or exported between peer networks. Check the StackType enum for the list of possible values.



55429
55430
55431
55432
55433
55434
55435
55436
55437
55438
55439
55440
55441
55442
55443
55444
55445
55446
55447
55448
55449
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55429

class NetworkPeeringConnectionStatusTrafficConfiguration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Which IP version(s) of traffic and routes are being imported or
  # exported between peer networks.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # This Peering will allow IPv4 traffic and routes to be
    # exchanged. Additionally if the matching peering is
    # IPV4_IPV6, IPv6 traffic and routes will be exchanged as
    # well.
    IPV4_IPV6 = 22_197_249

    # This Peering will only allow IPv4 traffic and routes to be
    # exchanged, even if the matching peering is IPV4_IPV6.
    IPV4_ONLY = 22_373_798
  end
end