Class: Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusTrafficConfiguration
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkPeeringConnectionStatusTrafficConfiguration
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: StackType
Instance Attribute Summary collapse
-
#export_custom_routes_to_peer ⇒ ::Boolean
Whether custom routes are being exported to the peer network.
-
#export_subnet_routes_with_public_ip_to_peer ⇒ ::Boolean
Whether subnet routes with public IP ranges are being exported to the peer network.
-
#import_custom_routes_from_peer ⇒ ::Boolean
Whether custom routes are being imported from the peer network.
-
#import_subnet_routes_with_public_ip_from_peer ⇒ ::Boolean
Whether subnet routes with public IP ranges are being imported from the peer network.
-
#stack_type ⇒ ::String
Which IP version(s) of traffic and routes are being imported or exported between peer networks.
Instance Attribute Details
#export_custom_routes_to_peer ⇒ ::Boolean
Returns Whether custom routes are being exported to the peer network.
58453 58454 58455 58456 58457 58458 58459 58460 58461 58462 58463 58464 58465 58466 58467 58468 58469 58470 58471 58472 58473 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58453 class NetworkPeeringConnectionStatusTrafficConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are being imported or # exported between peer networks. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end end |
#export_subnet_routes_with_public_ip_to_peer ⇒ ::Boolean
Returns Whether subnet routes with public IP ranges are being exported to the peer network.
58453 58454 58455 58456 58457 58458 58459 58460 58461 58462 58463 58464 58465 58466 58467 58468 58469 58470 58471 58472 58473 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58453 class NetworkPeeringConnectionStatusTrafficConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are being imported or # exported between peer networks. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end end |
#import_custom_routes_from_peer ⇒ ::Boolean
Returns Whether custom routes are being imported from the peer network.
58453 58454 58455 58456 58457 58458 58459 58460 58461 58462 58463 58464 58465 58466 58467 58468 58469 58470 58471 58472 58473 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58453 class NetworkPeeringConnectionStatusTrafficConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are being imported or # exported between peer networks. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end end |
#import_subnet_routes_with_public_ip_from_peer ⇒ ::Boolean
Returns Whether subnet routes with public IP ranges are being imported from the peer network.
58453 58454 58455 58456 58457 58458 58459 58460 58461 58462 58463 58464 58465 58466 58467 58468 58469 58470 58471 58472 58473 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58453 class NetworkPeeringConnectionStatusTrafficConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are being imported or # exported between peer networks. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end end |
#stack_type ⇒ ::String
Returns Which IP version(s) of traffic and routes are being imported or exported between peer networks. Check the StackType enum for the list of possible values.
58453 58454 58455 58456 58457 58458 58459 58460 58461 58462 58463 58464 58465 58466 58467 58468 58469 58470 58471 58472 58473 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58453 class NetworkPeeringConnectionStatusTrafficConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Which IP version(s) of traffic and routes are being imported or # exported between peer networks. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # This Peering will allow IPv4 traffic and routes to be # exchanged. Additionally if the matching peering is # IPV4_IPV6, IPv6 traffic and routes will be exchanged as # well. IPV4_IPV6 = 22_197_249 # This Peering will only allow IPv4 traffic and routes to be # exchanged, even if the matching peering is IPV4_IPV6. IPV4_ONLY = 22_373_798 end end |