Class: Google::Cloud::Compute::V1::NetworkProfileLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkProfileLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Scope
Instance Attribute Summary collapse
- #name ⇒ ::String
-
#scope ⇒ ::String
Check the Scope enum for the list of possible values.
Instance Attribute Details
#name ⇒ ::String
56590 56591 56592 56593 56594 56595 56596 56597 56598 56599 56600 56601 56602 56603 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56590 class NetworkProfileLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Scope # A value indicating that the enum field is not set. UNDEFINED_SCOPE = 0 REGION = 266_017_524 ZONE = 2_759_596 end end |
#scope ⇒ ::String
Returns Check the Scope enum for the list of possible values.
56590 56591 56592 56593 56594 56595 56596 56597 56598 56599 56600 56601 56602 56603 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56590 class NetworkProfileLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Scope # A value indicating that the enum field is not set. UNDEFINED_SCOPE = 0 REGION = 266_017_524 ZONE = 2_759_596 end end |