Class: Google::Cloud::Compute::V1::NetworkProfileLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Scope

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns:

  • (::String)


55514
55515
55516
55517
55518
55519
55520
55521
55522
55523
55524
55525
55526
55527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55514

class NetworkProfileLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Scope
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPE = 0

    REGION = 266_017_524

    ZONE = 2_759_596
  end
end

#scope::String

Returns Check the Scope enum for the list of possible values.

Returns:

  • (::String)

    Check the Scope enum for the list of possible values.



55514
55515
55516
55517
55518
55519
55520
55521
55522
55523
55524
55525
55526
55527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 55514

class NetworkProfileLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Scope
    # A value indicating that the enum field is not set.
    UNDEFINED_SCOPE = 0

    REGION = 266_017_524

    ZONE = 2_759_596
  end
end