Class: Google::Cloud::Compute::V1::NetworkProfileLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkProfileLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Scope
Instance Attribute Summary collapse
- #name ⇒ ::String
-
#scope ⇒ ::String
Check the Scope enum for the list of possible values.
Instance Attribute Details
#name ⇒ ::String
58538 58539 58540 58541 58542 58543 58544 58545 58546 58547 58548 58549 58550 58551 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58538 class NetworkProfileLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Scope # A value indicating that the enum field is not set. UNDEFINED_SCOPE = 0 REGION = 266_017_524 ZONE = 2_759_596 end end |
#scope ⇒ ::String
Returns Check the Scope enum for the list of possible values.
58538 58539 58540 58541 58542 58543 58544 58545 58546 58547 58548 58549 58550 58551 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58538 class NetworkProfileLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Scope # A value indicating that the enum field is not set. UNDEFINED_SCOPE = 0 REGION = 266_017_524 ZONE = 2_759_596 end end |