Module: Google::Cloud::Compute::V1::NetworkProfileNetworkFeatures::AllowVpcFirewallRules
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies whether VPC firewall rules can be created under the network.
Constant Summary collapse
- UNDEFINED_ALLOW_VPC_FIREWALL_RULES =
A value indicating that the enum field is not set.
0- VPC_FIREWALL_RULES_ALLOWED =
489_586_007- VPC_FIREWALL_RULES_BLOCKED =
305_749_403