Module: Google::Cloud::Compute::V1::NetworkProfileNetworkFeatures::SubnetworkStackTypes
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Constant Summary collapse
- UNDEFINED_SUBNETWORK_STACK_TYPES =
A value indicating that the enum field is not set.
0- IPV4_IPV6 =
New VMs in this subnet can have both IPv4 and IPv6 addresses.
22_197_249- IPV4_ONLY =
New VMs in this subnet will only be assigned IPv4 addresses.
22_373_798- IPV6_ONLY =
New VMs in this subnet will only be assigned IPv6 addresses.
79_632_100