Class: Google::Cloud::Compute::V1::NetworkProfileProfileType
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkProfileProfileType
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: NetworkType, RdmaSubtype, UllSubtype, VpcSubtype
Instance Attribute Summary collapse
-
#network_type ⇒ ::String
Check the NetworkType enum for the list of possible values.
-
#rdma_subtype ⇒ ::String
Check the RdmaSubtype enum for the list of possible values.
-
#ull_subtype ⇒ ::String
Check the UllSubtype enum for the list of possible values.
-
#vpc_subtype ⇒ ::String
Check the VpcSubtype enum for the list of possible values.
Instance Attribute Details
#network_type ⇒ ::String
Returns Check the NetworkType enum for the list of possible values.
24514 24515 24516 24517 24518 24519 24520 24521 24522 24523 24524 24525 24526 24527 24528 24529 24530 24531 24532 24533 24534 24535 24536 24537 24538 24539 24540 24541 24542 24543 24544 24545 24546 24547 24548 24549 24550 24551 24552 24553 24554 24555 24556 24557 24558 24559 24560 24561 24562 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24514 class NetworkProfileProfileType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module NetworkType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_TYPE = 0 # RDMA network. RDMA = 2_510_662 # ULL network. ULL = 84_117 # VPC network. VPC = 85_193 end module RdmaSubtype # A value indicating that the enum field is not set. UNDEFINED_RDMA_SUBTYPE = 0 # RDMA over Falcon. FALCON = 455_787_729 # RDMA over Converged Ethernet (RoCE). ROCE = 2_520_927 end module UllSubtype # A value indicating that the enum field is not set. UNDEFINED_ULL_SUBTYPE = 0 # Exchange operator. OPERATOR = 282_073_252 # Exchange participant. PARTICIPANT = 236_028_691 end module VpcSubtype # A value indicating that the enum field is not set. UNDEFINED_VPC_SUBTYPE = 0 # Regionally bound VPC network. REGIONAL = 92_288_543 end end |
#rdma_subtype ⇒ ::String
Returns Check the RdmaSubtype enum for the list of possible values.
24514 24515 24516 24517 24518 24519 24520 24521 24522 24523 24524 24525 24526 24527 24528 24529 24530 24531 24532 24533 24534 24535 24536 24537 24538 24539 24540 24541 24542 24543 24544 24545 24546 24547 24548 24549 24550 24551 24552 24553 24554 24555 24556 24557 24558 24559 24560 24561 24562 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24514 class NetworkProfileProfileType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module NetworkType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_TYPE = 0 # RDMA network. RDMA = 2_510_662 # ULL network. ULL = 84_117 # VPC network. VPC = 85_193 end module RdmaSubtype # A value indicating that the enum field is not set. UNDEFINED_RDMA_SUBTYPE = 0 # RDMA over Falcon. FALCON = 455_787_729 # RDMA over Converged Ethernet (RoCE). ROCE = 2_520_927 end module UllSubtype # A value indicating that the enum field is not set. UNDEFINED_ULL_SUBTYPE = 0 # Exchange operator. OPERATOR = 282_073_252 # Exchange participant. PARTICIPANT = 236_028_691 end module VpcSubtype # A value indicating that the enum field is not set. UNDEFINED_VPC_SUBTYPE = 0 # Regionally bound VPC network. REGIONAL = 92_288_543 end end |
#ull_subtype ⇒ ::String
Returns Check the UllSubtype enum for the list of possible values.
24514 24515 24516 24517 24518 24519 24520 24521 24522 24523 24524 24525 24526 24527 24528 24529 24530 24531 24532 24533 24534 24535 24536 24537 24538 24539 24540 24541 24542 24543 24544 24545 24546 24547 24548 24549 24550 24551 24552 24553 24554 24555 24556 24557 24558 24559 24560 24561 24562 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24514 class NetworkProfileProfileType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module NetworkType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_TYPE = 0 # RDMA network. RDMA = 2_510_662 # ULL network. ULL = 84_117 # VPC network. VPC = 85_193 end module RdmaSubtype # A value indicating that the enum field is not set. UNDEFINED_RDMA_SUBTYPE = 0 # RDMA over Falcon. FALCON = 455_787_729 # RDMA over Converged Ethernet (RoCE). ROCE = 2_520_927 end module UllSubtype # A value indicating that the enum field is not set. UNDEFINED_ULL_SUBTYPE = 0 # Exchange operator. OPERATOR = 282_073_252 # Exchange participant. PARTICIPANT = 236_028_691 end module VpcSubtype # A value indicating that the enum field is not set. UNDEFINED_VPC_SUBTYPE = 0 # Regionally bound VPC network. REGIONAL = 92_288_543 end end |
#vpc_subtype ⇒ ::String
Returns Check the VpcSubtype enum for the list of possible values.
24514 24515 24516 24517 24518 24519 24520 24521 24522 24523 24524 24525 24526 24527 24528 24529 24530 24531 24532 24533 24534 24535 24536 24537 24538 24539 24540 24541 24542 24543 24544 24545 24546 24547 24548 24549 24550 24551 24552 24553 24554 24555 24556 24557 24558 24559 24560 24561 24562 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 24514 class NetworkProfileProfileType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module NetworkType # A value indicating that the enum field is not set. UNDEFINED_NETWORK_TYPE = 0 # RDMA network. RDMA = 2_510_662 # ULL network. ULL = 84_117 # VPC network. VPC = 85_193 end module RdmaSubtype # A value indicating that the enum field is not set. UNDEFINED_RDMA_SUBTYPE = 0 # RDMA over Falcon. FALCON = 455_787_729 # RDMA over Converged Ethernet (RoCE). ROCE = 2_520_927 end module UllSubtype # A value indicating that the enum field is not set. UNDEFINED_ULL_SUBTYPE = 0 # Exchange operator. OPERATOR = 282_073_252 # Exchange participant. PARTICIPANT = 236_028_691 end module VpcSubtype # A value indicating that the enum field is not set. UNDEFINED_VPC_SUBTYPE = 0 # Regionally bound VPC network. REGIONAL = 92_288_543 end end |