Class: Google::Cloud::Compute::V1::NetworkRoutingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkRoutingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.
Defined Under Namespace
Modules: BgpBestPathSelectionMode, BgpInterRegionCost, EffectiveBgpInterRegionCost, RoutingMode
Instance Attribute Summary collapse
-
#bgp_always_compare_med ⇒ ::Boolean
Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.
-
#bgp_best_path_selection_mode ⇒ ::String
The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers.
-
#bgp_inter_region_cost ⇒ ::String
Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm.
-
#effective_bgp_always_compare_med ⇒ ::Boolean
Output only.
-
#effective_bgp_inter_region_cost ⇒ ::String
Output only.
-
#routing_mode ⇒ ::String
The network-wide routing mode to use.
Instance Attribute Details
#bgp_always_compare_med ⇒ ::Boolean
Returns Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.
56261 56262 56263 56264 56265 56266 56267 56268 56269 56270 56271 56272 56273 56274 56275 56276 56277 56278 56279 56280 56281 56282 56283 56284 56285 56286 56287 56288 56289 56290 56291 56292 56293 56294 56295 56296 56297 56298 56299 56300 56301 56302 56303 56304 56305 56306 56307 56308 56309 56310 56311 56312 56313 56314 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56261 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network # for dynamic routes learned by Cloud Routers. Can be LEGACY # (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in # the selection process when using the STANDARD BGP best path # selection algorithm. Can be DEFAULT orADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # Output only. [Output Only] Effective value of the bgp_inter_region_cost # field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, # this network's Cloud Routers will only advertise routes with subnets # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise # routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#bgp_best_path_selection_mode ⇒ ::String
Returns The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. Check the BgpBestPathSelectionMode enum for the list of possible values.
56261 56262 56263 56264 56265 56266 56267 56268 56269 56270 56271 56272 56273 56274 56275 56276 56277 56278 56279 56280 56281 56282 56283 56284 56285 56286 56287 56288 56289 56290 56291 56292 56293 56294 56295 56296 56297 56298 56299 56300 56301 56302 56303 56304 56305 56306 56307 56308 56309 56310 56311 56312 56313 56314 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56261 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network # for dynamic routes learned by Cloud Routers. Can be LEGACY # (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in # the selection process when using the STANDARD BGP best path # selection algorithm. Can be DEFAULT orADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # Output only. [Output Only] Effective value of the bgp_inter_region_cost # field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, # this network's Cloud Routers will only advertise routes with subnets # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise # routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#bgp_inter_region_cost ⇒ ::String
Returns Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT orADD_COST_TO_MED. Check the BgpInterRegionCost enum for the list of possible values.
56261 56262 56263 56264 56265 56266 56267 56268 56269 56270 56271 56272 56273 56274 56275 56276 56277 56278 56279 56280 56281 56282 56283 56284 56285 56286 56287 56288 56289 56290 56291 56292 56293 56294 56295 56296 56297 56298 56299 56300 56301 56302 56303 56304 56305 56306 56307 56308 56309 56310 56311 56312 56313 56314 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56261 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network # for dynamic routes learned by Cloud Routers. Can be LEGACY # (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in # the selection process when using the STANDARD BGP best path # selection algorithm. Can be DEFAULT orADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # Output only. [Output Only] Effective value of the bgp_inter_region_cost # field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, # this network's Cloud Routers will only advertise routes with subnets # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise # routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#effective_bgp_always_compare_med ⇒ ::Boolean
Returns Output only. [Output Only] Effective value of the bgp_always_compare_med field.
56261 56262 56263 56264 56265 56266 56267 56268 56269 56270 56271 56272 56273 56274 56275 56276 56277 56278 56279 56280 56281 56282 56283 56284 56285 56286 56287 56288 56289 56290 56291 56292 56293 56294 56295 56296 56297 56298 56299 56300 56301 56302 56303 56304 56305 56306 56307 56308 56309 56310 56311 56312 56313 56314 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56261 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network # for dynamic routes learned by Cloud Routers. Can be LEGACY # (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in # the selection process when using the STANDARD BGP best path # selection algorithm. Can be DEFAULT orADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # Output only. [Output Only] Effective value of the bgp_inter_region_cost # field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, # this network's Cloud Routers will only advertise routes with subnets # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise # routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#effective_bgp_inter_region_cost ⇒ ::String
Returns Output only. [Output Only] Effective value of the bgp_inter_region_cost field. Check the EffectiveBgpInterRegionCost enum for the list of possible values.
56261 56262 56263 56264 56265 56266 56267 56268 56269 56270 56271 56272 56273 56274 56275 56276 56277 56278 56279 56280 56281 56282 56283 56284 56285 56286 56287 56288 56289 56290 56291 56292 56293 56294 56295 56296 56297 56298 56299 56300 56301 56302 56303 56304 56305 56306 56307 56308 56309 56310 56311 56312 56313 56314 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56261 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network # for dynamic routes learned by Cloud Routers. Can be LEGACY # (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in # the selection process when using the STANDARD BGP best path # selection algorithm. Can be DEFAULT orADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # Output only. [Output Only] Effective value of the bgp_inter_region_cost # field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, # this network's Cloud Routers will only advertise routes with subnets # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise # routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#routing_mode ⇒ ::String
Returns The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. Check the RoutingMode enum for the list of possible values.
56261 56262 56263 56264 56265 56266 56267 56268 56269 56270 56271 56272 56273 56274 56275 56276 56277 56278 56279 56280 56281 56282 56283 56284 56285 56286 56287 56288 56289 56290 56291 56292 56293 56294 56295 56296 56297 56298 56299 56300 56301 56302 56303 56304 56305 56306 56307 56308 56309 56310 56311 56312 56313 56314 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56261 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network # for dynamic routes learned by Cloud Routers. Can be LEGACY # (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in # the selection process when using the STANDARD BGP best path # selection algorithm. Can be DEFAULT orADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # Output only. [Output Only] Effective value of the bgp_inter_region_cost # field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, # this network's Cloud Routers will only advertise routes with subnets # of this network in the same region as the router. If set toGLOBAL, this network's Cloud Routers will advertise # routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |