Class: Google::Cloud::Compute::V1::NetworkRoutingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworkRoutingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.
Defined Under Namespace
Modules: BgpBestPathSelectionMode, BgpInterRegionCost, EffectiveBgpInterRegionCost, RoutingMode
Instance Attribute Summary collapse
-
#bgp_always_compare_med ⇒ ::Boolean
Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.
-
#bgp_best_path_selection_mode ⇒ ::String
The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers.
-
#bgp_inter_region_cost ⇒ ::String
Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm.
-
#effective_bgp_always_compare_med ⇒ ::Boolean
[Output Only] Effective value of the bgp_always_compare_med field.
-
#effective_bgp_inter_region_cost ⇒ ::String
[Output Only] Effective value of the bgp_inter_region_cost field.
-
#routing_mode ⇒ ::String
The network-wide routing mode to use.
Instance Attribute Details
#bgp_always_compare_med ⇒ ::Boolean
Returns Enable comparison of Multi-Exit Discriminators (MED) across routes with different neighbor ASNs when using the STANDARD BGP best path selection algorithm.
22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 22657 22658 22659 22660 22661 22662 22663 22664 22665 22666 22667 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22622 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT or ADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # [Output Only] Effective value of the bgp_inter_region_cost field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#bgp_best_path_selection_mode ⇒ ::String
Returns The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. Check the BgpBestPathSelectionMode enum for the list of possible values.
22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 22657 22658 22659 22660 22661 22662 22663 22664 22665 22666 22667 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22622 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT or ADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # [Output Only] Effective value of the bgp_inter_region_cost field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#bgp_inter_region_cost ⇒ ::String
Returns Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT or ADD_COST_TO_MED. Check the BgpInterRegionCost enum for the list of possible values.
22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 22657 22658 22659 22660 22661 22662 22663 22664 22665 22666 22667 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22622 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT or ADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # [Output Only] Effective value of the bgp_inter_region_cost field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#effective_bgp_always_compare_med ⇒ ::Boolean
Returns [Output Only] Effective value of the bgp_always_compare_med field.
22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 22657 22658 22659 22660 22661 22662 22663 22664 22665 22666 22667 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22622 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT or ADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # [Output Only] Effective value of the bgp_inter_region_cost field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#effective_bgp_inter_region_cost ⇒ ::String
Returns [Output Only] Effective value of the bgp_inter_region_cost field. Check the EffectiveBgpInterRegionCost enum for the list of possible values.
22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 22657 22658 22659 22660 22661 22662 22663 22664 22665 22666 22667 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22622 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT or ADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # [Output Only] Effective value of the bgp_inter_region_cost field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |
#routing_mode ⇒ ::String
Returns The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. Check the RoutingMode enum for the list of possible values.
22622 22623 22624 22625 22626 22627 22628 22629 22630 22631 22632 22633 22634 22635 22636 22637 22638 22639 22640 22641 22642 22643 22644 22645 22646 22647 22648 22649 22650 22651 22652 22653 22654 22655 22656 22657 22658 22659 22660 22661 22662 22663 22664 22665 22666 22667 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 22622 class NetworkRoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The BGP best path selection algorithm to be employed within this network for dynamic routes learned by Cloud Routers. Can be LEGACY (default) or STANDARD. module BgpBestPathSelectionMode # A value indicating that the enum field is not set. UNDEFINED_BGP_BEST_PATH_SELECTION_MODE = 0 LEGACY = 94_234_569 STANDARD = 484_642_493 end # Allows to define a preferred approach for handling inter-region cost in the selection process when using the STANDARD BGP best path selection algorithm. Can be DEFAULT or ADD_COST_TO_MED. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module BgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_BGP_INTER_REGION_COST = 0 ADD_COST_TO_MED = 490_583_004 DEFAULT = 115_302_945 end # [Output Only] Effective value of the bgp_inter_region_cost field. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADD_COST_TO_MED # DEFAULT module EffectiveBgpInterRegionCost # A value indicating that the enum field is not set. UNDEFINED_EFFECTIVE_BGP_INTER_REGION_COST = 0 end # The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. module RoutingMode # A value indicating that the enum field is not set. UNDEFINED_ROUTING_MODE = 0 GLOBAL = 494_663_587 REGIONAL = 92_288_543 end end |