Class: Google::Cloud::Compute::V1::NetworkRoutingConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A routing configuration attached to a network resource. The message includes the list of routers associated with the network, and a flag indicating the type of routing behavior to enforce network-wide.

Defined Under Namespace

Modules: RoutingMode

Instance Attribute Summary collapse

Instance Attribute Details

#routing_mode::String

Returns The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. Check the RoutingMode enum for the list of possible values.

Returns:

  • (::String)

    The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions. Check the RoutingMode enum for the list of possible values.



18774
18775
18776
18777
18778
18779
18780
18781
18782
18783
18784
18785
18786
18787
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 18774

class NetworkRoutingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The network-wide routing mode to use. If set to REGIONAL, this network's Cloud Routers will only advertise routes with subnets of this network in the same region as the router. If set to GLOBAL, this network's Cloud Routers will advertise routes with all subnets of this network, across regions.
  module RoutingMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ROUTING_MODE = 0

    GLOBAL = 494663587

    REGIONAL = 92288543
  end
end