Class: Google::Cloud::Compute::V1::NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy.



58018
58019
58020
58021
58022
58023
58024
58025
58026
58027
58028
58029
58030
58031
58032
58033
58034
58035
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58018

class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    SYSTEM = 313_484_847

    UNSPECIFIED = 526_786_327
  end
end

#name::String

Returns Output only. [Output Only] The name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] The name of the firewall policy.



58018
58019
58020
58021
58022
58023
58024
58025
58026
58027
58028
58029
58030
58031
58032
58033
58034
58035
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58018

class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    SYSTEM = 313_484_847

    UNSPECIFIED = 526_786_327
  end
end

#packet_mirroring_rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns Output only. [Output Only] The packet mirroring rules that apply to the network.

Returns:



58018
58019
58020
58021
58022
58023
58024
58025
58026
58027
58028
58029
58030
58031
58032
58033
58034
58035
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58018

class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    SYSTEM = 313_484_847

    UNSPECIFIED = 526_786_327
  end
end

#priority::Integer

Returns Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.

Returns:

  • (::Integer)

    Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.



58018
58019
58020
58021
58022
58023
58024
58025
58026
58027
58028
58029
58030
58031
58032
58033
58034
58035
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58018

class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    SYSTEM = 313_484_847

    UNSPECIFIED = 526_786_327
  end
end

#rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns [Output Only] The rules that apply to the network.

Returns:



58018
58019
58020
58021
58022
58023
58024
58025
58026
58027
58028
58029
58030
58031
58032
58033
58034
58035
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58018

class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    SYSTEM = 313_484_847

    UNSPECIFIED = 526_786_327
  end
end

#short_name::String

Returns Output only. [Output Only] The short name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] The short name of the firewall policy.



58018
58019
58020
58021
58022
58023
58024
58025
58026
58027
58028
58029
58030
58031
58032
58033
58034
58035
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58018

class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    SYSTEM = 313_484_847

    UNSPECIFIED = 526_786_327
  end
end

#type::String

Returns Output only. [Output Only] The type of the firewall policy. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The type of the firewall policy. Check the Type enum for the list of possible values.



58018
58019
58020
58021
58022
58023
58024
58025
58026
58027
58028
58029
58030
58031
58032
58033
58034
58035
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58018

class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    SYSTEM = 313_484_847

    UNSPECIFIED = 526_786_327
  end
end