Class: Google::Cloud::Compute::V1::NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
Output only.
-
#name ⇒ ::String
Output only.
-
#packet_mirroring_rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
Output only.
-
#priority ⇒ ::Integer
Output only.
-
#rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
[Output Only] The rules that apply to the network.
-
#short_name ⇒ ::String
Output only.
-
#type ⇒ ::String
Output only.
Instance Attribute Details
#display_name ⇒ ::String
Returns Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy.
57470 57471 57472 57473 57474 57475 57476 57477 57478 57479 57480 57481 57482 57483 57484 57485 57486 57487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57470 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#name ⇒ ::String
Returns Output only. [Output Only] The name of the firewall policy.
57470 57471 57472 57473 57474 57475 57476 57477 57478 57479 57480 57481 57482 57483 57484 57485 57486 57487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57470 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#packet_mirroring_rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
Returns Output only. [Output Only] The packet mirroring rules that apply to the network.
57470 57471 57472 57473 57474 57475 57476 57477 57478 57479 57480 57481 57482 57483 57484 57485 57486 57487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57470 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#priority ⇒ ::Integer
Returns Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.
57470 57471 57472 57473 57474 57475 57476 57477 57478 57479 57480 57481 57482 57483 57484 57485 57486 57487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57470 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#rules ⇒ ::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>
Returns [Output Only] The rules that apply to the network.
57470 57471 57472 57473 57474 57475 57476 57477 57478 57479 57480 57481 57482 57483 57484 57485 57486 57487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57470 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#short_name ⇒ ::String
Returns Output only. [Output Only] The short name of the firewall policy.
57470 57471 57472 57473 57474 57475 57476 57477 57478 57479 57480 57481 57482 57483 57484 57485 57486 57487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57470 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |
#type ⇒ ::String
Returns Output only. [Output Only] The type of the firewall policy. Check the Type enum for the list of possible values.
57470 57471 57472 57473 57474 57475 57476 57477 57478 57479 57480 57481 57482 57483 57484 57485 57486 57487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57470 class NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The type of the firewall policy. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HIERARCHY = 69_902_869 NETWORK = 413_984_270 SYSTEM = 313_484_847 UNSPECIFIED = 526_786_327 end end |