Class: Google::Cloud::Compute::V1::NodeGroupAutoscalingPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NodeGroupAutoscalingPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#max_nodes ⇒ ::Integer
The maximum number of nodes that the group should have.
-
#min_nodes ⇒ ::Integer
The minimum number of nodes that the group should have.
-
#mode ⇒ ::String
The autoscaling mode.
Instance Attribute Details
#max_nodes ⇒ ::Integer
Returns The maximum number of nodes that the group should have. Must be set if autoscaling is enabled. Maximum value allowed is 100.
58256 58257 58258 58259 58260 58261 58262 58263 58264 58265 58266 58267 58268 58269 58270 58271 58272 58273 58274 58275 58276 58277 58278 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58256 class NodeGroupAutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The autoscaling mode. Set to one of: ON, OFF, # or ONLY_SCALE_OUT. For more information, see # Autoscaler modes. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 MODE_UNSPECIFIED = 371_348_091 # Autoscaling is disabled. OFF = 78_159 # Autocaling is fully enabled. ON = 2527 # Autoscaling will only scale out and will not remove nodes. ONLY_SCALE_OUT = 152_713_670 end end |
#min_nodes ⇒ ::Integer
Returns The minimum number of nodes that the group should have.
58256 58257 58258 58259 58260 58261 58262 58263 58264 58265 58266 58267 58268 58269 58270 58271 58272 58273 58274 58275 58276 58277 58278 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58256 class NodeGroupAutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The autoscaling mode. Set to one of: ON, OFF, # or ONLY_SCALE_OUT. For more information, see # Autoscaler modes. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 MODE_UNSPECIFIED = 371_348_091 # Autoscaling is disabled. OFF = 78_159 # Autocaling is fully enabled. ON = 2527 # Autoscaling will only scale out and will not remove nodes. ONLY_SCALE_OUT = 152_713_670 end end |
#mode ⇒ ::String
Returns The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For more information, see Autoscaler modes. Check the Mode enum for the list of possible values.
58256 58257 58258 58259 58260 58261 58262 58263 58264 58265 58266 58267 58268 58269 58270 58271 58272 58273 58274 58275 58276 58277 58278 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58256 class NodeGroupAutoscalingPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The autoscaling mode. Set to one of: ON, OFF, # or ONLY_SCALE_OUT. For more information, see # Autoscaler modes. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 MODE_UNSPECIFIED = 371_348_091 # Autoscaling is disabled. OFF = 78_159 # Autocaling is fully enabled. ON = 2527 # Autoscaling will only scale out and will not remove nodes. ONLY_SCALE_OUT = 152_713_670 end end |