Class: Google::Cloud::Compute::V1::NodeGroupNode
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NodeGroupNode
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: CpuOvercommitType, Status
Instance Attribute Summary collapse
-
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
Accelerators for this node.
-
#consumed_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Output only.
-
#cpu_overcommit_type ⇒ ::String
CPU overcommit.
-
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
Local disk configurations.
-
#instance_consumption_data ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceConsumptionData>
Output only.
-
#instances ⇒ ::Array<::String>
Instances scheduled on this node.
-
#name ⇒ ::String
The name of the node.
-
#node_type ⇒ ::String
The type of this node.
-
#satisfies_pzs ⇒ ::Boolean
Output only.
-
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
Binding properties for the physical server.
-
#server_id ⇒ ::String
Server ID associated with this node.
-
#status ⇒ ::String
Check the Status enum for the list of possible values.
-
#total_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Output only.
-
#upcoming_maintenance ⇒ ::Google::Cloud::Compute::V1::UpcomingMaintenance
Output only.
Instance Attribute Details
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
Returns Accelerators for this node.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#consumed_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Returns Output only. Node resources that are reserved by all instances.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#cpu_overcommit_type ⇒ ::String
Returns CPU overcommit. Check the CpuOvercommitType enum for the list of possible values.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
Returns Local disk configurations.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#instance_consumption_data ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceConsumptionData>
Returns Output only. Instance data that shows consumed resources on the node.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#instances ⇒ ::Array<::String>
Returns Instances scheduled on this node.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#name ⇒ ::String
Returns The name of the node.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#node_type ⇒ ::String
Returns The type of this node.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#satisfies_pzs ⇒ ::Boolean
Returns Output only. [Output Only] Reserved for future use.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
Returns Binding properties for the physical server.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#server_id ⇒ ::String
Returns Server ID associated with this node.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#status ⇒ ::String
Returns Check the Status enum for the list of possible values.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#total_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Returns Output only. Total amount of available resources on the node.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#upcoming_maintenance ⇒ ::Google::Cloud::Compute::V1::UpcomingMaintenance
Returns Output only. [Output Only] The information about an upcoming maintenance event.
57820 57821 57822 57823 57824 57825 57826 57827 57828 57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 57847 57848 57849 57850 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57820 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |