Class: Google::Cloud::Compute::V1::NodeGroupNode

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: CpuOvercommitType, Status

Instance Attribute Summary collapse

Instance Attribute Details

#accelerators::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>

Returns Accelerators for this node.

Returns:

  • Accelerators for this node.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#consumed_resources::Google::Cloud::Compute::V1::InstanceConsumptionInfo

Returns Node resources that are reserved by all instances.

Returns:

  • Node resources that are reserved by all instances.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#cpu_overcommit_type::String

Returns CPU overcommit. Check the CpuOvercommitType enum for the list of possible values.

Returns:

  • CPU overcommit. Check the CpuOvercommitType enum for the list of possible values.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#disks::Array<::Google::Cloud::Compute::V1::LocalDisk>

Returns Local disk configurations.

Returns:

  • Local disk configurations.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#instance_consumption_data::Array<::Google::Cloud::Compute::V1::InstanceConsumptionData>

Returns Instance data that shows consumed resources on the node.

Returns:

  • Instance data that shows consumed resources on the node.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#instances::Array<::String>

Returns Instances scheduled on this node.

Returns:

  • Instances scheduled on this node.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#name::String

Returns The name of the node.

Returns:

  • The name of the node.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#node_type::String

Returns The type of this node.

Returns:

  • The type of this node.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#satisfies_pzs::Boolean

Returns [Output Only] Reserved for future use.

Returns:

  • [Output Only] Reserved for future use.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#server_binding::Google::Cloud::Compute::V1::ServerBinding

Returns Binding properties for the physical server.

Returns:

  • Binding properties for the physical server.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#server_id::String

Returns Server ID associated with this node.

Returns:

  • Server ID associated with this node.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#status::String

Returns Check the Status enum for the list of possible values.

Returns:

  • Check the Status enum for the list of possible values.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#total_resources::Google::Cloud::Compute::V1::InstanceConsumptionInfo

Returns Total amount of available resources on the node.

Returns:

  • Total amount of available resources on the node.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end

#upcoming_maintenance::Google::Cloud::Compute::V1::UpcomingMaintenance

Returns [Output Only] The information about an upcoming maintenance event.

Returns:

  • [Output Only] The information about an upcoming maintenance event.



23007
23008
23009
23010
23011
23012
23013
23014
23015
23016
23017
23018
23019
23020
23021
23022
23023
23024
23025
23026
23027
23028
23029
23030
23031
23032
23033
23034
23035
23036
23037
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23007

class NodeGroupNode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CPU overcommit.
  module CpuOvercommitType
    # A value indicating that the enum field is not set.
    UNDEFINED_CPU_OVERCOMMIT_TYPE = 0

    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615

    ENABLED = 182_130_465

    NONE = 2_402_104
  end

  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    CREATING = 455_564_985

    DELETING = 528_602_024

    INVALID = 530_283_991

    READY = 77_848_963

    REPAIRING = 413_483_285
  end
end