Class: Google::Cloud::Compute::V1::NodeGroupNode
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NodeGroupNode
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: CpuOvercommitType, Status
Instance Attribute Summary collapse
-
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
Accelerators for this node.
-
#consumed_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Node resources that are reserved by all instances.
-
#cpu_overcommit_type ⇒ ::String
CPU overcommit.
-
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
Local disk configurations.
-
#instance_consumption_data ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceConsumptionData>
Instance data that shows consumed resources on the node.
-
#instances ⇒ ::Array<::String>
Instances scheduled on this node.
-
#name ⇒ ::String
The name of the node.
-
#node_type ⇒ ::String
The type of this node.
-
#satisfies_pzs ⇒ ::Boolean
[Output Only] Reserved for future use.
-
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
Binding properties for the physical server.
-
#server_id ⇒ ::String
Server ID associated with this node.
-
#status ⇒ ::String
Check the Status enum for the list of possible values.
-
#total_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Total amount of available resources on the node.
Instance Attribute Details
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
Returns Accelerators for this node.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#consumed_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Returns Node resources that are reserved by all instances.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#cpu_overcommit_type ⇒ ::String
Returns CPU overcommit. Check the CpuOvercommitType enum for the list of possible values.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
Returns Local disk configurations.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#instance_consumption_data ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceConsumptionData>
Returns Instance data that shows consumed resources on the node.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#instances ⇒ ::Array<::String>
Returns Instances scheduled on this node.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#name ⇒ ::String
Returns The name of the node.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#node_type ⇒ ::String
Returns The type of this node.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#satisfies_pzs ⇒ ::Boolean
Returns [Output Only] Reserved for future use.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
Returns Binding properties for the physical server.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#server_id ⇒ ::String
Returns Server ID associated with this node.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#status ⇒ ::String
Returns Check the Status enum for the list of possible values.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |
#total_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Returns Total amount of available resources on the node.
19091 19092 19093 19094 19095 19096 19097 19098 19099 19100 19101 19102 19103 19104 19105 19106 19107 19108 19109 19110 19111 19112 19113 19114 19115 19116 19117 19118 19119 19120 19121 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 19091 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520665615 ENABLED = 182130465 NONE = 2402104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455564985 DELETING = 528602024 INVALID = 530283991 READY = 77848963 REPAIRING = 413483285 end end |