Class: Google::Cloud::Compute::V1::NodeGroupNode
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NodeGroupNode
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: CpuOvercommitType, Status
Instance Attribute Summary collapse
-
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
Accelerators for this node.
-
#consumed_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Output only.
-
#cpu_overcommit_type ⇒ ::String
CPU overcommit.
-
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
Local disk configurations.
-
#instance_consumption_data ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceConsumptionData>
Output only.
-
#instances ⇒ ::Array<::String>
Instances scheduled on this node.
-
#name ⇒ ::String
The name of the node.
-
#node_type ⇒ ::String
The type of this node.
-
#satisfies_pzs ⇒ ::Boolean
Output only.
-
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
Binding properties for the physical server.
-
#server_id ⇒ ::String
Server ID associated with this node.
-
#status ⇒ ::String
Check the Status enum for the list of possible values.
-
#total_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Output only.
-
#upcoming_maintenance ⇒ ::Google::Cloud::Compute::V1::UpcomingMaintenance
Output only.
Instance Attribute Details
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
Returns Accelerators for this node.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#consumed_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Returns Output only. Node resources that are reserved by all instances.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#cpu_overcommit_type ⇒ ::String
Returns CPU overcommit. Check the CpuOvercommitType enum for the list of possible values.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
Returns Local disk configurations.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#instance_consumption_data ⇒ ::Array<::Google::Cloud::Compute::V1::InstanceConsumptionData>
Returns Output only. Instance data that shows consumed resources on the node.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#instances ⇒ ::Array<::String>
Returns Instances scheduled on this node.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#name ⇒ ::String
Returns The name of the node.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#node_type ⇒ ::String
Returns The type of this node.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#satisfies_pzs ⇒ ::Boolean
Returns Output only. [Output Only] Reserved for future use.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
Returns Binding properties for the physical server.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#server_id ⇒ ::String
Returns Server ID associated with this node.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#status ⇒ ::String
Returns Check the Status enum for the list of possible values.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#total_resources ⇒ ::Google::Cloud::Compute::V1::InstanceConsumptionInfo
Returns Output only. Total amount of available resources on the node.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |
#upcoming_maintenance ⇒ ::Google::Cloud::Compute::V1::UpcomingMaintenance
Returns Output only. [Output Only] The information about an upcoming maintenance event.
59766 59767 59768 59769 59770 59771 59772 59773 59774 59775 59776 59777 59778 59779 59780 59781 59782 59783 59784 59785 59786 59787 59788 59789 59790 59791 59792 59793 59794 59795 59796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59766 class NodeGroupNode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 INVALID = 530_283_991 READY = 77_848_963 REPAIRING = 413_483_285 end end |