Class: Google::Cloud::Compute::V1::NodeTemplate
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NodeTemplate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represent a sole-tenant Node Template resource.
You can use a template to define properties for nodes in a node group. For more information, readCreating node groups and instances.
Defined Under Namespace
Modules: CpuOvercommitType, Status Classes: NodeAffinityLabelsEntry
Instance Attribute Summary collapse
- #accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
-
#cpu_overcommit_type ⇒ ::String
CPU overcommit.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
- #disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
The name of the resource, provided by the client when initially creating the resource.
-
#node_affinity_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels to use for node affinity, which will be used in instance scheduling.
-
#node_type ⇒ ::String
The node type to use for nodes group that are created from this template.
-
#node_type_flexibility ⇒ ::Google::Cloud::Compute::V1::NodeTemplateNodeTypeFlexibility
Do not use.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
Sets the binding properties for the physical server.
-
#status ⇒ ::String
Output only.
-
#status_message ⇒ ::String
Output only.
Instance Attribute Details
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#cpu_overcommit_type ⇒ ::String
Returns CPU overcommit. Check the CpuOvercommitType enum for the list of possible values.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] The type of the resource. Alwayscompute#nodeTemplate for node templates.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#name ⇒ ::String
Returns The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#node_affinity_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels to use for node affinity, which will be used in instance scheduling.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#node_type ⇒ ::String
Returns The node type to use for nodes group that are created from this template.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#node_type_flexibility ⇒ ::Google::Cloud::Compute::V1::NodeTemplateNodeTypeFlexibility
Returns Do not use. Instead, use the node_type property.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#region ⇒ ::String
Returns Output only. [Output Only] The name of the region where the node template resides, such as us-central1.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
Returns Sets the binding properties for the physical server. Valid values include:
- [Default] RESTART_NODE_ON_ANY_SERVER: Restarts VMs on any available physical server
- RESTART_NODE_ON_MINIMAL_SERVER: Restarts VMs on the same physical server whenever possible
See Sole-tenant node options for more information.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#status ⇒ ::String
Returns Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. Check the Status enum for the list of possible values.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#status_message ⇒ ::String
Returns Output only. [Output Only] An optional, human-readable explanation of the status.
56925 56926 56927 56928 56929 56930 56931 56932 56933 56934 56935 56936 56937 56938 56939 56940 56941 56942 56943 56944 56945 56946 56947 56948 56949 56950 56951 56952 56953 56954 56955 56956 56957 56958 56959 56960 56961 56962 56963 56964 56965 56966 56967 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 56925 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |