Class: Google::Cloud::Compute::V1::NodeTemplate
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::NodeTemplate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represent a sole-tenant Node Template resource. You can use a template to define properties for nodes in a node group. For more information, read Creating node groups and instances.
Defined Under Namespace
Modules: CpuOvercommitType, Status Classes: NodeAffinityLabelsEntry
Instance Attribute Summary collapse
- #accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
-
#cpu_overcommit_type ⇒ ::String
CPU overcommit.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ ::String
An optional description of this resource.
- #disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
[Output Only] The type of the resource.
-
#name ⇒ ::String
The name of the resource, provided by the client when initially creating the resource.
-
#node_affinity_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels to use for node affinity, which will be used in instance scheduling.
-
#node_type ⇒ ::String
The node type to use for nodes group that are created from this template.
-
#node_type_flexibility ⇒ ::Google::Cloud::Compute::V1::NodeTemplateNodeTypeFlexibility
Do not use.
-
#region ⇒ ::String
[Output Only] The name of the region where the node template resides, such as us-central1.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
Sets the binding properties for the physical server.
-
#status ⇒ ::String
[Output Only] The status of the node template.
-
#status_message ⇒ ::String
[Output Only] An optional, human-readable explanation of the status.
Instance Attribute Details
#accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#cpu_overcommit_type ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#creation_timestamp ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#description ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::LocalDisk>
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#id ⇒ ::Integer
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#kind ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#name ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#node_affinity_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#node_type ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#node_type_flexibility ⇒ ::Google::Cloud::Compute::V1::NodeTemplateNodeTypeFlexibility
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#region ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#self_link ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#server_binding ⇒ ::Google::Cloud::Compute::V1::ServerBinding
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#status ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |
#status_message ⇒ ::String
25158 25159 25160 25161 25162 25163 25164 25165 25166 25167 25168 25169 25170 25171 25172 25173 25174 25175 25176 25177 25178 25179 25180 25181 25182 25183 25184 25185 25186 25187 25188 25189 25190 25191 25192 25193 25194 25195 25196 25197 25198 25199 25200 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25158 class NodeTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class NodeAffinityLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CPU overcommit. module CpuOvercommitType # A value indicating that the enum field is not set. UNDEFINED_CPU_OVERCOMMIT_TYPE = 0 CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 520_665_615 ENABLED = 182_130_465 NONE = 2_402_104 end # [Output Only] The status of the node template. One of the following values: CREATING, READY, and DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated. CREATING = 455_564_985 # The node template is currently being deleted. DELETING = 528_602_024 # Invalid status. INVALID = 530_283_991 # The node template is ready. READY = 77_848_963 end end |