Class: Google::Cloud::Compute::V1::NodeType

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information read Node types.

Instance Attribute Summary collapse

Instance Attribute Details

#cpu_platform::String



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#creation_timestamp::String



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deprecated::Google::Cloud::Compute::V1::DeprecationStatus



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#guest_cpus::Integer



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id::Integer



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::String



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#local_ssd_gb::Integer



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_vms::Integer



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#memory_mb::Integer



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end


23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zone::String



23593
23594
23595
23596
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23593

class NodeType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end