Class: Google::Cloud::Compute::V1::Operation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Operation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents an Operation resource.
Google Compute Engine has three Operation resources:
You can use an operation resource to manage asynchronous API requests. For more information, readHandling API responses.
Operations can be global, regional or zonal.
- For global operations, use the
globalOperationsresource. - For regional operations, use the
regionOperationsresource. - For zonal operations, use
the
zoneOperationsresource.
For more information, read Global, Regional, and Zonal Resources.
Note that completed Operation resources have a limited retention period.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#client_operation_id ⇒ ::String
[Output Only] The value of
requestIdif you provided it in the request. -
#creation_timestamp ⇒ ::String
[Deprecated] This field is deprecated.
-
#description ⇒ ::String
[Output Only] A textual description of the operation, which is set when the operation is created.
-
#end_time ⇒ ::String
[Output Only] The time that this operation was completed.
-
#error ⇒ ::Google::Cloud::Compute::V1::Error
[Output Only] If errors are generated during processing of the operation, this field will be populated.
- #get_version_operation_metadata ⇒ ::Google::Cloud::Compute::V1::GetVersionOperationMetadata
-
#http_error_message ⇒ ::String
[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as
NOT FOUND. -
#http_error_status_code ⇒ ::Integer
[Output Only] If the operation fails, this field contains the HTTP error status code that was returned.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the operation.
-
#insert_time ⇒ ::String
[Output Only] The time that this operation was requested.
- #instances_bulk_insert_operation_metadata ⇒ ::Google::Cloud::Compute::V1::InstancesBulkInsertOperationMetadata
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
[Output Only] Name of the operation.
-
#operation_group_id ⇒ ::String
Output only.
-
#operation_type ⇒ ::String
[Output Only] The type of operation, such as
insert,update, ordelete, and so on. -
#progress ⇒ ::Integer
[Output Only] An optional progress indicator that ranges from 0 to 100.
-
#region ⇒ ::String
[Output Only] The URL of the region where the operation resides.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#set_common_instance_metadata_operation_metadata ⇒ ::Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadata
Output only.
-
#start_time ⇒ ::String
[Output Only] The time that this operation was started by the server.
-
#status ⇒ ::Google::Cloud::Compute::V1::Operation::Status
[Output Only] The status of the operation, which can be one of the following:
PENDING,RUNNING, orDONE. -
#status_message ⇒ ::String
[Output Only] An optional textual description of the current status of the operation.
-
#target_id ⇒ ::Integer
[Output Only] The unique target ID, which identifies a specific incarnation of the target resource.
-
#target_link ⇒ ::String
[Output Only] The URL of the resource that the operation modifies.
-
#user ⇒ ::String
[Output Only] User who requested the operation, for example:
user@example.comoralice_smith_identifier (global/workforcePools/example-com-us-employees). -
#warnings ⇒ ::Array<::Google::Cloud::Compute::V1::Warnings>
[Output Only] If warning messages are generated during processing of the operation, this field will be populated.
-
#zone ⇒ ::String
[Output Only] The URL of the zone where the operation resides.
Instance Attribute Details
#client_operation_id ⇒ ::String
Returns [Output Only] The value of requestId if you provided it in the request.
Not present otherwise.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#creation_timestamp ⇒ ::String
Returns [Deprecated] This field is deprecated.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#description ⇒ ::String
Returns [Output Only] A textual description of the operation, which is set when the operation is created.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#end_time ⇒ ::String
Returns [Output Only] The time that this operation was completed. This value is inRFC3339 text format.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#error ⇒ ::Google::Cloud::Compute::V1::Error
Returns [Output Only] If errors are generated during processing of the operation, this field will be populated.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#get_version_operation_metadata ⇒ ::Google::Cloud::Compute::V1::GetVersionOperationMetadata
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#http_error_message ⇒ ::String
Returns [Output Only] If the operation fails, this field contains the HTTP error
message that was returned, such as NOT FOUND.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#http_error_status_code ⇒ ::Integer
Returns [Output Only] If the operation fails, this field contains the HTTP error
status code that was returned. For example, a 404 means the
resource was not found.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the operation. This identifier is defined by the server.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#insert_time ⇒ ::String
Returns [Output Only] The time that this operation was requested. This value is inRFC3339 text format.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#instances_bulk_insert_operation_metadata ⇒ ::Google::Cloud::Compute::V1::InstancesBulkInsertOperationMetadata
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#operation for
Operation resources.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#name ⇒ ::String
Returns [Output Only] Name of the operation.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#operation_group_id ⇒ ::String
Returns Output only. [Output Only] An ID that represents a group of operations, such as when a
group of operations results from a bulkInsert API request.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#operation_type ⇒ ::String
Returns [Output Only] The type of operation, such as insert,
update, or delete, and so on.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#progress ⇒ ::Integer
Returns [Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#region ⇒ ::String
Returns [Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#set_common_instance_metadata_operation_metadata ⇒ ::Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadata
Returns Output only. [Output Only] If the operation is for projects.setCommonInstanceMetadata, this field will contain information on all underlying zonal actions and their state.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#start_time ⇒ ::String
Returns [Output Only] The time that this operation was started by the server. This value is inRFC3339 text format.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#status ⇒ ::Google::Cloud::Compute::V1::Operation::Status
Returns [Output Only] The status of the operation, which can be one of the
following:
PENDING, RUNNING, or DONE.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#status_message ⇒ ::String
Returns [Output Only] An optional textual description of the current status of the operation.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#target_id ⇒ ::Integer
Returns [Output Only] The unique target ID, which identifies a specific incarnation of the target resource.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#target_link ⇒ ::String
Returns [Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the disk that the snapshot was created from.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#user ⇒ ::String
Returns [Output Only] User who requested the operation, for example:
user@example.com or
alice_smith_identifier (global/workforcePools/example-com-us-employees).
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#warnings ⇒ ::Array<::Google::Cloud::Compute::V1::Warnings>
Returns [Output Only] If warning messages are generated during processing of the operation, this field will be populated.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |
#zone ⇒ ::String
Returns [Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations.
58584 58585 58586 58587 58588 58589 58590 58591 58592 58593 58594 58595 58596 58597 58598 58599 58600 58601 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58584 class Operation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The status of the operation, which can be one of the # following: # `PENDING`, `RUNNING`, or `DONE`. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DONE = 2_104_194 PENDING = 35_394_935 RUNNING = 121_282_975 end end |