Class: Google::Cloud::Compute::V1::OperationAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#id::String

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::String)

    [Output Only] The unique identifier for the resource. This identifier is defined by the server.



59179
59180
59181
59182
59183
59184
59185
59186
59187
59188
59189
59190
59191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59179

class OperationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::OperationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::OperationsScopedList}

Returns [Output Only] A map of scoped operation lists.

Returns:



59179
59180
59181
59182
59183
59184
59185
59186
59187
59188
59189
59190
59191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59179

class OperationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::OperationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns Output only. [Output Only] Type of resource. Always compute#operationAggregatedList for aggregated lists of operations.

Returns:

  • (::String)

    Output only. [Output Only] Type of resource. Always compute#operationAggregatedList for aggregated lists of operations.



59179
59180
59181
59182
59183
59184
59185
59186
59187
59188
59189
59190
59191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59179

class OperationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::OperationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



59179
59180
59181
59182
59183
59184
59185
59186
59187
59188
59189
59190
59191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59179

class OperationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::OperationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns [Output Only] Server-defined URL for this resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for this resource.



59179
59180
59181
59182
59183
59184
59185
59186
59187
59188
59189
59190
59191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59179

class OperationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::OperationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Unreachable resources.



59179
59180
59181
59182
59183
59184
59185
59186
59187
59188
59189
59190
59191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59179

class OperationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::OperationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



59179
59180
59181
59182
59183
59184
59185
59186
59187
59188
59189
59190
59191
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59179

class OperationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::OperationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end