Class: Google::Cloud::Compute::V1::OperationAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::OperationAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] The unique identifier for the resource.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::OperationsScopedList}
[Output Only] A map of scoped operation lists.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
57545 57546 57547 57548 57549 57550 57551 57552 57553 57554 57555 57556 57557 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57545 class OperationAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::OperationsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::OperationsScopedList}
Returns [Output Only] A map of scoped operation lists.
57545 57546 57547 57548 57549 57550 57551 57552 57553 57554 57555 57556 57557 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57545 class OperationAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::OperationsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Always compute#operationAggregatedList
for aggregated lists of operations.
57545 57546 57547 57548 57549 57550 57551 57552 57553 57554 57555 57556 57557 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57545 class OperationAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::OperationsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
57545 57546 57547 57548 57549 57550 57551 57552 57553 57554 57555 57556 57557 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57545 class OperationAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::OperationsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for this resource.
57545 57546 57547 57548 57549 57550 57551 57552 57553 57554 57555 57556 57557 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57545 class OperationAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::OperationsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
57545 57546 57547 57548 57549 57550 57551 57552 57553 57554 57555 57556 57557 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57545 class OperationAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::OperationsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
57545 57546 57547 57548 57549 57550 57551 57552 57553 57554 57555 57556 57557 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57545 class OperationAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::OperationsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |