Class: Google::Cloud::Compute::V1::PacketIntervals
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PacketIntervals
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Next free: 7
Defined Under Namespace
Instance Attribute Summary collapse
-
#avg_ms ⇒ ::Integer
Average observed inter-packet interval in milliseconds.
-
#duration ⇒ ::String
From how long ago in the past these intervals were observed.
-
#max_ms ⇒ ::Integer
Maximum observed inter-packet interval in milliseconds.
-
#min_ms ⇒ ::Integer
Minimum observed inter-packet interval in milliseconds.
-
#num_intervals ⇒ ::Integer
Number of inter-packet intervals from which these statistics were derived.
-
#type ⇒ ::String
The type of packets for which inter-packet intervals were computed.
Instance Attribute Details
#avg_ms ⇒ ::Integer
Returns Average observed inter-packet interval in milliseconds.
59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 59363 59364 59365 59366 59367 59368 59369 59370 59371 59372 59373 59374 59375 59376 59377 59378 59379 59380 59381 59382 59383 59384 59385 59386 59387 59388 59389 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59353 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#duration ⇒ ::String
Returns From how long ago in the past these intervals were observed. Check the Duration enum for the list of possible values.
59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 59363 59364 59365 59366 59367 59368 59369 59370 59371 59372 59373 59374 59375 59376 59377 59378 59379 59380 59381 59382 59383 59384 59385 59386 59387 59388 59389 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59353 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#max_ms ⇒ ::Integer
Returns Maximum observed inter-packet interval in milliseconds.
59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 59363 59364 59365 59366 59367 59368 59369 59370 59371 59372 59373 59374 59375 59376 59377 59378 59379 59380 59381 59382 59383 59384 59385 59386 59387 59388 59389 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59353 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#min_ms ⇒ ::Integer
Returns Minimum observed inter-packet interval in milliseconds.
59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 59363 59364 59365 59366 59367 59368 59369 59370 59371 59372 59373 59374 59375 59376 59377 59378 59379 59380 59381 59382 59383 59384 59385 59386 59387 59388 59389 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59353 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#num_intervals ⇒ ::Integer
Returns Number of inter-packet intervals from which these statistics were derived.
59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 59363 59364 59365 59366 59367 59368 59369 59370 59371 59372 59373 59374 59375 59376 59377 59378 59379 59380 59381 59382 59383 59384 59385 59386 59387 59388 59389 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59353 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#type ⇒ ::String
Returns The type of packets for which inter-packet intervals were computed. Check the Type enum for the list of possible values.
59353 59354 59355 59356 59357 59358 59359 59360 59361 59362 59363 59364 59365 59366 59367 59368 59369 59370 59371 59372 59373 59374 59375 59376 59377 59378 59379 59380 59381 59382 59383 59384 59385 59386 59387 59388 59389 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 59353 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |