Class: Google::Cloud::Compute::V1::PacketIntervals

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Next free: 7

Defined Under Namespace

Modules: Duration, Type

Instance Attribute Summary collapse

Instance Attribute Details

#avg_ms::Integer

Returns Average observed inter-packet interval in milliseconds.

Returns:

  • (::Integer)

    Average observed inter-packet interval in milliseconds.



58805
58806
58807
58808
58809
58810
58811
58812
58813
58814
58815
58816
58817
58818
58819
58820
58821
58822
58823
58824
58825
58826
58827
58828
58829
58830
58831
58832
58833
58834
58835
58836
58837
58838
58839
58840
58841
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58805

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#duration::String

Returns From how long ago in the past these intervals were observed. Check the Duration enum for the list of possible values.

Returns:

  • (::String)

    From how long ago in the past these intervals were observed. Check the Duration enum for the list of possible values.



58805
58806
58807
58808
58809
58810
58811
58812
58813
58814
58815
58816
58817
58818
58819
58820
58821
58822
58823
58824
58825
58826
58827
58828
58829
58830
58831
58832
58833
58834
58835
58836
58837
58838
58839
58840
58841
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58805

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#max_ms::Integer

Returns Maximum observed inter-packet interval in milliseconds.

Returns:

  • (::Integer)

    Maximum observed inter-packet interval in milliseconds.



58805
58806
58807
58808
58809
58810
58811
58812
58813
58814
58815
58816
58817
58818
58819
58820
58821
58822
58823
58824
58825
58826
58827
58828
58829
58830
58831
58832
58833
58834
58835
58836
58837
58838
58839
58840
58841
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58805

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#min_ms::Integer

Returns Minimum observed inter-packet interval in milliseconds.

Returns:

  • (::Integer)

    Minimum observed inter-packet interval in milliseconds.



58805
58806
58807
58808
58809
58810
58811
58812
58813
58814
58815
58816
58817
58818
58819
58820
58821
58822
58823
58824
58825
58826
58827
58828
58829
58830
58831
58832
58833
58834
58835
58836
58837
58838
58839
58840
58841
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58805

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#num_intervals::Integer

Returns Number of inter-packet intervals from which these statistics were derived.

Returns:

  • (::Integer)

    Number of inter-packet intervals from which these statistics were derived.



58805
58806
58807
58808
58809
58810
58811
58812
58813
58814
58815
58816
58817
58818
58819
58820
58821
58822
58823
58824
58825
58826
58827
58828
58829
58830
58831
58832
58833
58834
58835
58836
58837
58838
58839
58840
58841
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58805

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end

#type::String

Returns The type of packets for which inter-packet intervals were computed. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    The type of packets for which inter-packet intervals were computed. Check the Type enum for the list of possible values.



58805
58806
58807
58808
58809
58810
58811
58812
58813
58814
58815
58816
58817
58818
58819
58820
58821
58822
58823
58824
58825
58826
58827
58828
58829
58830
58831
58832
58833
58834
58835
58836
58837
58838
58839
58840
58841
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 58805

class PacketIntervals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # From how long ago in the past these intervals were observed.
  module Duration
    # A value indicating that the enum field is not set.
    UNDEFINED_DURATION = 0

    DURATION_UNSPECIFIED = 529_071_340

    HOUR = 2_223_588

    # From BfdSession object creation time.
    MAX = 76_100

    MINUTE = 126_786_068
  end

  # The type of packets for which inter-packet intervals were computed.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Only applies to Echo packets. This shows the intervals between sending
    # and receiving the same packet.
    LOOPBACK = 356_174_219

    # Intervals between received packets.
    RECEIVE = 189_660_867

    # Intervals between transmitted packets.
    TRANSMIT = 452_903_600

    TYPE_UNSPECIFIED = 437_714_322
  end
end