Class: Google::Cloud::Compute::V1::PacketIntervals
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PacketIntervals
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Next free: 7
Defined Under Namespace
Instance Attribute Summary collapse
-
#avg_ms ⇒ ::Integer
Average observed inter-packet interval in milliseconds.
-
#duration ⇒ ::String
From how long ago in the past these intervals were observed.
-
#max_ms ⇒ ::Integer
Maximum observed inter-packet interval in milliseconds.
-
#min_ms ⇒ ::Integer
Minimum observed inter-packet interval in milliseconds.
-
#num_intervals ⇒ ::Integer
Number of inter-packet intervals from which these statistics were derived.
-
#type ⇒ ::String
The type of packets for which inter-packet intervals were computed.
Instance Attribute Details
#avg_ms ⇒ ::Integer
Returns Average observed inter-packet interval in milliseconds.
57719 57720 57721 57722 57723 57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 57737 57738 57739 57740 57741 57742 57743 57744 57745 57746 57747 57748 57749 57750 57751 57752 57753 57754 57755 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57719 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#duration ⇒ ::String
Returns From how long ago in the past these intervals were observed. Check the Duration enum for the list of possible values.
57719 57720 57721 57722 57723 57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 57737 57738 57739 57740 57741 57742 57743 57744 57745 57746 57747 57748 57749 57750 57751 57752 57753 57754 57755 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57719 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#max_ms ⇒ ::Integer
Returns Maximum observed inter-packet interval in milliseconds.
57719 57720 57721 57722 57723 57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 57737 57738 57739 57740 57741 57742 57743 57744 57745 57746 57747 57748 57749 57750 57751 57752 57753 57754 57755 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57719 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#min_ms ⇒ ::Integer
Returns Minimum observed inter-packet interval in milliseconds.
57719 57720 57721 57722 57723 57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 57737 57738 57739 57740 57741 57742 57743 57744 57745 57746 57747 57748 57749 57750 57751 57752 57753 57754 57755 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57719 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#num_intervals ⇒ ::Integer
Returns Number of inter-packet intervals from which these statistics were derived.
57719 57720 57721 57722 57723 57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 57737 57738 57739 57740 57741 57742 57743 57744 57745 57746 57747 57748 57749 57750 57751 57752 57753 57754 57755 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57719 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |
#type ⇒ ::String
Returns The type of packets for which inter-packet intervals were computed. Check the Type enum for the list of possible values.
57719 57720 57721 57722 57723 57724 57725 57726 57727 57728 57729 57730 57731 57732 57733 57734 57735 57736 57737 57738 57739 57740 57741 57742 57743 57744 57745 57746 57747 57748 57749 57750 57751 57752 57753 57754 57755 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57719 class PacketIntervals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # From how long ago in the past these intervals were observed. module Duration # A value indicating that the enum field is not set. UNDEFINED_DURATION = 0 DURATION_UNSPECIFIED = 529_071_340 HOUR = 2_223_588 # From BfdSession object creation time. MAX = 76_100 MINUTE = 126_786_068 end # The type of packets for which inter-packet intervals were computed. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Only applies to Echo packets. This shows the intervals between sending # and receiving the same packet. LOOPBACK = 356_174_219 # Intervals between received packets. RECEIVE = 189_660_867 # Intervals between transmitted packets. TRANSMIT = 452_903_600 TYPE_UNSPECIFIED = 437_714_322 end end |