Class: Google::Cloud::Compute::V1::PacketMirroring
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PacketMirroring
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Packet Mirroring resource.
Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, seeUsing Packet Mirroring.
Defined Under Namespace
Modules: Enable
Instance Attribute Summary collapse
-
#collector_ilb ⇒ ::Google::Cloud::Compute::V1::PacketMirroringForwardingRuleInfo
The Forwarding Rule resource of typeloadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#enable ⇒ ::String
Indicates whether or not this packet mirroring takes effect.
-
#filter ⇒ ::Google::Cloud::Compute::V1::PacketMirroringFilter
Filter for mirrored traffic.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#mirrored_resources ⇒ ::Google::Cloud::Compute::V1::PacketMirroringMirroredResourceInfo
PacketMirroring mirroredResourceInfos.
-
#name ⇒ ::String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ ::Google::Cloud::Compute::V1::PacketMirroringNetworkInfo
Specifies the mirrored VPC network.
-
#priority ⇒ ::Integer
The priority of applying this configuration.
-
#region ⇒ ::String
[Output Only] URI of the region where the packetMirroring resides.
-
#self_link ⇒ ::String
Output only.
Instance Attribute Details
#collector_ilb ⇒ ::Google::Cloud::Compute::V1::PacketMirroringForwardingRuleInfo
Returns The Forwarding Rule resource of typeloadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic. The specified forwarding rule must have isMirroringCollector set to true.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#enable ⇒ ::String
Returns Indicates whether or not this packet mirroring takes effect. If set to FALSE, this packet mirroring policy will not be enforced on the network.
The default is TRUE. Check the Enable enum for the list of possible values.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#filter ⇒ ::Google::Cloud::Compute::V1::PacketMirroringFilter
Returns Filter for mirrored traffic. If unspecified, all IPv4 traffic is mirrored.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#packetMirroring for packet mirrorings.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#mirrored_resources ⇒ ::Google::Cloud::Compute::V1::PacketMirroringMirroredResourceInfo
Returns PacketMirroring mirroredResourceInfos. MirroredResourceInfo specifies a set of mirrored VM instances, subnetworks and/or tags for which traffic from/to all VM instances will be mirrored.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#name ⇒ ::String
Returns Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#network ⇒ ::Google::Cloud::Compute::V1::PacketMirroringNetworkInfo
Returns Specifies the mirrored VPC network. Only packets in this network will be mirrored. All mirrored VMs should have a NIC in the given network. All mirrored subnetworks should belong to the given network.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#priority ⇒ ::Integer
Returns The priority of applying this configuration. Priority is used to break ties in cases where there is more than one matching rule. In the case of two rules that apply for a given Instance, the one with the lowest-numbered priority value wins.
Default value is 1000. Valid range is 0 through 65535.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#region ⇒ ::String
Returns [Output Only] URI of the region where the packetMirroring resides.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
57829 57830 57831 57832 57833 57834 57835 57836 57837 57838 57839 57840 57841 57842 57843 57844 57845 57846 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 57829 class PacketMirroring include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates whether or not this packet mirroring takes effect. # If set to FALSE, this packet mirroring policy will not be enforced on the # network. # # The default is TRUE. module Enable # A value indicating that the enum field is not set. UNDEFINED_ENABLE = 0 FALSE = 66_658_563 TRUE = 2_583_950 end end |