Class: Google::Cloud::Compute::V1::PacketMirroringFilter
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PacketMirroringFilter
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Direction
Instance Attribute Summary collapse
-
#cidr_ranges ⇒ ::Array<::String>
One or more IPv4 or IPv6 CIDR ranges that apply as filters on the source (ingress) or destination (egress) IP in the IP header.
-
#direction ⇒ ::String
Direction of traffic to mirror, either INGRESS, EGRESS, or BOTH.
-
#I_p_protocols ⇒ ::Array<::String>
Protocols that apply as filter on mirrored traffic.
Instance Attribute Details
#cidr_ranges ⇒ ::Array<::String>
Returns One or more IPv4 or IPv6 CIDR ranges that apply as filters on the source (ingress) or destination (egress) IP in the IP header. If no ranges are specified, all IPv4 traffic that matches the specified IPProtocols is mirrored. If neither cidrRanges nor IPProtocols is specified, all IPv4 traffic is mirrored. To mirror all IPv4 and IPv6 traffic, use "0.0.0.0/0,::/0".
25836 25837 25838 25839 25840 25841 25842 25843 25844 25845 25846 25847 25848 25849 25850 25851 25852 25853 25854 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25836 class PacketMirroringFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to mirror, either INGRESS, EGRESS, or BOTH. The default is BOTH. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Default, both directions are mirrored. BOTH = 2_044_801 # Only egress traffic is mirrored. EGRESS = 432_880_501 # Only ingress traffic is mirrored. INGRESS = 516_931_221 end end |
#direction ⇒ ::String
Returns Direction of traffic to mirror, either INGRESS, EGRESS, or BOTH. The default is BOTH. Check the Direction enum for the list of possible values.
25836 25837 25838 25839 25840 25841 25842 25843 25844 25845 25846 25847 25848 25849 25850 25851 25852 25853 25854 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25836 class PacketMirroringFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to mirror, either INGRESS, EGRESS, or BOTH. The default is BOTH. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Default, both directions are mirrored. BOTH = 2_044_801 # Only egress traffic is mirrored. EGRESS = 432_880_501 # Only ingress traffic is mirrored. INGRESS = 516_931_221 end end |
#I_p_protocols ⇒ ::Array<::String>
Returns Protocols that apply as filter on mirrored traffic. If no protocols are specified, all traffic that matches the specified CIDR ranges is mirrored. If neither cidrRanges nor IPProtocols is specified, all IPv4 traffic is mirrored.
25836 25837 25838 25839 25840 25841 25842 25843 25844 25845 25846 25847 25848 25849 25850 25851 25852 25853 25854 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25836 class PacketMirroringFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Direction of traffic to mirror, either INGRESS, EGRESS, or BOTH. The default is BOTH. module Direction # A value indicating that the enum field is not set. UNDEFINED_DIRECTION = 0 # Default, both directions are mirrored. BOTH = 2_044_801 # Only egress traffic is mirrored. EGRESS = 432_880_501 # Only ingress traffic is mirrored. INGRESS = 516_931_221 end end |