Class: Google::Cloud::Compute::V1::PathMatcher

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A matcher for the path portion of the URL. The BackendService from the longest-matched rule will serve the URL. If no rule was matched, the default service is used.

Instance Attribute Summary collapse

Instance Attribute Details

#default_custom_error_response_policy::Google::Cloud::Compute::V1::CustomErrorResponsePolicy



25305
25306
25307
25308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25305

class PathMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#default_route_action::Google::Cloud::Compute::V1::HttpRouteAction



25305
25306
25307
25308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25305

class PathMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#default_service::String



25305
25306
25307
25308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25305

class PathMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#default_url_redirect::Google::Cloud::Compute::V1::HttpRedirectAction



25305
25306
25307
25308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25305

class PathMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String



25305
25306
25307
25308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25305

class PathMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#header_action::Google::Cloud::Compute::V1::HttpHeaderAction



25305
25306
25307
25308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25305

class PathMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String



25305
25306
25307
25308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25305

class PathMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path_rules::Array<::Google::Cloud::Compute::V1::PathRule>



25305
25306
25307
25308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25305

class PathMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#route_rules::Array<::Google::Cloud::Compute::V1::HttpRouteRule>



25305
25306
25307
25308
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25305

class PathMatcher
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end