Class: Google::Cloud::Compute::V1::PerInstanceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PerInstanceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#fingerprint ⇒ ::String
Fingerprint of this per-instance config.
-
#name ⇒ ::String
The name of a per-instance configuration and its corresponding instance.
-
#preserved_state ⇒ ::Google::Cloud::Compute::V1::PreservedState
The intended preserved state for the given instance.
-
#status ⇒ ::String
The status of applying this per-instance configuration on the corresponding managed instance.
Instance Attribute Details
#fingerprint ⇒ ::String
Returns Fingerprint of this per-instance config. This field can be used in optimistic locking. It is ignored when inserting a per-instance config. An up-to-date fingerprint must be provided in order to update an existing per-instance configuration or the field needs to be unset.
63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 63430 63431 63432 63433 63434 63435 63436 63437 63438 63439 63440 63441 63442 63443 63444 63445 63446 63447 63448 63449 63450 63451 63452 63453 63454 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63419 class PerInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of applying this per-instance configuration on the corresponding # managed instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The per-instance configuration is being applied to the instance, but is # not yet effective, possibly waiting for the instance to, for example,REFRESH. APPLYING = 352_003_508 # The per-instance configuration deletion is being applied on the instance, # possibly waiting for the instance to, for example, REFRESH. DELETING = 528_602_024 # The per-instance configuration is effective on the instance, meaning that # all disks, ips and metadata specified in this configuration are attached # or set on the instance. EFFECTIVE = 244_201_863 # *[Default]* The default status, when no per-instance configuration # exists. NONE = 2_402_104 # The per-instance configuration is set on an instance but not been applied # yet. UNAPPLIED = 483_935_140 # The per-instance configuration has been deleted, but the deletion is not # yet applied. UNAPPLIED_DELETION = 313_956_873 end end |
#name ⇒ ::String
Returns The name of a per-instance configuration and its corresponding instance. Serves as a merge key during UpdatePerInstanceConfigs operations, that is, if a per-instance configuration with the same name exists then it will be updated, otherwise a new one will be created for the VM instance with the same name. An attempt to create a per-instance configuration for a VM instance that either doesn't exist or is not part of the group will result in an error.
63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 63430 63431 63432 63433 63434 63435 63436 63437 63438 63439 63440 63441 63442 63443 63444 63445 63446 63447 63448 63449 63450 63451 63452 63453 63454 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63419 class PerInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of applying this per-instance configuration on the corresponding # managed instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The per-instance configuration is being applied to the instance, but is # not yet effective, possibly waiting for the instance to, for example,REFRESH. APPLYING = 352_003_508 # The per-instance configuration deletion is being applied on the instance, # possibly waiting for the instance to, for example, REFRESH. DELETING = 528_602_024 # The per-instance configuration is effective on the instance, meaning that # all disks, ips and metadata specified in this configuration are attached # or set on the instance. EFFECTIVE = 244_201_863 # *[Default]* The default status, when no per-instance configuration # exists. NONE = 2_402_104 # The per-instance configuration is set on an instance but not been applied # yet. UNAPPLIED = 483_935_140 # The per-instance configuration has been deleted, but the deletion is not # yet applied. UNAPPLIED_DELETION = 313_956_873 end end |
#preserved_state ⇒ ::Google::Cloud::Compute::V1::PreservedState
Returns The intended preserved state for the given instance. Does not contain preserved state generated from a stateful policy.
63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 63430 63431 63432 63433 63434 63435 63436 63437 63438 63439 63440 63441 63442 63443 63444 63445 63446 63447 63448 63449 63450 63451 63452 63453 63454 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63419 class PerInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of applying this per-instance configuration on the corresponding # managed instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The per-instance configuration is being applied to the instance, but is # not yet effective, possibly waiting for the instance to, for example,REFRESH. APPLYING = 352_003_508 # The per-instance configuration deletion is being applied on the instance, # possibly waiting for the instance to, for example, REFRESH. DELETING = 528_602_024 # The per-instance configuration is effective on the instance, meaning that # all disks, ips and metadata specified in this configuration are attached # or set on the instance. EFFECTIVE = 244_201_863 # *[Default]* The default status, when no per-instance configuration # exists. NONE = 2_402_104 # The per-instance configuration is set on an instance but not been applied # yet. UNAPPLIED = 483_935_140 # The per-instance configuration has been deleted, but the deletion is not # yet applied. UNAPPLIED_DELETION = 313_956_873 end end |
#status ⇒ ::String
Returns The status of applying this per-instance configuration on the corresponding managed instance. Check the Status enum for the list of possible values.
63419 63420 63421 63422 63423 63424 63425 63426 63427 63428 63429 63430 63431 63432 63433 63434 63435 63436 63437 63438 63439 63440 63441 63442 63443 63444 63445 63446 63447 63448 63449 63450 63451 63452 63453 63454 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63419 class PerInstanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of applying this per-instance configuration on the corresponding # managed instance. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The per-instance configuration is being applied to the instance, but is # not yet effective, possibly waiting for the instance to, for example,REFRESH. APPLYING = 352_003_508 # The per-instance configuration deletion is being applied on the instance, # possibly waiting for the instance to, for example, REFRESH. DELETING = 528_602_024 # The per-instance configuration is effective on the instance, meaning that # all disks, ips and metadata specified in this configuration are attached # or set on the instance. EFFECTIVE = 244_201_863 # *[Default]* The default status, when no per-instance configuration # exists. NONE = 2_402_104 # The per-instance configuration is set on an instance but not been applied # yet. UNAPPLIED = 483_935_140 # The per-instance configuration has been deleted, but the deletion is not # yet applied. UNAPPLIED_DELETION = 313_956_873 end end |