Class: Google::Cloud::Compute::V1::PeriodicPartialMaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PeriodicPartialMaintenanceSchedule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)
Defined Under Namespace
Instance Attribute Summary collapse
-
#sub_type ⇒ ::String
The maintenance type in which the zone is during the given window.
-
#target_resource ⇒ ::String
The target resource that the maintenance window is for.
-
#type ⇒ ::String
Check the Type enum for the list of possible values.
-
#window_end_time ⇒ ::Google::Cloud::Compute::V1::DateTime
The end civil timestamp of the window (not inclusive).
-
#window_start_time ⇒ ::Google::Cloud::Compute::V1::DateTime
The start civil timestamp of the window.
Instance Attribute Details
#sub_type ⇒ ::String
Returns The maintenance type in which the zone is during the given window. Check the SubType enum for the list of possible values.
62244 62245 62246 62247 62248 62249 62250 62251 62252 62253 62254 62255 62256 62257 62258 62259 62260 62261 62262 62263 62264 62265 62266 62267 62268 62269 62270 62271 62272 62273 62274 62275 62276 62277 62278 62279 62280 62281 62282 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62244 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |
#target_resource ⇒ ::String
Returns The target resource that the maintenance window is for. For example, "projects/my-project/zones/us-central1-a".
62244 62245 62246 62247 62248 62249 62250 62251 62252 62253 62254 62255 62256 62257 62258 62259 62260 62261 62262 62263 62264 62265 62266 62267 62268 62269 62270 62271 62272 62273 62274 62275 62276 62277 62278 62279 62280 62281 62282 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62244 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |
#type ⇒ ::String
Returns Check the Type enum for the list of possible values.
62244 62245 62246 62247 62248 62249 62250 62251 62252 62253 62254 62255 62256 62257 62258 62259 62260 62261 62262 62263 62264 62265 62266 62267 62268 62269 62270 62271 62272 62273 62274 62275 62276 62277 62278 62279 62280 62281 62282 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62244 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |
#window_end_time ⇒ ::Google::Cloud::Compute::V1::DateTime
Returns The end civil timestamp of the window (not inclusive). This contains a time zone.
62244 62245 62246 62247 62248 62249 62250 62251 62252 62253 62254 62255 62256 62257 62258 62259 62260 62261 62262 62263 62264 62265 62266 62267 62268 62269 62270 62271 62272 62273 62274 62275 62276 62277 62278 62279 62280 62281 62282 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62244 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |
#window_start_time ⇒ ::Google::Cloud::Compute::V1::DateTime
Returns The start civil timestamp of the window. This contains a time zone.
62244 62245 62246 62247 62248 62249 62250 62251 62252 62253 62254 62255 62256 62257 62258 62259 62260 62261 62262 62263 62264 62265 62266 62267 62268 62269 62270 62271 62272 62273 62274 62275 62276 62277 62278 62279 62280 62281 62282 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62244 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |