Class: Google::Cloud::Compute::V1::PeriodicPartialMaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PeriodicPartialMaintenanceSchedule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)
Defined Under Namespace
Instance Attribute Summary collapse
-
#sub_type ⇒ ::String
The maintenance type in which the zone is during the given window.
-
#target_resource ⇒ ::String
The target resource that the maintenance window is for.
-
#type ⇒ ::String
Check the Type enum for the list of possible values.
-
#window_end_time ⇒ ::Google::Cloud::Compute::V1::DateTime
The end civil timestamp of the window (not inclusive).
-
#window_start_time ⇒ ::Google::Cloud::Compute::V1::DateTime
The start civil timestamp of the window.
Instance Attribute Details
#sub_type ⇒ ::String
Returns The maintenance type in which the zone is during the given window. Check the SubType enum for the list of possible values.
63648 63649 63650 63651 63652 63653 63654 63655 63656 63657 63658 63659 63660 63661 63662 63663 63664 63665 63666 63667 63668 63669 63670 63671 63672 63673 63674 63675 63676 63677 63678 63679 63680 63681 63682 63683 63684 63685 63686 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63648 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |
#target_resource ⇒ ::String
Returns The target resource that the maintenance window is for. For example, "projects/my-project/zones/us-central1-a".
63648 63649 63650 63651 63652 63653 63654 63655 63656 63657 63658 63659 63660 63661 63662 63663 63664 63665 63666 63667 63668 63669 63670 63671 63672 63673 63674 63675 63676 63677 63678 63679 63680 63681 63682 63683 63684 63685 63686 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63648 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |
#type ⇒ ::String
Returns Check the Type enum for the list of possible values.
63648 63649 63650 63651 63652 63653 63654 63655 63656 63657 63658 63659 63660 63661 63662 63663 63664 63665 63666 63667 63668 63669 63670 63671 63672 63673 63674 63675 63676 63677 63678 63679 63680 63681 63682 63683 63684 63685 63686 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63648 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |
#window_end_time ⇒ ::Google::Cloud::Compute::V1::DateTime
Returns The end civil timestamp of the window (not inclusive). This contains a time zone.
63648 63649 63650 63651 63652 63653 63654 63655 63656 63657 63658 63659 63660 63661 63662 63663 63664 63665 63666 63667 63668 63669 63670 63671 63672 63673 63674 63675 63676 63677 63678 63679 63680 63681 63682 63683 63684 63685 63686 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63648 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |
#window_start_time ⇒ ::Google::Cloud::Compute::V1::DateTime
Returns The start civil timestamp of the window. This contains a time zone.
63648 63649 63650 63651 63652 63653 63654 63655 63656 63657 63658 63659 63660 63661 63662 63663 63664 63665 63666 63667 63668 63669 63670 63671 63672 63673 63674 63675 63676 63677 63678 63679 63680 63681 63682 63683 63684 63685 63686 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63648 class PeriodicPartialMaintenanceSchedule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The maintenance type in which the zone is during the given window. module SubType # A value indicating that the enum field is not set. UNDEFINED_SUB_TYPE = 0 # Default value. MAINTENANCE_SUBTYPE_UNSPECIFIED = 294_853_734 # A dedicated window for customers to perform their own maintenance. This # often runs concurrently with a DISRUPTIVE_UPGRADE. MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE = 431_585_707 # For disruptive updates, including host machine kernel or firmware # upgrades. MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE = 385_079_609 # A post-maintenance window for customers to conduct final testing and # performance validation before resuming full business operations. MAINTENANCE_TYPE_STABLE = 141_316_244 # For preliminary, non-disruptive tasks such as key rotations. MAINTENANCE_TYPE_TRANSITION = 348_575_278 end module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Default value. MAINTENANCE_TYPE_UNSPECIFIED = 351_550_814 # The zone is in a private maintenance window. PRIVATE_ZONE_MAINTENANCE = 55_583_292 end end |