Class: Google::Cloud::Compute::V1::PreservedState
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PreservedState
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Preserved state for a given instance.
Defined Under Namespace
Classes: DisksEntry, ExternalIPsEntry, InternalIPsEntry, MetadataEntry
Instance Attribute Summary collapse
-
#disks ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::PreservedStatePreservedDisk}
Preserved disks defined for this instance.
-
#external_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp}
Preserved external IPs defined for this instance.
-
#internal_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp}
Preserved internal IPs defined for this instance.
-
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
Preserved metadata defined for this instance.
Instance Attribute Details
#disks ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::PreservedStatePreservedDisk}
Returns Preserved disks defined for this instance. This map is keyed with the device names of the disks.
62441 62442 62443 62444 62445 62446 62447 62448 62449 62450 62451 62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 62462 62463 62464 62465 62466 62467 62468 62469 62470 62471 62472 62473 62474 62475 62476 62477 62478 62479 62480 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62441 class PreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedDisk] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#external_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp}
Returns Preserved external IPs defined for this instance. This map is keyed with the name of the network interface.
62441 62442 62443 62444 62445 62446 62447 62448 62449 62450 62451 62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 62462 62463 62464 62465 62466 62467 62468 62469 62470 62471 62472 62473 62474 62475 62476 62477 62478 62479 62480 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62441 class PreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedDisk] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#internal_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp}
Returns Preserved internal IPs defined for this instance. This map is keyed with the name of the network interface.
62441 62442 62443 62444 62445 62446 62447 62448 62449 62450 62451 62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 62462 62463 62464 62465 62466 62467 62468 62469 62470 62471 62472 62473 62474 62475 62476 62477 62478 62479 62480 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62441 class PreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedDisk] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Preserved metadata defined for this instance.
62441 62442 62443 62444 62445 62446 62447 62448 62449 62450 62451 62452 62453 62454 62455 62456 62457 62458 62459 62460 62461 62462 62463 62464 62465 62466 62467 62468 62469 62470 62471 62472 62473 62474 62475 62476 62477 62478 62479 62480 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62441 class PreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedDisk] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |