Class: Google::Cloud::Compute::V1::PreservedStatePreservedDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: AutoDelete, Mode

Instance Attribute Summary collapse

Instance Attribute Details

#auto_delete::String

Returns These stateful disks will never be deleted during autohealing, update, instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole MIG is deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted. Check the AutoDelete enum for the list of possible values.

Returns:

  • (::String)

    These stateful disks will never be deleted during autohealing, update, instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole MIG is deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted. Check the AutoDelete enum for the list of possible values.



61825
61826
61827
61828
61829
61830
61831
61832
61833
61834
61835
61836
61837
61838
61839
61840
61841
61842
61843
61844
61845
61846
61847
61848
61849
61850
61851
61852
61853
61854
61855
61856
61857
61858
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61825

class PreservedStatePreservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These stateful disks will never be deleted during autohealing,
  # update, instance recreate operations. This flag is used to configure
  # if the disk should be deleted after it is no longer used by the group,
  # e.g. when the given instance or the whole MIG is deleted.
  # Note: disks attached in READ_ONLY mode cannot be
  # auto-deleted.
  module AutoDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_AUTO_DELETE = 0

    NEVER = 74_175_084

    ON_PERMANENT_INSTANCE_DELETION = 95_727_719
  end

  # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the
  # disk in READ_WRITE mode.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple VM instances can use
    # a disk in READ_ONLY mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in READ_WRITE mode. Only
    # one VM instance at a time can be attached to a disk inREAD_WRITE mode.
    READ_WRITE = 173_607_894
  end
end

#mode::String

Returns The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode. Check the Mode enum for the list of possible values.

Returns:

  • (::String)

    The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode. Check the Mode enum for the list of possible values.



61825
61826
61827
61828
61829
61830
61831
61832
61833
61834
61835
61836
61837
61838
61839
61840
61841
61842
61843
61844
61845
61846
61847
61848
61849
61850
61851
61852
61853
61854
61855
61856
61857
61858
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61825

class PreservedStatePreservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These stateful disks will never be deleted during autohealing,
  # update, instance recreate operations. This flag is used to configure
  # if the disk should be deleted after it is no longer used by the group,
  # e.g. when the given instance or the whole MIG is deleted.
  # Note: disks attached in READ_ONLY mode cannot be
  # auto-deleted.
  module AutoDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_AUTO_DELETE = 0

    NEVER = 74_175_084

    ON_PERMANENT_INSTANCE_DELETION = 95_727_719
  end

  # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the
  # disk in READ_WRITE mode.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple VM instances can use
    # a disk in READ_ONLY mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in READ_WRITE mode. Only
    # one VM instance at a time can be attached to a disk inREAD_WRITE mode.
    READ_WRITE = 173_607_894
  end
end

#source::String

Returns The URL of the disk resource that is stateful and should be attached to the VM instance.

Returns:

  • (::String)

    The URL of the disk resource that is stateful and should be attached to the VM instance.



61825
61826
61827
61828
61829
61830
61831
61832
61833
61834
61835
61836
61837
61838
61839
61840
61841
61842
61843
61844
61845
61846
61847
61848
61849
61850
61851
61852
61853
61854
61855
61856
61857
61858
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61825

class PreservedStatePreservedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These stateful disks will never be deleted during autohealing,
  # update, instance recreate operations. This flag is used to configure
  # if the disk should be deleted after it is no longer used by the group,
  # e.g. when the given instance or the whole MIG is deleted.
  # Note: disks attached in READ_ONLY mode cannot be
  # auto-deleted.
  module AutoDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_AUTO_DELETE = 0

    NEVER = 74_175_084

    ON_PERMANENT_INSTANCE_DELETION = 95_727_719
  end

  # The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the
  # disk in READ_WRITE mode.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # Attaches this disk in read-only mode. Multiple VM instances can use
    # a disk in READ_ONLY mode at a time.
    READ_ONLY = 91_950_261

    # *[Default]* Attaches this disk in READ_WRITE mode. Only
    # one VM instance at a time can be attached to a disk inREAD_WRITE mode.
    READ_WRITE = 173_607_894
  end
end