Class: Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: AutoDelete
Instance Attribute Summary collapse
-
#auto_delete ⇒ ::String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
-
#ip_address ⇒ ::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIpIpAddress
Ip address representation.
Instance Attribute Details
#auto_delete ⇒ ::String
Returns These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Check the AutoDelete enum for the list of possible values.
61871 61872 61873 61874 61875 61876 61877 61878 61879 61880 61881 61882 61883 61884 61885 61886 61887 61888 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61871 class PreservedStatePreservedNetworkIp include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # These stateful IPs will never be released during autohealing, # update or VM instance recreate operations. # This flag is used to configure if the IP reservation should be deleted # after it is no longer used by the group, e.g. when the given instance # or the whole group is deleted. module AutoDelete # A value indicating that the enum field is not set. UNDEFINED_AUTO_DELETE = 0 NEVER = 74_175_084 ON_PERMANENT_INSTANCE_DELETION = 95_727_719 end end |
#ip_address ⇒ ::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIpIpAddress
Returns Ip address representation.
61871 61872 61873 61874 61875 61876 61877 61878 61879 61880 61881 61882 61883 61884 61885 61886 61887 61888 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61871 class PreservedStatePreservedNetworkIp include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # These stateful IPs will never be released during autohealing, # update or VM instance recreate operations. # This flag is used to configure if the IP reservation should be deleted # after it is no longer used by the group, e.g. when the given instance # or the whole group is deleted. module AutoDelete # A value indicating that the enum field is not set. UNDEFINED_AUTO_DELETE = 0 NEVER = 74_175_084 ON_PERMANENT_INSTANCE_DELETION = 95_727_719 end end |