Class: Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIp
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: AutoDelete
Instance Attribute Summary collapse
-
#auto_delete ⇒ ::String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
-
#ip_address ⇒ ::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIpIpAddress
Ip address representation.
Instance Attribute Details
#auto_delete ⇒ ::String
Returns These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Check the AutoDelete enum for the list of possible values.
60785 60786 60787 60788 60789 60790 60791 60792 60793 60794 60795 60796 60797 60798 60799 60800 60801 60802 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60785 class PreservedStatePreservedNetworkIp include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # These stateful IPs will never be released during autohealing, # update or VM instance recreate operations. # This flag is used to configure if the IP reservation should be deleted # after it is no longer used by the group, e.g. when the given instance # or the whole group is deleted. module AutoDelete # A value indicating that the enum field is not set. UNDEFINED_AUTO_DELETE = 0 NEVER = 74_175_084 ON_PERMANENT_INSTANCE_DELETION = 95_727_719 end end |
#ip_address ⇒ ::Google::Cloud::Compute::V1::PreservedStatePreservedNetworkIpIpAddress
Returns Ip address representation.
60785 60786 60787 60788 60789 60790 60791 60792 60793 60794 60795 60796 60797 60798 60799 60800 60801 60802 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60785 class PreservedStatePreservedNetworkIp include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # These stateful IPs will never be released during autohealing, # update or VM instance recreate operations. # This flag is used to configure if the IP reservation should be deleted # after it is no longer used by the group, e.g. when the given instance # or the whole group is deleted. module AutoDelete # A value indicating that the enum field is not set. UNDEFINED_AUTO_DELETE = 0 NEVER = 74_175_084 ON_PERMANENT_INSTANCE_DELETION = 95_727_719 end end |