Class: Google::Cloud::Compute::V1::PreviewFeatureRolloutOperationRolloutInput

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents the input for the rollout operation.

Defined Under Namespace

Modules: PredefinedRolloutPlan

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns The name of the rollout plan Ex. organizations//locations/global/rolloutPlans/ Ex. folders//locations/global/rolloutPlans/ Ex. projects//locations/global/rolloutPlans/.

Returns:

  • (::String)

    The name of the rollout plan Ex. organizations//locations/global/rolloutPlans/ Ex. folders//locations/global/rolloutPlans/ Ex. projects//locations/global/rolloutPlans/.



60918
60919
60920
60921
60922
60923
60924
60925
60926
60927
60928
60929
60930
60931
60932
60933
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60918

class PreviewFeatureRolloutOperationRolloutInput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Predefined rollout plan.
  module PredefinedRolloutPlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0

    ROLLOUT_PLAN_FAST_ROLLOUT = 167_808_726

    ROLLOUT_PLAN_TWO_DAY_ROLLOUT = 349_866_771

    ROLLOUT_PLAN_UNSPECIFIED = 144_511_983
  end
end

#predefined_rollout_plan::String

Returns Predefined rollout plan. Check the PredefinedRolloutPlan enum for the list of possible values.

Returns:

  • (::String)

    Predefined rollout plan. Check the PredefinedRolloutPlan enum for the list of possible values.



60918
60919
60920
60921
60922
60923
60924
60925
60926
60927
60928
60929
60930
60931
60932
60933
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 60918

class PreviewFeatureRolloutOperationRolloutInput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Predefined rollout plan.
  module PredefinedRolloutPlan
    # A value indicating that the enum field is not set.
    UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0

    ROLLOUT_PLAN_FAST_ROLLOUT = 167_808_726

    ROLLOUT_PLAN_TWO_DAY_ROLLOUT = 349_866_771

    ROLLOUT_PLAN_UNSPECIFIED = 144_511_983
  end
end