Class: Google::Cloud::Compute::V1::PreviewFeatureRolloutOperationRolloutInput
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PreviewFeatureRolloutOperationRolloutInput
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents the input for the rollout operation.
Defined Under Namespace
Modules: PredefinedRolloutPlan
Instance Attribute Summary collapse
-
#name ⇒ ::String
The name of the rollout plan Ex.
-
#predefined_rollout_plan ⇒ ::String
Predefined rollout plan.
Instance Attribute Details
#name ⇒ ::String
Returns The name of the rollout plan Ex. organizations//locations/global/rolloutPlans/ Ex. folders//locations/global/rolloutPlans/ Ex. projects//locations/global/rolloutPlans/.
64083 64084 64085 64086 64087 64088 64089 64090 64091 64092 64093 64094 64095 64096 64097 64098 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64083 class PreviewFeatureRolloutOperationRolloutInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predefined rollout plan. module PredefinedRolloutPlan # A value indicating that the enum field is not set. UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0 ROLLOUT_PLAN_FAST_ROLLOUT = 167_808_726 ROLLOUT_PLAN_TWO_DAY_ROLLOUT = 349_866_771 ROLLOUT_PLAN_UNSPECIFIED = 144_511_983 end end |
#predefined_rollout_plan ⇒ ::String
Returns Predefined rollout plan. Check the PredefinedRolloutPlan enum for the list of possible values.
64083 64084 64085 64086 64087 64088 64089 64090 64091 64092 64093 64094 64095 64096 64097 64098 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64083 class PreviewFeatureRolloutOperationRolloutInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predefined rollout plan. module PredefinedRolloutPlan # A value indicating that the enum field is not set. UNDEFINED_PREDEFINED_ROLLOUT_PLAN = 0 ROLLOUT_PLAN_FAST_ROLLOUT = 167_808_726 ROLLOUT_PLAN_TWO_DAY_ROLLOUT = 349_866_771 ROLLOUT_PLAN_UNSPECIFIED = 144_511_983 end end |