Class: Google::Cloud::Compute::V1::PreviewFeatureStatusReleaseStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PreviewFeatureStatusReleaseStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] The release status of the feature.
Defined Under Namespace
Modules: Stage
Instance Attribute Summary collapse
-
#stage ⇒ ::String
Output only.
-
#update_date ⇒ ::Google::Cloud::Compute::V1::Date
Output only.
Instance Attribute Details
#stage ⇒ ::String
Returns Output only. [Output Only] The stage of the feature. Check the Stage enum for the list of possible values.
62718 62719 62720 62721 62722 62723 62724 62725 62726 62727 62728 62729 62730 62731 62732 62733 62734 62735 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62718 class PreviewFeatureStatusReleaseStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The stage of the feature. module Stage # A value indicating that the enum field is not set. UNDEFINED_STAGE = 0 DEPRECATED = 463_360_435 GA = 2266 PREVIEW = 399_798_184 STAGE_UNSPECIFIED = 63_695_670 end end |
#update_date ⇒ ::Google::Cloud::Compute::V1::Date
Returns Output only. The last date when a feature transitioned between ReleaseStatuses.
62718 62719 62720 62721 62722 62723 62724 62725 62726 62727 62728 62729 62730 62731 62732 62733 62734 62735 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62718 class PreviewFeatureStatusReleaseStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The stage of the feature. module Stage # A value indicating that the enum field is not set. UNDEFINED_STAGE = 0 DEPRECATED = 463_360_435 GA = 2266 PREVIEW = 399_798_184 STAGE_UNSPECIFIED = 63_695_670 end end |