Class: Google::Cloud::Compute::V1::PreviewFeatureStatusReleaseStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] The release status of the feature.

Defined Under Namespace

Modules: Stage

Instance Attribute Summary collapse

Instance Attribute Details

#stage::String

Returns Output only. [Output Only] The stage of the feature. Check the Stage enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The stage of the feature. Check the Stage enum for the list of possible values.



62043
62044
62045
62046
62047
62048
62049
62050
62051
62052
62053
62054
62055
62056
62057
62058
62059
62060
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62043

class PreviewFeatureStatusReleaseStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The stage of the feature.
  module Stage
    # A value indicating that the enum field is not set.
    UNDEFINED_STAGE = 0

    DEPRECATED = 463_360_435

    GA = 2266

    PREVIEW = 399_798_184

    STAGE_UNSPECIFIED = 63_695_670
  end
end

#update_date::Google::Cloud::Compute::V1::Date

Returns Output only. The last date when a feature transitioned between ReleaseStatuses.

Returns:



62043
62044
62045
62046
62047
62048
62049
62050
62051
62052
62053
62054
62055
62056
62057
62058
62059
62060
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62043

class PreviewFeatureStatusReleaseStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The stage of the feature.
  module Stage
    # A value indicating that the enum field is not set.
    UNDEFINED_STAGE = 0

    DEPRECATED = 463_360_435

    GA = 2266

    PREVIEW = 399_798_184

    STAGE_UNSPECIFIED = 63_695_670
  end
end