Class: Google::Cloud::Compute::V1::PreviewFeatureStatusReleaseStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PreviewFeatureStatusReleaseStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] The release status of the feature.
Defined Under Namespace
Modules: Stage
Instance Attribute Summary collapse
-
#stage ⇒ ::String
Output only.
-
#update_date ⇒ ::Google::Cloud::Compute::V1::Date
Output only.
Instance Attribute Details
#stage ⇒ ::String
Returns Output only. [Output Only] The stage of the feature. Check the Stage enum for the list of possible values.
64122 64123 64124 64125 64126 64127 64128 64129 64130 64131 64132 64133 64134 64135 64136 64137 64138 64139 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64122 class PreviewFeatureStatusReleaseStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The stage of the feature. module Stage # A value indicating that the enum field is not set. UNDEFINED_STAGE = 0 DEPRECATED = 463_360_435 GA = 2266 PREVIEW = 399_798_184 STAGE_UNSPECIFIED = 63_695_670 end end |
#update_date ⇒ ::Google::Cloud::Compute::V1::Date
Returns Output only. The last date when a feature transitioned between ReleaseStatuses.
64122 64123 64124 64125 64126 64127 64128 64129 64130 64131 64132 64133 64134 64135 64136 64137 64138 64139 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64122 class PreviewFeatureStatusReleaseStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The stage of the feature. module Stage # A value indicating that the enum field is not set. UNDEFINED_STAGE = 0 DEPRECATED = 463_360_435 GA = 2266 PREVIEW = 399_798_184 STAGE_UNSPECIFIED = 63_695_670 end end |