Class: Google::Cloud::Compute::V1::Project

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Project resource.

A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.

Defined Under Namespace

Modules: CloudArmorTier, DefaultNetworkTier, VmDnsSetting, XpnProjectStatus

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_armor_tier::String

Returns Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.

If this field is not specified, it is assumed to beCA_STANDARD. Check the CloudArmorTier enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.

    If this field is not specified, it is assumed to beCA_STANDARD. Check the CloudArmorTier enum for the list of possible values.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#common_instance_metadata::Google::Cloud::Compute::V1::Metadata

Returns Metadata key/value pairs available to all instances contained in this project. See Custom metadata for more information.

Returns:



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#creation_timestamp::String

Returns [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    [Output Only] Creation timestamp inRFC3339 text format.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#default_network_tier::String

Returns This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Check the DefaultNetworkTier enum for the list of possible values.

Returns:

  • (::String)

    This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Check the DefaultNetworkTier enum for the list of possible values.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#default_service_account::String

Returns [Output Only] Default service account used by VMs running in this project.

Returns:

  • (::String)

    [Output Only] Default service account used by VMs running in this project.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#description::String

Returns An optional textual description of the resource.

Returns:

  • (::String)

    An optional textual description of the resource.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#enabled_features::Array<::String>

Returns An optional list of restricted features enabled for use on this project.

Returns:

  • (::Array<::String>)

    An optional list of restricted features enabled for use on this project.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#id::Integer

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources.

Returns:

  • (::Integer)

    [Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Always compute#project for projects.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Always compute#project for projects.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#name::String

Returns The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine.

Returns:

  • (::String)

    The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#quotas::Array<::Google::Cloud::Compute::V1::Quota>

Returns [Output Only] Quotas assigned to this project.

Returns:



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for the resource.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#usage_export_location::Google::Cloud::Compute::V1::UsageExportLocation

Returns An optional naming prefix for daily usage reports and the Google Cloud Storage bucket where they are stored.

Returns:



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#vm_dns_setting::String

Returns Output only. [Output Only] Default internal DNS setting used by VMs running in this project. Check the VmDnsSetting enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] Default internal DNS setting used by VMs running in this project. Check the VmDnsSetting enum for the list of possible values.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end

#xpn_project_status::String

Returns [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Check the XpnProjectStatus enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Check the XpnProjectStatus enum for the list of possible values.



61064
61065
61066
61067
61068
61069
61070
61071
61072
61073
61074
61075
61076
61077
61078
61079
61080
61081
61082
61083
61084
61085
61086
61087
61088
61089
61090
61091
61092
61093
61094
61095
61096
61097
61098
61099
61100
61101
61102
61103
61104
61105
61106
61107
61108
61109
61110
61111
61112
61113
61114
61115
61116
61117
61118
61119
61120
61121
61122
61123
61124
61125
61126
61127
61128
61129
61130
61131
61132
61133
61134
61135
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61064

class Project
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the
  # following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
  #
  # If this field is not specified, it is assumed to beCA_STANDARD.
  module CloudArmorTier
    # A value indicating that the enum field is not set.
    UNDEFINED_CLOUD_ARMOR_TIER = 0

    # Enterprise tier protection billed annually.
    CA_ENTERPRISE_ANNUAL = 219_921_116

    # Enterprise tier protection billed monthly.
    CA_ENTERPRISE_PAYGO = 453_530_323

    # Standard protection.
    CA_STANDARD = 13_156_734
  end

  # This signifies the default network tier used for configuring resources of
  # the project and can only take the following values:PREMIUM, STANDARD. Initially the default network
  # tier is PREMIUM.
  module DefaultNetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_DEFAULT_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking
    # products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking
    # products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier
    # is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end

  # Output only. [Output Only] Default internal DNS setting used by VMs running in
  # this project.
  module VmDnsSetting
    # A value indicating that the enum field is not set.
    UNDEFINED_VM_DNS_SETTING = 0

    GLOBAL_DEFAULT = 345_419_141

    UNSPECIFIED_VM_DNS_SETTING = 35_691_930

    ZONAL_DEFAULT = 368_475_782

    ZONAL_ONLY = 521_198_951
  end

  # [Output Only] The role this project has in a shared VPC configuration.
  # Currently, only projects with the host role, which is specified by the
  # value HOST, are differentiated.
  module XpnProjectStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_XPN_PROJECT_STATUS = 0

    HOST = 2_223_528

    UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257
  end
end