Class: Google::Cloud::Compute::V1::Project
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Project
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.
Defined Under Namespace
Modules: CloudArmorTier, DefaultNetworkTier, VmDnsSetting, XpnProjectStatus
Instance Attribute Summary collapse
-
#cloud_armor_tier ⇒ ::String
[Output Only] The Cloud Armor tier for this project.
-
#common_instance_metadata ⇒ ::Google::Cloud::Compute::V1::Metadata
Metadata key/value pairs available to all instances contained in this project.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#default_network_tier ⇒ ::String
This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD.
-
#default_service_account ⇒ ::String
[Output Only] Default service account used by VMs running in this project.
-
#description ⇒ ::String
An optional textual description of the resource.
-
#enabled_features ⇒ ::Array<::String>
An optional list of restricted features enabled for use on this project.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
[Output Only] Type of the resource.
-
#name ⇒ ::String
The project ID.
-
#quotas ⇒ ::Array<::Google::Cloud::Compute::V1::Quota>
[Output Only] Quotas assigned to this project.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#usage_export_location ⇒ ::Google::Cloud::Compute::V1::UsageExportLocation
An optional naming prefix for daily usage reports and the Google Cloud Storage bucket where they are stored.
-
#vm_dns_setting ⇒ ::String
[Output Only] Default internal DNS setting used by VMs running in this project.
-
#xpn_project_status ⇒ ::String
[Output Only] The role this project has in a shared VPC configuration.
Instance Attribute Details
#cloud_armor_tier ⇒ ::String
Returns [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. Check the CloudArmorTier enum for the list of possible values.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#common_instance_metadata ⇒ ::Google::Cloud::Compute::V1::Metadata
Returns Metadata key/value pairs available to all instances contained in this project. See Custom metadata for more information.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#creation_timestamp ⇒ ::String
Returns [Output Only] Creation timestamp in RFC3339 text format.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#default_network_tier ⇒ ::String
Returns This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Check the DefaultNetworkTier enum for the list of possible values.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#default_service_account ⇒ ::String
Returns [Output Only] Default service account used by VMs running in this project.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#description ⇒ ::String
Returns An optional textual description of the resource.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#enabled_features ⇒ ::Array<::String>
Returns An optional list of restricted features enabled for use on this project.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#kind ⇒ ::String
Returns [Output Only] Type of the resource. Always compute#project for projects.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#name ⇒ ::String
Returns The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#quotas ⇒ ::Array<::Google::Cloud::Compute::V1::Quota>
Returns [Output Only] Quotas assigned to this project.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#usage_export_location ⇒ ::Google::Cloud::Compute::V1::UsageExportLocation
Returns An optional naming prefix for daily usage reports and the Google Cloud Storage bucket where they are stored.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#vm_dns_setting ⇒ ::String
Returns [Output Only] Default internal DNS setting used by VMs running in this project. Check the VmDnsSetting enum for the list of possible values.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |
#xpn_project_status ⇒ ::String
Returns [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Check the XpnProjectStatus enum for the list of possible values.
25400 25401 25402 25403 25404 25405 25406 25407 25408 25409 25410 25411 25412 25413 25414 25415 25416 25417 25418 25419 25420 25421 25422 25423 25424 25425 25426 25427 25428 25429 25430 25431 25432 25433 25434 25435 25436 25437 25438 25439 25440 25441 25442 25443 25444 25445 25446 25447 25448 25449 25450 25451 25452 25453 25454 25455 25456 25457 25458 25459 25460 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25400 class Project include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to be CA_STANDARD. module CloudArmorTier # A value indicating that the enum field is not set. UNDEFINED_CLOUD_ARMOR_TIER = 0 # Enterprise tier protection billed annually. CA_ENTERPRISE_ANNUAL = 219_921_116 # Enterprise tier protection billed monthly. CA_ENTERPRISE_PAYGO = 453_530_323 # Standard protection. CA_STANDARD = 13_156_734 end # This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM. module DefaultNetworkTier # A value indicating that the enum field is not set. UNDEFINED_DEFAULT_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end # [Output Only] Default internal DNS setting used by VMs running in this project. module VmDnsSetting # A value indicating that the enum field is not set. UNDEFINED_VM_DNS_SETTING = 0 GLOBAL_DEFAULT = 345_419_141 UNSPECIFIED_VM_DNS_SETTING = 35_691_930 ZONAL_DEFAULT = 368_475_782 ZONAL_ONLY = 521_198_951 end # [Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. module XpnProjectStatus # A value indicating that the enum field is not set. UNDEFINED_XPN_PROJECT_STATUS = 0 HOST = 2_223_528 UNSPECIFIED_XPN_PROJECT_STATUS = 340_393_257 end end |