Module: Google::Cloud::Compute::V1::Project::CloudArmorTier
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
If this field is not specified, it is assumed to beCA_STANDARD.
Constant Summary collapse
- UNDEFINED_CLOUD_ARMOR_TIER =
A value indicating that the enum field is not set.
0- CA_ENTERPRISE_ANNUAL =
Enterprise tier protection billed annually.
219_921_116- CA_ENTERPRISE_PAYGO =
Enterprise tier protection billed monthly.
453_530_323- CA_STANDARD =
Standard protection.
13_156_734