Class: Google::Cloud::Compute::V1::ProjectsListXpnHostsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ProjectsListXpnHostsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#organization ⇒ ::String
Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects.
Instance Attribute Details
#organization ⇒ ::String
Returns Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project.
62264 62265 62266 62267 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62264 class ProjectsListXpnHostsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |