Class: Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: NetworkTier
Instance Attribute Summary collapse
-
#network_tier ⇒ ::String
Default network tier to be set.
Instance Attribute Details
#network_tier ⇒ ::String
Returns Default network tier to be set. Check the NetworkTier enum for the list of possible values.
62972 62973 62974 62975 62976 62977 62978 62979 62980 62981 62982 62983 62984 62985 62986 62987 62988 62989 62990 62991 62992 62993 62994 62995 62996 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62972 class ProjectsSetDefaultNetworkTierRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Default network tier to be set. module NetworkTier # A value indicating that the enum field is not set. UNDEFINED_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking # products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking # products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier # is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end end |