Class: Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: NetworkTier
Instance Attribute Summary collapse
-
#network_tier ⇒ ::String
Default network tier to be set.
Instance Attribute Details
#network_tier ⇒ ::String
Returns Default network tier to be set. Check the NetworkTier enum for the list of possible values.
62297 62298 62299 62300 62301 62302 62303 62304 62305 62306 62307 62308 62309 62310 62311 62312 62313 62314 62315 62316 62317 62318 62319 62320 62321 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62297 class ProjectsSetDefaultNetworkTierRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Default network tier to be set. module NetworkTier # A value indicating that the enum field is not set. UNDEFINED_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking # products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking # products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier # is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end end |