Class: Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: NetworkTier
Instance Attribute Summary collapse
-
#network_tier ⇒ ::String
Default network tier to be set.
Instance Attribute Details
#network_tier ⇒ ::String
Returns Default network tier to be set. Check the NetworkTier enum for the list of possible values.
61211 61212 61213 61214 61215 61216 61217 61218 61219 61220 61221 61222 61223 61224 61225 61226 61227 61228 61229 61230 61231 61232 61233 61234 61235 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 61211 class ProjectsSetDefaultNetworkTierRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Default network tier to be set. module NetworkTier # A value indicating that the enum field is not set. UNDEFINED_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310_464_328 # High quality, Google-grade network tier, support for all networking # products. PREMIUM = 399_530_551 # Public internet quality, only limited support for other networking # products. STANDARD = 484_642_493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier # is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234 end end |