Class: Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: NetworkTier

Instance Attribute Summary collapse

Instance Attribute Details

#network_tier::String

Returns Default network tier to be set. Check the NetworkTier enum for the list of possible values.

Returns:

  • (::String)

    Default network tier to be set. Check the NetworkTier enum for the list of possible values.



25806
25807
25808
25809
25810
25811
25812
25813
25814
25815
25816
25817
25818
25819
25820
25821
25822
25823
25824
25825
25826
25827
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25806

class ProjectsSetDefaultNetworkTierRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Default network tier to be set.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end
end