Class: Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: NetworkTier

Instance Attribute Summary collapse

Instance Attribute Details

#network_tier::String

Returns Default network tier to be set. Check the NetworkTier enum for the list of possible values.

Returns:

  • (::String)

    Default network tier to be set. Check the NetworkTier enum for the list of possible values.



25498
25499
25500
25501
25502
25503
25504
25505
25506
25507
25508
25509
25510
25511
25512
25513
25514
25515
25516
25517
25518
25519
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 25498

class ProjectsSetDefaultNetworkTierRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Default network tier to be set.
  module NetworkTier
    # A value indicating that the enum field is not set.
    UNDEFINED_NETWORK_TIER = 0

    # Public internet quality with fixed bandwidth.
    FIXED_STANDARD = 310_464_328

    # High quality, Google-grade network tier, support for all networking products.
    PREMIUM = 399_530_551

    # Public internet quality, only limited support for other networking products.
    STANDARD = 484_642_493

    # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured.
    STANDARD_OVERRIDES_FIXED_STANDARD = 465_847_234
  end
end