Class: Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ProjectsSetDefaultNetworkTierRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: NetworkTier
Instance Attribute Summary collapse
-
#network_tier ⇒ ::String
Default network tier to be set.
Instance Attribute Details
#network_tier ⇒ ::String
Returns Default network tier to be set. Check the NetworkTier enum for the list of possible values.
21251 21252 21253 21254 21255 21256 21257 21258 21259 21260 21261 21262 21263 21264 21265 21266 21267 21268 21269 21270 21271 21272 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 21251 class ProjectsSetDefaultNetworkTierRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Default network tier to be set. module NetworkTier # A value indicating that the enum field is not set. UNDEFINED_NETWORK_TIER = 0 # Public internet quality with fixed bandwidth. FIXED_STANDARD = 310464328 # High quality, Google-grade network tier, support for all networking products. PREMIUM = 399530551 # Public internet quality, only limited support for other networking products. STANDARD = 484642493 # (Output only) Temporary tier for FIXED_STANDARD when fixed standard tier is expired or not configured. STANDARD_OVERRIDES_FIXED_STANDARD = 465847234 end end |