Class: Google::Cloud::Compute::V1::PublicDelegatedPrefixAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::PublicDelegatedPrefixAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::PublicDelegatedPrefixesScopedList}
A list of PublicDelegatedPrefixesScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
64898 64899 64900 64901 64902 64903 64904 64905 64906 64907 64908 64909 64910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64898 class PublicDelegatedPrefixAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PublicDelegatedPrefixesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::PublicDelegatedPrefixesScopedList}
Returns A list of PublicDelegatedPrefixesScopedList resources.
64898 64899 64900 64901 64902 64903 64904 64905 64906 64907 64908 64909 64910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64898 class PublicDelegatedPrefixAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PublicDelegatedPrefixesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes.
64898 64899 64900 64901 64902 64903 64904 64905 64906 64907 64908 64909 64910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64898 class PublicDelegatedPrefixAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PublicDelegatedPrefixesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
64898 64899 64900 64901 64902 64903 64904 64905 64906 64907 64908 64909 64910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64898 class PublicDelegatedPrefixAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PublicDelegatedPrefixesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for this resource.
64898 64899 64900 64901 64902 64903 64904 64905 64906 64907 64908 64909 64910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64898 class PublicDelegatedPrefixAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PublicDelegatedPrefixesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
64898 64899 64900 64901 64902 64903 64904 64905 64906 64907 64908 64909 64910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64898 class PublicDelegatedPrefixAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PublicDelegatedPrefixesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
64898 64899 64900 64901 64902 64903 64904 64905 64906 64907 64908 64909 64910 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64898 class PublicDelegatedPrefixAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::PublicDelegatedPrefixesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |