Class: Google::Cloud::Compute::V1::PublicDelegatedPrefixPublicDelegatedSubPrefix

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a sub PublicDelegatedPrefix.

Defined Under Namespace

Modules: Ipv6AccessType, Mode, Status

Instance Attribute Summary collapse

Instance Attribute Details

#allocatable_prefix_length::Integer

Returns The allocatable prefix length supported by this PublicDelegatedSubPrefix.

Returns:

  • (::Integer)

    The allocatable prefix length supported by this PublicDelegatedSubPrefix.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#delegatee_project::String

Returns Name of the project scoping this PublicDelegatedSubPrefix.

Returns:

  • (::String)

    Name of the project scoping this PublicDelegatedSubPrefix.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#enable_enhanced_ipv4_allocation::Boolean

Returns Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only.

Returns:

  • (::Boolean)

    Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#ip_cidr_range::String

Returns The IP address range, in CIDR format, represented by this sub public delegated prefix.

Returns:

  • (::String)

    The IP address range, in CIDR format, represented by this sub public delegated prefix.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#ipv6_access_type::String

Returns Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub Prefixes. Inherited from parent prefix. Check the Ipv6AccessType enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub Prefixes. Inherited from parent prefix. Check the Ipv6AccessType enum for the list of possible values.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#is_address::Boolean

Returns Whether the sub prefix is delegated to create Address resources in the delegatee project.

Returns:

  • (::Boolean)

    Whether the sub prefix is delegated to create Address resources in the delegatee project.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#mode::String

Returns The PublicDelegatedSubPrefix mode for IPv6 only. Check the Mode enum for the list of possible values.

Returns:

  • (::String)

    The PublicDelegatedSubPrefix mode for IPv6 only. Check the Mode enum for the list of possible values.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#name::String

Returns The name of the sub public delegated prefix.

Returns:

  • (::String)

    The name of the sub public delegated prefix.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#region::String

Returns Output only. [Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global.

Returns:

  • (::String)

    Output only. [Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end

#status::String

Returns Output only. [Output Only] The status of the sub public delegated prefix. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The status of the sub public delegated prefix. Check the Status enum for the list of possible values.



62887
62888
62889
62890
62891
62892
62893
62894
62895
62896
62897
62898
62899
62900
62901
62902
62903
62904
62905
62906
62907
62908
62909
62910
62911
62912
62913
62914
62915
62916
62917
62918
62919
62920
62921
62922
62923
62924
62925
62926
62927
62928
62929
62930
62931
62932
62933
62934
62935
62936
62937
62938
62939
62940
62941
62942
62943
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62887

class PublicDelegatedPrefixPublicDelegatedSubPrefix
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub
  # Prefixes. Inherited from parent prefix.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # The parent public advertised prefix will be announced to the internet.
    # All children public delegated prefixes will have IPv6 access type as
    # EXTERNAL.
    EXTERNAL = 35_607_499

    # The parent public advertised prefix will not be announced to the
    # internet. Prefix will be used privately within Cloud. All children
    # public delegated prefixes will have IPv6 access type as INTERNAL.
    INTERNAL = 279_295_677
  end

  # The PublicDelegatedSubPrefix mode for IPv6 only.
  module Mode
    # A value indicating that the enum field is not set.
    UNDEFINED_MODE = 0

    # The public delegated prefix is used for further sub-delegation only. Such
    # prefixes cannot set allocatablePrefixLength.
    DELEGATION = 264_149_288

    # The public delegated prefix is used for creating forwarding rules only.
    # Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_FORWARDING_RULE_CREATION = 398_684_356

    # The public delegated prefix is used for creating dual-mode subnetworks
    # only. Such prefixes cannot set publicDelegatedSubPrefixes. Parent public
    # delegated prefix must have IPv6 access type as EXTERNAL.
    EXTERNAL_IPV6_SUBNETWORK_CREATION = 61_198_284

    # The public delegated prefix is used for creating dual stack or IPv6-only
    # subnetwork with internal access only. Such prefixes cannot set
    # publicDelegatedSubPrefixes and allocatablePrefixLength. Parent public
    # delegated prefix must have IPv6 access type as INTERNAL.
    INTERNAL_IPV6_SUBNETWORK_CREATION = 153_239_834
  end

  # Output only. [Output Only] The status of the sub public delegated prefix.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    ACTIVE = 314_733_318

    INACTIVE = 270_421_099
  end
end