Class: Google::Cloud::Compute::V1::QuotaExceededInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Additional details for quota exceeded error for resource quota.

Defined Under Namespace

Modules: RolloutStatus Classes: DimensionsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#dimensions::Google::Protobuf::Map{::String => ::String}

Returns The map holding related quota dimensions.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    The map holding related quota dimensions.



64010
64011
64012
64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
64029
64030
64031
64032
64033
64034
64035
64036
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64010

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#future_limit::Float

Returns Future quota limit being rolled out. The limit's unit depends on the quota type or metric.

Returns:

  • (::Float)

    Future quota limit being rolled out. The limit's unit depends on the quota type or metric.



64010
64011
64012
64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
64029
64030
64031
64032
64033
64034
64035
64036
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64010

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#limit::Float

Returns Current effective quota limit. The limit's unit depends on the quota type or metric.

Returns:

  • (::Float)

    Current effective quota limit. The limit's unit depends on the quota type or metric.



64010
64011
64012
64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
64029
64030
64031
64032
64033
64034
64035
64036
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64010

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#limit_name::String

Returns The name of the quota limit.

Returns:

  • (::String)

    The name of the quota limit.



64010
64011
64012
64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
64029
64030
64031
64032
64033
64034
64035
64036
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64010

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#metric_name::String

Returns The Compute Engine quota metric name.

Returns:

  • (::String)

    The Compute Engine quota metric name.



64010
64011
64012
64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
64029
64030
64031
64032
64033
64034
64035
64036
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64010

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#rollout_status::String

Returns Rollout status of the future quota limit. Check the RolloutStatus enum for the list of possible values.

Returns:

  • (::String)

    Rollout status of the future quota limit. Check the RolloutStatus enum for the list of possible values.



64010
64011
64012
64013
64014
64015
64016
64017
64018
64019
64020
64021
64022
64023
64024
64025
64026
64027
64028
64029
64030
64031
64032
64033
64034
64035
64036
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64010

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end