Class: Google::Cloud::Compute::V1::QuotaExceededInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Additional details for quota exceeded error for resource quota.

Defined Under Namespace

Modules: RolloutStatus Classes: DimensionsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#dimensions::Google::Protobuf::Map{::String => ::String}

Returns The map holding related quota dimensions.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    The map holding related quota dimensions.



62249
62250
62251
62252
62253
62254
62255
62256
62257
62258
62259
62260
62261
62262
62263
62264
62265
62266
62267
62268
62269
62270
62271
62272
62273
62274
62275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62249

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#future_limit::Float

Returns Future quota limit being rolled out. The limit's unit depends on the quota type or metric.

Returns:

  • (::Float)

    Future quota limit being rolled out. The limit's unit depends on the quota type or metric.



62249
62250
62251
62252
62253
62254
62255
62256
62257
62258
62259
62260
62261
62262
62263
62264
62265
62266
62267
62268
62269
62270
62271
62272
62273
62274
62275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62249

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#limit::Float

Returns Current effective quota limit. The limit's unit depends on the quota type or metric.

Returns:

  • (::Float)

    Current effective quota limit. The limit's unit depends on the quota type or metric.



62249
62250
62251
62252
62253
62254
62255
62256
62257
62258
62259
62260
62261
62262
62263
62264
62265
62266
62267
62268
62269
62270
62271
62272
62273
62274
62275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62249

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#limit_name::String

Returns The name of the quota limit.

Returns:

  • (::String)

    The name of the quota limit.



62249
62250
62251
62252
62253
62254
62255
62256
62257
62258
62259
62260
62261
62262
62263
62264
62265
62266
62267
62268
62269
62270
62271
62272
62273
62274
62275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62249

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#metric_name::String

Returns The Compute Engine quota metric name.

Returns:

  • (::String)

    The Compute Engine quota metric name.



62249
62250
62251
62252
62253
62254
62255
62256
62257
62258
62259
62260
62261
62262
62263
62264
62265
62266
62267
62268
62269
62270
62271
62272
62273
62274
62275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62249

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end

#rollout_status::String

Returns Rollout status of the future quota limit. Check the RolloutStatus enum for the list of possible values.

Returns:

  • (::String)

    Rollout status of the future quota limit. Check the RolloutStatus enum for the list of possible values.



62249
62250
62251
62252
62253
62254
62255
62256
62257
62258
62259
62260
62261
62262
62263
62264
62265
62266
62267
62268
62269
62270
62271
62272
62273
62274
62275
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62249

class QuotaExceededInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Rollout status of the future quota limit.
  module RolloutStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLLOUT_STATUS = 0

    # IN_PROGRESS - A rollout is in process which will change the limit value
    # to future limit.
    IN_PROGRESS = 469_193_735

    # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default
    # value.
    ROLLOUT_STATUS_UNSPECIFIED = 26_864_568
  end
end