Class: Google::Cloud::Compute::V1::QuotaExceededInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::QuotaExceededInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Additional details for quota exceeded error for resource quota.
Defined Under Namespace
Modules: RolloutStatus Classes: DimensionsEntry
Instance Attribute Summary collapse
-
#dimensions ⇒ ::Google::Protobuf::Map{::String => ::String}
The map holding related quota dimensions.
-
#future_limit ⇒ ::Float
Future quota limit being rolled out.
-
#limit ⇒ ::Float
Current effective quota limit.
-
#limit_name ⇒ ::String
The name of the quota limit.
-
#metric_name ⇒ ::String
The Compute Engine quota metric name.
-
#rollout_status ⇒ ::String
Rollout status of the future quota limit.
Instance Attribute Details
#dimensions ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The map holding related quota dimensions.
65431 65432 65433 65434 65435 65436 65437 65438 65439 65440 65441 65442 65443 65444 65445 65446 65447 65448 65449 65450 65451 65452 65453 65454 65455 65456 65457 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65431 class QuotaExceededInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DimensionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Rollout status of the future quota limit. module RolloutStatus # A value indicating that the enum field is not set. UNDEFINED_ROLLOUT_STATUS = 0 # IN_PROGRESS - A rollout is in process which will change the limit value # to future limit. IN_PROGRESS = 469_193_735 # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default # value. ROLLOUT_STATUS_UNSPECIFIED = 26_864_568 end end |
#future_limit ⇒ ::Float
Returns Future quota limit being rolled out. The limit's unit depends on the quota type or metric.
65431 65432 65433 65434 65435 65436 65437 65438 65439 65440 65441 65442 65443 65444 65445 65446 65447 65448 65449 65450 65451 65452 65453 65454 65455 65456 65457 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65431 class QuotaExceededInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DimensionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Rollout status of the future quota limit. module RolloutStatus # A value indicating that the enum field is not set. UNDEFINED_ROLLOUT_STATUS = 0 # IN_PROGRESS - A rollout is in process which will change the limit value # to future limit. IN_PROGRESS = 469_193_735 # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default # value. ROLLOUT_STATUS_UNSPECIFIED = 26_864_568 end end |
#limit ⇒ ::Float
Returns Current effective quota limit. The limit's unit depends on the quota type or metric.
65431 65432 65433 65434 65435 65436 65437 65438 65439 65440 65441 65442 65443 65444 65445 65446 65447 65448 65449 65450 65451 65452 65453 65454 65455 65456 65457 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65431 class QuotaExceededInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DimensionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Rollout status of the future quota limit. module RolloutStatus # A value indicating that the enum field is not set. UNDEFINED_ROLLOUT_STATUS = 0 # IN_PROGRESS - A rollout is in process which will change the limit value # to future limit. IN_PROGRESS = 469_193_735 # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default # value. ROLLOUT_STATUS_UNSPECIFIED = 26_864_568 end end |
#limit_name ⇒ ::String
Returns The name of the quota limit.
65431 65432 65433 65434 65435 65436 65437 65438 65439 65440 65441 65442 65443 65444 65445 65446 65447 65448 65449 65450 65451 65452 65453 65454 65455 65456 65457 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65431 class QuotaExceededInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DimensionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Rollout status of the future quota limit. module RolloutStatus # A value indicating that the enum field is not set. UNDEFINED_ROLLOUT_STATUS = 0 # IN_PROGRESS - A rollout is in process which will change the limit value # to future limit. IN_PROGRESS = 469_193_735 # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default # value. ROLLOUT_STATUS_UNSPECIFIED = 26_864_568 end end |
#metric_name ⇒ ::String
Returns The Compute Engine quota metric name.
65431 65432 65433 65434 65435 65436 65437 65438 65439 65440 65441 65442 65443 65444 65445 65446 65447 65448 65449 65450 65451 65452 65453 65454 65455 65456 65457 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65431 class QuotaExceededInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DimensionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Rollout status of the future quota limit. module RolloutStatus # A value indicating that the enum field is not set. UNDEFINED_ROLLOUT_STATUS = 0 # IN_PROGRESS - A rollout is in process which will change the limit value # to future limit. IN_PROGRESS = 469_193_735 # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default # value. ROLLOUT_STATUS_UNSPECIFIED = 26_864_568 end end |
#rollout_status ⇒ ::String
Returns Rollout status of the future quota limit. Check the RolloutStatus enum for the list of possible values.
65431 65432 65433 65434 65435 65436 65437 65438 65439 65440 65441 65442 65443 65444 65445 65446 65447 65448 65449 65450 65451 65452 65453 65454 65455 65456 65457 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65431 class QuotaExceededInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DimensionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Rollout status of the future quota limit. module RolloutStatus # A value indicating that the enum field is not set. UNDEFINED_ROLLOUT_STATUS = 0 # IN_PROGRESS - A rollout is in process which will change the limit value # to future limit. IN_PROGRESS = 469_193_735 # ROLLOUT_STATUS_UNSPECIFIED - Rollout status is not specified. The default # value. ROLLOUT_STATUS_UNSPECIFIED = 26_864_568 end end |