Class: Google::Cloud::Compute::V1::RawDisk
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RawDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The parameters of the raw disk image.
Defined Under Namespace
Modules: ContainerType
Instance Attribute Summary collapse
-
#container_type ⇒ ::String
The format used to encode and transmit the block device, which should beTAR.
-
#sha1_checksum ⇒ ::String
[Deprecated] This field is deprecated.
-
#source ⇒ ::String
The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored.
Instance Attribute Details
#container_type ⇒ ::String
Returns The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created. Check the ContainerType enum for the list of possible values.
64206 64207 64208 64209 64210 64211 64212 64213 64214 64215 64216 64217 64218 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64206 class RawDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not # a runtime format. Provided by the client when the disk image is created. module ContainerType # A value indicating that the enum field is not set. UNDEFINED_CONTAINER_TYPE = 0 TAR = 82_821 end end |
#sha1_checksum ⇒ ::String
Returns [Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created.
64206 64207 64208 64209 64210 64211 64212 64213 64214 64215 64216 64217 64218 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64206 class RawDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not # a runtime format. Provided by the client when the disk image is created. module ContainerType # A value indicating that the enum field is not set. UNDEFINED_CONTAINER_TYPE = 0 TAR = 82_821 end end |
#source ⇒ ::String
Returns The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:
- https://storage.googleapis.com/bucket_name/image_archive_name
- https://storage.googleapis.com/bucket_name/folder_name/image_archive_name
- projects/project/locations/location/repositories/repo/packages/package/versions/version_id
- projects/project/locations/location/repositories/repo/packages/package/versions/version_id@dirsum_sha256:hex_value
In order to create an image, you must provide the full or partial URL of one of the following:
- The rawDisk.source URL
- The sourceDisk URL
- The sourceImage URL
- The sourceSnapshot URL.
64206 64207 64208 64209 64210 64211 64212 64213 64214 64215 64216 64217 64218 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64206 class RawDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not # a runtime format. Provided by the client when the disk image is created. module ContainerType # A value indicating that the enum field is not set. UNDEFINED_CONTAINER_TYPE = 0 TAR = 82_821 end end |