Class: Google::Cloud::Compute::V1::RawDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The parameters of the raw disk image.

Defined Under Namespace

Modules: ContainerType

Instance Attribute Summary collapse

Instance Attribute Details

#container_type::String

Returns The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created. Check the ContainerType enum for the list of possible values.

Returns:

  • (::String)

    The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created. Check the ContainerType enum for the list of possible values.



62445
62446
62447
62448
62449
62450
62451
62452
62453
62454
62455
62456
62457
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62445

class RawDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not
  # a runtime format. Provided by the client when the disk image is created.
  module ContainerType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTAINER_TYPE = 0

    TAR = 82_821
  end
end

#sha1_checksum::String

Returns [Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created.

Returns:

  • (::String)

    [Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created.



62445
62446
62447
62448
62449
62450
62451
62452
62453
62454
62455
62456
62457
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62445

class RawDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not
  # a runtime format. Provided by the client when the disk image is created.
  module ContainerType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTAINER_TYPE = 0

    TAR = 82_821
  end
end

#source::String

Returns The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:

In order to create an image, you must provide the full or partial URL of one of the following:

  • The rawDisk.source URL
  • The sourceDisk URL
  • The sourceImage URL
  • The sourceSnapshot URL.

Returns:

  • (::String)

    The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:

    In order to create an image, you must provide the full or partial URL of one of the following:

    • The rawDisk.source URL
    • The sourceDisk URL
    • The sourceImage URL
    • The sourceSnapshot URL


62445
62446
62447
62448
62449
62450
62451
62452
62453
62454
62455
62456
62457
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62445

class RawDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not
  # a runtime format. Provided by the client when the disk image is created.
  module ContainerType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONTAINER_TYPE = 0

    TAR = 82_821
  end
end