Class: Google::Cloud::Compute::V1::RegexRewrite
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RegexRewrite
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The spec for modifying the path using a regular expression.
Instance Attribute Summary collapse
-
#path_pattern ⇒ ::String
Required.
-
#path_substitution ⇒ ::String
Required.
Instance Attribute Details
#path_pattern ⇒ ::String
Returns Required. The regular expression used to match against the URL path. It uses RE2 syntax with the following constraints:
- Any single character operators
- Groups are allowed to have only submatch operator inside
- Groups are allowed only without any char repetition, e.g.
.*
- Any char repetition, e.g. .*, is
only allowed to be used in a single regex together with:
- Empty string operators
- Other repetitions
- Ranges
- Repetitions of ranges
- Ranges are only allowed to have:
- Character range
- Digits range
- Symbols listed in characters allowed for ranges.
65770 65771 65772 65773 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65770 class RegexRewrite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#path_substitution ⇒ ::String
Returns Required. Required when path pattern is specified. Used to rewrite matching parts of the path.
65770 65771 65772 65773 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65770 class RegexRewrite include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |