Class: Google::Cloud::Compute::V1::Region
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Region
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Region resource.
A region is a geographical area where a resource is located. For more information, readRegions and Zones.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ ::Google::Cloud::Compute::V1::DeprecationStatus
[Output Only] The deprecation status associated with this region.
-
#description ⇒ ::String
[Output Only] Textual description of the resource.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
[Output Only] Name of the resource.
-
#quota_status_warning ⇒ ::Google::Cloud::Compute::V1::QuotaStatusWarning
Output only.
-
#quotas ⇒ ::Array<::Google::Cloud::Compute::V1::Quota>
[Output Only] Quotas assigned to this region.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ ::String
[Output Only] Status of the region, either UP orDOWN.
-
#supports_pzs ⇒ ::Boolean
Output only.
-
#zones ⇒ ::Array<::String>
[Output Only] A list of zones available in this region, in the form of resource URLs.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns [Output Only] Creation timestamp inRFC3339 text format.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#deprecated ⇒ ::Google::Cloud::Compute::V1::DeprecationStatus
Returns [Output Only] The deprecation status associated with this region.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#description ⇒ ::String
Returns [Output Only] Textual description of the resource.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#region for regions.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#name ⇒ ::String
Returns [Output Only] Name of the resource.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#quota_status_warning ⇒ ::Google::Cloud::Compute::V1::QuotaStatusWarning
Returns Output only. [Output Only] Warning of fetching the quotas field for this region. This
field is populated only if fetching of the quotas field fails.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#quotas ⇒ ::Array<::Google::Cloud::Compute::V1::Quota>
Returns [Output Only] Quotas assigned to this region.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#status ⇒ ::String
Returns [Output Only] Status of the region, either UP orDOWN. Check the Status enum for the list of possible values.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#supports_pzs ⇒ ::Boolean
Returns Output only. [Output Only] Reserved for future use.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#zones ⇒ ::Array<::String>
Returns [Output Only] A list of zones available in this region, in the form of resource URLs.
64365 64366 64367 64368 64369 64370 64371 64372 64373 64374 64375 64376 64377 64378 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64365 class Region include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the region, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |