Class: Google::Cloud::Compute::V1::Region

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Region resource.

A region is a geographical area where a resource is located. For more information, readRegions and Zones.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    [Output Only] Creation timestamp inRFC3339 text format.



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#deprecated::Google::Cloud::Compute::V1::DeprecationStatus

Returns [Output Only] The deprecation status associated with this region.

Returns:



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#description::String

Returns [Output Only] Textual description of the resource.

Returns:

  • (::String)

    [Output Only] Textual description of the resource.



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#id::Integer

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    [Output Only] The unique identifier for the resource. This identifier is defined by the server.



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Always compute#region for regions.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Always compute#region for regions.



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#name::String

Returns [Output Only] Name of the resource.

Returns:

  • (::String)

    [Output Only] Name of the resource.



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#quota_status_warning::Google::Cloud::Compute::V1::QuotaStatusWarning

Returns Output only. [Output Only] Warning of fetching the quotas field for this region. This field is populated only if fetching of the quotas field fails.

Returns:



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#quotas::Array<::Google::Cloud::Compute::V1::Quota>

Returns [Output Only] Quotas assigned to this region.

Returns:



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for the resource.



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#status::String

Returns [Output Only] Status of the region, either UP orDOWN. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] Status of the region, either UP orDOWN. Check the Status enum for the list of possible values.



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#supports_pzs::Boolean

Returns Output only. [Output Only] Reserved for future use.

Returns:

  • (::Boolean)

    Output only. [Output Only] Reserved for future use.



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#zones::Array<::String>

Returns [Output Only] A list of zones available in this region, in the form of resource URLs.

Returns:

  • (::Array<::String>)

    [Output Only] A list of zones available in this region, in the form of resource URLs.



62596
62597
62598
62599
62600
62601
62602
62603
62604
62605
62606
62607
62608
62609
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62596

class Region
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the region, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end