Class: Google::Cloud::Compute::V1::RegionDiskUpdateKmsKeyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RegionDiskUpdateKmsKeyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#kms_key_name ⇒ ::String
Optional.
Instance Attribute Details
#kms_key_name ⇒ ::String
Returns Optional. The new KMS key to replace the current one on the disk. If empty, the disk will be re-encrypted using the primary version of the disk's current KMS key.
The KMS key can be provided in the following formats:
- projects/project_id/locations/location/keyRings/key_ring/cryptoKeys/key
Where project is the project ID or project number.
62699 62700 62701 62702 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62699 class RegionDiskUpdateKmsKeyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |