Class: Google::Cloud::Compute::V1::RegionInstanceGroupManagersApplyUpdatesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RegionInstanceGroupManagersApplyUpdatesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
RegionInstanceGroupManagers.applyUpdatesToInstances
Defined Under Namespace
Modules: MinimalAction, MostDisruptiveAllowedAction
Instance Attribute Summary collapse
-
#all_instances ⇒ ::Boolean
Flag to update all instances instead of specified list of “instances”.
-
#instances ⇒ ::Array<::String>
The list of URLs of one or more instances for which you want to apply updates.
-
#minimal_action ⇒ ::String
The minimal action that you want to perform on each instance during the update:.
-
#most_disruptive_allowed_action ⇒ ::String
The most disruptive action that you want to perform on each instance during the update:.
Instance Attribute Details
#all_instances ⇒ ::Boolean
Returns Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.
64021 64022 64023 64024 64025 64026 64027 64028 64029 64030 64031 64032 64033 64034 64035 64036 64037 64038 64039 64040 64041 64042 64043 64044 64045 64046 64047 64048 64049 64050 64051 64052 64053 64054 64055 64056 64057 64058 64059 64060 64061 64062 64063 64064 64065 64066 64067 64068 64069 64070 64071 64072 64073 64074 64075 64076 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64021 class RegionInstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#instances ⇒ ::Array<::String>
Returns The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].
64021 64022 64023 64024 64025 64026 64027 64028 64029 64030 64031 64032 64033 64034 64035 64036 64037 64038 64039 64040 64041 64042 64043 64044 64045 64046 64047 64048 64049 64050 64051 64052 64053 64054 64055 64056 64057 64058 64059 64060 64061 64062 64063 64064 64065 64066 64067 64068 64069 64070 64071 64072 64073 64074 64075 64076 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64021 class RegionInstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#minimal_action ⇒ ::String
Returns The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it
again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not disrupt the instance at all.
By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.
64021 64022 64023 64024 64025 64026 64027 64028 64029 64030 64031 64032 64033 64034 64035 64036 64037 64038 64039 64040 64041 64042 64043 64044 64045 64046 64047 64048 64049 64050 64051 64052 64053 64054 64055 64056 64057 64058 64059 64060 64061 64062 64063 64064 64065 64066 64067 64068 64069 64070 64071 64072 64073 64074 64075 64076 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64021 class RegionInstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#most_disruptive_allowed_action ⇒ ::String
Returns The most disruptive action that you want to perform on each instance during the update:
- REPLACE: Delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption
as much as possible.
- NONE: Do not disrupt the instance at all.
By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.
64021 64022 64023 64024 64025 64026 64027 64028 64029 64030 64031 64032 64033 64034 64035 64036 64037 64038 64039 64040 64041 64042 64043 64044 64045 64046 64047 64048 64049 64050 64051 64052 64053 64054 64055 64056 64057 64058 64059 64060 64061 64062 64063 64064 64065 64066 64067 64068 64069 64070 64071 64072 64073 64074 64075 64076 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64021 class RegionInstanceGroupManagersApplyUpdatesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimal action that you want to perform on each instance during the # update: # # # - REPLACE: At minimum, delete the instance and create it # again. # - RESTART: Stop the instance and start it # again. # - REFRESH: Do not stop the instance and limit # disruption as much as possible. # - NONE: Do not # disrupt the instance at all. # # # By default, the minimum action is NONE. If your update # requires a more disruptive action than you set with this flag, the # necessary action is performed to execute the update. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # The most disruptive action that you want to perform on each instance during # the update: # # # - REPLACE: Delete the instance and create it again. # - RESTART: Stop the instance and start it again. # - REFRESH: Do not stop the instance and limit disruption # as much as possible. # - NONE: Do not disrupt the # instance at all. # # # By default, the most disruptive allowed action is REPLACE. If # your update requires a more disruptive action than you set with this flag, # the update request will fail. # Additional supported values which may be not listed in the enum directly due to technical reasons: # NONE # REFRESH # REPLACE # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |