Class: Google::Cloud::Compute::V1::RegionInstanceGroupManagersApplyUpdatesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

RegionInstanceGroupManagers.applyUpdatesToInstances

Defined Under Namespace

Modules: MinimalAction, MostDisruptiveAllowedAction

Instance Attribute Summary collapse

Instance Attribute Details

#all_instances::Boolean

Returns Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.

Returns:

  • (::Boolean)

    Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request.



62936
62937
62938
62939
62940
62941
62942
62943
62944
62945
62946
62947
62948
62949
62950
62951
62952
62953
62954
62955
62956
62957
62958
62959
62960
62961
62962
62963
62964
62965
62966
62967
62968
62969
62970
62971
62972
62973
62974
62975
62976
62977
62978
62979
62980
62981
62982
62983
62984
62985
62986
62987
62988
62989
62990
62991
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62936

class RegionInstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#instances::Array<::String>

Returns The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].

Returns:

  • (::Array<::String>)

    The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/instances/[INSTANCE_NAME].



62936
62937
62938
62939
62940
62941
62942
62943
62944
62945
62946
62947
62948
62949
62950
62951
62952
62953
62954
62955
62956
62957
62958
62959
62960
62961
62962
62963
62964
62965
62966
62967
62968
62969
62970
62971
62972
62973
62974
62975
62976
62977
62978
62979
62980
62981
62982
62983
62984
62985
62986
62987
62988
62989
62990
62991
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62936

class RegionInstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#minimal_action::String

Returns The minimal action that you want to perform on each instance during the update:

 - REPLACE: At minimum, delete the instance and create it
 again.
  • RESTART: Stop the instance and start it again.
  • REFRESH: Do not stop the instance and limit disruption as much as possible.
  • NONE: Do not disrupt the instance at all.

By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.

Returns:

  • (::String)

    The minimal action that you want to perform on each instance during the update:

     - REPLACE: At minimum, delete the instance and create it
     again.
    
    • RESTART: Stop the instance and start it again.
    • REFRESH: Do not stop the instance and limit disruption as much as possible.
    • NONE: Do not disrupt the instance at all.

    By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Check the MinimalAction enum for the list of possible values.



62936
62937
62938
62939
62940
62941
62942
62943
62944
62945
62946
62947
62948
62949
62950
62951
62952
62953
62954
62955
62956
62957
62958
62959
62960
62961
62962
62963
62964
62965
62966
62967
62968
62969
62970
62971
62972
62973
62974
62975
62976
62977
62978
62979
62980
62981
62982
62983
62984
62985
62986
62987
62988
62989
62990
62991
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62936

class RegionInstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#most_disruptive_allowed_action::String

Returns The most disruptive action that you want to perform on each instance during the update:

 - REPLACE: Delete the instance and create it again.
 - RESTART: Stop the instance and start it again.
 - REFRESH: Do not stop the instance and limit disruption
 as much as possible.
  • NONE: Do not disrupt the instance at all.

By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.

Returns:

  • (::String)

    The most disruptive action that you want to perform on each instance during the update:

     - REPLACE: Delete the instance and create it again.
     - RESTART: Stop the instance and start it again.
     - REFRESH: Do not stop the instance and limit disruption
     as much as possible.
    
    • NONE: Do not disrupt the instance at all.

    By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Check the MostDisruptiveAllowedAction enum for the list of possible values.



62936
62937
62938
62939
62940
62941
62942
62943
62944
62945
62946
62947
62948
62949
62950
62951
62952
62953
62954
62955
62956
62957
62958
62959
62960
62961
62962
62963
62964
62965
62966
62967
62968
62969
62970
62971
62972
62973
62974
62975
62976
62977
62978
62979
62980
62981
62982
62983
62984
62985
62986
62987
62988
62989
62990
62991
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 62936

class RegionInstanceGroupManagersApplyUpdatesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimal action that you want to perform on each instance during the
  # update:
  #
  #
  #      - REPLACE: At minimum, delete the instance and create it
  #      again.
  #    - RESTART: Stop the instance and start it
  #      again.
  #    - REFRESH: Do not stop the instance and limit
  #      disruption as much as possible.
  #    - NONE: Do not
  #      disrupt the instance at all.
  #
  #
  # By default, the minimum action is NONE. If your update
  # requires a more disruptive action than you set with this flag, the
  # necessary action is performed to execute the update.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # The most disruptive action that you want to perform on each instance during
  # the update:
  #
  #
  #      - REPLACE: Delete the instance and create it again.
  #      - RESTART: Stop the instance and start it again.
  #      - REFRESH: Do not stop the instance and limit disruption
  #      as much as possible.
  #    - NONE: Do not disrupt the
  #      instance at all.
  #
  #
  # By default, the most disruptive allowed action is REPLACE. If
  # your update requires a more disruptive action than you set with this flag,
  # the update request will fail.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # NONE
  # REFRESH
  # REPLACE
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end