Class: Google::Cloud::Compute::V1::RegionInstanceGroupManagersDeleteInstancesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RegionInstanceGroupManagersDeleteInstancesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#instances ⇒ ::Array<::String>
The URLs of one or more instances to delete.
-
#skip_instances_on_validation_error ⇒ ::Boolean
Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned.
Instance Attribute Details
#instances ⇒ ::Array<::String>
Returns The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
63015 63016 63017 63018 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63015 class RegionInstanceGroupManagersDeleteInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#skip_instances_on_validation_error ⇒ ::Boolean
Returns Specifies whether the request should proceed despite the inclusion of
instances that are not members of the group or that are already in the
process of being deleted or abandoned. If this field is set to false and
such an instance is specified in the request, the operation fails. The
operation always fails if the request contains a malformed instance URL or
a reference to an instance that exists in a zone or region other than the
group's zone or region.
63015 63016 63017 63018 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63015 class RegionInstanceGroupManagersDeleteInstancesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |