Class: Google::Cloud::Compute::V1::RegionInstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: InstanceState

Instance Attribute Summary collapse

Instance Attribute Details

#instance_state ⇒ ::String

Returns Instances in which state should be returned. Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances. Check the InstanceState enum for the list of possible values.

Returns:

  • (::String) —

    Instances in which state should be returned. Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances. Check the InstanceState enum for the list of possible values.



66407
66408
66409
66410
66411
66412
66413
66414
66415
66416
66417
66418
66419
66420
66421
66422
66423
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66407

class RegionInstanceGroupsListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Instances in which state should be returned. Valid options are:
  # 'ALL', 'RUNNING'. By default, it lists all instances.
  module InstanceState
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_STATE = 0

    # Matches any status of the instances, running, non-running and others.
    ALL = 64_897

    # Instance is in RUNNING state if it is running.
    RUNNING = 121_282_975
  end
end

#port_name ⇒ ::String

Returns Name of port user is interested in. It is optional. If it is set, only information about this ports will be returned. If it is not set, all the named ports will be returned. Always lists all instances.

Returns:

  • (::String) —

    Name of port user is interested in. It is optional. If it is set, only information about this ports will be returned. If it is not set, all the named ports will be returned. Always lists all instances.



66407
66408
66409
66410
66411
66412
66413
66414
66415
66416
66417
66418
66419
66420
66421
66422
66423
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66407

class RegionInstanceGroupsListInstancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Instances in which state should be returned. Valid options are:
  # 'ALL', 'RUNNING'. By default, it lists all instances.
  module InstanceState
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_STATE = 0

    # Matches any status of the instances, running, non-running and others.
    ALL = 64_897

    # Instance is in RUNNING state if it is running.
    RUNNING = 121_282_975
  end
end