Class: Google::Cloud::Compute::V1::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#firewall_policys ⇒ ::Array<::Google::Cloud::Compute::V1::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy>
Output only.
-
#firewalls ⇒ ::Array<::Google::Cloud::Compute::V1::Firewall>
Effective firewalls on the network.
Instance Attribute Details
#firewall_policys ⇒ ::Array<::Google::Cloud::Compute::V1::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy>
Returns Output only. [Output only] Effective firewalls from firewall policy. It applies to Regional Network Firewall Policies in the specified region, Global Network Firewall Policies and Hierachial Firewall Policies which are associated with the network.
65038 65039 65040 65041 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65038 class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#firewalls ⇒ ::Array<::Google::Cloud::Compute::V1::Firewall>
Returns Effective firewalls on the network.
65038 65039 65040 65041 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65038 class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |