Class: Google::Cloud::Compute::V1::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#firewall_policys::Array<::Google::Cloud::Compute::V1::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy>

Returns Output only. [Output only] Effective firewalls from firewall policy. It applies to Regional Network Firewall Policies in the specified region, Global Network Firewall Policies and Hierachial Firewall Policies which are associated with the network.

Returns:



63270
63271
63272
63273
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63270

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#firewalls::Array<::Google::Cloud::Compute::V1::Firewall>

Returns Effective firewalls on the network.

Returns:



63270
63271
63272
63273
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63270

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end