Class: Google::Cloud::Compute::V1::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Output only. [Output Only] The display name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] The display name of the firewall policy.



64381
64382
64383
64384
64385
64386
64387
64388
64389
64390
64391
64392
64393
64394
64395
64396
64397
64398
64399
64400
64401
64402
64403
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64381

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#name::String

Returns Output only. [Output Only] The name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] The name of the firewall policy.



64381
64382
64383
64384
64385
64386
64387
64388
64389
64390
64391
64392
64393
64394
64395
64396
64397
64398
64399
64400
64401
64402
64403
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64381

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#packet_mirroring_rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns Output only. [Output only] The packet mirroring rules that apply to the network.

Returns:



64381
64382
64383
64384
64385
64386
64387
64388
64389
64390
64391
64392
64393
64394
64395
64396
64397
64398
64399
64400
64401
64402
64403
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64381

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#priority::Integer

Returns Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.

Returns:

  • (::Integer)

    Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.



64381
64382
64383
64384
64385
64386
64387
64388
64389
64390
64391
64392
64393
64394
64395
64396
64397
64398
64399
64400
64401
64402
64403
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64381

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns Output only. [Output only] The rules that apply to the network.

Returns:



64381
64382
64383
64384
64385
64386
64387
64388
64389
64390
64391
64392
64393
64394
64395
64396
64397
64398
64399
64400
64401
64402
64403
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64381

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#type::String

Returns Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Check the Type enum for the list of possible values.



64381
64382
64383
64384
64385
64386
64387
64388
64389
64390
64391
64392
64393
64394
64395
64396
64397
64398
64399
64400
64401
64402
64403
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64381

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end