Class: Google::Cloud::Compute::V1::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Output only. [Output Only] The display name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] The display name of the firewall policy.



63296
63297
63298
63299
63300
63301
63302
63303
63304
63305
63306
63307
63308
63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63296

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#name::String

Returns Output only. [Output Only] The name of the firewall policy.

Returns:

  • (::String)

    Output only. [Output Only] The name of the firewall policy.



63296
63297
63298
63299
63300
63301
63302
63303
63304
63305
63306
63307
63308
63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63296

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#packet_mirroring_rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns Output only. [Output only] The packet mirroring rules that apply to the network.

Returns:



63296
63297
63298
63299
63300
63301
63302
63303
63304
63305
63306
63307
63308
63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63296

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#priority::Integer

Returns Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.

Returns:

  • (::Integer)

    Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY.



63296
63297
63298
63299
63300
63301
63302
63303
63304
63305
63306
63307
63308
63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63296

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#rules::Array<::Google::Cloud::Compute::V1::FirewallPolicyRule>

Returns Output only. [Output only] The rules that apply to the network.

Returns:



63296
63297
63298
63299
63300
63301
63302
63303
63304
63305
63306
63307
63308
63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63296

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end

#type::String

Returns Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Check the Type enum for the list of possible values.



63296
63297
63298
63299
63300
63301
63302
63303
63304
63305
63306
63307
63308
63309
63310
63311
63312
63313
63314
63315
63316
63317
63318
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63296

class RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
  # NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    HIERARCHY = 69_902_869

    NETWORK = 413_984_270

    NETWORK_REGIONAL = 190_804_272

    SYSTEM_GLOBAL = 60_099_507

    SYSTEM_REGIONAL = 161_777_199

    UNSPECIFIED = 526_786_327
  end
end