Class: Google::Cloud::Compute::V1::RegionSnapshotUpdateKmsKeyRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RegionSnapshotUpdateKmsKeyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#kms_key_name ⇒ ::String
Optional.
Instance Attribute Details
#kms_key_name ⇒ ::String
Returns Optional. The new KMS key to replace the current one on the snapshot. If empty, the snapshot will be re-encrypted using the primary version of the snapshot's current KMS key.
The KMS key can be provided in the following formats:
- projects/project_id/locations/region/keyRings/region/cryptoKeys/key.
63373 63374 63375 63376 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 63373 class RegionSnapshotUpdateKmsKeyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |