Module: Google::Cloud::Compute::V1::Reservation::DeploymentType
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies the deployment strategy for this reservation.
Constant Summary collapse
- UNDEFINED_DEPLOYMENT_TYPE =
A value indicating that the enum field is not set.
0- DENSE =
The reserved capacity is made up of densely deployed reservation blocks.
64_932_607- DEPLOYMENT_TYPE_UNSPECIFIED =
234_847_180