Module: Google::Cloud::Compute::V1::Reservation::ProtectionTier
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Protection tier for the workload which specifies the workload expectations in the event of infrastructure failures at data center (e.g. power and/or cooling failures).
Constant Summary collapse
- UNDEFINED_PROTECTION_TIER =
A value indicating that the enum field is not set.
0- CAPACITY_OPTIMIZED =
CAPACITY_OPTIMIZED capacity leverages redundancies (e.g. power, cooling) at the data center during normal operating conditions. In the event of infrastructure failures at data center (e.g. power and/or cooling failures), this workload may be disrupted. As a consequence, it has a weaker availability SLO than STANDARD.
17_430_466- PROTECTION_TIER_UNSPECIFIED =
Unspecified protection tier.
262_261_984- STANDARD =
STANDARD protection for workload that should be protected by redundancies (e.g. power, cooling) at the data center level. In the event of infrastructure failures at data center (e.g. power and/or cooling failures), this workload is expected to continue as normal using the redundancies.
484_642_493