Class: Google::Cloud::Compute::V1::ReservationAdvancedDeploymentControl

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Advance control for cluster management, applicable only to DENSE deployment type reservations.

Defined Under Namespace

Modules: ReservationOperationalMode

Instance Attribute Summary collapse

Instance Attribute Details

#reservation_operational_mode::String

Returns Indicates chosen reservation operational mode for the reservation. Check the ReservationOperationalMode enum for the list of possible values.

Returns:

  • (::String)

    Indicates chosen reservation operational mode for the reservation. Check the ReservationOperationalMode enum for the list of possible values.



64305
64306
64307
64308
64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
64324
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64305

class ReservationAdvancedDeploymentControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates chosen reservation operational mode for the reservation.
  module ReservationOperationalMode
    # A value indicating that the enum field is not set.
    UNDEFINED_RESERVATION_OPERATIONAL_MODE = 0

    # Google Cloud does not manage the failure of machines, but provides
    # additional capacity, which is not guaranteed to be available.
    ALL_CAPACITY = 500_029_880

    # Google Cloud manages the failure of machines to provide high
    # availability.
    HIGHLY_AVAILABLE_CAPACITY = 110_861_600

    RESERVATION_OPERATIONAL_MODE_UNSPECIFIED = 194_296_603
  end
end