Class: Google::Cloud::Compute::V1::ReservationAffinity

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specifies the reservations that this instance can consume from.

Defined Under Namespace

Modules: ConsumeReservationType

Instance Attribute Summary collapse

Instance Attribute Details

#consume_reservation_type::String

Returns Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples. Check the ConsumeReservationType enum for the list of possible values.

Returns:

  • (::String)

    Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples. Check the ConsumeReservationType enum for the list of possible values.



66111
66112
66113
66114
66115
66116
66117
66118
66119
66120
66121
66122
66123
66124
66125
66126
66127
66128
66129
66130
66131
66132
66133
66134
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66111

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of reservation from which this instance can consume
  # resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See
  # Consuming reserved instances for examples.
  module ConsumeReservationType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONSUME_RESERVATION_TYPE = 0

    # Consume any allocation available.
    ANY_RESERVATION = 200_008_121

    # Do not consume from any allocated capacity.
    NO_RESERVATION = 169_322_030

    # Must consume from a specific reservation. Must specify key value fields
    # for specifying the reservations.
    SPECIFIC_RESERVATION = 229_889_055

    UNSPECIFIED = 526_786_327
  end
end

#key::String

Returns Corresponds to the label key of a reservation resource. To target aSPECIFIC_RESERVATION by name, specifygoogleapis.com/reservation-name as the key and specify the name of your reservation as its value.

Returns:

  • (::String)

    Corresponds to the label key of a reservation resource. To target aSPECIFIC_RESERVATION by name, specifygoogleapis.com/reservation-name as the key and specify the name of your reservation as its value.



66111
66112
66113
66114
66115
66116
66117
66118
66119
66120
66121
66122
66123
66124
66125
66126
66127
66128
66129
66130
66131
66132
66133
66134
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66111

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of reservation from which this instance can consume
  # resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See
  # Consuming reserved instances for examples.
  module ConsumeReservationType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONSUME_RESERVATION_TYPE = 0

    # Consume any allocation available.
    ANY_RESERVATION = 200_008_121

    # Do not consume from any allocated capacity.
    NO_RESERVATION = 169_322_030

    # Must consume from a specific reservation. Must specify key value fields
    # for specifying the reservations.
    SPECIFIC_RESERVATION = 229_889_055

    UNSPECIFIED = 526_786_327
  end
end

#values::Array<::String>

Returns Corresponds to the label values of a reservation resource. This can be either a name to a reservation in the same project or "projects/different-project/reservations/some-reservation-name" to target a shared reservation in the same zone but in a different project.

Returns:

  • (::Array<::String>)

    Corresponds to the label values of a reservation resource. This can be either a name to a reservation in the same project or "projects/different-project/reservations/some-reservation-name" to target a shared reservation in the same zone but in a different project.



66111
66112
66113
66114
66115
66116
66117
66118
66119
66120
66121
66122
66123
66124
66125
66126
66127
66128
66129
66130
66131
66132
66133
66134
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66111

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of reservation from which this instance can consume
  # resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See
  # Consuming reserved instances for examples.
  module ConsumeReservationType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONSUME_RESERVATION_TYPE = 0

    # Consume any allocation available.
    ANY_RESERVATION = 200_008_121

    # Do not consume from any allocated capacity.
    NO_RESERVATION = 169_322_030

    # Must consume from a specific reservation. Must specify key value fields
    # for specifying the reservations.
    SPECIFIC_RESERVATION = 229_889_055

    UNSPECIFIED = 526_786_327
  end
end