Class: Google::Cloud::Compute::V1::ReservationAffinity

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Specifies the reservations that this instance can consume from.

Defined Under Namespace

Modules: ConsumeReservationType

Instance Attribute Summary collapse

Instance Attribute Details

#consume_reservation_type::String

Returns Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples. Check the ConsumeReservationType enum for the list of possible values.

Returns:

  • (::String)

    Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples. Check the ConsumeReservationType enum for the list of possible values.



65428
65429
65430
65431
65432
65433
65434
65435
65436
65437
65438
65439
65440
65441
65442
65443
65444
65445
65446
65447
65448
65449
65450
65451
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65428

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of reservation from which this instance can consume
  # resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See
  # Consuming reserved instances for examples.
  module ConsumeReservationType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONSUME_RESERVATION_TYPE = 0

    # Consume any allocation available.
    ANY_RESERVATION = 200_008_121

    # Do not consume from any allocated capacity.
    NO_RESERVATION = 169_322_030

    # Must consume from a specific reservation. Must specify key value fields
    # for specifying the reservations.
    SPECIFIC_RESERVATION = 229_889_055

    UNSPECIFIED = 526_786_327
  end
end

#key::String

Returns Corresponds to the label key of a reservation resource. To target aSPECIFIC_RESERVATION by name, specifygoogleapis.com/reservation-name as the key and specify the name of your reservation as its value.

Returns:

  • (::String)

    Corresponds to the label key of a reservation resource. To target aSPECIFIC_RESERVATION by name, specifygoogleapis.com/reservation-name as the key and specify the name of your reservation as its value.



65428
65429
65430
65431
65432
65433
65434
65435
65436
65437
65438
65439
65440
65441
65442
65443
65444
65445
65446
65447
65448
65449
65450
65451
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65428

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of reservation from which this instance can consume
  # resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See
  # Consuming reserved instances for examples.
  module ConsumeReservationType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONSUME_RESERVATION_TYPE = 0

    # Consume any allocation available.
    ANY_RESERVATION = 200_008_121

    # Do not consume from any allocated capacity.
    NO_RESERVATION = 169_322_030

    # Must consume from a specific reservation. Must specify key value fields
    # for specifying the reservations.
    SPECIFIC_RESERVATION = 229_889_055

    UNSPECIFIED = 526_786_327
  end
end

#values::Array<::String>

Returns Corresponds to the label values of a reservation resource. This can be either a name to a reservation in the same project or "projects/different-project/reservations/some-reservation-name" to target a shared reservation in the same zone but in a different project.

Returns:

  • (::Array<::String>)

    Corresponds to the label values of a reservation resource. This can be either a name to a reservation in the same project or "projects/different-project/reservations/some-reservation-name" to target a shared reservation in the same zone but in a different project.



65428
65429
65430
65431
65432
65433
65434
65435
65436
65437
65438
65439
65440
65441
65442
65443
65444
65445
65446
65447
65448
65449
65450
65451
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65428

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the type of reservation from which this instance can consume
  # resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See
  # Consuming reserved instances for examples.
  module ConsumeReservationType
    # A value indicating that the enum field is not set.
    UNDEFINED_CONSUME_RESERVATION_TYPE = 0

    # Consume any allocation available.
    ANY_RESERVATION = 200_008_121

    # Do not consume from any allocated capacity.
    NO_RESERVATION = 169_322_030

    # Must consume from a specific reservation. Must specify key value fields
    # for specifying the reservations.
    SPECIFIC_RESERVATION = 229_889_055

    UNSPECIFIED = 526_786_327
  end
end