Class: Google::Cloud::Compute::V1::ReservationAffinity
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationAffinity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies the reservations that this instance can consume from.
Defined Under Namespace
Modules: ConsumeReservationType
Instance Attribute Summary collapse
-
#consume_reservation_type ⇒ ::String
Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION.
-
#key ⇒ ::String
Corresponds to the label key of a reservation resource.
-
#values ⇒ ::Array<::String>
Corresponds to the label values of a reservation resource.
Instance Attribute Details
#consume_reservation_type ⇒ ::String
Returns Specifies the type of reservation from which this instance can consume resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See Consuming reserved instances for examples. Check the ConsumeReservationType enum for the list of possible values.
67648 67649 67650 67651 67652 67653 67654 67655 67656 67657 67658 67659 67660 67661 67662 67663 67664 67665 67666 67667 67668 67669 67670 67671 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67648 class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of reservation from which this instance can consume # resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See # Consuming reserved instances for examples. module ConsumeReservationType # A value indicating that the enum field is not set. UNDEFINED_CONSUME_RESERVATION_TYPE = 0 # Consume any allocation available. ANY_RESERVATION = 200_008_121 # Do not consume from any allocated capacity. NO_RESERVATION = 169_322_030 # Must consume from a specific reservation. Must specify key value fields # for specifying the reservations. SPECIFIC_RESERVATION = 229_889_055 UNSPECIFIED = 526_786_327 end end |
#key ⇒ ::String
Returns Corresponds to the label key of a reservation resource. To target aSPECIFIC_RESERVATION by name, specifygoogleapis.com/reservation-name as the key and specify the name of your reservation as its value.
67648 67649 67650 67651 67652 67653 67654 67655 67656 67657 67658 67659 67660 67661 67662 67663 67664 67665 67666 67667 67668 67669 67670 67671 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67648 class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of reservation from which this instance can consume # resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See # Consuming reserved instances for examples. module ConsumeReservationType # A value indicating that the enum field is not set. UNDEFINED_CONSUME_RESERVATION_TYPE = 0 # Consume any allocation available. ANY_RESERVATION = 200_008_121 # Do not consume from any allocated capacity. NO_RESERVATION = 169_322_030 # Must consume from a specific reservation. Must specify key value fields # for specifying the reservations. SPECIFIC_RESERVATION = 229_889_055 UNSPECIFIED = 526_786_327 end end |
#values ⇒ ::Array<::String>
Returns Corresponds to the label values of a reservation resource. This can be either a name to a reservation in the same project or "projects/different-project/reservations/some-reservation-name" to target a shared reservation in the same zone but in a different project.
67648 67649 67650 67651 67652 67653 67654 67655 67656 67657 67658 67659 67660 67661 67662 67663 67664 67665 67666 67667 67668 67669 67670 67671 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67648 class ReservationAffinity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of reservation from which this instance can consume # resources: ANY_RESERVATION (default),SPECIFIC_RESERVATION, or NO_RESERVATION. See # Consuming reserved instances for examples. module ConsumeReservationType # A value indicating that the enum field is not set. UNDEFINED_CONSUME_RESERVATION_TYPE = 0 # Consume any allocation available. ANY_RESERVATION = 200_008_121 # Do not consume from any allocated capacity. NO_RESERVATION = 169_322_030 # Must consume from a specific reservation. Must specify key value fields # for specifying the reservations. SPECIFIC_RESERVATION = 229_889_055 UNSPECIFIED = 526_786_327 end end |