Class: Google::Cloud::Compute::V1::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#id::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    [Output Only] Unique identifier for the resource; defined by the server.



66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66162

class ReservationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::ReservationsScopedList}

Returns A list of Allocation resources.

Returns:



66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66162

class ReservationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns Output only. Type of resource.

Returns:

  • (::String)

    Output only. Type of resource.



66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66162

class ReservationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66162

class ReservationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource.



66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66162

class ReservationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Unreachable resources.



66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66162

class ReservationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



66162
66163
66164
66165
66166
66167
66168
66169
66170
66171
66172
66173
66174
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66162

class ReservationAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ReservationsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end