Class: Google::Cloud::Compute::V1::ReservationBlock
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationBlock
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a reservation block resource.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#count ⇒ ::Integer
Output only.
-
#creation_timestamp ⇒ ::String
Output only.
-
#health_info ⇒ ::Google::Cloud::Compute::V1::ReservationBlockHealthInfo
Output only.
-
#id ⇒ ::Integer
Output only.
-
#in_use_count ⇒ ::Integer
Output only.
-
#in_use_host_count ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Output only.
-
#physical_topology ⇒ ::Google::Cloud::Compute::V1::ReservationBlockPhysicalTopology
Output only.
-
#reservation_maintenance ⇒ ::Google::Cloud::Compute::V1::GroupMaintenanceInfo
Output only.
-
#reservation_sub_block_count ⇒ ::Integer
Output only.
-
#reservation_sub_block_in_use_count ⇒ ::Integer
Output only.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#status ⇒ ::String
Output only.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#count ⇒ ::Integer
Returns Output only. [Output Only] The number of resources that are allocated in this reservation block.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#health_info ⇒ ::Google::Cloud::Compute::V1::ReservationBlockHealthInfo
Returns Output only. [Output Only] Health information for the reservation block.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#in_use_count ⇒ ::Integer
Returns Output only. [Output Only] The number of instances that are currently in use on this reservation block.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#in_use_host_count ⇒ ::Integer
Returns Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#reservationBlock for reservation blocks.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#name ⇒ ::String
Returns Output only. [Output Only] The name of this reservation block generated by Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#physical_topology ⇒ ::Google::Cloud::Compute::V1::ReservationBlockPhysicalTopology
Returns Output only. [Output Only] The physical topology of the reservation block.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#reservation_maintenance ⇒ ::Google::Cloud::Compute::V1::GroupMaintenanceInfo
Returns Output only. [Output Only] Maintenance information for this reservation block.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#reservation_sub_block_count ⇒ ::Integer
Returns Output only. [Output Only] The number of reservation subBlocks associated with this reservation block.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#reservation_sub_block_in_use_count ⇒ ::Integer
Returns Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource with the resource id.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#status ⇒ ::String
Returns Output only. [Output Only] Status of the reservation block. Check the Status enum for the list of possible values.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |
#zone ⇒ ::String
Returns Output only. [Output Only] Zone in which the reservation block resides.
66235 66236 66237 66238 66239 66240 66241 66242 66243 66244 66245 66246 66247 66248 66249 66250 66251 66252 66253 66254 66255 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66235 class ReservationBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation block. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation block. CREATING = 455_564_985 # Reservation block is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation block has allocated all its resources. READY = 77_848_963 end end |