Class: Google::Cloud::Compute::V1::ReservationBlock

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a reservation block resource.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#count::Integer

Returns Output only. [Output Only] The number of resources that are allocated in this reservation block.

Returns:

  • (::Integer)

    Output only. [Output Only] The number of resources that are allocated in this reservation block.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#health_info::Google::Cloud::Compute::V1::ReservationBlockHealthInfo

Returns Output only. [Output Only] Health information for the reservation block.

Returns:



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#in_use_count::Integer

Returns Output only. [Output Only] The number of instances that are currently in use on this reservation block.

Returns:

  • (::Integer)

    Output only. [Output Only] The number of instances that are currently in use on this reservation block.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#in_use_host_count::Integer

Returns Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.

Returns:

  • (::Integer)

    Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Alwayscompute#reservationBlock for reservation blocks.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Alwayscompute#reservationBlock for reservation blocks.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#name::String

Returns Output only. [Output Only] The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z?.

Returns:

  • (::String)

    Output only. [Output Only] The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z?



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#physical_topology::Google::Cloud::Compute::V1::ReservationBlockPhysicalTopology

Returns Output only. [Output Only] The physical topology of the reservation block.

Returns:



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#reservation_maintenance::Google::Cloud::Compute::V1::GroupMaintenanceInfo

Returns Output only. [Output Only] Maintenance information for this reservation block.

Returns:



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#reservation_sub_block_count::Integer

Returns Output only. [Output Only] The number of reservation subBlocks associated with this reservation block.

Returns:

  • (::Integer)

    Output only. [Output Only] The number of reservation subBlocks associated with this reservation block.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#reservation_sub_block_in_use_count::Integer

Returns Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use.

Returns:

  • (::Integer)

    Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined fully-qualified URL for this resource.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource with the resource id.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource with the resource id.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#status::String

Returns Output only. [Output Only] Status of the reservation block. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] Status of the reservation block. Check the Status enum for the list of possible values.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end

#zone::String

Returns Output only. [Output Only] Zone in which the reservation block resides.

Returns:

  • (::String)

    Output only. [Output Only] Zone in which the reservation block resides.



65552
65553
65554
65555
65556
65557
65558
65559
65560
65561
65562
65563
65564
65565
65566
65567
65568
65569
65570
65571
65572
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65552

class ReservationBlock
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] Status of the reservation block.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Resources are being allocated for the reservation block.
    CREATING = 455_564_985

    # Reservation block is currently being deleted.
    DELETING = 528_602_024

    INVALID = 530_283_991

    # Reservation block has allocated all its resources.
    READY = 77_848_963
  end
end