Class: Google::Cloud::Compute::V1::ReservationBlockHealthInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Health information for the reservation block.

Defined Under Namespace

Modules: HealthStatus

Instance Attribute Summary collapse

Instance Attribute Details

#degraded_sub_block_count::Integer

Returns The number of subBlocks that are degraded.

Returns:

  • (::Integer)

    The number of subBlocks that are degraded.



66268
66269
66270
66271
66272
66273
66274
66275
66276
66277
66278
66279
66280
66281
66282
66283
66284
66285
66286
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66268

class ReservationBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation block.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation block is degraded.
    DEGRADED = 396_890_926

    # The reservation block is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation block is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#health_status::String

Returns The health status of the reservation block. Check the HealthStatus enum for the list of possible values.

Returns:

  • (::String)

    The health status of the reservation block. Check the HealthStatus enum for the list of possible values.



66268
66269
66270
66271
66272
66273
66274
66275
66276
66277
66278
66279
66280
66281
66282
66283
66284
66285
66286
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66268

class ReservationBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation block.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation block is degraded.
    DEGRADED = 396_890_926

    # The reservation block is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation block is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#healthy_sub_block_count::Integer

Returns The number of subBlocks that are healthy.

Returns:

  • (::Integer)

    The number of subBlocks that are healthy.



66268
66269
66270
66271
66272
66273
66274
66275
66276
66277
66278
66279
66280
66281
66282
66283
66284
66285
66286
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66268

class ReservationBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation block.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation block is degraded.
    DEGRADED = 396_890_926

    # The reservation block is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation block is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end