Class: Google::Cloud::Compute::V1::ReservationBlockHealthInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Health information for the reservation block.

Defined Under Namespace

Modules: HealthStatus

Instance Attribute Summary collapse

Instance Attribute Details

#degraded_sub_block_count::Integer

Returns The number of subBlocks that are degraded.

Returns:

  • (::Integer)

    The number of subBlocks that are degraded.



65585
65586
65587
65588
65589
65590
65591
65592
65593
65594
65595
65596
65597
65598
65599
65600
65601
65602
65603
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65585

class ReservationBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation block.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation block is degraded.
    DEGRADED = 396_890_926

    # The reservation block is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation block is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#health_status::String

Returns The health status of the reservation block. Check the HealthStatus enum for the list of possible values.

Returns:

  • (::String)

    The health status of the reservation block. Check the HealthStatus enum for the list of possible values.



65585
65586
65587
65588
65589
65590
65591
65592
65593
65594
65595
65596
65597
65598
65599
65600
65601
65602
65603
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65585

class ReservationBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation block.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation block is degraded.
    DEGRADED = 396_890_926

    # The reservation block is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation block is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#healthy_sub_block_count::Integer

Returns The number of subBlocks that are healthy.

Returns:

  • (::Integer)

    The number of subBlocks that are healthy.



65585
65586
65587
65588
65589
65590
65591
65592
65593
65594
65595
65596
65597
65598
65599
65600
65601
65602
65603
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65585

class ReservationBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation block.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation block is degraded.
    DEGRADED = 396_890_926

    # The reservation block is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation block is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end