Class: Google::Cloud::Compute::V1::ReservationBlockHealthInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationBlockHealthInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Health information for the reservation block.
Defined Under Namespace
Modules: HealthStatus
Instance Attribute Summary collapse
-
#degraded_sub_block_count ⇒ ::Integer
The number of subBlocks that are degraded.
-
#health_status ⇒ ::String
The health status of the reservation block.
-
#healthy_sub_block_count ⇒ ::Integer
The number of subBlocks that are healthy.
Instance Attribute Details
#degraded_sub_block_count ⇒ ::Integer
Returns The number of subBlocks that are degraded.
67805 67806 67807 67808 67809 67810 67811 67812 67813 67814 67815 67816 67817 67818 67819 67820 67821 67822 67823 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67805 class ReservationBlockHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation block. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation block is degraded. DEGRADED = 396_890_926 # The reservation block is healthy. HEALTHY = 439_801_213 # The health status of the reservation block is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |
#health_status ⇒ ::String
Returns The health status of the reservation block. Check the HealthStatus enum for the list of possible values.
67805 67806 67807 67808 67809 67810 67811 67812 67813 67814 67815 67816 67817 67818 67819 67820 67821 67822 67823 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67805 class ReservationBlockHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation block. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation block is degraded. DEGRADED = 396_890_926 # The reservation block is healthy. HEALTHY = 439_801_213 # The health status of the reservation block is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |
#healthy_sub_block_count ⇒ ::Integer
Returns The number of subBlocks that are healthy.
67805 67806 67807 67808 67809 67810 67811 67812 67813 67814 67815 67816 67817 67818 67819 67820 67821 67822 67823 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67805 class ReservationBlockHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation block. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation block is degraded. DEGRADED = 396_890_926 # The reservation block is healthy. HEALTHY = 439_801_213 # The health status of the reservation block is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |