Class: Google::Cloud::Compute::V1::ReservationSlot

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a reservation slot resource.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.

Returns:

  • (::String)

    Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for this resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for this resource. This identifier is defined by the server.



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#kind::String

Returns Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot for reservation slots.

Returns:

  • (::String)

    Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot for reservation slots.



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#name::String

Returns Output only. [Output Only] The name of the reservation slot.

Returns:

  • (::String)

    Output only. [Output Only] The name of the reservation slot.



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#physical_topology::Google::Cloud::Compute::V1::ReservationSlotPhysicalTopology

Returns Output only. [Output Only] The physical topology of the reservation slot.

Returns:



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

Returns Output only. [Output Only] A server-defined fully-qualified URL for this resource.

Returns:

  • (::String)

    Output only. [Output Only] A server-defined fully-qualified URL for this resource.



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

Returns Output only. [Output Only] A server-defined URL for this resource with the resource ID.

Returns:

  • (::String)

    Output only. [Output Only] A server-defined URL for this resource with the resource ID.



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#share_settings::Google::Cloud::Compute::V1::ShareSettings

Returns Specify share settings to create a shared slot. Set to empty to inherit the share settings from a parent resource.

Returns:



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#state::String

Returns Output only. [Output Only] The state of the reservation slot. Check the State enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The state of the reservation slot. Check the State enum for the list of possible values.



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#status::Google::Cloud::Compute::V1::ReservationSlotStatus

Returns Output only. [Output Only] The status of the reservation slot.

Returns:



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end

#zone::String

Returns Output only. [Output Only] The zone in which the reservation slot resides.

Returns:

  • (::String)

    Output only. [Output Only] The zone in which the reservation slot resides.



65771
65772
65773
65774
65775
65776
65777
65778
65779
65780
65781
65782
65783
65784
65785
65786
65787
65788
65789
65790
65791
65792
65793
65794
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65771

class ReservationSlot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The state of the reservation slot.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # The reservation slot has allocated all its resources.
    ACTIVE = 314_733_318

    # The resources are being allocated for the reservation slot.
    CREATING = 455_564_985

    # The reservation slot is currently being deleted.
    DELETING = 528_602_024

    STATE_UNSPECIFIED = 470_755_401

    # The reservation slot is currently unavailable.
    UNAVAILABLE = 413_756_464
  end
end