Module: Google::Cloud::Compute::V1::ReservationSlot::State
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Output only. [Output Only] The state of the reservation slot.
Constant Summary collapse
- UNDEFINED_STATE =
A value indicating that the enum field is not set.
0- ACTIVE =
The reservation slot has allocated all its resources.
314_733_318- CREATING =
The resources are being allocated for the reservation slot.
455_564_985- DELETING =
The reservation slot is currently being deleted.
528_602_024- STATE_UNSPECIFIED =
470_755_401- UNAVAILABLE =
The reservation slot is currently unavailable.
413_756_464