Class: Google::Cloud::Compute::V1::ReservationSubBlock
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationSubBlock
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a reservation subBlock resource.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#accelerator_topologies_info ⇒ ::Google::Cloud::Compute::V1::AcceleratorTopologiesInfo
Output only.
-
#count ⇒ ::Integer
Output only.
-
#creation_timestamp ⇒ ::String
Output only.
-
#health_info ⇒ ::Google::Cloud::Compute::V1::ReservationSubBlockHealthInfo
Output only.
-
#id ⇒ ::Integer
Output only.
-
#in_use_count ⇒ ::Integer
Output only.
-
#in_use_host_count ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Output only.
-
#physical_topology ⇒ ::Google::Cloud::Compute::V1::ReservationSubBlockPhysicalTopology
Output only.
-
#reservation_sub_block_maintenance ⇒ ::Google::Cloud::Compute::V1::GroupMaintenanceInfo
Output only.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#status ⇒ ::String
Output only.
-
#zone ⇒ ::String
Output only.
Instance Attribute Details
#accelerator_topologies_info ⇒ ::Google::Cloud::Compute::V1::AcceleratorTopologiesInfo
Returns Output only. [Output Only] Slice info for the reservation subBlock.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#count ⇒ ::Integer
Returns Output only. [Output Only] The number of hosts that are allocated in this reservation subBlock.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#health_info ⇒ ::Google::Cloud::Compute::V1::ReservationSubBlockHealthInfo
Returns Output only. [Output Only] Health information for the reservation subBlock.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#in_use_count ⇒ ::Integer
Returns Output only. [Output Only] The number of instances that are currently in use on this reservation subBlock.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#in_use_host_count ⇒ ::Integer
Returns Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#reservationSubBlock for reservation subBlocks.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#name ⇒ ::String
Returns Output only. [Output Only] The name of this reservation subBlock generated by Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#physical_topology ⇒ ::Google::Cloud::Compute::V1::ReservationSubBlockPhysicalTopology
Returns Output only. [Output Only] The physical topology of the reservation subBlock.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#reservation_sub_block_maintenance ⇒ ::Google::Cloud::Compute::V1::GroupMaintenanceInfo
Returns Output only. Maintenance information for this reservation subBlock.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource with the resource id.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#status ⇒ ::String
Returns Output only. [Output Only] Status of the reservation subBlock. Check the Status enum for the list of possible values.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |
#zone ⇒ ::String
Returns Output only. [Output Only] Zone in which the reservation subBlock resides.
65938 65939 65940 65941 65942 65943 65944 65945 65946 65947 65948 65949 65950 65951 65952 65953 65954 65955 65956 65957 65958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65938 class ReservationSubBlock include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] Status of the reservation subBlock. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resources are being allocated for the reservation subBlock. CREATING = 455_564_985 # Reservation subBlock is currently being deleted. DELETING = 528_602_024 INVALID = 530_283_991 # Reservation subBlock has allocated all its resources. READY = 77_848_963 end end |