Class: Google::Cloud::Compute::V1::ReservationSubBlockHealthInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationSubBlockHealthInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Health information for the reservation subBlock.
Defined Under Namespace
Modules: HealthStatus
Instance Attribute Summary collapse
-
#degraded_host_count ⇒ ::Integer
The number of degraded hosts in the reservation subBlock.
-
#degraded_infra_count ⇒ ::Integer
The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.
-
#health_status ⇒ ::String
The health status of the reservation subBlock.
-
#healthy_host_count ⇒ ::Integer
The number of healthy hosts in the reservation subBlock.
-
#healthy_infra_count ⇒ ::Integer
The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.
Instance Attribute Details
#degraded_host_count ⇒ ::Integer
Returns The number of degraded hosts in the reservation subBlock.
66662 66663 66664 66665 66666 66667 66668 66669 66670 66671 66672 66673 66674 66675 66676 66677 66678 66679 66680 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66662 class ReservationSubBlockHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation subBlock. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation subBlock is degraded. DEGRADED = 396_890_926 # The reservation subBlock is healthy. HEALTHY = 439_801_213 # The health status of the reservation subBlock is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |
#degraded_infra_count ⇒ ::Integer
Returns The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.
66662 66663 66664 66665 66666 66667 66668 66669 66670 66671 66672 66673 66674 66675 66676 66677 66678 66679 66680 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66662 class ReservationSubBlockHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation subBlock. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation subBlock is degraded. DEGRADED = 396_890_926 # The reservation subBlock is healthy. HEALTHY = 439_801_213 # The health status of the reservation subBlock is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |
#health_status ⇒ ::String
Returns The health status of the reservation subBlock. Check the HealthStatus enum for the list of possible values.
66662 66663 66664 66665 66666 66667 66668 66669 66670 66671 66672 66673 66674 66675 66676 66677 66678 66679 66680 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66662 class ReservationSubBlockHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation subBlock. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation subBlock is degraded. DEGRADED = 396_890_926 # The reservation subBlock is healthy. HEALTHY = 439_801_213 # The health status of the reservation subBlock is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |
#healthy_host_count ⇒ ::Integer
Returns The number of healthy hosts in the reservation subBlock.
66662 66663 66664 66665 66666 66667 66668 66669 66670 66671 66672 66673 66674 66675 66676 66677 66678 66679 66680 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66662 class ReservationSubBlockHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation subBlock. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation subBlock is degraded. DEGRADED = 396_890_926 # The reservation subBlock is healthy. HEALTHY = 439_801_213 # The health status of the reservation subBlock is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |
#healthy_infra_count ⇒ ::Integer
Returns The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.
66662 66663 66664 66665 66666 66667 66668 66669 66670 66671 66672 66673 66674 66675 66676 66677 66678 66679 66680 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66662 class ReservationSubBlockHealthInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The health status of the reservation subBlock. module HealthStatus # A value indicating that the enum field is not set. UNDEFINED_HEALTH_STATUS = 0 # The reservation subBlock is degraded. DEGRADED = 396_890_926 # The reservation subBlock is healthy. HEALTHY = 439_801_213 # The health status of the reservation subBlock is unspecified. HEALTH_STATUS_UNSPECIFIED = 482_246_925 end end |