Class: Google::Cloud::Compute::V1::ReservationSubBlockHealthInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Health information for the reservation subBlock.

Defined Under Namespace

Modules: HealthStatus

Instance Attribute Summary collapse

Instance Attribute Details

#degraded_host_count::Integer

Returns The number of degraded hosts in the reservation subBlock.

Returns:

  • (::Integer)

    The number of degraded hosts in the reservation subBlock.



65979
65980
65981
65982
65983
65984
65985
65986
65987
65988
65989
65990
65991
65992
65993
65994
65995
65996
65997
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65979

class ReservationSubBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation subBlock.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation subBlock is degraded.
    DEGRADED = 396_890_926

    # The reservation subBlock is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation subBlock is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#degraded_infra_count::Integer

Returns The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.

Returns:

  • (::Integer)

    The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.



65979
65980
65981
65982
65983
65984
65985
65986
65987
65988
65989
65990
65991
65992
65993
65994
65995
65996
65997
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65979

class ReservationSubBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation subBlock.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation subBlock is degraded.
    DEGRADED = 396_890_926

    # The reservation subBlock is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation subBlock is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#health_status::String

Returns The health status of the reservation subBlock. Check the HealthStatus enum for the list of possible values.

Returns:

  • (::String)

    The health status of the reservation subBlock. Check the HealthStatus enum for the list of possible values.



65979
65980
65981
65982
65983
65984
65985
65986
65987
65988
65989
65990
65991
65992
65993
65994
65995
65996
65997
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65979

class ReservationSubBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation subBlock.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation subBlock is degraded.
    DEGRADED = 396_890_926

    # The reservation subBlock is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation subBlock is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#healthy_host_count::Integer

Returns The number of healthy hosts in the reservation subBlock.

Returns:

  • (::Integer)

    The number of healthy hosts in the reservation subBlock.



65979
65980
65981
65982
65983
65984
65985
65986
65987
65988
65989
65990
65991
65992
65993
65994
65995
65996
65997
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65979

class ReservationSubBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation subBlock.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation subBlock is degraded.
    DEGRADED = 396_890_926

    # The reservation subBlock is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation subBlock is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end

#healthy_infra_count::Integer

Returns The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.

Returns:

  • (::Integer)

    The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.



65979
65980
65981
65982
65983
65984
65985
65986
65987
65988
65989
65990
65991
65992
65993
65994
65995
65996
65997
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65979

class ReservationSubBlockHealthInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The health status of the reservation subBlock.
  module HealthStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_HEALTH_STATUS = 0

    # The reservation subBlock is degraded.
    DEGRADED = 396_890_926

    # The reservation subBlock is healthy.
    HEALTHY = 439_801_213

    # The health status of the reservation subBlock is unspecified.
    HEALTH_STATUS_UNSPECIFIED = 482_246_925
  end
end