Class: Google::Cloud::Compute::V1::ReservationSubBlocksReportFaultyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DisruptionSchedule, FailureComponent

Instance Attribute Summary collapse

Instance Attribute Details

#disruption_schedule::String

Returns The disruption schedule for the subBlock. Check the DisruptionSchedule enum for the list of possible values.

Returns:

  • (::String)

    The disruption schedule for the subBlock. Check the DisruptionSchedule enum for the list of possible values.



64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64996

class ReservationSubBlocksReportFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the subBlock.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # All VMs will be disrupted immediately.
    IMMEDIATE = 152_881_041
  end

  # The component that experienced the fault.
  module FailureComponent
    # A value indicating that the enum field is not set.
    UNDEFINED_FAILURE_COMPONENT = 0

    FAILURE_COMPONENT_UNSPECIFIED = 332_003_744

    # Multiple hosts experienced the fault.
    MULTIPLE_FAULTY_HOSTS = 423_545_298

    # The NVLink switch experienced the fault.
    NVLINK_SWITCH = 239_107_153
  end
end

#failure_component::String

Returns The component that experienced the fault. Check the FailureComponent enum for the list of possible values.

Returns:

  • (::String)

    The component that experienced the fault. Check the FailureComponent enum for the list of possible values.



64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64996

class ReservationSubBlocksReportFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the subBlock.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # All VMs will be disrupted immediately.
    IMMEDIATE = 152_881_041
  end

  # The component that experienced the fault.
  module FailureComponent
    # A value indicating that the enum field is not set.
    UNDEFINED_FAILURE_COMPONENT = 0

    FAILURE_COMPONENT_UNSPECIFIED = 332_003_744

    # Multiple hosts experienced the fault.
    MULTIPLE_FAULTY_HOSTS = 423_545_298

    # The NVLink switch experienced the fault.
    NVLINK_SWITCH = 239_107_153
  end
end

#fault_reasons::Array<::Google::Cloud::Compute::V1::ReservationSubBlocksReportFaultyRequestFaultReason>

Returns The reasons for the fault experienced with the subBlock.

Returns:



64996
64997
64998
64999
65000
65001
65002
65003
65004
65005
65006
65007
65008
65009
65010
65011
65012
65013
65014
65015
65016
65017
65018
65019
65020
65021
65022
65023
65024
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 64996

class ReservationSubBlocksReportFaultyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The disruption schedule for the subBlock.
  module DisruptionSchedule
    # A value indicating that the enum field is not set.
    UNDEFINED_DISRUPTION_SCHEDULE = 0

    DISRUPTION_SCHEDULE_UNSPECIFIED = 332_543_835

    # All VMs will be disrupted immediately.
    IMMEDIATE = 152_881_041
  end

  # The component that experienced the fault.
  module FailureComponent
    # A value indicating that the enum field is not set.
    UNDEFINED_FAILURE_COMPONENT = 0

    FAILURE_COMPONENT_UNSPECIFIED = 332_003_744

    # Multiple hosts experienced the fault.
    MULTIPLE_FAULTY_HOSTS = 423_545_298

    # The NVLink switch experienced the fault.
    NVLINK_SWITCH = 239_107_153
  end
end