Class: Google::Cloud::Compute::V1::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The reason for the fault experienced with the subBlock.

Defined Under Namespace

Modules: Behavior

Instance Attribute Summary collapse

Instance Attribute Details

#behavior::String

Returns The behavior of the fault experienced with the subBlock. Check the Behavior enum for the list of possible values.

Returns:

  • (::String)

    The behavior of the fault experienced with the subBlock. Check the Behavior enum for the list of possible values.



66802
66803
66804
66805
66806
66807
66808
66809
66810
66811
66812
66813
66814
66815
66816
66817
66818
66819
66820
66821
66822
66823
66824
66825
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66802

class ReservationSubBlocksReportFaultyRequestFaultReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The behavior of the fault experienced with the subBlock.
  module Behavior
    # A value indicating that the enum field is not set.
    UNDEFINED_BEHAVIOR = 0

    FAULT_BEHAVIOR_UNSPECIFIED = 447_660_743

    # The subBlock experienced a GPU error.
    GPU_ERROR = 198_817_909

    # The subBlock experienced performance issues.
    PERFORMANCE = 135_701_520

    # The subBlock experienced silent data corruption.
    SILENT_DATA_CORRUPTION = 111_360_678

    # The subBlock experienced a switch failure.
    SWITCH_FAILURE = 254_909_279
  end
end

#description::String

Returns The description of the fault experienced with the subBlock.

Returns:

  • (::String)

    The description of the fault experienced with the subBlock.



66802
66803
66804
66805
66806
66807
66808
66809
66810
66811
66812
66813
66814
66815
66816
66817
66818
66819
66820
66821
66822
66823
66824
66825
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66802

class ReservationSubBlocksReportFaultyRequestFaultReason
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The behavior of the fault experienced with the subBlock.
  module Behavior
    # A value indicating that the enum field is not set.
    UNDEFINED_BEHAVIOR = 0

    FAULT_BEHAVIOR_UNSPECIFIED = 447_660_743

    # The subBlock experienced a GPU error.
    GPU_ERROR = 198_817_909

    # The subBlock experienced performance issues.
    PERFORMANCE = 135_701_520

    # The subBlock experienced silent data corruption.
    SILENT_DATA_CORRUPTION = 111_360_678

    # The subBlock experienced a switch failure.
    SWITCH_FAILURE = 254_909_279
  end
end