Class: Google::Cloud::Compute::V1::ReservationSubBlocksReportFaultyRequestFaultReason
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationSubBlocksReportFaultyRequestFaultReason
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The reason for the fault experienced with the subBlock.
Defined Under Namespace
Modules: Behavior
Instance Attribute Summary collapse
-
#behavior ⇒ ::String
The behavior of the fault experienced with the subBlock.
-
#description ⇒ ::String
The description of the fault experienced with the subBlock.
Instance Attribute Details
#behavior ⇒ ::String
Returns The behavior of the fault experienced with the subBlock. Check the Behavior enum for the list of possible values.
65034 65035 65036 65037 65038 65039 65040 65041 65042 65043 65044 65045 65046 65047 65048 65049 65050 65051 65052 65053 65054 65055 65056 65057 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65034 class ReservationSubBlocksReportFaultyRequestFaultReason include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The behavior of the fault experienced with the subBlock. module Behavior # A value indicating that the enum field is not set. UNDEFINED_BEHAVIOR = 0 FAULT_BEHAVIOR_UNSPECIFIED = 447_660_743 # The subBlock experienced a GPU error. GPU_ERROR = 198_817_909 # The subBlock experienced performance issues. PERFORMANCE = 135_701_520 # The subBlock experienced silent data corruption. SILENT_DATA_CORRUPTION = 111_360_678 # The subBlock experienced a switch failure. SWITCH_FAILURE = 254_909_279 end end |
#description ⇒ ::String
Returns The description of the fault experienced with the subBlock.
65034 65035 65036 65037 65038 65039 65040 65041 65042 65043 65044 65045 65046 65047 65048 65049 65050 65051 65052 65053 65054 65055 65056 65057 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65034 class ReservationSubBlocksReportFaultyRequestFaultReason include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The behavior of the fault experienced with the subBlock. module Behavior # A value indicating that the enum field is not set. UNDEFINED_BEHAVIOR = 0 FAULT_BEHAVIOR_UNSPECIFIED = 447_660_743 # The subBlock experienced a GPU error. GPU_ERROR = 198_817_909 # The subBlock experienced performance issues. PERFORMANCE = 135_701_520 # The subBlock experienced silent data corruption. SILENT_DATA_CORRUPTION = 111_360_678 # The subBlock experienced a switch failure. SWITCH_FAILURE = 254_909_279 end end |