Class: Google::Cloud::Compute::V1::ReservationsBlocksPerformMaintenanceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationsBlocksPerformMaintenanceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: MaintenanceScope
Instance Attribute Summary collapse
-
#maintenance_scope ⇒ ::String
Specifies if all, running or unused hosts are in scope for this request.
Instance Attribute Details
#maintenance_scope ⇒ ::String
Returns Specifies if all, running or unused hosts are in scope for this request. Check the MaintenanceScope enum for the list of possible values.
66831 66832 66833 66834 66835 66836 66837 66838 66839 66840 66841 66842 66843 66844 66845 66846 66847 66848 66849 66850 66851 66852 66853 66854 66855 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66831 class ReservationsBlocksPerformMaintenanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies if all, running or unused hosts are in scope for this request. module MaintenanceScope # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_SCOPE = 0 # Trigger maintenance for all hosts belonging to this reservation # irrespective of whether VMs are running on them or not. ALL = 64_897 # Internal only MAINTENANCE_SCOPE_UNSPECIFIED = 78_827_328 # Trigger maintenance only on the hosts belonging to this reservation which # have VMs running on them. RUNNING_VMS = 535_770_588 # Trigger maintenance only on the hosts belonging to this reservation which # do not have any VMs running on them. This is not allowed for Standard ExR UNUSED_CAPACITY = 212_724_995 end end |