Class: Google::Cloud::Compute::V1::ReservationsPerformMaintenanceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationsPerformMaintenanceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: MaintenanceScope
Instance Attribute Summary collapse
-
#maintenance_scope ⇒ ::String
Specifies if all, running or unused hosts are in scope for this request.
Instance Attribute Details
#maintenance_scope ⇒ ::String
Returns Specifies if all, running or unused hosts are in scope for this request. Check the MaintenanceScope enum for the list of possible values.
66861 66862 66863 66864 66865 66866 66867 66868 66869 66870 66871 66872 66873 66874 66875 66876 66877 66878 66879 66880 66881 66882 66883 66884 66885 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66861 class ReservationsPerformMaintenanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies if all, running or unused hosts are in scope for this request. module MaintenanceScope # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_SCOPE = 0 # Trigger maintenance for all hosts belonging to this reservation # irrespective of whether VMs are running on them or not. ALL = 64_897 # Internal only MAINTENANCE_SCOPE_UNSPECIFIED = 78_827_328 # Trigger maintenance only on the hosts belonging to this reservation which # have VMs running on them. RUNNING_VMS = 535_770_588 # Trigger maintenance only on the hosts belonging to this reservation which # do not have any VMs running on them. This is not allowed for Standard ExR UNUSED_CAPACITY = 212_724_995 end end |