Class: Google::Cloud::Compute::V1::ReservationsPerformMaintenanceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ReservationsPerformMaintenanceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: MaintenanceScope
Instance Attribute Summary collapse
-
#maintenance_scope ⇒ ::String
Specifies if all, running or unused hosts are in scope for this request.
Instance Attribute Details
#maintenance_scope ⇒ ::String
Returns Specifies if all, running or unused hosts are in scope for this request. Check the MaintenanceScope enum for the list of possible values.
65093 65094 65095 65096 65097 65098 65099 65100 65101 65102 65103 65104 65105 65106 65107 65108 65109 65110 65111 65112 65113 65114 65115 65116 65117 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65093 class ReservationsPerformMaintenanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies if all, running or unused hosts are in scope for this request. module MaintenanceScope # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_SCOPE = 0 # Trigger maintenance for all hosts belonging to this reservation # irrespective of whether VMs are running on them or not. ALL = 64_897 # Internal only MAINTENANCE_SCOPE_UNSPECIFIED = 78_827_328 # Trigger maintenance only on the hosts belonging to this reservation which # have VMs running on them. RUNNING_VMS = 535_770_588 # Trigger maintenance only on the hosts belonging to this reservation which # do not have any VMs running on them. This is not allowed for Standard ExR UNUSED_CAPACITY = 212_724_995 end end |