Class: Google::Cloud::Compute::V1::ResourceCommitment
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourceCommitment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Commitment for a particular hardware resource (a commitment is composed of one or more of these).
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#accelerator_type ⇒ ::String
Name of the accelerator type or GPU resource.
-
#amount ⇒ ::Integer
The quantity of the hardware resource that you want to commit to purchasing (in a type-dependent unit).
-
#type ⇒ ::String
The type of hardware resource that you want to specify.
Instance Attribute Details
#accelerator_type ⇒ ::String
Returns Name of the accelerator type or GPU resource. Specify this field only when the type of hardware resource is ACCELERATOR.
66457 66458 66459 66460 66461 66462 66463 66464 66465 66466 66467 66468 66469 66470 66471 66472 66473 66474 66475 66476 66477 66478 66479 66480 66481 66482 66483 66484 66485 66486 66487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66457 class ResourceCommitment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of hardware resource that you want to specify. # You can specify any of the following values: # # - VCPU # - MEMORY # - LOCAL_SSD # - ACCELERATOR # # # # Specify as a separate entry in the list for each # individual resource type. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 ACCELERATOR = 429_815_371 LOCAL_SSD = 508_934_896 MEMORY = 123_056_385 UNSPECIFIED = 526_786_327 VCPU = 2_628_978 end end |
#amount ⇒ ::Integer
Returns The quantity of the hardware resource that you want to commit to purchasing (in a type-dependent unit).
- For vCPUs, you must specify an integer value.
- For memory, you specify the amount of MB that you want. The value you specify must be a multiple of 256 MB, with up to 6.5 GB of memory per every vCPU.
- For GPUs, you must specify an integer value.
- For Local SSD disks, you must specify the amount in GB. The size of a single Local SSD disk is 375 GB.
66457 66458 66459 66460 66461 66462 66463 66464 66465 66466 66467 66468 66469 66470 66471 66472 66473 66474 66475 66476 66477 66478 66479 66480 66481 66482 66483 66484 66485 66486 66487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66457 class ResourceCommitment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of hardware resource that you want to specify. # You can specify any of the following values: # # - VCPU # - MEMORY # - LOCAL_SSD # - ACCELERATOR # # # # Specify as a separate entry in the list for each # individual resource type. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 ACCELERATOR = 429_815_371 LOCAL_SSD = 508_934_896 MEMORY = 123_056_385 UNSPECIFIED = 526_786_327 VCPU = 2_628_978 end end |
#type ⇒ ::String
Returns The type of hardware resource that you want to specify. You can specify any of the following values:
- VCPU
- MEMORY
- LOCAL_SSD
- ACCELERATOR
Specify as a separate entry in the list for each individual resource type. Check the Type enum for the list of possible values.
66457 66458 66459 66460 66461 66462 66463 66464 66465 66466 66467 66468 66469 66470 66471 66472 66473 66474 66475 66476 66477 66478 66479 66480 66481 66482 66483 66484 66485 66486 66487 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66457 class ResourceCommitment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of hardware resource that you want to specify. # You can specify any of the following values: # # - VCPU # - MEMORY # - LOCAL_SSD # - ACCELERATOR # # # # Specify as a separate entry in the list for each # individual resource type. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 ACCELERATOR = 429_815_371 LOCAL_SSD = 508_934_896 MEMORY = 123_056_385 UNSPECIFIED = 526_786_327 VCPU = 2_628_978 end end |