Class: Google::Cloud::Compute::V1::ResourceCommitment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Commitment for a particular hardware resource (a commitment is composed of one or more of these).

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#accelerator_type::String

Returns Name of the accelerator type or GPU resource. Specify this field only when the type of hardware resource is ACCELERATOR.

Returns:

  • (::String)

    Name of the accelerator type or GPU resource. Specify this field only when the type of hardware resource is ACCELERATOR.



65372
65373
65374
65375
65376
65377
65378
65379
65380
65381
65382
65383
65384
65385
65386
65387
65388
65389
65390
65391
65392
65393
65394
65395
65396
65397
65398
65399
65400
65401
65402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65372

class ResourceCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of hardware resource that you want to specify.
  # You can specify any of the following values:
  #
  #    - VCPU
  #    - MEMORY
  #    - LOCAL_SSD
  #    - ACCELERATOR
  #
  #
  #
  # Specify as a separate entry in the list for each
  # individual resource type.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    ACCELERATOR = 429_815_371

    LOCAL_SSD = 508_934_896

    MEMORY = 123_056_385

    UNSPECIFIED = 526_786_327

    VCPU = 2_628_978
  end
end

#amount::Integer

Returns The quantity of the hardware resource that you want to commit to purchasing (in a type-dependent unit).

  • For vCPUs, you must specify an integer value.
  • For memory, you specify the amount of MB that you want. The value you specify must be a multiple of 256 MB, with up to 6.5 GB of memory per every vCPU.
  • For GPUs, you must specify an integer value.
  • For Local SSD disks, you must specify the amount in GB. The size of a single Local SSD disk is 375 GB.

Returns:

  • (::Integer)

    The quantity of the hardware resource that you want to commit to purchasing (in a type-dependent unit).

    • For vCPUs, you must specify an integer value.
    • For memory, you specify the amount of MB that you want. The value you specify must be a multiple of 256 MB, with up to 6.5 GB of memory per every vCPU.
    • For GPUs, you must specify an integer value.
    • For Local SSD disks, you must specify the amount in GB. The size of a single Local SSD disk is 375 GB.


65372
65373
65374
65375
65376
65377
65378
65379
65380
65381
65382
65383
65384
65385
65386
65387
65388
65389
65390
65391
65392
65393
65394
65395
65396
65397
65398
65399
65400
65401
65402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65372

class ResourceCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of hardware resource that you want to specify.
  # You can specify any of the following values:
  #
  #    - VCPU
  #    - MEMORY
  #    - LOCAL_SSD
  #    - ACCELERATOR
  #
  #
  #
  # Specify as a separate entry in the list for each
  # individual resource type.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    ACCELERATOR = 429_815_371

    LOCAL_SSD = 508_934_896

    MEMORY = 123_056_385

    UNSPECIFIED = 526_786_327

    VCPU = 2_628_978
  end
end

#type::String

Returns The type of hardware resource that you want to specify. You can specify any of the following values:

  • VCPU
  • MEMORY
  • LOCAL_SSD
  • ACCELERATOR

Specify as a separate entry in the list for each individual resource type. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    The type of hardware resource that you want to specify. You can specify any of the following values:

    • VCPU
    • MEMORY
    • LOCAL_SSD
    • ACCELERATOR

    Specify as a separate entry in the list for each individual resource type. Check the Type enum for the list of possible values.



65372
65373
65374
65375
65376
65377
65378
65379
65380
65381
65382
65383
65384
65385
65386
65387
65388
65389
65390
65391
65392
65393
65394
65395
65396
65397
65398
65399
65400
65401
65402
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65372

class ResourceCommitment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of hardware resource that you want to specify.
  # You can specify any of the following values:
  #
  #    - VCPU
  #    - MEMORY
  #    - LOCAL_SSD
  #    - ACCELERATOR
  #
  #
  #
  # Specify as a separate entry in the list for each
  # individual resource type.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    ACCELERATOR = 429_815_371

    LOCAL_SSD = 508_934_896

    MEMORY = 123_056_385

    UNSPECIFIED = 526_786_327

    VCPU = 2_628_978
  end
end