Class: Google::Cloud::Compute::V1::ResourceMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourceMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Standardized resource metadata common to all compute resources.
Instance Attribute Summary collapse
-
#api_version ⇒ ::String
The version of the API interface that this resource was retrieved through.
-
#resource_type ⇒ ::String
The canonical resource type name in the format of a resource type as defined by AIP-123.
Instance Attribute Details
#api_version ⇒ ::String
Returns The version of the API interface that this resource was retrieved through.
For example, "2025-01-01" or "2025-01-01-preview".
68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68728 class ResourceMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_type ⇒ ::String
Returns The canonical resource type name in the format of a resource type
as defined by AIP-123.
For example, "compute.googleapis.com/Instance".
68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68728 class ResourceMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |