Class: Google::Cloud::Compute::V1::ResourcePolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them toschedule persistent disk snapshots.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
- #description ⇒ ::String
-
#disk_consistency_group_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyDiskConsistencyGroupPolicy
Resource policy for disk consistency groups.
-
#group_placement_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyGroupPlacementPolicy
Resource policy for instances for placement configuration.
-
#id ⇒ ::Integer
Output only.
-
#instance_schedule_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyInstanceSchedulePolicy
Resource policy for scheduling instance operations.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
The name of the resource, provided by the client when initially creating the resource.
- #region ⇒ ::String
-
#resource_status ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyResourceStatus
Output only.
-
#self_link ⇒ ::String
Output only.
-
#snapshot_schedule_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicy
Resource policy for persistent disks for creating snapshots.
-
#status ⇒ ::String
Output only.
-
#workload_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyWorkloadPolicy
Resource policy for defining instance placement for MIGs.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#description ⇒ ::String
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#disk_consistency_group_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyDiskConsistencyGroupPolicy
Returns Resource policy for disk consistency groups.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#group_placement_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyGroupPlacementPolicy
Returns Resource policy for instances for placement configuration.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#instance_schedule_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyInstanceSchedulePolicy
Returns Resource policy for scheduling instance operations.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#resource_policies for resource policies.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#name ⇒ ::String
Returns The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#region ⇒ ::String
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#resource_status ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyResourceStatus
Returns Output only. [Output Only] The system status of the resource policy.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#snapshot_schedule_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicy
Returns Resource policy for persistent disks for creating snapshots.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#status ⇒ ::String
Returns Output only. [Output Only] The status of resource policy creation. Check the Status enum for the list of possible values.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |
#workload_policy ⇒ ::Google::Cloud::Compute::V1::ResourcePolicyWorkloadPolicy
Returns Resource policy for defining instance placement for MIGs.
65479 65480 65481 65482 65483 65484 65485 65486 65487 65488 65489 65490 65491 65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65479 class ResourcePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The status of resource policy creation. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Resource policy is being created. CREATING = 455_564_985 # Resource policy is being deleted. DELETING = 528_602_024 # Resource policy is expired and will not run again. EXPIRED = 482_489_093 INVALID = 530_283_991 # Resource policy is ready to be used. READY = 77_848_963 end end |