Class: Google::Cloud::Compute::V1::ResourcePolicyGroupPlacementPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicyGroupPlacementPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation
Defined Under Namespace
Modules: AcceleratorTopologyMode, Collocation
Instance Attribute Summary collapse
-
#accelerator_topology_mode ⇒ ::String
Specifies the connection mode for the accelerator topology.
-
#availability_domain_count ⇒ ::Integer
The number of availability domains to spread instances across.
-
#collocation ⇒ ::String
Specifies network collocation Check the Collocation enum for the list of possible values.
-
#gpu_topology ⇒ ::String
Specifies the shape of the GPU slice, in slice based GPU families eg.
-
#vm_count ⇒ ::Integer
Number of VMs in this placement group.
Instance Attribute Details
#accelerator_topology_mode ⇒ ::String
Returns Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Check the AcceleratorTopologyMode enum for the list of possible values.
65596 65597 65598 65599 65600 65601 65602 65603 65604 65605 65606 65607 65608 65609 65610 65611 65612 65613 65614 65615 65616 65617 65618 65619 65620 65621 65622 65623 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65596 class ResourcePolicyGroupPlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies network collocation module Collocation # A value indicating that the enum field is not set. UNDEFINED_COLLOCATION = 0 COLLOCATED = 103_257_554 UNSPECIFIED_COLLOCATION = 464_308_205 end end |
#availability_domain_count ⇒ ::Integer
Returns The number of availability domains to spread instances across. If two instances are in different availability domain, they are not in the same low latency network.
65596 65597 65598 65599 65600 65601 65602 65603 65604 65605 65606 65607 65608 65609 65610 65611 65612 65613 65614 65615 65616 65617 65618 65619 65620 65621 65622 65623 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65596 class ResourcePolicyGroupPlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies network collocation module Collocation # A value indicating that the enum field is not set. UNDEFINED_COLLOCATION = 0 COLLOCATED = 103_257_554 UNSPECIFIED_COLLOCATION = 464_308_205 end end |
#collocation ⇒ ::String
Returns Specifies network collocation Check the Collocation enum for the list of possible values.
65596 65597 65598 65599 65600 65601 65602 65603 65604 65605 65606 65607 65608 65609 65610 65611 65612 65613 65614 65615 65616 65617 65618 65619 65620 65621 65622 65623 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65596 class ResourcePolicyGroupPlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies network collocation module Collocation # A value indicating that the enum field is not set. UNDEFINED_COLLOCATION = 0 COLLOCATED = 103_257_554 UNSPECIFIED_COLLOCATION = 464_308_205 end end |
#gpu_topology ⇒ ::String
Returns Specifies the shape of the GPU slice, in slice based GPU families eg. A4X.
65596 65597 65598 65599 65600 65601 65602 65603 65604 65605 65606 65607 65608 65609 65610 65611 65612 65613 65614 65615 65616 65617 65618 65619 65620 65621 65622 65623 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65596 class ResourcePolicyGroupPlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies network collocation module Collocation # A value indicating that the enum field is not set. UNDEFINED_COLLOCATION = 0 COLLOCATED = 103_257_554 UNSPECIFIED_COLLOCATION = 464_308_205 end end |
#vm_count ⇒ ::Integer
Returns Number of VMs in this placement group. Google does not recommend that you use this field unless you use a compact policy and you want your policy to work only if it contains this exact number of VMs.
65596 65597 65598 65599 65600 65601 65602 65603 65604 65605 65606 65607 65608 65609 65610 65611 65612 65613 65614 65615 65616 65617 65618 65619 65620 65621 65622 65623 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65596 class ResourcePolicyGroupPlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies network collocation module Collocation # A value indicating that the enum field is not set. UNDEFINED_COLLOCATION = 0 COLLOCATED = 103_257_554 UNSPECIFIED_COLLOCATION = 464_308_205 end end |