Class: Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Policy for retention of scheduled snapshots.

Defined Under Namespace

Modules: OnSourceDiskDelete

Instance Attribute Summary collapse

Instance Attribute Details

#max_retention_days::Integer

Returns Maximum age of the snapshot that is allowed to be kept.

Returns:

  • (::Integer)

    Maximum age of the snapshot that is allowed to be kept.



67531
67532
67533
67534
67535
67536
67537
67538
67539
67540
67541
67542
67543
67544
67545
67546
67547
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67531

class ResourcePolicySnapshotSchedulePolicyRetentionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the behavior to apply to scheduled snapshots when
  # the source disk is deleted.
  module OnSourceDiskDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_SOURCE_DISK_DELETE = 0

    APPLY_RETENTION_POLICY = 535_071_332

    KEEP_AUTO_SNAPSHOTS = 258_925_689

    UNSPECIFIED_ON_SOURCE_DISK_DELETE = 239_140_769
  end
end

#on_source_disk_delete::String

Returns Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Check the OnSourceDiskDelete enum for the list of possible values.

Returns:

  • (::String)

    Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Check the OnSourceDiskDelete enum for the list of possible values.



67531
67532
67533
67534
67535
67536
67537
67538
67539
67540
67541
67542
67543
67544
67545
67546
67547
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67531

class ResourcePolicySnapshotSchedulePolicyRetentionPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the behavior to apply to scheduled snapshots when
  # the source disk is deleted.
  module OnSourceDiskDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_SOURCE_DISK_DELETE = 0

    APPLY_RETENTION_POLICY = 535_071_332

    KEEP_AUTO_SNAPSHOTS = 258_925_689

    UNSPECIFIED_ON_SOURCE_DISK_DELETE = 239_140_769
  end
end