Class: Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicyRetentionPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Policy for retention of scheduled snapshots.
Defined Under Namespace
Modules: OnSourceDiskDelete
Instance Attribute Summary collapse
-
#max_retention_days ⇒ ::Integer
Maximum age of the snapshot that is allowed to be kept.
-
#on_source_disk_delete ⇒ ::String
Specifies the behavior to apply to scheduled snapshots when the source disk is deleted.
Instance Attribute Details
#max_retention_days ⇒ ::Integer
Returns Maximum age of the snapshot that is allowed to be kept.
65763 65764 65765 65766 65767 65768 65769 65770 65771 65772 65773 65774 65775 65776 65777 65778 65779 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65763 class ResourcePolicySnapshotSchedulePolicyRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the behavior to apply to scheduled snapshots when # the source disk is deleted. module OnSourceDiskDelete # A value indicating that the enum field is not set. UNDEFINED_ON_SOURCE_DISK_DELETE = 0 APPLY_RETENTION_POLICY = 535_071_332 KEEP_AUTO_SNAPSHOTS = 258_925_689 UNSPECIFIED_ON_SOURCE_DISK_DELETE = 239_140_769 end end |
#on_source_disk_delete ⇒ ::String
Returns Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Check the OnSourceDiskDelete enum for the list of possible values.
65763 65764 65765 65766 65767 65768 65769 65770 65771 65772 65773 65774 65775 65776 65777 65778 65779 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65763 class ResourcePolicySnapshotSchedulePolicyRetentionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the behavior to apply to scheduled snapshots when # the source disk is deleted. module OnSourceDiskDelete # A value indicating that the enum field is not set. UNDEFINED_ON_SOURCE_DISK_DELETE = 0 APPLY_RETENTION_POLICY = 535_071_332 KEEP_AUTO_SNAPSHOTS = 258_925_689 UNSPECIFIED_ON_SOURCE_DISK_DELETE = 239_140_769 end end |