Class: Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicySnapshotProperties
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicySnapshotProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specified snapshot properties for scheduled snapshots created by this policy.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#chain_name ⇒ ::String
Chain name that the snapshot is created in.
-
#guest_flush ⇒ ::Boolean
Indication to perform a 'guest aware' snapshot.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels to apply to scheduled snapshots.
-
#storage_locations ⇒ ::Array<::String>
Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).
Instance Attribute Details
#chain_name ⇒ ::String
Returns Chain name that the snapshot is created in.
67577 67578 67579 67580 67581 67582 67583 67584 67585 67586 67587 67588 67589 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67577 class ResourcePolicySnapshotSchedulePolicySnapshotProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#guest_flush ⇒ ::Boolean
Returns Indication to perform a 'guest aware' snapshot.
67577 67578 67579 67580 67581 67582 67583 67584 67585 67586 67587 67588 67589 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67577 class ResourcePolicySnapshotSchedulePolicySnapshotProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty.
67577 67578 67579 67580 67581 67582 67583 67584 67585 67586 67587 67588 67589 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67577 class ResourcePolicySnapshotSchedulePolicySnapshotProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#storage_locations ⇒ ::Array<::String>
Returns Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).
67577 67578 67579 67580 67581 67582 67583 67584 67585 67586 67587 67588 67589 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67577 class ResourcePolicySnapshotSchedulePolicySnapshotProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |