Class: Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicySnapshotProperties
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicySnapshotSchedulePolicySnapshotProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specified snapshot properties for scheduled snapshots created by this policy.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#chain_name ⇒ ::String
Chain name that the snapshot is created in.
-
#guest_flush ⇒ ::Boolean
Indication to perform a 'guest aware' snapshot.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels to apply to scheduled snapshots.
-
#storage_locations ⇒ ::Array<::String>
Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).
Instance Attribute Details
#chain_name ⇒ ::String
Returns Chain name that the snapshot is created in.
66894 66895 66896 66897 66898 66899 66900 66901 66902 66903 66904 66905 66906 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66894 class ResourcePolicySnapshotSchedulePolicySnapshotProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#guest_flush ⇒ ::Boolean
Returns Indication to perform a 'guest aware' snapshot.
66894 66895 66896 66897 66898 66899 66900 66901 66902 66903 66904 66905 66906 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66894 class ResourcePolicySnapshotSchedulePolicySnapshotProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty.
66894 66895 66896 66897 66898 66899 66900 66901 66902 66903 66904 66905 66906 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66894 class ResourcePolicySnapshotSchedulePolicySnapshotProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#storage_locations ⇒ ::Array<::String>
Returns Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).
66894 66895 66896 66897 66898 66899 66900 66901 66902 66903 66904 66905 66906 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66894 class ResourcePolicySnapshotSchedulePolicySnapshotProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |