Class: Google::Cloud::Compute::V1::ResourcePolicyWeeklyCycleDayOfWeek

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Day

Instance Attribute Summary collapse

Instance Attribute Details

#day::String

Returns Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.

Returns:

  • (::String)

    Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.



67614
67615
67616
67617
67618
67619
67620
67621
67622
67623
67624
67625
67626
67627
67628
67629
67630
67631
67632
67633
67634
67635
67636
67637
67638
67639
67640
67641
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67614

class ResourcePolicyWeeklyCycleDayOfWeek
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines a schedule that runs on specific days of the week. Specify
  # one or more days. The following options are available:
  # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
  module Day
    # A value indicating that the enum field is not set.
    UNDEFINED_DAY = 0

    FRIDAY = 471_398_751

    INVALID = 530_283_991

    MONDAY = 132_310_288

    SATURDAY = 279_037_881

    SUNDAY = 309_626_320

    THURSDAY = 207_198_682

    TUESDAY = 277_509_677

    WEDNESDAY = 422_029_110
  end
end

#duration::String

Returns Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.

Returns:

  • (::String)

    Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.



67614
67615
67616
67617
67618
67619
67620
67621
67622
67623
67624
67625
67626
67627
67628
67629
67630
67631
67632
67633
67634
67635
67636
67637
67638
67639
67640
67641
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67614

class ResourcePolicyWeeklyCycleDayOfWeek
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines a schedule that runs on specific days of the week. Specify
  # one or more days. The following options are available:
  # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
  module Day
    # A value indicating that the enum field is not set.
    UNDEFINED_DAY = 0

    FRIDAY = 471_398_751

    INVALID = 530_283_991

    MONDAY = 132_310_288

    SATURDAY = 279_037_881

    SUNDAY = 309_626_320

    THURSDAY = 207_198_682

    TUESDAY = 277_509_677

    WEDNESDAY = 422_029_110
  end
end

#start_time::String

Returns Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.

Returns:

  • (::String)

    Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.



67614
67615
67616
67617
67618
67619
67620
67621
67622
67623
67624
67625
67626
67627
67628
67629
67630
67631
67632
67633
67634
67635
67636
67637
67638
67639
67640
67641
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67614

class ResourcePolicyWeeklyCycleDayOfWeek
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines a schedule that runs on specific days of the week. Specify
  # one or more days. The following options are available:
  # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
  module Day
    # A value indicating that the enum field is not set.
    UNDEFINED_DAY = 0

    FRIDAY = 471_398_751

    INVALID = 530_283_991

    MONDAY = 132_310_288

    SATURDAY = 279_037_881

    SUNDAY = 309_626_320

    THURSDAY = 207_198_682

    TUESDAY = 277_509_677

    WEDNESDAY = 422_029_110
  end
end