Class: Google::Cloud::Compute::V1::ResourcePolicyWeeklyCycleDayOfWeek
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicyWeeklyCycleDayOfWeek
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Day
Instance Attribute Summary collapse
-
#day ⇒ ::String
Defines a schedule that runs on specific days of the week.
-
#duration ⇒ ::String
Output only.
-
#start_time ⇒ ::String
Time within the window to start the operations.
Instance Attribute Details
#day ⇒ ::String
Returns Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.
66931 66932 66933 66934 66935 66936 66937 66938 66939 66940 66941 66942 66943 66944 66945 66946 66947 66948 66949 66950 66951 66952 66953 66954 66955 66956 66957 66958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66931 class ResourcePolicyWeeklyCycleDayOfWeek include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a schedule that runs on specific days of the week. Specify # one or more days. The following options are available: # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. module Day # A value indicating that the enum field is not set. UNDEFINED_DAY = 0 FRIDAY = 471_398_751 INVALID = 530_283_991 MONDAY = 132_310_288 SATURDAY = 279_037_881 SUNDAY = 309_626_320 THURSDAY = 207_198_682 TUESDAY = 277_509_677 WEDNESDAY = 422_029_110 end end |
#duration ⇒ ::String
Returns Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.
66931 66932 66933 66934 66935 66936 66937 66938 66939 66940 66941 66942 66943 66944 66945 66946 66947 66948 66949 66950 66951 66952 66953 66954 66955 66956 66957 66958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66931 class ResourcePolicyWeeklyCycleDayOfWeek include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a schedule that runs on specific days of the week. Specify # one or more days. The following options are available: # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. module Day # A value indicating that the enum field is not set. UNDEFINED_DAY = 0 FRIDAY = 471_398_751 INVALID = 530_283_991 MONDAY = 132_310_288 SATURDAY = 279_037_881 SUNDAY = 309_626_320 THURSDAY = 207_198_682 TUESDAY = 277_509_677 WEDNESDAY = 422_029_110 end end |
#start_time ⇒ ::String
Returns Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
66931 66932 66933 66934 66935 66936 66937 66938 66939 66940 66941 66942 66943 66944 66945 66946 66947 66948 66949 66950 66951 66952 66953 66954 66955 66956 66957 66958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66931 class ResourcePolicyWeeklyCycleDayOfWeek include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a schedule that runs on specific days of the week. Specify # one or more days. The following options are available: # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. module Day # A value indicating that the enum field is not set. UNDEFINED_DAY = 0 FRIDAY = 471_398_751 INVALID = 530_283_991 MONDAY = 132_310_288 SATURDAY = 279_037_881 SUNDAY = 309_626_320 THURSDAY = 207_198_682 TUESDAY = 277_509_677 WEDNESDAY = 422_029_110 end end |