Class: Google::Cloud::Compute::V1::ResourcePolicyWeeklyCycleDayOfWeek

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Day

Instance Attribute Summary collapse

Instance Attribute Details

#day::String

Returns Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.

Returns:

  • (::String)

    Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.



65846
65847
65848
65849
65850
65851
65852
65853
65854
65855
65856
65857
65858
65859
65860
65861
65862
65863
65864
65865
65866
65867
65868
65869
65870
65871
65872
65873
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65846

class ResourcePolicyWeeklyCycleDayOfWeek
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines a schedule that runs on specific days of the week. Specify
  # one or more days. The following options are available:
  # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
  module Day
    # A value indicating that the enum field is not set.
    UNDEFINED_DAY = 0

    FRIDAY = 471_398_751

    INVALID = 530_283_991

    MONDAY = 132_310_288

    SATURDAY = 279_037_881

    SUNDAY = 309_626_320

    THURSDAY = 207_198_682

    TUESDAY = 277_509_677

    WEDNESDAY = 422_029_110
  end
end

#duration::String

Returns Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.

Returns:

  • (::String)

    Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.



65846
65847
65848
65849
65850
65851
65852
65853
65854
65855
65856
65857
65858
65859
65860
65861
65862
65863
65864
65865
65866
65867
65868
65869
65870
65871
65872
65873
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65846

class ResourcePolicyWeeklyCycleDayOfWeek
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines a schedule that runs on specific days of the week. Specify
  # one or more days. The following options are available:
  # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
  module Day
    # A value indicating that the enum field is not set.
    UNDEFINED_DAY = 0

    FRIDAY = 471_398_751

    INVALID = 530_283_991

    MONDAY = 132_310_288

    SATURDAY = 279_037_881

    SUNDAY = 309_626_320

    THURSDAY = 207_198_682

    TUESDAY = 277_509_677

    WEDNESDAY = 422_029_110
  end
end

#start_time::String

Returns Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.

Returns:

  • (::String)

    Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.



65846
65847
65848
65849
65850
65851
65852
65853
65854
65855
65856
65857
65858
65859
65860
65861
65862
65863
65864
65865
65866
65867
65868
65869
65870
65871
65872
65873
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65846

class ResourcePolicyWeeklyCycleDayOfWeek
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines a schedule that runs on specific days of the week. Specify
  # one or more days. The following options are available:
  # MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
  module Day
    # A value indicating that the enum field is not set.
    UNDEFINED_DAY = 0

    FRIDAY = 471_398_751

    INVALID = 530_283_991

    MONDAY = 132_310_288

    SATURDAY = 279_037_881

    SUNDAY = 309_626_320

    THURSDAY = 207_198_682

    TUESDAY = 277_509_677

    WEDNESDAY = 422_029_110
  end
end