Class: Google::Cloud::Compute::V1::ResourcePolicyWeeklyCycleDayOfWeek
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicyWeeklyCycleDayOfWeek
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Day
Instance Attribute Summary collapse
-
#day ⇒ ::String
Defines a schedule that runs on specific days of the week.
-
#duration ⇒ ::String
[Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.
-
#start_time ⇒ ::String
Time within the window to start the operations.
Instance Attribute Details
#day ⇒ ::String
Returns Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.
28139 28140 28141 28142 28143 28144 28145 28146 28147 28148 28149 28150 28151 28152 28153 28154 28155 28156 28157 28158 28159 28160 28161 28162 28163 28164 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28139 class ResourcePolicyWeeklyCycleDayOfWeek include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. module Day # A value indicating that the enum field is not set. UNDEFINED_DAY = 0 FRIDAY = 471_398_751 INVALID = 530_283_991 MONDAY = 132_310_288 SATURDAY = 279_037_881 SUNDAY = 309_626_320 THURSDAY = 207_198_682 TUESDAY = 277_509_677 WEDNESDAY = 422_029_110 end end |
#duration ⇒ ::String
Returns [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.
28139 28140 28141 28142 28143 28144 28145 28146 28147 28148 28149 28150 28151 28152 28153 28154 28155 28156 28157 28158 28159 28160 28161 28162 28163 28164 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28139 class ResourcePolicyWeeklyCycleDayOfWeek include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. module Day # A value indicating that the enum field is not set. UNDEFINED_DAY = 0 FRIDAY = 471_398_751 INVALID = 530_283_991 MONDAY = 132_310_288 SATURDAY = 279_037_881 SUNDAY = 309_626_320 THURSDAY = 207_198_682 TUESDAY = 277_509_677 WEDNESDAY = 422_029_110 end end |
#start_time ⇒ ::String
Returns Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
28139 28140 28141 28142 28143 28144 28145 28146 28147 28148 28149 28150 28151 28152 28153 28154 28155 28156 28157 28158 28159 28160 28161 28162 28163 28164 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28139 class ResourcePolicyWeeklyCycleDayOfWeek include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. module Day # A value indicating that the enum field is not set. UNDEFINED_DAY = 0 FRIDAY = 471_398_751 INVALID = 530_283_991 MONDAY = 132_310_288 SATURDAY = 279_037_881 SUNDAY = 309_626_320 THURSDAY = 207_198_682 TUESDAY = 277_509_677 WEDNESDAY = 422_029_110 end end |