Class: Google::Cloud::Compute::V1::ResourcePolicyWeeklyCycleDayOfWeek
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicyWeeklyCycleDayOfWeek
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Day
Instance Attribute Summary collapse
-
#day ⇒ ::String
Defines a schedule that runs on specific days of the week.
-
#duration ⇒ ::String
[Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.
-
#start_time ⇒ ::String
Time within the window to start the operations.
Instance Attribute Details
#day ⇒ ::String
Returns Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. Check the Day enum for the list of possible values.
23450 23451 23452 23453 23454 23455 23456 23457 23458 23459 23460 23461 23462 23463 23464 23465 23466 23467 23468 23469 23470 23471 23472 23473 23474 23475 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23450 class ResourcePolicyWeeklyCycleDayOfWeek include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. module Day # A value indicating that the enum field is not set. UNDEFINED_DAY = 0 FRIDAY = 471398751 INVALID = 530283991 MONDAY = 132310288 SATURDAY = 279037881 SUNDAY = 309626320 THURSDAY = 207198682 TUESDAY = 277509677 WEDNESDAY = 422029110 end end |
#duration ⇒ ::String
Returns [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario.
23450 23451 23452 23453 23454 23455 23456 23457 23458 23459 23460 23461 23462 23463 23464 23465 23466 23467 23468 23469 23470 23471 23472 23473 23474 23475 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23450 class ResourcePolicyWeeklyCycleDayOfWeek include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. module Day # A value indicating that the enum field is not set. UNDEFINED_DAY = 0 FRIDAY = 471398751 INVALID = 530283991 MONDAY = 132310288 SATURDAY = 279037881 SUNDAY = 309626320 THURSDAY = 207198682 TUESDAY = 277509677 WEDNESDAY = 422029110 end end |
#start_time ⇒ ::String
Returns Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
23450 23451 23452 23453 23454 23455 23456 23457 23458 23459 23460 23461 23462 23463 23464 23465 23466 23467 23468 23469 23470 23471 23472 23473 23474 23475 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 23450 class ResourcePolicyWeeklyCycleDayOfWeek include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines a schedule that runs on specific days of the week. Specify one or more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY. module Day # A value indicating that the enum field is not set. UNDEFINED_DAY = 0 FRIDAY = 471398751 INVALID = 530283991 MONDAY = 132310288 SATURDAY = 279037881 SUNDAY = 309626320 THURSDAY = 207198682 TUESDAY = 277509677 WEDNESDAY = 422029110 end end |