Class: Google::Cloud::Compute::V1::ResourcePolicyWorkloadPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicyWorkloadPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents the workload policy.
Defined Under Namespace
Modules: AcceleratorTopologyMode, MaxTopologyDistance, Type
Instance Attribute Summary collapse
-
#accelerator_topology ⇒ ::String
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
-
#accelerator_topology_mode ⇒ ::String
Specifies the connection mode for the accelerator topology.
-
#max_topology_distance ⇒ ::String
Specifies the maximum distance between instances.
-
#type ⇒ ::String
Specifies the intent of the instance placement in the MIG.
Instance Attribute Details
#accelerator_topology ⇒ ::String
Returns Specifies the topology required to create a partition for VMs that have interconnected GPUs.
67661 67662 67663 67664 67665 67666 67667 67668 67669 67670 67671 67672 67673 67674 67675 67676 67677 67678 67679 67680 67681 67682 67683 67684 67685 67686 67687 67688 67689 67690 67691 67692 67693 67694 67695 67696 67697 67698 67699 67700 67701 67702 67703 67704 67705 67706 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67661 class ResourcePolicyWorkloadPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies the maximum distance between instances. module MaxTopologyDistance # A value indicating that the enum field is not set. UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0 # VMs must be provisioned in the same block. BLOCK = 63_294_573 # VMs must be provisioned in the same cluster. CLUSTER = 516_333_018 # VMs must be provisioned in the same subblock. SUBBLOCK = 316_202_573 end # Specifies the intent of the instance placement in the MIG. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG spreads out the instances as much as possible for high availability. HIGH_AVAILABILITY = 409_487_576 # MIG provisions instances as close to each other as possible for high # throughput. HIGH_THROUGHPUT = 146_499_815 end end |
#accelerator_topology_mode ⇒ ::String
Returns Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Check the AcceleratorTopologyMode enum for the list of possible values.
67661 67662 67663 67664 67665 67666 67667 67668 67669 67670 67671 67672 67673 67674 67675 67676 67677 67678 67679 67680 67681 67682 67683 67684 67685 67686 67687 67688 67689 67690 67691 67692 67693 67694 67695 67696 67697 67698 67699 67700 67701 67702 67703 67704 67705 67706 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67661 class ResourcePolicyWorkloadPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies the maximum distance between instances. module MaxTopologyDistance # A value indicating that the enum field is not set. UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0 # VMs must be provisioned in the same block. BLOCK = 63_294_573 # VMs must be provisioned in the same cluster. CLUSTER = 516_333_018 # VMs must be provisioned in the same subblock. SUBBLOCK = 316_202_573 end # Specifies the intent of the instance placement in the MIG. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG spreads out the instances as much as possible for high availability. HIGH_AVAILABILITY = 409_487_576 # MIG provisions instances as close to each other as possible for high # throughput. HIGH_THROUGHPUT = 146_499_815 end end |
#max_topology_distance ⇒ ::String
Returns Specifies the maximum distance between instances. Check the MaxTopologyDistance enum for the list of possible values.
67661 67662 67663 67664 67665 67666 67667 67668 67669 67670 67671 67672 67673 67674 67675 67676 67677 67678 67679 67680 67681 67682 67683 67684 67685 67686 67687 67688 67689 67690 67691 67692 67693 67694 67695 67696 67697 67698 67699 67700 67701 67702 67703 67704 67705 67706 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67661 class ResourcePolicyWorkloadPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies the maximum distance between instances. module MaxTopologyDistance # A value indicating that the enum field is not set. UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0 # VMs must be provisioned in the same block. BLOCK = 63_294_573 # VMs must be provisioned in the same cluster. CLUSTER = 516_333_018 # VMs must be provisioned in the same subblock. SUBBLOCK = 316_202_573 end # Specifies the intent of the instance placement in the MIG. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG spreads out the instances as much as possible for high availability. HIGH_AVAILABILITY = 409_487_576 # MIG provisions instances as close to each other as possible for high # throughput. HIGH_THROUGHPUT = 146_499_815 end end |
#type ⇒ ::String
Returns Specifies the intent of the instance placement in the MIG. Check the Type enum for the list of possible values.
67661 67662 67663 67664 67665 67666 67667 67668 67669 67670 67671 67672 67673 67674 67675 67676 67677 67678 67679 67680 67681 67682 67683 67684 67685 67686 67687 67688 67689 67690 67691 67692 67693 67694 67695 67696 67697 67698 67699 67700 67701 67702 67703 67704 67705 67706 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67661 class ResourcePolicyWorkloadPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies the maximum distance between instances. module MaxTopologyDistance # A value indicating that the enum field is not set. UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0 # VMs must be provisioned in the same block. BLOCK = 63_294_573 # VMs must be provisioned in the same cluster. CLUSTER = 516_333_018 # VMs must be provisioned in the same subblock. SUBBLOCK = 316_202_573 end # Specifies the intent of the instance placement in the MIG. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG spreads out the instances as much as possible for high availability. HIGH_AVAILABILITY = 409_487_576 # MIG provisions instances as close to each other as possible for high # throughput. HIGH_THROUGHPUT = 146_499_815 end end |