Class: Google::Cloud::Compute::V1::ResourcePolicyWorkloadPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents the workload policy.

Defined Under Namespace

Modules: AcceleratorTopologyMode, MaxTopologyDistance, Type

Instance Attribute Summary collapse

Instance Attribute Details

#accelerator_topology::String

Returns Specifies the topology required to create a partition for VMs that have interconnected GPUs.

Returns:

  • (::String)

    Specifies the topology required to create a partition for VMs that have interconnected GPUs.



66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
66989
66990
66991
66992
66993
66994
66995
66996
66997
66998
66999
67000
67001
67002
67003
67004
67005
67006
67007
67008
67009
67010
67011
67012
67013
67014
67015
67016
67017
67018
67019
67020
67021
67022
67023
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66978

class ResourcePolicyWorkloadPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the connection mode for the accelerator topology. If not
  # specified, the default is AUTO_CONNECT.
  module AcceleratorTopologyMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0

    # The interconnected chips are pre-configured at the time of VM creation.
    AUTO_CONNECT = 491_872_826

    # The interconnected chips are connected on demand. At the time of VM
    # creation, the chips are not connected.
    PROVISION_ONLY = 399_134_966
  end

  # Specifies the maximum distance between instances.
  module MaxTopologyDistance
    # A value indicating that the enum field is not set.
    UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0

    # VMs must be provisioned in the same block.
    BLOCK = 63_294_573

    # VMs must be provisioned in the same cluster.
    CLUSTER = 516_333_018

    # VMs must be provisioned in the same subblock.
    SUBBLOCK = 316_202_573
  end

  # Specifies the intent of the instance placement in the MIG.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG spreads out the instances as much as possible for high availability.
    HIGH_AVAILABILITY = 409_487_576

    # MIG provisions instances as close to each other as possible for high
    # throughput.
    HIGH_THROUGHPUT = 146_499_815
  end
end

#accelerator_topology_mode::String

Returns Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Check the AcceleratorTopologyMode enum for the list of possible values.

Returns:

  • (::String)

    Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Check the AcceleratorTopologyMode enum for the list of possible values.



66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
66989
66990
66991
66992
66993
66994
66995
66996
66997
66998
66999
67000
67001
67002
67003
67004
67005
67006
67007
67008
67009
67010
67011
67012
67013
67014
67015
67016
67017
67018
67019
67020
67021
67022
67023
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66978

class ResourcePolicyWorkloadPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the connection mode for the accelerator topology. If not
  # specified, the default is AUTO_CONNECT.
  module AcceleratorTopologyMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0

    # The interconnected chips are pre-configured at the time of VM creation.
    AUTO_CONNECT = 491_872_826

    # The interconnected chips are connected on demand. At the time of VM
    # creation, the chips are not connected.
    PROVISION_ONLY = 399_134_966
  end

  # Specifies the maximum distance between instances.
  module MaxTopologyDistance
    # A value indicating that the enum field is not set.
    UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0

    # VMs must be provisioned in the same block.
    BLOCK = 63_294_573

    # VMs must be provisioned in the same cluster.
    CLUSTER = 516_333_018

    # VMs must be provisioned in the same subblock.
    SUBBLOCK = 316_202_573
  end

  # Specifies the intent of the instance placement in the MIG.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG spreads out the instances as much as possible for high availability.
    HIGH_AVAILABILITY = 409_487_576

    # MIG provisions instances as close to each other as possible for high
    # throughput.
    HIGH_THROUGHPUT = 146_499_815
  end
end

#max_topology_distance::String

Returns Specifies the maximum distance between instances. Check the MaxTopologyDistance enum for the list of possible values.

Returns:

  • (::String)

    Specifies the maximum distance between instances. Check the MaxTopologyDistance enum for the list of possible values.



66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
66989
66990
66991
66992
66993
66994
66995
66996
66997
66998
66999
67000
67001
67002
67003
67004
67005
67006
67007
67008
67009
67010
67011
67012
67013
67014
67015
67016
67017
67018
67019
67020
67021
67022
67023
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66978

class ResourcePolicyWorkloadPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the connection mode for the accelerator topology. If not
  # specified, the default is AUTO_CONNECT.
  module AcceleratorTopologyMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0

    # The interconnected chips are pre-configured at the time of VM creation.
    AUTO_CONNECT = 491_872_826

    # The interconnected chips are connected on demand. At the time of VM
    # creation, the chips are not connected.
    PROVISION_ONLY = 399_134_966
  end

  # Specifies the maximum distance between instances.
  module MaxTopologyDistance
    # A value indicating that the enum field is not set.
    UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0

    # VMs must be provisioned in the same block.
    BLOCK = 63_294_573

    # VMs must be provisioned in the same cluster.
    CLUSTER = 516_333_018

    # VMs must be provisioned in the same subblock.
    SUBBLOCK = 316_202_573
  end

  # Specifies the intent of the instance placement in the MIG.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG spreads out the instances as much as possible for high availability.
    HIGH_AVAILABILITY = 409_487_576

    # MIG provisions instances as close to each other as possible for high
    # throughput.
    HIGH_THROUGHPUT = 146_499_815
  end
end

#type::String

Returns Specifies the intent of the instance placement in the MIG. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    Specifies the intent of the instance placement in the MIG. Check the Type enum for the list of possible values.



66978
66979
66980
66981
66982
66983
66984
66985
66986
66987
66988
66989
66990
66991
66992
66993
66994
66995
66996
66997
66998
66999
67000
67001
67002
67003
67004
67005
67006
67007
67008
67009
67010
67011
67012
67013
67014
67015
67016
67017
67018
67019
67020
67021
67022
67023
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66978

class ResourcePolicyWorkloadPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the connection mode for the accelerator topology. If not
  # specified, the default is AUTO_CONNECT.
  module AcceleratorTopologyMode
    # A value indicating that the enum field is not set.
    UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0

    # The interconnected chips are pre-configured at the time of VM creation.
    AUTO_CONNECT = 491_872_826

    # The interconnected chips are connected on demand. At the time of VM
    # creation, the chips are not connected.
    PROVISION_ONLY = 399_134_966
  end

  # Specifies the maximum distance between instances.
  module MaxTopologyDistance
    # A value indicating that the enum field is not set.
    UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0

    # VMs must be provisioned in the same block.
    BLOCK = 63_294_573

    # VMs must be provisioned in the same cluster.
    CLUSTER = 516_333_018

    # VMs must be provisioned in the same subblock.
    SUBBLOCK = 316_202_573
  end

  # Specifies the intent of the instance placement in the MIG.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # MIG spreads out the instances as much as possible for high availability.
    HIGH_AVAILABILITY = 409_487_576

    # MIG provisions instances as close to each other as possible for high
    # throughput.
    HIGH_THROUGHPUT = 146_499_815
  end
end