Class: Google::Cloud::Compute::V1::ResourcePolicyWorkloadPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourcePolicyWorkloadPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents the workload policy.
Defined Under Namespace
Modules: AcceleratorTopologyMode, MaxTopologyDistance, Type
Instance Attribute Summary collapse
-
#accelerator_topology ⇒ ::String
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
-
#accelerator_topology_mode ⇒ ::String
Specifies the connection mode for the accelerator topology.
-
#max_topology_distance ⇒ ::String
Specifies the maximum distance between instances.
-
#type ⇒ ::String
Specifies the intent of the instance placement in the MIG.
Instance Attribute Details
#accelerator_topology ⇒ ::String
Returns Specifies the topology required to create a partition for VMs that have interconnected GPUs.
65893 65894 65895 65896 65897 65898 65899 65900 65901 65902 65903 65904 65905 65906 65907 65908 65909 65910 65911 65912 65913 65914 65915 65916 65917 65918 65919 65920 65921 65922 65923 65924 65925 65926 65927 65928 65929 65930 65931 65932 65933 65934 65935 65936 65937 65938 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65893 class ResourcePolicyWorkloadPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies the maximum distance between instances. module MaxTopologyDistance # A value indicating that the enum field is not set. UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0 # VMs must be provisioned in the same block. BLOCK = 63_294_573 # VMs must be provisioned in the same cluster. CLUSTER = 516_333_018 # VMs must be provisioned in the same subblock. SUBBLOCK = 316_202_573 end # Specifies the intent of the instance placement in the MIG. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG spreads out the instances as much as possible for high availability. HIGH_AVAILABILITY = 409_487_576 # MIG provisions instances as close to each other as possible for high # throughput. HIGH_THROUGHPUT = 146_499_815 end end |
#accelerator_topology_mode ⇒ ::String
Returns Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Check the AcceleratorTopologyMode enum for the list of possible values.
65893 65894 65895 65896 65897 65898 65899 65900 65901 65902 65903 65904 65905 65906 65907 65908 65909 65910 65911 65912 65913 65914 65915 65916 65917 65918 65919 65920 65921 65922 65923 65924 65925 65926 65927 65928 65929 65930 65931 65932 65933 65934 65935 65936 65937 65938 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65893 class ResourcePolicyWorkloadPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies the maximum distance between instances. module MaxTopologyDistance # A value indicating that the enum field is not set. UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0 # VMs must be provisioned in the same block. BLOCK = 63_294_573 # VMs must be provisioned in the same cluster. CLUSTER = 516_333_018 # VMs must be provisioned in the same subblock. SUBBLOCK = 316_202_573 end # Specifies the intent of the instance placement in the MIG. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG spreads out the instances as much as possible for high availability. HIGH_AVAILABILITY = 409_487_576 # MIG provisions instances as close to each other as possible for high # throughput. HIGH_THROUGHPUT = 146_499_815 end end |
#max_topology_distance ⇒ ::String
Returns Specifies the maximum distance between instances. Check the MaxTopologyDistance enum for the list of possible values.
65893 65894 65895 65896 65897 65898 65899 65900 65901 65902 65903 65904 65905 65906 65907 65908 65909 65910 65911 65912 65913 65914 65915 65916 65917 65918 65919 65920 65921 65922 65923 65924 65925 65926 65927 65928 65929 65930 65931 65932 65933 65934 65935 65936 65937 65938 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65893 class ResourcePolicyWorkloadPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies the maximum distance between instances. module MaxTopologyDistance # A value indicating that the enum field is not set. UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0 # VMs must be provisioned in the same block. BLOCK = 63_294_573 # VMs must be provisioned in the same cluster. CLUSTER = 516_333_018 # VMs must be provisioned in the same subblock. SUBBLOCK = 316_202_573 end # Specifies the intent of the instance placement in the MIG. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG spreads out the instances as much as possible for high availability. HIGH_AVAILABILITY = 409_487_576 # MIG provisions instances as close to each other as possible for high # throughput. HIGH_THROUGHPUT = 146_499_815 end end |
#type ⇒ ::String
Returns Specifies the intent of the instance placement in the MIG. Check the Type enum for the list of possible values.
65893 65894 65895 65896 65897 65898 65899 65900 65901 65902 65903 65904 65905 65906 65907 65908 65909 65910 65911 65912 65913 65914 65915 65916 65917 65918 65919 65920 65921 65922 65923 65924 65925 65926 65927 65928 65929 65930 65931 65932 65933 65934 65935 65936 65937 65938 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 65893 class ResourcePolicyWorkloadPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the connection mode for the accelerator topology. If not # specified, the default is AUTO_CONNECT. module AcceleratorTopologyMode # A value indicating that the enum field is not set. UNDEFINED_ACCELERATOR_TOPOLOGY_MODE = 0 # The interconnected chips are pre-configured at the time of VM creation. AUTO_CONNECT = 491_872_826 # The interconnected chips are connected on demand. At the time of VM # creation, the chips are not connected. PROVISION_ONLY = 399_134_966 end # Specifies the maximum distance between instances. module MaxTopologyDistance # A value indicating that the enum field is not set. UNDEFINED_MAX_TOPOLOGY_DISTANCE = 0 # VMs must be provisioned in the same block. BLOCK = 63_294_573 # VMs must be provisioned in the same cluster. CLUSTER = 516_333_018 # VMs must be provisioned in the same subblock. SUBBLOCK = 316_202_573 end # Specifies the intent of the instance placement in the MIG. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # MIG spreads out the instances as much as possible for high availability. HIGH_AVAILABILITY = 409_487_576 # MIG provisions instances as close to each other as possible for high # throughput. HIGH_THROUGHPUT = 146_499_815 end end |