Class: Google::Cloud::Compute::V1::ResourceStatusPhysicalHostTopologyAdditionalAttributes
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourceStatusPhysicalHostTopologyAdditionalAttributes
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Additional location information of the running instance.
Defined Under Namespace
Classes: AcceleratorTopologyIdsEntry
Instance Attribute Summary collapse
Instance Attribute Details
#accelerator_topology_ids ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Output only. The IDs of the accelerator topologies the instance belongs to. For example The key will be topologies like "4x4", "2x2x2" and the value will be the location ID of the topologies.
67806 67807 67808 67809 67810 67811 67812 67813 67814 67815 67816 67817 67818 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67806 class ResourceStatusPhysicalHostTopologyAdditionalAttributes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AcceleratorTopologyIdsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |