Class: Google::Cloud::Compute::V1::ResourceStatusReservationConsumptionInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourceStatusReservationConsumptionInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Reservation consumption information that the instance is consuming from.
Instance Attribute Summary collapse
-
#consumed_reservation ⇒ ::String
Output only.
Instance Attribute Details
#consumed_reservation ⇒ ::String
Returns Output only. [Output Only] The full resource name of the reservation that this instance is consuming from.
66033 66034 66035 66036 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66033 class ResourceStatusReservationConsumptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |