Class: Google::Cloud::Compute::V1::ResourceStatusShutdownDetails
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ResourceStatusShutdownDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies if the instance is in PENDING_STOP state or there is a
programmed stop scheduled.
Defined Under Namespace
Modules: StopState, TargetState
Instance Attribute Summary collapse
-
#max_duration ⇒ ::Google::Cloud::Compute::V1::Duration
The duration for graceful shutdown.
-
#request_timestamp ⇒ ::String
Past timestamp indicating the beginning of current
stopStatein RFC3339 text format. -
#stop_state ⇒ ::String
Current stopping state of the instance.
-
#target_state ⇒ ::String
Target instance state.
Instance Attribute Details
#max_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Returns The duration for graceful shutdown. Only applicable when
stop_state=PENDING_STOP.
69427 69428 69429 69430 69431 69432 69433 69434 69435 69436 69437 69438 69439 69440 69441 69442 69443 69444 69445 69446 69447 69448 69449 69450 69451 69452 69453 69454 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69427 class ResourceStatusShutdownDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Current stopping state of the instance. module StopState # A value indicating that the enum field is not set. UNDEFINED_STOP_STATE = 0 # The instance is gracefully shutting down. PENDING_STOP = 362_509_770 # The instance is stopping. STOPPING = 350_791_796 end # Target instance state. module TargetState # A value indicating that the enum field is not set. UNDEFINED_TARGET_STATE = 0 # The instance will be deleted. DELETED = 120_962_041 # The instance will be stopped. STOPPED = 444_276_141 end end |
#request_timestamp ⇒ ::String
Returns Past timestamp indicating the beginning of current stopState in RFC3339 text format.
69427 69428 69429 69430 69431 69432 69433 69434 69435 69436 69437 69438 69439 69440 69441 69442 69443 69444 69445 69446 69447 69448 69449 69450 69451 69452 69453 69454 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69427 class ResourceStatusShutdownDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Current stopping state of the instance. module StopState # A value indicating that the enum field is not set. UNDEFINED_STOP_STATE = 0 # The instance is gracefully shutting down. PENDING_STOP = 362_509_770 # The instance is stopping. STOPPING = 350_791_796 end # Target instance state. module TargetState # A value indicating that the enum field is not set. UNDEFINED_TARGET_STATE = 0 # The instance will be deleted. DELETED = 120_962_041 # The instance will be stopped. STOPPED = 444_276_141 end end |
#stop_state ⇒ ::String
Returns Current stopping state of the instance. Check the StopState enum for the list of possible values.
69427 69428 69429 69430 69431 69432 69433 69434 69435 69436 69437 69438 69439 69440 69441 69442 69443 69444 69445 69446 69447 69448 69449 69450 69451 69452 69453 69454 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69427 class ResourceStatusShutdownDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Current stopping state of the instance. module StopState # A value indicating that the enum field is not set. UNDEFINED_STOP_STATE = 0 # The instance is gracefully shutting down. PENDING_STOP = 362_509_770 # The instance is stopping. STOPPING = 350_791_796 end # Target instance state. module TargetState # A value indicating that the enum field is not set. UNDEFINED_TARGET_STATE = 0 # The instance will be deleted. DELETED = 120_962_041 # The instance will be stopped. STOPPED = 444_276_141 end end |
#target_state ⇒ ::String
Returns Target instance state. Check the TargetState enum for the list of possible values.
69427 69428 69429 69430 69431 69432 69433 69434 69435 69436 69437 69438 69439 69440 69441 69442 69443 69444 69445 69446 69447 69448 69449 69450 69451 69452 69453 69454 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69427 class ResourceStatusShutdownDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Current stopping state of the instance. module StopState # A value indicating that the enum field is not set. UNDEFINED_STOP_STATE = 0 # The instance is gracefully shutting down. PENDING_STOP = 362_509_770 # The instance is stopping. STOPPING = 350_791_796 end # Target instance state. module TargetState # A value indicating that the enum field is not set. UNDEFINED_TARGET_STATE = 0 # The instance will be deleted. DELETED = 120_962_041 # The instance will be stopped. STOPPED = 444_276_141 end end |