Class: Google::Cloud::Compute::V1::RiskDetails
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RiskDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Detailed insights and metrics about a detected reliability risk.
Defined Under Namespace
Instance Attribute Summary collapse
-
#duration ⇒ ::String
The duration of the risk since it was detected.
-
#global_dns_insight ⇒ ::Google::Cloud::Compute::V1::RiskDetailsGlobalDnsInsight
Insight details for global DNS risk.
-
#last_update_timestamp ⇒ ::String
The last time the risk was updated.
-
#severity ⇒ ::String
The severity of the risk.
-
#type ⇒ ::String
The type of risk.
Instance Attribute Details
#duration ⇒ ::String
Returns The duration of the risk since it was detected.
69603 69604 69605 69606 69607 69608 69609 69610 69611 69612 69613 69614 69615 69616 69617 69618 69619 69620 69621 69622 69623 69624 69625 69626 69627 69628 69629 69630 69631 69632 69633 69634 69635 69636 69637 69638 69639 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69603 class RiskDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The severity of the risk. module Severity # A value indicating that the enum field is not set. UNDEFINED_SEVERITY = 0 # Critical severity. CRITICAL = 50_423_711 # High severity. HIGH = 2_217_378 # Low severity. LOW = 75_572 # Medium severity. MEDIUM = 122_782_581 # No severity specified. The default value. SEVERITY_UNSPECIFIED = 304_082_133 end # The type of risk. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Risk type related to global DNS. GLOBAL_DNS = 164_472_429 # Default value. This value is unused. RISK_TYPE_UNSPECIFIED = 71_308_546 end end |
#global_dns_insight ⇒ ::Google::Cloud::Compute::V1::RiskDetailsGlobalDnsInsight
Returns Insight details for global DNS risk.
69603 69604 69605 69606 69607 69608 69609 69610 69611 69612 69613 69614 69615 69616 69617 69618 69619 69620 69621 69622 69623 69624 69625 69626 69627 69628 69629 69630 69631 69632 69633 69634 69635 69636 69637 69638 69639 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69603 class RiskDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The severity of the risk. module Severity # A value indicating that the enum field is not set. UNDEFINED_SEVERITY = 0 # Critical severity. CRITICAL = 50_423_711 # High severity. HIGH = 2_217_378 # Low severity. LOW = 75_572 # Medium severity. MEDIUM = 122_782_581 # No severity specified. The default value. SEVERITY_UNSPECIFIED = 304_082_133 end # The type of risk. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Risk type related to global DNS. GLOBAL_DNS = 164_472_429 # Default value. This value is unused. RISK_TYPE_UNSPECIFIED = 71_308_546 end end |
#last_update_timestamp ⇒ ::String
Returns The last time the risk was updated.
69603 69604 69605 69606 69607 69608 69609 69610 69611 69612 69613 69614 69615 69616 69617 69618 69619 69620 69621 69622 69623 69624 69625 69626 69627 69628 69629 69630 69631 69632 69633 69634 69635 69636 69637 69638 69639 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69603 class RiskDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The severity of the risk. module Severity # A value indicating that the enum field is not set. UNDEFINED_SEVERITY = 0 # Critical severity. CRITICAL = 50_423_711 # High severity. HIGH = 2_217_378 # Low severity. LOW = 75_572 # Medium severity. MEDIUM = 122_782_581 # No severity specified. The default value. SEVERITY_UNSPECIFIED = 304_082_133 end # The type of risk. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Risk type related to global DNS. GLOBAL_DNS = 164_472_429 # Default value. This value is unused. RISK_TYPE_UNSPECIFIED = 71_308_546 end end |
#severity ⇒ ::String
Returns The severity of the risk. Check the Severity enum for the list of possible values.
69603 69604 69605 69606 69607 69608 69609 69610 69611 69612 69613 69614 69615 69616 69617 69618 69619 69620 69621 69622 69623 69624 69625 69626 69627 69628 69629 69630 69631 69632 69633 69634 69635 69636 69637 69638 69639 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69603 class RiskDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The severity of the risk. module Severity # A value indicating that the enum field is not set. UNDEFINED_SEVERITY = 0 # Critical severity. CRITICAL = 50_423_711 # High severity. HIGH = 2_217_378 # Low severity. LOW = 75_572 # Medium severity. MEDIUM = 122_782_581 # No severity specified. The default value. SEVERITY_UNSPECIFIED = 304_082_133 end # The type of risk. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Risk type related to global DNS. GLOBAL_DNS = 164_472_429 # Default value. This value is unused. RISK_TYPE_UNSPECIFIED = 71_308_546 end end |
#type ⇒ ::String
Returns The type of risk. Check the Type enum for the list of possible values.
69603 69604 69605 69606 69607 69608 69609 69610 69611 69612 69613 69614 69615 69616 69617 69618 69619 69620 69621 69622 69623 69624 69625 69626 69627 69628 69629 69630 69631 69632 69633 69634 69635 69636 69637 69638 69639 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69603 class RiskDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The severity of the risk. module Severity # A value indicating that the enum field is not set. UNDEFINED_SEVERITY = 0 # Critical severity. CRITICAL = 50_423_711 # High severity. HIGH = 2_217_378 # Low severity. LOW = 75_572 # Medium severity. MEDIUM = 122_782_581 # No severity specified. The default value. SEVERITY_UNSPECIFIED = 304_082_133 end # The type of risk. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Risk type related to global DNS. GLOBAL_DNS = 164_472_429 # Default value. This value is unused. RISK_TYPE_UNSPECIFIED = 71_308_546 end end |