Class: Google::Cloud::Compute::V1::Rollout
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Rollout
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Rollout resource.
A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#cancellation_time ⇒ ::String
Output only.
-
#completion_time ⇒ ::String
Output only.
-
#creation_timestamp ⇒ ::String
Output only.
-
#current_wave_number ⇒ ::Integer
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#etag ⇒ ::String
Output only.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#pause_time ⇒ ::String
Output only.
-
#resume_time ⇒ ::String
Output only.
-
#rollout_entity ⇒ ::Google::Cloud::Compute::V1::RolloutRolloutEntity
Required.
-
#rollout_plan ⇒ ::String
Required.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#state ⇒ ::String
Output only.
-
#wave_details ⇒ ::Array<::Google::Cloud::Compute::V1::RolloutWaveDetails>
Output only.
Instance Attribute Details
#cancellation_time ⇒ ::String
Returns Output only. The timestamp at which the Rollout was cancelled.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#completion_time ⇒ ::String
Returns Output only. The timestamp at which the Rollout was completed.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#current_wave_number ⇒ ::Integer
Returns Output only. The number of the currently running wave. Ex. 1.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#etag ⇒ ::String
Returns Output only. etag of the Rollout Ex. abc1234.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#rollout for rollouts.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#pause_time ⇒ ::String
Returns Output only. The timestamp at which the Rollout was paused.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#resume_time ⇒ ::String
Returns Output only. The timestamp at which the Rollout was resumed.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#rollout_entity ⇒ ::Google::Cloud::Compute::V1::RolloutRolloutEntity
Returns Required. The resource being rolled out.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#rollout_plan ⇒ ::String
Returns Required. Rollout Plan used to model the Rollout. Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource's resource id.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#state ⇒ ::String
Returns Output only. The current state of the Rollout. Check the State enum for the list of possible values.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#wave_details ⇒ ::Array<::Google::Cloud::Compute::V1::RolloutWaveDetails>
Returns Output only. Details about each wave of the rollout.
68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 68067 68068 68069 68070 68071 68072 68073 68074 68075 68076 68077 68078 68079 68080 68081 68082 68083 68084 68085 68086 68087 68088 68089 68090 68091 68092 68093 68094 68095 68096 68097 68098 68099 68100 68101 68102 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68039 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |