Class: Google::Cloud::Compute::V1::Rollout
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Rollout
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Rollout resource.
A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#cancellation_time ⇒ ::String
Output only.
-
#completion_time ⇒ ::String
Output only.
-
#creation_timestamp ⇒ ::String
Output only.
-
#current_wave_number ⇒ ::Integer
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#etag ⇒ ::String
Output only.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#rollout_entity ⇒ ::Google::Cloud::Compute::V1::RolloutRolloutEntity
Required.
-
#rollout_plan ⇒ ::String
Required.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#state ⇒ ::String
Output only.
-
#wave_details ⇒ ::Array<::Google::Cloud::Compute::V1::RolloutWaveDetails>
Output only.
Instance Attribute Details
#cancellation_time ⇒ ::String
Returns Output only. The timestamp at which the Rollout was cancelled.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#completion_time ⇒ ::String
Returns Output only. The timestamp at which the Rollout was completed.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#current_wave_number ⇒ ::Integer
Returns Output only. The number of the currently running wave. Ex. 1.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#etag ⇒ ::String
Returns Output only. etag of the Rollout Ex. abc1234.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#rollout for rollouts.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#rollout_entity ⇒ ::Google::Cloud::Compute::V1::RolloutRolloutEntity
Returns Required. The resource being rolled out.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#rollout_plan ⇒ ::String
Returns Required. Rollout Plan used to model the Rollout. Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource's resource id.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#state ⇒ ::String
Returns Output only. The current state of the Rollout. Check the State enum for the list of possible values.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |
#wave_details ⇒ ::Array<::Google::Cloud::Compute::V1::RolloutWaveDetails>
Returns Output only. Details about each wave of the rollout.
67294 67295 67296 67297 67298 67299 67300 67301 67302 67303 67304 67305 67306 67307 67308 67309 67310 67311 67312 67313 67314 67315 67316 67317 67318 67319 67320 67321 67322 67323 67324 67325 67326 67327 67328 67329 67330 67331 67332 67333 67334 67335 67336 67337 67338 67339 67340 67341 67342 67343 67344 67345 67346 67347 67348 67349 67350 67351 67352 67353 67354 67355 67356 67357 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67294 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. The current state of the Rollout. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The rollout is in a failure terminal state. CANCELLED = 41_957_681 # The rollout is being cancelled. CANCELLING = 226_950_512 # An attempted cancel operation was unsuccessful. CANCEL_FAILED = 389_121_442 # The rollout is in a successful terminal state. COMPLETED = 309_921_323 # An attempted complete operation was unsuccessful. COMPLETE_FAILED = 188_367_363 # The rollout is being marked as completed. COMPLETING = 480_759_734 # The rollout completed with failures. FAILED = 455_706_685 # The rollout is paused. PAUSED = 205_491_502 # An attempted pause operation was unsuccessful. PAUSE_FAILED = 7_486_150 # The rollout is being paused. PAUSING = 464_660_755 # A wave is being processed by the product. PROCESSING = 370_416_403 # The rollout has been successfully initialized and is ready to start. READY = 77_848_963 # The rollout is being resumed after being paused. RESUMING = 446_856_618 # An attempted rollback operation failed to complete successfully. ROLLBACK_WAVE_FAILED = 326_793_064 # A wave rollback is in progress for this rollout. ROLLING_BACK = 259_411_649 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 # The rollout has been created but is not yet ready to be started. UNINITIALIZED = 327_337_595 # The product failed to process the wave. WAVE_FAILED = 195_452_995 end end |