Module: Google::Cloud::Compute::V1::Rollout::State
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Output only. The current state of the Rollout.
Constant Summary collapse
- UNDEFINED_STATE =
A value indicating that the enum field is not set.
0- CANCELLED =
The rollout is in a failure terminal state.
41_957_681- CANCELLING =
The rollout is being cancelled.
226_950_512- CANCEL_FAILED =
An attempted cancel operation was unsuccessful.
389_121_442- COMPLETED =
The rollout is in a successful terminal state.
309_921_323- COMPLETE_FAILED =
An attempted complete operation was unsuccessful.
188_367_363- COMPLETING =
The rollout is being marked as completed.
480_759_734- FAILED =
The rollout completed with failures.
455_706_685- PAUSED =
The rollout is paused.
205_491_502- PAUSE_FAILED =
An attempted pause operation was unsuccessful.
7_486_150- PAUSING =
The rollout is being paused.
464_660_755- PROCESSING =
A wave is being processed by the product.
370_416_403- READY =
The rollout has been successfully initialized and is ready to start.
77_848_963- RESUMING =
The rollout is being resumed after being paused.
446_856_618- ROLLBACK_WAVE_FAILED =
An attempted rollback operation failed to complete successfully.
326_793_064- ROLLING_BACK =
A wave rollback is in progress for this rollout.
259_411_649- STATE_UNSPECIFIED =
Undefined default state. Should never be exposed to users.
470_755_401- UNINITIALIZED =
The rollout has been created but is not yet ready to be started.
327_337_595- WAVE_FAILED =
The product failed to process the wave.
195_452_995