Class: Google::Cloud::Compute::V1::RolloutPlan

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

RolloutPlan resource.

A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as "waves". Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.

Defined Under Namespace

Modules: LocationScope

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



68149
68150
68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
68161
68162
68163
68164
68165
68166
68167
68168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68149

class RolloutPlan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location scope of the rollout plan. If not specified, the location
  # scope is considered as ZONAL.
  module LocationScope
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_SCOPE = 0

    # Unspecified value. Considered as ZONAL.
    LOCATION_SCOPE_UNSPECIFIED = 416_410_498

    # Regional scope.
    REGIONAL = 92_288_543

    # Zonal scope.
    ZONAL = 85_547_428
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



68149
68150
68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
68161
68162
68163
68164
68165
68166
68167
68168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68149

class RolloutPlan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location scope of the rollout plan. If not specified, the location
  # scope is considered as ZONAL.
  module LocationScope
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_SCOPE = 0

    # Unspecified value. Considered as ZONAL.
    LOCATION_SCOPE_UNSPECIFIED = 416_410_498

    # Regional scope.
    REGIONAL = 92_288_543

    # Zonal scope.
    ZONAL = 85_547_428
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



68149
68150
68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
68161
68162
68163
68164
68165
68166
68167
68168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68149

class RolloutPlan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location scope of the rollout plan. If not specified, the location
  # scope is considered as ZONAL.
  module LocationScope
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_SCOPE = 0

    # Unspecified value. Considered as ZONAL.
    LOCATION_SCOPE_UNSPECIFIED = 416_410_498

    # Regional scope.
    REGIONAL = 92_288_543

    # Zonal scope.
    ZONAL = 85_547_428
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Always compute#rolloutPlan for rolloutPlans.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Always compute#rolloutPlan for rolloutPlans.



68149
68150
68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
68161
68162
68163
68164
68165
68166
68167
68168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68149

class RolloutPlan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location scope of the rollout plan. If not specified, the location
  # scope is considered as ZONAL.
  module LocationScope
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_SCOPE = 0

    # Unspecified value. Considered as ZONAL.
    LOCATION_SCOPE_UNSPECIFIED = 416_410_498

    # Regional scope.
    REGIONAL = 92_288_543

    # Zonal scope.
    ZONAL = 85_547_428
  end
end

#location_scope::String

Returns The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL. Check the LocationScope enum for the list of possible values.

Returns:

  • (::String)

    The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL. Check the LocationScope enum for the list of possible values.



68149
68150
68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
68161
68162
68163
68164
68165
68166
68167
68168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68149

class RolloutPlan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location scope of the rollout plan. If not specified, the location
  # scope is considered as ZONAL.
  module LocationScope
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_SCOPE = 0

    # Unspecified value. Considered as ZONAL.
    LOCATION_SCOPE_UNSPECIFIED = 416_410_498

    # Regional scope.
    REGIONAL = 92_288_543

    # Zonal scope.
    ZONAL = 85_547_428
  end
end

#name::String

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



68149
68150
68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
68161
68162
68163
68164
68165
68166
68167
68168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68149

class RolloutPlan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location scope of the rollout plan. If not specified, the location
  # scope is considered as ZONAL.
  module LocationScope
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_SCOPE = 0

    # Unspecified value. Considered as ZONAL.
    LOCATION_SCOPE_UNSPECIFIED = 416_410_498

    # Regional scope.
    REGIONAL = 92_288_543

    # Zonal scope.
    ZONAL = 85_547_428
  end
end

Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined fully-qualified URL for this resource.



68149
68150
68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
68161
68162
68163
68164
68165
68166
68167
68168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68149

class RolloutPlan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location scope of the rollout plan. If not specified, the location
  # scope is considered as ZONAL.
  module LocationScope
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_SCOPE = 0

    # Unspecified value. Considered as ZONAL.
    LOCATION_SCOPE_UNSPECIFIED = 416_410_498

    # Regional scope.
    REGIONAL = 92_288_543

    # Zonal scope.
    ZONAL = 85_547_428
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource's resource id.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource's resource id.



68149
68150
68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
68161
68162
68163
68164
68165
68166
68167
68168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68149

class RolloutPlan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location scope of the rollout plan. If not specified, the location
  # scope is considered as ZONAL.
  module LocationScope
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_SCOPE = 0

    # Unspecified value. Considered as ZONAL.
    LOCATION_SCOPE_UNSPECIFIED = 416_410_498

    # Regional scope.
    REGIONAL = 92_288_543

    # Zonal scope.
    ZONAL = 85_547_428
  end
end

#waves::Array<::Google::Cloud::Compute::V1::RolloutPlanWave>

Returns Required. The waves included in this rollout plan.

Returns:



68149
68150
68151
68152
68153
68154
68155
68156
68157
68158
68159
68160
68161
68162
68163
68164
68165
68166
68167
68168
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68149

class RolloutPlan
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location scope of the rollout plan. If not specified, the location
  # scope is considered as ZONAL.
  module LocationScope
    # A value indicating that the enum field is not set.
    UNDEFINED_LOCATION_SCOPE = 0

    # Unspecified value. Considered as ZONAL.
    LOCATION_SCOPE_UNSPECIFIED = 416_410_498

    # Regional scope.
    REGIONAL = 92_288_543

    # Zonal scope.
    ZONAL = 85_547_428
  end
end