Class: Google::Cloud::Compute::V1::RolloutPlan
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RolloutPlan
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
RolloutPlan resource.
A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as "waves". Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.
Defined Under Namespace
Modules: LocationScope
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#location_scope ⇒ ::String
The location scope of the rollout plan.
-
#name ⇒ ::String
Name of the resource.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#waves ⇒ ::Array<::Google::Cloud::Compute::V1::RolloutPlanWave>
Required.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
67404 67405 67406 67407 67408 67409 67410 67411 67412 67413 67414 67415 67416 67417 67418 67419 67420 67421 67422 67423 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67404 class RolloutPlan include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope of the rollout plan. If not specified, the location # scope is considered as ZONAL. module LocationScope # A value indicating that the enum field is not set. UNDEFINED_LOCATION_SCOPE = 0 # Unspecified value. Considered as ZONAL. LOCATION_SCOPE_UNSPECIFIED = 416_410_498 # Regional scope. REGIONAL = 92_288_543 # Zonal scope. ZONAL = 85_547_428 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
67404 67405 67406 67407 67408 67409 67410 67411 67412 67413 67414 67415 67416 67417 67418 67419 67420 67421 67422 67423 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67404 class RolloutPlan include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope of the rollout plan. If not specified, the location # scope is considered as ZONAL. module LocationScope # A value indicating that the enum field is not set. UNDEFINED_LOCATION_SCOPE = 0 # Unspecified value. Considered as ZONAL. LOCATION_SCOPE_UNSPECIFIED = 416_410_498 # Regional scope. REGIONAL = 92_288_543 # Zonal scope. ZONAL = 85_547_428 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
67404 67405 67406 67407 67408 67409 67410 67411 67412 67413 67414 67415 67416 67417 67418 67419 67420 67421 67422 67423 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67404 class RolloutPlan include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope of the rollout plan. If not specified, the location # scope is considered as ZONAL. module LocationScope # A value indicating that the enum field is not set. UNDEFINED_LOCATION_SCOPE = 0 # Unspecified value. Considered as ZONAL. LOCATION_SCOPE_UNSPECIFIED = 416_410_498 # Regional scope. REGIONAL = 92_288_543 # Zonal scope. ZONAL = 85_547_428 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#rolloutPlan for rolloutPlans.
67404 67405 67406 67407 67408 67409 67410 67411 67412 67413 67414 67415 67416 67417 67418 67419 67420 67421 67422 67423 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67404 class RolloutPlan include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope of the rollout plan. If not specified, the location # scope is considered as ZONAL. module LocationScope # A value indicating that the enum field is not set. UNDEFINED_LOCATION_SCOPE = 0 # Unspecified value. Considered as ZONAL. LOCATION_SCOPE_UNSPECIFIED = 416_410_498 # Regional scope. REGIONAL = 92_288_543 # Zonal scope. ZONAL = 85_547_428 end end |
#location_scope ⇒ ::String
Returns The location scope of the rollout plan. If not specified, the location scope is considered as ZONAL. Check the LocationScope enum for the list of possible values.
67404 67405 67406 67407 67408 67409 67410 67411 67412 67413 67414 67415 67416 67417 67418 67419 67420 67421 67422 67423 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67404 class RolloutPlan include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope of the rollout plan. If not specified, the location # scope is considered as ZONAL. module LocationScope # A value indicating that the enum field is not set. UNDEFINED_LOCATION_SCOPE = 0 # Unspecified value. Considered as ZONAL. LOCATION_SCOPE_UNSPECIFIED = 416_410_498 # Regional scope. REGIONAL = 92_288_543 # Zonal scope. ZONAL = 85_547_428 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
67404 67405 67406 67407 67408 67409 67410 67411 67412 67413 67414 67415 67416 67417 67418 67419 67420 67421 67422 67423 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67404 class RolloutPlan include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope of the rollout plan. If not specified, the location # scope is considered as ZONAL. module LocationScope # A value indicating that the enum field is not set. UNDEFINED_LOCATION_SCOPE = 0 # Unspecified value. Considered as ZONAL. LOCATION_SCOPE_UNSPECIFIED = 416_410_498 # Regional scope. REGIONAL = 92_288_543 # Zonal scope. ZONAL = 85_547_428 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.
67404 67405 67406 67407 67408 67409 67410 67411 67412 67413 67414 67415 67416 67417 67418 67419 67420 67421 67422 67423 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67404 class RolloutPlan include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope of the rollout plan. If not specified, the location # scope is considered as ZONAL. module LocationScope # A value indicating that the enum field is not set. UNDEFINED_LOCATION_SCOPE = 0 # Unspecified value. Considered as ZONAL. LOCATION_SCOPE_UNSPECIFIED = 416_410_498 # Regional scope. REGIONAL = 92_288_543 # Zonal scope. ZONAL = 85_547_428 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource's resource id.
67404 67405 67406 67407 67408 67409 67410 67411 67412 67413 67414 67415 67416 67417 67418 67419 67420 67421 67422 67423 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67404 class RolloutPlan include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope of the rollout plan. If not specified, the location # scope is considered as ZONAL. module LocationScope # A value indicating that the enum field is not set. UNDEFINED_LOCATION_SCOPE = 0 # Unspecified value. Considered as ZONAL. LOCATION_SCOPE_UNSPECIFIED = 416_410_498 # Regional scope. REGIONAL = 92_288_543 # Zonal scope. ZONAL = 85_547_428 end end |
#waves ⇒ ::Array<::Google::Cloud::Compute::V1::RolloutPlanWave>
Returns Required. The waves included in this rollout plan.
67404 67405 67406 67407 67408 67409 67410 67411 67412 67413 67414 67415 67416 67417 67418 67419 67420 67421 67422 67423 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67404 class RolloutPlan include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope of the rollout plan. If not specified, the location # scope is considered as ZONAL. module LocationScope # A value indicating that the enum field is not set. UNDEFINED_LOCATION_SCOPE = 0 # Unspecified value. Considered as ZONAL. LOCATION_SCOPE_UNSPECIFIED = 416_410_498 # Regional scope. REGIONAL = 92_288_543 # Zonal scope. ZONAL = 85_547_428 end end |