Class: Google::Cloud::Compute::V1::RolloutPlanWave
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RolloutPlanWave
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A single wave in a rollout plan.
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
Optional.
-
#number ⇒ ::Integer
Output only.
-
#orchestration_options ⇒ ::Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptions
Optional.
-
#selectors ⇒ ::Array<::Google::Cloud::Compute::V1::RolloutPlanWaveSelector>
Required.
-
#validation ⇒ ::Google::Cloud::Compute::V1::RolloutPlanWaveValidation
Required.
Instance Attribute Details
#display_name ⇒ ::String
Returns Optional. The display name of this wave of the rollout plan.
67443 67444 67445 67446 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67443 class RolloutPlanWave include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#number ⇒ ::Integer
Returns Output only. The wave number.
67443 67444 67445 67446 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67443 class RolloutPlanWave include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#orchestration_options ⇒ ::Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptions
Returns Optional. The orchestration options for this wave.
67443 67444 67445 67446 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67443 class RolloutPlanWave include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#selectors ⇒ ::Array<::Google::Cloud::Compute::V1::RolloutPlanWaveSelector>
Returns Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave.
67443 67444 67445 67446 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67443 class RolloutPlanWave include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validation ⇒ ::Google::Cloud::Compute::V1::RolloutPlanWaveValidation
Returns Required. The validation to be performed at the end of this wave.
67443 67444 67445 67446 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67443 class RolloutPlanWave include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |