Class: Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.

Instance Attribute Summary collapse

Instance Attribute Details

#delays::Array<::Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptionsDelay>

Returns Optional. Delays, if any, to be added between batches of projects. We allow multiple Delays to be specified, letting users set separate delays between batches of projects corresponding to different locations and batches of projects corresponding to the same location.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptionsDelay>)

    Optional. Delays, if any, to be added between batches of projects. We allow multiple Delays to be specified, letting users set separate delays between batches of projects corresponding to different locations and batches of projects corresponding to the same location.



67464
67465
67466
67467
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67464

class RolloutPlanWaveOrchestrationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_concurrent_locations::Integer

Returns Optional. Maximum number of locations to be orchestrated in parallel.

Returns:

  • (::Integer)

    Optional. Maximum number of locations to be orchestrated in parallel.



67464
67465
67466
67467
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67464

class RolloutPlanWaveOrchestrationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_concurrent_resources_per_location::Integer

Returns Optional. Maximum number of resources to be orchestrated per location in parallel.

Returns:

  • (::Integer)

    Optional. Maximum number of resources to be orchestrated per location in parallel.



67464
67465
67466
67467
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67464

class RolloutPlanWaveOrchestrationOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end