Class: Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptionsDelay

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Options to control the delay, if any, between batches of projects.

Defined Under Namespace

Modules: Delimiter, Type

Instance Attribute Summary collapse

Instance Attribute Details

#delimiter::String

Returns Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location.

Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. Check the Delimiter enum for the list of possible values.

Returns:

  • (::String)

    Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location.

    Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. Check the Delimiter enum for the list of possible values.



68235
68236
68237
68238
68239
68240
68241
68242
68243
68244
68245
68246
68247
68248
68249
68250
68251
68252
68253
68254
68255
68256
68257
68258
68259
68260
68261
68262
68263
68264
68265
68266
68267
68268
68269
68270
68271
68272
68273
68274
68275
68276
68277
68278
68279
68280
68281
68282
68283
68284
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68235

class RolloutPlanWaveOrchestrationOptionsDelay
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Controls whether the delay should only be added between batches of
  # projects corresponding to different locations, or also between
  # batches of projects corresponding to the same location.
  #
  # Must be set to DELIMITER_UNSPECIFIED if no delay is to be added.
  module Delimiter
    # A value indicating that the enum field is not set.
    UNDEFINED_DELIMITER = 0

    # The delay will also be added between batches of projects
    # corresponding to the same location.
    DELIMITER_BATCH = 253_390_530

    # The delay will only be added between batches of projects
    # corresponding to different locations.
    DELIMITER_LOCATION = 189_398_797

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    DELIMITER_UNSPECIFIED = 372_199_615
  end

  # Optional. Controls whether the specified duration is to be added at the end of
  # each batch, or if the total processing time for each batch will be
  # padded if needed to meet the specified duration.
  #
  # Must be set to TYPE_UNSPECIFIED if no delay is to be added.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The total processing time for each batch of projects will be padded
    # if needed to meet the specified delay duration.
    TYPE_MINIMUM = 234_909_673

    # The specified delay will directly be added after each batch of
    # projects as specified by the delimiter.
    TYPE_OFFSET = 165_747_000

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    TYPE_UNSPECIFIED = 437_714_322
  end
end

#duration::String

Returns Optional. The duration of the delay, if any, to be added between batches of projects. A zero duration corresponds to no delay.

Returns:

  • (::String)

    Optional. The duration of the delay, if any, to be added between batches of projects. A zero duration corresponds to no delay.



68235
68236
68237
68238
68239
68240
68241
68242
68243
68244
68245
68246
68247
68248
68249
68250
68251
68252
68253
68254
68255
68256
68257
68258
68259
68260
68261
68262
68263
68264
68265
68266
68267
68268
68269
68270
68271
68272
68273
68274
68275
68276
68277
68278
68279
68280
68281
68282
68283
68284
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68235

class RolloutPlanWaveOrchestrationOptionsDelay
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Controls whether the delay should only be added between batches of
  # projects corresponding to different locations, or also between
  # batches of projects corresponding to the same location.
  #
  # Must be set to DELIMITER_UNSPECIFIED if no delay is to be added.
  module Delimiter
    # A value indicating that the enum field is not set.
    UNDEFINED_DELIMITER = 0

    # The delay will also be added between batches of projects
    # corresponding to the same location.
    DELIMITER_BATCH = 253_390_530

    # The delay will only be added between batches of projects
    # corresponding to different locations.
    DELIMITER_LOCATION = 189_398_797

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    DELIMITER_UNSPECIFIED = 372_199_615
  end

  # Optional. Controls whether the specified duration is to be added at the end of
  # each batch, or if the total processing time for each batch will be
  # padded if needed to meet the specified duration.
  #
  # Must be set to TYPE_UNSPECIFIED if no delay is to be added.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The total processing time for each batch of projects will be padded
    # if needed to meet the specified delay duration.
    TYPE_MINIMUM = 234_909_673

    # The specified delay will directly be added after each batch of
    # projects as specified by the delimiter.
    TYPE_OFFSET = 165_747_000

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    TYPE_UNSPECIFIED = 437_714_322
  end
end

#type::String

Returns Optional. Controls whether the specified duration is to be added at the end of each batch, or if the total processing time for each batch will be padded if needed to meet the specified duration.

Must be set to TYPE_UNSPECIFIED if no delay is to be added. Check the Type enum for the list of possible values.

Returns:

  • (::String)

    Optional. Controls whether the specified duration is to be added at the end of each batch, or if the total processing time for each batch will be padded if needed to meet the specified duration.

    Must be set to TYPE_UNSPECIFIED if no delay is to be added. Check the Type enum for the list of possible values.



68235
68236
68237
68238
68239
68240
68241
68242
68243
68244
68245
68246
68247
68248
68249
68250
68251
68252
68253
68254
68255
68256
68257
68258
68259
68260
68261
68262
68263
68264
68265
68266
68267
68268
68269
68270
68271
68272
68273
68274
68275
68276
68277
68278
68279
68280
68281
68282
68283
68284
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68235

class RolloutPlanWaveOrchestrationOptionsDelay
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Optional. Controls whether the delay should only be added between batches of
  # projects corresponding to different locations, or also between
  # batches of projects corresponding to the same location.
  #
  # Must be set to DELIMITER_UNSPECIFIED if no delay is to be added.
  module Delimiter
    # A value indicating that the enum field is not set.
    UNDEFINED_DELIMITER = 0

    # The delay will also be added between batches of projects
    # corresponding to the same location.
    DELIMITER_BATCH = 253_390_530

    # The delay will only be added between batches of projects
    # corresponding to different locations.
    DELIMITER_LOCATION = 189_398_797

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    DELIMITER_UNSPECIFIED = 372_199_615
  end

  # Optional. Controls whether the specified duration is to be added at the end of
  # each batch, or if the total processing time for each batch will be
  # padded if needed to meet the specified duration.
  #
  # Must be set to TYPE_UNSPECIFIED if no delay is to be added.
  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # The total processing time for each batch of projects will be padded
    # if needed to meet the specified delay duration.
    TYPE_MINIMUM = 234_909_673

    # The specified delay will directly be added after each batch of
    # projects as specified by the delimiter.
    TYPE_OFFSET = 165_747_000

    # No delay will be added between batches of projects. Processing will
    # continue with the next batch as soon as the previous batch of LROs
    # is done.
    TYPE_UNSPECIFIED = 437_714_322
  end
end