Class: Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptionsDelay
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RolloutPlanWaveOrchestrationOptionsDelay
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Options to control the delay, if any, between batches of projects.
Defined Under Namespace
Instance Attribute Summary collapse
-
#delimiter ⇒ ::String
Optional.
-
#duration ⇒ ::String
Optional.
-
#type ⇒ ::String
Optional.
Instance Attribute Details
#delimiter ⇒ ::String
Returns Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location.
Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. Check the Delimiter enum for the list of possible values.
67490 67491 67492 67493 67494 67495 67496 67497 67498 67499 67500 67501 67502 67503 67504 67505 67506 67507 67508 67509 67510 67511 67512 67513 67514 67515 67516 67517 67518 67519 67520 67521 67522 67523 67524 67525 67526 67527 67528 67529 67530 67531 67532 67533 67534 67535 67536 67537 67538 67539 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67490 class RolloutPlanWaveOrchestrationOptionsDelay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Controls whether the delay should only be added between batches of # projects corresponding to different locations, or also between # batches of projects corresponding to the same location. # # Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. module Delimiter # A value indicating that the enum field is not set. UNDEFINED_DELIMITER = 0 # The delay will also be added between batches of projects # corresponding to the same location. DELIMITER_BATCH = 253_390_530 # The delay will only be added between batches of projects # corresponding to different locations. DELIMITER_LOCATION = 189_398_797 # No delay will be added between batches of projects. Processing will # continue with the next batch as soon as the previous batch of LROs # is done. DELIMITER_UNSPECIFIED = 372_199_615 end # Optional. Controls whether the specified duration is to be added at the end of # each batch, or if the total processing time for each batch will be # padded if needed to meet the specified duration. # # Must be set to TYPE_UNSPECIFIED if no delay is to be added. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # The total processing time for each batch of projects will be padded # if needed to meet the specified delay duration. TYPE_MINIMUM = 234_909_673 # The specified delay will directly be added after each batch of # projects as specified by the delimiter. TYPE_OFFSET = 165_747_000 # No delay will be added between batches of projects. Processing will # continue with the next batch as soon as the previous batch of LROs # is done. TYPE_UNSPECIFIED = 437_714_322 end end |
#duration ⇒ ::String
Returns Optional. The duration of the delay, if any, to be added between batches of projects. A zero duration corresponds to no delay.
67490 67491 67492 67493 67494 67495 67496 67497 67498 67499 67500 67501 67502 67503 67504 67505 67506 67507 67508 67509 67510 67511 67512 67513 67514 67515 67516 67517 67518 67519 67520 67521 67522 67523 67524 67525 67526 67527 67528 67529 67530 67531 67532 67533 67534 67535 67536 67537 67538 67539 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67490 class RolloutPlanWaveOrchestrationOptionsDelay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Controls whether the delay should only be added between batches of # projects corresponding to different locations, or also between # batches of projects corresponding to the same location. # # Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. module Delimiter # A value indicating that the enum field is not set. UNDEFINED_DELIMITER = 0 # The delay will also be added between batches of projects # corresponding to the same location. DELIMITER_BATCH = 253_390_530 # The delay will only be added between batches of projects # corresponding to different locations. DELIMITER_LOCATION = 189_398_797 # No delay will be added between batches of projects. Processing will # continue with the next batch as soon as the previous batch of LROs # is done. DELIMITER_UNSPECIFIED = 372_199_615 end # Optional. Controls whether the specified duration is to be added at the end of # each batch, or if the total processing time for each batch will be # padded if needed to meet the specified duration. # # Must be set to TYPE_UNSPECIFIED if no delay is to be added. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # The total processing time for each batch of projects will be padded # if needed to meet the specified delay duration. TYPE_MINIMUM = 234_909_673 # The specified delay will directly be added after each batch of # projects as specified by the delimiter. TYPE_OFFSET = 165_747_000 # No delay will be added between batches of projects. Processing will # continue with the next batch as soon as the previous batch of LROs # is done. TYPE_UNSPECIFIED = 437_714_322 end end |
#type ⇒ ::String
Returns Optional. Controls whether the specified duration is to be added at the end of each batch, or if the total processing time for each batch will be padded if needed to meet the specified duration.
Must be set to TYPE_UNSPECIFIED if no delay is to be added. Check the Type enum for the list of possible values.
67490 67491 67492 67493 67494 67495 67496 67497 67498 67499 67500 67501 67502 67503 67504 67505 67506 67507 67508 67509 67510 67511 67512 67513 67514 67515 67516 67517 67518 67519 67520 67521 67522 67523 67524 67525 67526 67527 67528 67529 67530 67531 67532 67533 67534 67535 67536 67537 67538 67539 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67490 class RolloutPlanWaveOrchestrationOptionsDelay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Optional. Controls whether the delay should only be added between batches of # projects corresponding to different locations, or also between # batches of projects corresponding to the same location. # # Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. module Delimiter # A value indicating that the enum field is not set. UNDEFINED_DELIMITER = 0 # The delay will also be added between batches of projects # corresponding to the same location. DELIMITER_BATCH = 253_390_530 # The delay will only be added between batches of projects # corresponding to different locations. DELIMITER_LOCATION = 189_398_797 # No delay will be added between batches of projects. Processing will # continue with the next batch as soon as the previous batch of LROs # is done. DELIMITER_UNSPECIFIED = 372_199_615 end # Optional. Controls whether the specified duration is to be added at the end of # each batch, or if the total processing time for each batch will be # padded if needed to meet the specified duration. # # Must be set to TYPE_UNSPECIFIED if no delay is to be added. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # The total processing time for each batch of projects will be padded # if needed to meet the specified delay duration. TYPE_MINIMUM = 234_909_673 # The specified delay will directly be added after each batch of # projects as specified by the delimiter. TYPE_OFFSET = 165_747_000 # No delay will be added between batches of projects. Processing will # continue with the next batch as soon as the previous batch of LROs # is done. TYPE_UNSPECIFIED = 437_714_322 end end |