Class: Google::Cloud::Compute::V1::RolloutPlanWaveValidation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The validation to be performed before progressing to the next wave.

Instance Attribute Summary collapse

Instance Attribute Details

#time_based_validation_metadata::Google::Cloud::Compute::V1::RolloutPlanWaveValidationTimeBasedValidationMetadata

Returns Optional. Metadata required if type = "time".

Returns:



67592
67593
67594
67595
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67592

class RolloutPlanWaveValidation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type::String

Returns Required. The type of the validation. If a type of validation is associated with a metadata object, the appropriate metadata field mapping to the validation type must be provided in the validation message. Possible values are in quotes below alongside an explanation: "manual": The system waits for an end-user approval API before progressing to the next wave. "time": The system waits for a user specified duration before progressing to the next wave. TimeBasedValidation must be provided.

Returns:

  • (::String)

    Required. The type of the validation. If a type of validation is associated with a metadata object, the appropriate metadata field mapping to the validation type must be provided in the validation message. Possible values are in quotes below alongside an explanation: "manual": The system waits for an end-user approval API before progressing to the next wave. "time": The system waits for a user specified duration before progressing to the next wave. TimeBasedValidation must be provided.



67592
67593
67594
67595
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67592

class RolloutPlanWaveValidation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end