Class: Google::Cloud::Compute::V1::RolloutPlanWaveValidationTimeBasedValidationMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RolloutPlanWaveValidationTimeBasedValidationMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Metadata required if type = "time".
Instance Attribute Summary collapse
-
#wait_duration ⇒ ::String
Optional.
Instance Attribute Details
#wait_duration ⇒ ::String
Returns Optional. The duration that the system waits in between waves. This wait starts after all changes in the wave are rolled out.
67602 67603 67604 67605 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67602 class RolloutPlanWaveValidationTimeBasedValidationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |