Class: Google::Cloud::Compute::V1::RolloutRolloutEntityOrchestratedEntity
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RolloutRolloutEntityOrchestratedEntity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
This message is used if the resource type follows the Orchestrated integration model with ProgressiveRollout.
Instance Attribute Summary collapse
-
#conflict_behavior ⇒ ::String
Required.
-
#orchestration_action ⇒ ::String
Required.
-
#orchestration_source ⇒ ::String
Required.
Instance Attribute Details
#conflict_behavior ⇒ ::String
Returns Required. Specifies the behavior of the Rollout if an out of band update is detected in a project during a Rollout. It can be one of the following values: 1) overwrite : Overwrite the local value with the rollout value. 2) no_overwrite : Do not overwrite the local value with the rollout value.
67674 67675 67676 67677 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67674 class RolloutRolloutEntityOrchestratedEntity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#orchestration_action ⇒ ::String
Returns Required. Orchestration action during the Rollout. It can be one of the following values: 1) "update": Resources will be updated by the rollout. 2) "delete": Resources will be deleted by the rollout.
67674 67675 67676 67677 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67674 class RolloutRolloutEntityOrchestratedEntity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#orchestration_source ⇒ ::String
Returns Required. Fully qualified resource name of the resource which contains the source of truth of the configuration being rolled out across locations/projects. For example, in the case of a global Rollout which is applied across regions, this contains the name of the global resource created by the user which contains a payload for a resource that is orchestrated across regions. This follows the following format: //.googleapis.com/projects//locations/global// e.g. //osconfig.googleapis.com/projects/1/locations/global/policyOrchestrators/po1.
67674 67675 67676 67677 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67674 class RolloutRolloutEntityOrchestratedEntity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |