Class: Google::Cloud::Compute::V1::RolloutWaveDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Additional metadata about the status of each wave provided by the server.

Instance Attribute Summary collapse

Instance Attribute Details

#orchestrated_wave_details::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetails

Returns Output only. Additional details of the wave for products using the Orchestrated Integration model.

Returns:



67691
67692
67693
67694
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67691

class RolloutWaveDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#wave_display_name::String

Returns Output only. Wave name. Ex. wave1.

Returns:

  • (::String)

    Output only. Wave name. Ex. wave1



67691
67692
67693
67694
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67691

class RolloutWaveDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#wave_number::Integer

Returns Output only. System generated number for the wave.

Returns:

  • (::Integer)

    Output only. System generated number for the wave.



67691
67692
67693
67694
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67691

class RolloutWaveDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end