Class: Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Details of the wave for products using the Orchestrated integration model.

Defined Under Namespace

Classes: LocationStatusEntry

Instance Attribute Summary collapse

Instance Attribute Details

#completed_resources_count::Integer

Returns Output only. Resource completed so far.

Returns:

  • (::Integer)

    Output only. Resource completed so far.



68465
68466
68467
68468
68469
68470
68471
68472
68473
68474
68475
68476
68477
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68465

class RolloutWaveDetailsOrchestratedWaveDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus]
  class LocationStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#estimated_completion_time::String

Returns Output only. Estimated timestamp at which the wave will complete. Extrapolated from current progress.

Returns:

  • (::String)

    Output only. Estimated timestamp at which the wave will complete. Extrapolated from current progress.



68465
68466
68467
68468
68469
68470
68471
68472
68473
68474
68475
68476
68477
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68465

class RolloutWaveDetailsOrchestratedWaveDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus]
  class LocationStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#estimated_total_resources_count::Integer

Returns Output only. Estimated total count of resources.

Returns:

  • (::Integer)

    Output only. Estimated total count of resources.



68465
68466
68467
68468
68469
68470
68471
68472
68473
68474
68475
68476
68477
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68465

class RolloutWaveDetailsOrchestratedWaveDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus]
  class LocationStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#failed_locations::Array<::String>

Returns Output only. Locations that failed during orchestration, and ProgressiveRollout stopped retrying. There may be some successful resources rolled out in the wave as the location may have failed later in the Rollout.

Returns:

  • (::Array<::String>)

    Output only. Locations that failed during orchestration, and ProgressiveRollout stopped retrying. There may be some successful resources rolled out in the wave as the location may have failed later in the Rollout.



68465
68466
68467
68468
68469
68470
68471
68472
68473
68474
68475
68476
68477
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68465

class RolloutWaveDetailsOrchestratedWaveDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus]
  class LocationStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#failed_resources_count::Integer

Returns Output only. Resources failed.

Returns:

  • (::Integer)

    Output only. Resources failed.



68465
68466
68467
68468
68469
68470
68471
68472
68473
68474
68475
68476
68477
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68465

class RolloutWaveDetailsOrchestratedWaveDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus]
  class LocationStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#location_status::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus}

Returns Output only. Status of each location in the wave. Map keys (locations) must be specified like "us-east1" or "asia-west1-a".

Returns:



68465
68466
68467
68468
68469
68470
68471
68472
68473
68474
68475
68476
68477
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68465

class RolloutWaveDetailsOrchestratedWaveDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus]
  class LocationStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end