Class: Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents the status of a location in a wave.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#state::String

Returns Output only. Location state of the wave. Check the State enum for the list of possible values.

Returns:

  • (::String)

    Output only. Location state of the wave. Check the State enum for the list of possible values.



68484
68485
68486
68487
68488
68489
68490
68491
68492
68493
68494
68495
68496
68497
68498
68499
68500
68501
68502
68503
68504
68505
68506
68507
68508
68509
68510
68511
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68484

class RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. Location state of the wave.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Work on the wave failed.
    STATE_FAILED = 50_857_931

    # Work on the wave is in progress.
    STATE_IN_PROGRESS = 413_162_809

    # Work on the wave is pending.
    STATE_PENDING = 369_985_449

    # Work on the wave was canceled or skipped.
    STATE_SKIPPED = 515_663_170

    # Work on the wave succeeded.
    STATE_SUCCEEDED = 466_911_219

    # Undefined default state. Should never be exposed to users.
    STATE_UNSPECIFIED = 470_755_401
  end
end