Class: Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents the status of a location in a wave.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::String
Output only.
Instance Attribute Details
#state ⇒ ::String
Returns Output only. Location state of the wave. Check the State enum for the list of possible values.
67739 67740 67741 67742 67743 67744 67745 67746 67747 67748 67749 67750 67751 67752 67753 67754 67755 67756 67757 67758 67759 67760 67761 67762 67763 67764 67765 67766 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67739 class RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Location state of the wave. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Work on the wave failed. STATE_FAILED = 50_857_931 # Work on the wave is in progress. STATE_IN_PROGRESS = 413_162_809 # Work on the wave is pending. STATE_PENDING = 369_985_449 # Work on the wave was canceled or skipped. STATE_SKIPPED = 515_663_170 # Work on the wave succeeded. STATE_SUCCEEDED = 466_911_219 # Undefined default state. Should never be exposed to users. STATE_UNSPECIFIED = 470_755_401 end end |