Module: Google::Cloud::Compute::V1::Route::RouteType
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] The type of this route, which can be one of the following values: - 'TRANSIT' for a transit route that this router learned from another Cloud Router and will readvertise to one of its BGP peers - 'SUBNET' for a route from a subnet of the VPC - 'BGP' for a route learned from a BGP peer of this router - 'STATIC' for a static route
Constant Summary collapse
- UNDEFINED_ROUTE_TYPE =
A value indicating that the enum field is not set.
0- BGP =
65_707- STATIC =
308_331_118- SUBNET =
309_278_557- TRANSIT =
187_793_843