Class: Google::Cloud::Compute::V1::RouteAsPath
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RouteAsPath
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: PathSegmentType
Instance Attribute Summary collapse
-
#as_lists ⇒ ::Array<::Integer>
[Output Only] The AS numbers of the AS Path.
-
#path_segment_type ⇒ ::String
[Output Only] The type of the AS Path, which can be one of the following values: - 'AS_SET': unordered set of autonomous systems that the route in has traversed - 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed - 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed - 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Check the PathSegmentType enum for the list of possible values.
Instance Attribute Details
#as_lists ⇒ ::Array<::Integer>
Returns [Output Only] The AS numbers of the AS Path.
68783 68784 68785 68786 68787 68788 68789 68790 68791 68792 68793 68794 68795 68796 68797 68798 68799 68800 68801 68802 68803 68804 68805 68806 68807 68808 68809 68810 68811 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68783 class RouteAsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the AS Path, which can be one of the following # values: # - 'AS_SET': unordered set of autonomous systems that the route # in has traversed # - 'AS_SEQUENCE': ordered set of autonomous # systems that the route has traversed # - 'AS_CONFED_SEQUENCE': # ordered set of Member Autonomous Systems in the local confederation that # the route has traversed # - 'AS_CONFED_SET': unordered set of # Member Autonomous Systems in the local confederation that the route has # traversed module PathSegmentType # A value indicating that the enum field is not set. UNDEFINED_PATH_SEGMENT_TYPE = 0 AS_CONFED_SEQUENCE = 222_152_624 AS_CONFED_SET = 374_040_307 AS_SEQUENCE = 106_735_918 AS_SET = 329_846_453 end end |
#path_segment_type ⇒ ::String
Returns [Output Only] The type of the AS Path, which can be one of the following values:
- 'AS_SET': unordered set of autonomous systems that the route in has traversed
- 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed
- 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed
- 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Check the PathSegmentType enum for the list of possible values.
68783 68784 68785 68786 68787 68788 68789 68790 68791 68792 68793 68794 68795 68796 68797 68798 68799 68800 68801 68802 68803 68804 68805 68806 68807 68808 68809 68810 68811 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68783 class RouteAsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the AS Path, which can be one of the following # values: # - 'AS_SET': unordered set of autonomous systems that the route # in has traversed # - 'AS_SEQUENCE': ordered set of autonomous # systems that the route has traversed # - 'AS_CONFED_SEQUENCE': # ordered set of Member Autonomous Systems in the local confederation that # the route has traversed # - 'AS_CONFED_SET': unordered set of # Member Autonomous Systems in the local confederation that the route has # traversed module PathSegmentType # A value indicating that the enum field is not set. UNDEFINED_PATH_SEGMENT_TYPE = 0 AS_CONFED_SEQUENCE = 222_152_624 AS_CONFED_SET = 374_040_307 AS_SEQUENCE = 106_735_918 AS_SET = 329_846_453 end end |