Class: Google::Cloud::Compute::V1::RouteAsPath
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RouteAsPath
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: PathSegmentType
Instance Attribute Summary collapse
-
#as_lists ⇒ ::Array<::Integer>
[Output Only] The AS numbers of the AS Path.
-
#path_segment_type ⇒ ::String
[Output Only] The type of the AS Path, which can be one of the following values: - 'AS_SET': unordered set of autonomous systems that the route in has traversed - 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed - 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed - 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Check the PathSegmentType enum for the list of possible values.
Instance Attribute Details
#as_lists ⇒ ::Array<::Integer>
Returns [Output Only] The AS numbers of the AS Path.
68038 68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68038 class RouteAsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the AS Path, which can be one of the following # values: # - 'AS_SET': unordered set of autonomous systems that the route # in has traversed # - 'AS_SEQUENCE': ordered set of autonomous # systems that the route has traversed # - 'AS_CONFED_SEQUENCE': # ordered set of Member Autonomous Systems in the local confederation that # the route has traversed # - 'AS_CONFED_SET': unordered set of # Member Autonomous Systems in the local confederation that the route has # traversed module PathSegmentType # A value indicating that the enum field is not set. UNDEFINED_PATH_SEGMENT_TYPE = 0 AS_CONFED_SEQUENCE = 222_152_624 AS_CONFED_SET = 374_040_307 AS_SEQUENCE = 106_735_918 AS_SET = 329_846_453 end end |
#path_segment_type ⇒ ::String
Returns [Output Only] The type of the AS Path, which can be one of the following values:
- 'AS_SET': unordered set of autonomous systems that the route in has traversed
- 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed
- 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed
- 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Check the PathSegmentType enum for the list of possible values.
68038 68039 68040 68041 68042 68043 68044 68045 68046 68047 68048 68049 68050 68051 68052 68053 68054 68055 68056 68057 68058 68059 68060 68061 68062 68063 68064 68065 68066 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68038 class RouteAsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the AS Path, which can be one of the following # values: # - 'AS_SET': unordered set of autonomous systems that the route # in has traversed # - 'AS_SEQUENCE': ordered set of autonomous # systems that the route has traversed # - 'AS_CONFED_SEQUENCE': # ordered set of Member Autonomous Systems in the local confederation that # the route has traversed # - 'AS_CONFED_SET': unordered set of # Member Autonomous Systems in the local confederation that the route has # traversed module PathSegmentType # A value indicating that the enum field is not set. UNDEFINED_PATH_SEGMENT_TYPE = 0 AS_CONFED_SEQUENCE = 222_152_624 AS_CONFED_SET = 374_040_307 AS_SEQUENCE = 106_735_918 AS_SET = 329_846_453 end end |