Class: Google::Cloud::Compute::V1::RouteAsPath
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RouteAsPath
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: PathSegmentType
Instance Attribute Summary collapse
-
#as_lists ⇒ ::Array<::Integer>
[Output Only] The AS numbers of the AS Path.
-
#path_segment_type ⇒ ::String
[Output Only] The type of the AS Path, which can be one of the following values: - 'AS_SET': unordered set of autonomous systems that the route in has traversed - 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed - 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed - 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Check the PathSegmentType enum for the list of possible values.
Instance Attribute Details
#as_lists ⇒ ::Array<::Integer>
Returns [Output Only] The AS numbers of the AS Path.
66385 66386 66387 66388 66389 66390 66391 66392 66393 66394 66395 66396 66397 66398 66399 66400 66401 66402 66403 66404 66405 66406 66407 66408 66409 66410 66411 66412 66413 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66385 class RouteAsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the AS Path, which can be one of the following # values: # - 'AS_SET': unordered set of autonomous systems that the route # in has traversed # - 'AS_SEQUENCE': ordered set of autonomous # systems that the route has traversed # - 'AS_CONFED_SEQUENCE': # ordered set of Member Autonomous Systems in the local confederation that # the route has traversed # - 'AS_CONFED_SET': unordered set of # Member Autonomous Systems in the local confederation that the route has # traversed module PathSegmentType # A value indicating that the enum field is not set. UNDEFINED_PATH_SEGMENT_TYPE = 0 AS_CONFED_SEQUENCE = 222_152_624 AS_CONFED_SET = 374_040_307 AS_SEQUENCE = 106_735_918 AS_SET = 329_846_453 end end |
#path_segment_type ⇒ ::String
Returns [Output Only] The type of the AS Path, which can be one of the following values:
- 'AS_SET': unordered set of autonomous systems that the route in has traversed
- 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed
- 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed
- 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Check the PathSegmentType enum for the list of possible values.
66385 66386 66387 66388 66389 66390 66391 66392 66393 66394 66395 66396 66397 66398 66399 66400 66401 66402 66403 66404 66405 66406 66407 66408 66409 66410 66411 66412 66413 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66385 class RouteAsPath include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The type of the AS Path, which can be one of the following # values: # - 'AS_SET': unordered set of autonomous systems that the route # in has traversed # - 'AS_SEQUENCE': ordered set of autonomous # systems that the route has traversed # - 'AS_CONFED_SEQUENCE': # ordered set of Member Autonomous Systems in the local confederation that # the route has traversed # - 'AS_CONFED_SET': unordered set of # Member Autonomous Systems in the local confederation that the route has # traversed module PathSegmentType # A value indicating that the enum field is not set. UNDEFINED_PATH_SEGMENT_TYPE = 0 AS_CONFED_SEQUENCE = 222_152_624 AS_CONFED_SET = 374_040_307 AS_SEQUENCE = 106_735_918 AS_SET = 329_846_453 end end |