Class: Google::Cloud::Compute::V1::Router
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Router
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Cloud Router resource.
For more information about Cloud Router, read theCloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ ::Google::Cloud::Compute::V1::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ ::Array<::Google::Cloud::Compute::V1::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ ::Boolean
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ ::Array<::Google::Cloud::Compute::V1::RouterInterface>
Router interfaces.
-
#kind ⇒ ::String
Output only.
-
#md5_authentication_keys ⇒ ::Array<::Google::Cloud::Compute::V1::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
-
#name ⇒ ::String
Name of the resource.
-
#nats ⇒ ::Array<::Google::Cloud::Compute::V1::RouterNat>
A list of NAT services created in this router.
-
#network ⇒ ::String
URI of the network to which this router belongs.
-
#params ⇒ ::Google::Cloud::Compute::V1::RouterParams
Input only.
-
#region ⇒ ::String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
Instance Attribute Details
#bgp ⇒ ::Google::Cloud::Compute::V1::RouterBgp
Returns BGP information specific to this router.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bgp_peers ⇒ ::Array<::Google::Cloud::Compute::V1::RouterBgpPeer>
Returns BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encrypted_interconnect_router ⇒ ::Boolean
Returns Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#interfaces ⇒ ::Array<::Google::Cloud::Compute::V1::RouterInterface>
Returns Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
- linkedVpnTunnel
- linkedInterconnectAttachment
- subnetwork
You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Always compute#router for routers.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#md5_authentication_keys ⇒ ::Array<::Google::Cloud::Compute::V1::RouterMd5AuthenticationKey>
Returns Keys used for MD5 authentication.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#nats ⇒ ::Array<::Google::Cloud::Compute::V1::RouterNat>
Returns A list of NAT services created in this router.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network ⇒ ::String
Returns URI of the network to which this router belongs.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#params ⇒ ::Google::Cloud::Compute::V1::RouterParams
Returns Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region ⇒ ::String
Returns [Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
66607 66608 66609 66610 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 66607 class Router include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |