Class: Google::Cloud::Compute::V1::RouterInterface
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RouterInterface
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: IpVersion, ManagementType
Instance Attribute Summary collapse
-
#ip_range ⇒ ::String
IP address and range of the interface.
-
#ip_version ⇒ ::String
IP version of this interface.
-
#linked_interconnect_attachment ⇒ ::String
URI of the linked Interconnect attachment.
-
#linked_vpn_tunnel ⇒ ::String
URI of the linked VPN tunnel, which must be in the same region as the router.
-
#management_type ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of this interface entry.
-
#private_ip_address ⇒ ::String
The regional private internal IP address that is used to establish BGP sessions to a VM instance acting as a third-party Router Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN VM.
-
#redundant_interface ⇒ ::String
Name of the interface that will be redundant with the current interface you are creating.
-
#subnetwork ⇒ ::String
The URI of the subnetwork resource that this interface belongs to, which must be in the same region as the Cloud Router.
Instance Attribute Details
#ip_range ⇒ ::String
Returns IP address and range of the interface.
- For Internet Protocol version 4 (IPv4), the IP range must be in theRFC3927 link-local IP address space. The value must be a CIDR-formatted string, for example, 169.254.0.1/30. Note: Do not truncate the IP address, as it represents the IP address of the interface.
- For Internet Protocol version 6 (IPv6), the value must be a unique local address (ULA) range from fdff:1::/64 with a mask length of 126 or less. This value should be a CIDR-formatted string, for example, fdff:1::1/112. Within the router's VPC, this IPv6 prefix will be reserved exclusively for this connection and cannot be used for any other purpose.
67086 67087 67088 67089 67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 67100 67101 67102 67103 67104 67105 67106 67107 67108 67109 67110 67111 67112 67113 67114 67115 67116 67117 67118 67119 67120 67121 67122 67123 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67086 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # Output only. [Output Only] The resource that configures and manages this interface. # # - MANAGED_BY_USER is the default value and can be managed directly # by users. # - MANAGED_BY_ATTACHMENT is an interface that is configured and # managed by Cloud Interconnect, specifically, by an InterconnectAttachment # of type PARTNER. Google automatically creates, updates, and deletes # this type of interface when the PARTNER InterconnectAttachment is # created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type # InterconnectAttachment, Google will automatically create/update/delete # this interface when the PARTNER InterconnectAttachment is # created/provisioned/deleted. # This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#ip_version ⇒ ::String
Returns IP version of this interface. Check the IpVersion enum for the list of possible values.
67086 67087 67088 67089 67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 67100 67101 67102 67103 67104 67105 67106 67107 67108 67109 67110 67111 67112 67113 67114 67115 67116 67117 67118 67119 67120 67121 67122 67123 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67086 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # Output only. [Output Only] The resource that configures and manages this interface. # # - MANAGED_BY_USER is the default value and can be managed directly # by users. # - MANAGED_BY_ATTACHMENT is an interface that is configured and # managed by Cloud Interconnect, specifically, by an InterconnectAttachment # of type PARTNER. Google automatically creates, updates, and deletes # this type of interface when the PARTNER InterconnectAttachment is # created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type # InterconnectAttachment, Google will automatically create/update/delete # this interface when the PARTNER InterconnectAttachment is # created/provisioned/deleted. # This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#linked_interconnect_attachment ⇒ ::String
Returns URI of the linked Interconnect attachment. It must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.
67086 67087 67088 67089 67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 67100 67101 67102 67103 67104 67105 67106 67107 67108 67109 67110 67111 67112 67113 67114 67115 67116 67117 67118 67119 67120 67121 67122 67123 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67086 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # Output only. [Output Only] The resource that configures and manages this interface. # # - MANAGED_BY_USER is the default value and can be managed directly # by users. # - MANAGED_BY_ATTACHMENT is an interface that is configured and # managed by Cloud Interconnect, specifically, by an InterconnectAttachment # of type PARTNER. Google automatically creates, updates, and deletes # this type of interface when the PARTNER InterconnectAttachment is # created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type # InterconnectAttachment, Google will automatically create/update/delete # this interface when the PARTNER InterconnectAttachment is # created/provisioned/deleted. # This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#linked_vpn_tunnel ⇒ ::String
Returns URI of the linked VPN tunnel, which must be in the same region as the router. Each interface can have one linked resource, which can be a VPN tunnel, an Interconnect attachment, or a subnetwork.
67086 67087 67088 67089 67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 67100 67101 67102 67103 67104 67105 67106 67107 67108 67109 67110 67111 67112 67113 67114 67115 67116 67117 67118 67119 67120 67121 67122 67123 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67086 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # Output only. [Output Only] The resource that configures and manages this interface. # # - MANAGED_BY_USER is the default value and can be managed directly # by users. # - MANAGED_BY_ATTACHMENT is an interface that is configured and # managed by Cloud Interconnect, specifically, by an InterconnectAttachment # of type PARTNER. Google automatically creates, updates, and deletes # this type of interface when the PARTNER InterconnectAttachment is # created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type # InterconnectAttachment, Google will automatically create/update/delete # this interface when the PARTNER InterconnectAttachment is # created/provisioned/deleted. # This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#management_type ⇒ ::String
Returns Output only. [Output Only] The resource that configures and manages this interface.
- MANAGED_BY_USER is the default value and can be managed directly by users.
- MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. Check the ManagementType enum for the list of possible values.
67086 67087 67088 67089 67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 67100 67101 67102 67103 67104 67105 67106 67107 67108 67109 67110 67111 67112 67113 67114 67115 67116 67117 67118 67119 67120 67121 67122 67123 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67086 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # Output only. [Output Only] The resource that configures and manages this interface. # # - MANAGED_BY_USER is the default value and can be managed directly # by users. # - MANAGED_BY_ATTACHMENT is an interface that is configured and # managed by Cloud Interconnect, specifically, by an InterconnectAttachment # of type PARTNER. Google automatically creates, updates, and deletes # this type of interface when the PARTNER InterconnectAttachment is # created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type # InterconnectAttachment, Google will automatically create/update/delete # this interface when the PARTNER InterconnectAttachment is # created/provisioned/deleted. # This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#name ⇒ ::String
Returns Name of this interface entry.
The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63
characters long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a
lowercase letter, and all following characters must be a dash, lowercase
letter, or digit, except the last character, which cannot be a dash.
67086 67087 67088 67089 67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 67100 67101 67102 67103 67104 67105 67106 67107 67108 67109 67110 67111 67112 67113 67114 67115 67116 67117 67118 67119 67120 67121 67122 67123 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67086 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # Output only. [Output Only] The resource that configures and manages this interface. # # - MANAGED_BY_USER is the default value and can be managed directly # by users. # - MANAGED_BY_ATTACHMENT is an interface that is configured and # managed by Cloud Interconnect, specifically, by an InterconnectAttachment # of type PARTNER. Google automatically creates, updates, and deletes # this type of interface when the PARTNER InterconnectAttachment is # created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type # InterconnectAttachment, Google will automatically create/update/delete # this interface when the PARTNER InterconnectAttachment is # created/provisioned/deleted. # This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#private_ip_address ⇒ ::String
Returns The regional private internal IP address that is used to establish BGP sessions to a VM instance acting as a third-party Router Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN VM.
67086 67087 67088 67089 67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 67100 67101 67102 67103 67104 67105 67106 67107 67108 67109 67110 67111 67112 67113 67114 67115 67116 67117 67118 67119 67120 67121 67122 67123 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67086 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # Output only. [Output Only] The resource that configures and manages this interface. # # - MANAGED_BY_USER is the default value and can be managed directly # by users. # - MANAGED_BY_ATTACHMENT is an interface that is configured and # managed by Cloud Interconnect, specifically, by an InterconnectAttachment # of type PARTNER. Google automatically creates, updates, and deletes # this type of interface when the PARTNER InterconnectAttachment is # created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type # InterconnectAttachment, Google will automatically create/update/delete # this interface when the PARTNER InterconnectAttachment is # created/provisioned/deleted. # This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#redundant_interface ⇒ ::String
Returns Name of the interface that will be redundant with the current interface
you are creating. The redundantInterface must belong to the same Cloud
Router as the interface here. To establish the BGP session to a Router
Appliance VM, you must create two BGP peers. The two BGP peers must be
attached to two separate interfaces that are redundant with each other.
The redundant_interface must be 1-63 characters long, and comply withRFC1035. Specifically, the redundant_interface must
be 1-63 characters long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a
lowercase letter, and all following characters must be a dash, lowercase
letter, or digit, except the last character, which cannot be a dash.
67086 67087 67088 67089 67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 67100 67101 67102 67103 67104 67105 67106 67107 67108 67109 67110 67111 67112 67113 67114 67115 67116 67117 67118 67119 67120 67121 67122 67123 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67086 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # Output only. [Output Only] The resource that configures and manages this interface. # # - MANAGED_BY_USER is the default value and can be managed directly # by users. # - MANAGED_BY_ATTACHMENT is an interface that is configured and # managed by Cloud Interconnect, specifically, by an InterconnectAttachment # of type PARTNER. Google automatically creates, updates, and deletes # this type of interface when the PARTNER InterconnectAttachment is # created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type # InterconnectAttachment, Google will automatically create/update/delete # this interface when the PARTNER InterconnectAttachment is # created/provisioned/deleted. # This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#subnetwork ⇒ ::String
Returns The URI of the subnetwork resource that this interface belongs to, which must be in the same region as the Cloud Router. When you establish a BGP session to a VM instance using this interface, the VM instance must belong to the same subnetwork as the subnetwork specified here.
67086 67087 67088 67089 67090 67091 67092 67093 67094 67095 67096 67097 67098 67099 67100 67101 67102 67103 67104 67105 67106 67107 67108 67109 67110 67111 67112 67113 67114 67115 67116 67117 67118 67119 67120 67121 67122 67123 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67086 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # Output only. [Output Only] The resource that configures and manages this interface. # # - MANAGED_BY_USER is the default value and can be managed directly # by users. # - MANAGED_BY_ATTACHMENT is an interface that is configured and # managed by Cloud Interconnect, specifically, by an InterconnectAttachment # of type PARTNER. Google automatically creates, updates, and deletes # this type of interface when the PARTNER InterconnectAttachment is # created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type # InterconnectAttachment, Google will automatically create/update/delete # this interface when the PARTNER InterconnectAttachment is # created/provisioned/deleted. # This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |