Class: Google::Cloud::Compute::V1::RouterInterface
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RouterInterface
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: IpVersion, ManagementType
Instance Attribute Summary collapse
-
#ip_range ⇒ ::String
IP address and range of the interface.
-
#ip_version ⇒ ::String
IP version of this interface.
-
#linked_interconnect_attachment ⇒ ::String
URI of the linked Interconnect attachment.
-
#linked_vpn_tunnel ⇒ ::String
URI of the linked VPN tunnel, which must be in the same region as the router.
-
#management_type ⇒ ::String
[Output Only] The resource that configures and manages this interface.
-
#name ⇒ ::String
Name of this interface entry.
-
#private_ip_address ⇒ ::String
The regional private internal IP address that is used to establish BGP sessions to a VM instance acting as a third-party Router Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN VM.
-
#redundant_interface ⇒ ::String
Name of the interface that will be redundant with the current interface you are creating.
-
#subnetwork ⇒ ::String
The URI of the subnetwork resource that this interface belongs to, which must be in the same region as the Cloud Router.
Instance Attribute Details
#ip_range ⇒ ::String
28849 28850 28851 28852 28853 28854 28855 28856 28857 28858 28859 28860 28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 28871 28872 28873 28874 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28849 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#ip_version ⇒ ::String
28849 28850 28851 28852 28853 28854 28855 28856 28857 28858 28859 28860 28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 28871 28872 28873 28874 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28849 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#linked_interconnect_attachment ⇒ ::String
28849 28850 28851 28852 28853 28854 28855 28856 28857 28858 28859 28860 28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 28871 28872 28873 28874 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28849 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#linked_vpn_tunnel ⇒ ::String
28849 28850 28851 28852 28853 28854 28855 28856 28857 28858 28859 28860 28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 28871 28872 28873 28874 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28849 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#management_type ⇒ ::String
28849 28850 28851 28852 28853 28854 28855 28856 28857 28858 28859 28860 28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 28871 28872 28873 28874 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28849 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#name ⇒ ::String
28849 28850 28851 28852 28853 28854 28855 28856 28857 28858 28859 28860 28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 28871 28872 28873 28874 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28849 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#private_ip_address ⇒ ::String
28849 28850 28851 28852 28853 28854 28855 28856 28857 28858 28859 28860 28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 28871 28872 28873 28874 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28849 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#redundant_interface ⇒ ::String
28849 28850 28851 28852 28853 28854 28855 28856 28857 28858 28859 28860 28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 28871 28872 28873 28874 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28849 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |
#subnetwork ⇒ ::String
28849 28850 28851 28852 28853 28854 28855 28856 28857 28858 28859 28860 28861 28862 28863 28864 28865 28866 28867 28868 28869 28870 28871 28872 28873 28874 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28849 class RouterInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # IP version of this interface. module IpVersion # A value indicating that the enum field is not set. UNDEFINED_IP_VERSION = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 end # [Output Only] The resource that configures and manages this interface. - MANAGED_BY_USER is the default value and can be managed directly by users. - MANAGED_BY_ATTACHMENT is an interface that is configured and managed by Cloud Interconnect, specifically, by an InterconnectAttachment of type PARTNER. Google automatically creates, updates, and deletes this type of interface when the PARTNER InterconnectAttachment is created, updated, or deleted. module ManagementType # A value indicating that the enum field is not set. UNDEFINED_MANAGEMENT_TYPE = 0 # The interface is automatically created for PARTNER type InterconnectAttachment, Google will automatically create/update/delete this interface when the PARTNER InterconnectAttachment is created/provisioned/deleted. This type of interface cannot be manually managed by user. MANAGED_BY_ATTACHMENT = 458_926_411 # Default value, the interface is manually created and managed by user. MANAGED_BY_USER = 317_294_067 end end |