Module: Google::Cloud::Compute::V1::RouterNat::EndpointTypes
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Constant Summary collapse
- UNDEFINED_ENDPOINT_TYPES =
A value indicating that the enum field is not set.
0- ENDPOINT_TYPE_MANAGED_PROXY_LB =
This is used for regional Application Load Balancers (internal and external) and regional proxy Network Load Balancers (internal and external) endpoints.
439_196_930- ENDPOINT_TYPE_SWG =
This is used for Secure Web Gateway endpoints.
159_344_456- ENDPOINT_TYPE_VM =
This is the default.
57_095_474