Class: Google::Cloud::Compute::V1::RouterNatLogConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Configuration of logging on a NAT.

Defined Under Namespace

Modules: Filter

Instance Attribute Summary collapse

Instance Attribute Details

#enable::Boolean

Returns Indicates whether or not to export logs. This is false by default.

Returns:

  • (::Boolean)

    Indicates whether or not to export logs. This is false by default.



69891
69892
69893
69894
69895
69896
69897
69898
69899
69900
69901
69902
69903
69904
69905
69906
69907
69908
69909
69910
69911
69912
69913
69914
69915
69916
69917
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69891

class RouterNatLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specify the desired filtering of logs on this NAT. If unspecified,
  # logs are exported for all connections handled by this NAT.
  # This option can take one of the following values:
  #
  #    - ERRORS_ONLY: Export logs only for connection failures.
  #    - TRANSLATIONS_ONLY: Export logs only for successful
  #    connections.
  #    - ALL: Export logs for all connections, successful and
  #    unsuccessful.
  module Filter
    # A value indicating that the enum field is not set.
    UNDEFINED_FILTER = 0

    # Export logs for all (successful and unsuccessful) connections.
    ALL = 64_897

    # Export logs for connection failures only.
    ERRORS_ONLY = 307_484_672

    # Export logs for successful connections only.
    TRANSLATIONS_ONLY = 357_212_649
  end
end

#filter::String

Returns Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:

  • ERRORS_ONLY: Export logs only for connection failures.
  • TRANSLATIONS_ONLY: Export logs only for successful connections.
  • ALL: Export logs for all connections, successful and unsuccessful. Check the Filter enum for the list of possible values.

Returns:

  • (::String)

    Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:

    • ERRORS_ONLY: Export logs only for connection failures.
    • TRANSLATIONS_ONLY: Export logs only for successful connections.
    • ALL: Export logs for all connections, successful and unsuccessful. Check the Filter enum for the list of possible values.


69891
69892
69893
69894
69895
69896
69897
69898
69899
69900
69901
69902
69903
69904
69905
69906
69907
69908
69909
69910
69911
69912
69913
69914
69915
69916
69917
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69891

class RouterNatLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specify the desired filtering of logs on this NAT. If unspecified,
  # logs are exported for all connections handled by this NAT.
  # This option can take one of the following values:
  #
  #    - ERRORS_ONLY: Export logs only for connection failures.
  #    - TRANSLATIONS_ONLY: Export logs only for successful
  #    connections.
  #    - ALL: Export logs for all connections, successful and
  #    unsuccessful.
  module Filter
    # A value indicating that the enum field is not set.
    UNDEFINED_FILTER = 0

    # Export logs for all (successful and unsuccessful) connections.
    ALL = 64_897

    # Export logs for connection failures only.
    ERRORS_ONLY = 307_484_672

    # Export logs for successful connections only.
    TRANSLATIONS_ONLY = 357_212_649
  end
end