Class: Google::Cloud::Compute::V1::RouterNatLogConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Configuration of logging on a NAT.

Defined Under Namespace

Modules: Filter

Instance Attribute Summary collapse

Instance Attribute Details

#enable::Boolean

Returns Indicates whether or not to export logs. This is false by default.

Returns:

  • (::Boolean)

    Indicates whether or not to export logs. This is false by default.



67484
67485
67486
67487
67488
67489
67490
67491
67492
67493
67494
67495
67496
67497
67498
67499
67500
67501
67502
67503
67504
67505
67506
67507
67508
67509
67510
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67484

class RouterNatLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specify the desired filtering of logs on this NAT. If unspecified,
  # logs are exported for all connections handled by this NAT.
  # This option can take one of the following values:
  #
  #    - ERRORS_ONLY: Export logs only for connection failures.
  #    - TRANSLATIONS_ONLY: Export logs only for successful
  #    connections.
  #    - ALL: Export logs for all connections, successful and
  #    unsuccessful.
  module Filter
    # A value indicating that the enum field is not set.
    UNDEFINED_FILTER = 0

    # Export logs for all (successful and unsuccessful) connections.
    ALL = 64_897

    # Export logs for connection failures only.
    ERRORS_ONLY = 307_484_672

    # Export logs for successful connections only.
    TRANSLATIONS_ONLY = 357_212_649
  end
end

#filter::String

Returns Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:

  • ERRORS_ONLY: Export logs only for connection failures.
  • TRANSLATIONS_ONLY: Export logs only for successful connections.
  • ALL: Export logs for all connections, successful and unsuccessful. Check the Filter enum for the list of possible values.

Returns:

  • (::String)

    Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:

    • ERRORS_ONLY: Export logs only for connection failures.
    • TRANSLATIONS_ONLY: Export logs only for successful connections.
    • ALL: Export logs for all connections, successful and unsuccessful. Check the Filter enum for the list of possible values.


67484
67485
67486
67487
67488
67489
67490
67491
67492
67493
67494
67495
67496
67497
67498
67499
67500
67501
67502
67503
67504
67505
67506
67507
67508
67509
67510
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 67484

class RouterNatLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specify the desired filtering of logs on this NAT. If unspecified,
  # logs are exported for all connections handled by this NAT.
  # This option can take one of the following values:
  #
  #    - ERRORS_ONLY: Export logs only for connection failures.
  #    - TRANSLATIONS_ONLY: Export logs only for successful
  #    connections.
  #    - ALL: Export logs for all connections, successful and
  #    unsuccessful.
  module Filter
    # A value indicating that the enum field is not set.
    UNDEFINED_FILTER = 0

    # Export logs for all (successful and unsuccessful) connections.
    ALL = 64_897

    # Export logs for connection failures only.
    ERRORS_ONLY = 307_484_672

    # Export logs for successful connections only.
    TRANSLATIONS_ONLY = 357_212_649
  end
end