Class: Google::Cloud::Compute::V1::RouterNatLogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RouterNatLogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configuration of logging on a NAT.
Defined Under Namespace
Modules: Filter
Instance Attribute Summary collapse
-
#enable ⇒ ::Boolean
Indicates whether or not to export logs.
-
#filter ⇒ ::String
Specify the desired filtering of logs on this NAT.
Instance Attribute Details
#enable ⇒ ::Boolean
Returns Indicates whether or not to export logs. This is false by default.
29531 29532 29533 29534 29535 29536 29537 29538 29539 29540 29541 29542 29543 29544 29545 29546 29547 29548 29549 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29531 class RouterNatLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values: - ERRORS_ONLY: Export logs only for connection failures. - TRANSLATIONS_ONLY: Export logs only for successful connections. - ALL: Export logs for all connections, successful and unsuccessful. module Filter # A value indicating that the enum field is not set. UNDEFINED_FILTER = 0 # Export logs for all (successful and unsuccessful) connections. ALL = 64_897 # Export logs for connection failures only. ERRORS_ONLY = 307_484_672 # Export logs for successful connections only. TRANSLATIONS_ONLY = 357_212_649 end end |
#filter ⇒ ::String
Returns Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values: - ERRORS_ONLY: Export logs only for connection failures. - TRANSLATIONS_ONLY: Export logs only for successful connections. - ALL: Export logs for all connections, successful and unsuccessful. Check the Filter enum for the list of possible values.
29531 29532 29533 29534 29535 29536 29537 29538 29539 29540 29541 29542 29543 29544 29545 29546 29547 29548 29549 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29531 class RouterNatLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values: - ERRORS_ONLY: Export logs only for connection failures. - TRANSLATIONS_ONLY: Export logs only for successful connections. - ALL: Export logs for all connections, successful and unsuccessful. module Filter # A value indicating that the enum field is not set. UNDEFINED_FILTER = 0 # Export logs for all (successful and unsuccessful) connections. ALL = 64_897 # Export logs for connection failures only. ERRORS_ONLY = 307_484_672 # Export logs for successful connections only. TRANSLATIONS_ONLY = 357_212_649 end end |