Class: Google::Cloud::Compute::V1::RouterNatLogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RouterNatLogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configuration of logging on a NAT.
Defined Under Namespace
Modules: Filter
Instance Attribute Summary collapse
-
#enable ⇒ ::Boolean
Indicates whether or not to export logs.
-
#filter ⇒ ::String
Specify the desired filtering of logs on this NAT.
Instance Attribute Details
#enable ⇒ ::Boolean
Returns Indicates whether or not to export logs. This is false by default.
29030 29031 29032 29033 29034 29035 29036 29037 29038 29039 29040 29041 29042 29043 29044 29045 29046 29047 29048 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29030 class RouterNatLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values: - ERRORS_ONLY: Export logs only for connection failures. - TRANSLATIONS_ONLY: Export logs only for successful connections. - ALL: Export logs for all connections, successful and unsuccessful. module Filter # A value indicating that the enum field is not set. UNDEFINED_FILTER = 0 # Export logs for all (successful and unsuccessful) connections. ALL = 64_897 # Export logs for connection failures only. ERRORS_ONLY = 307_484_672 # Export logs for successful connections only. TRANSLATIONS_ONLY = 357_212_649 end end |
#filter ⇒ ::String
Returns Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values: - ERRORS_ONLY: Export logs only for connection failures. - TRANSLATIONS_ONLY: Export logs only for successful connections. - ALL: Export logs for all connections, successful and unsuccessful. Check the Filter enum for the list of possible values.
29030 29031 29032 29033 29034 29035 29036 29037 29038 29039 29040 29041 29042 29043 29044 29045 29046 29047 29048 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29030 class RouterNatLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values: - ERRORS_ONLY: Export logs only for connection failures. - TRANSLATIONS_ONLY: Export logs only for successful connections. - ALL: Export logs for all connections, successful and unsuccessful. module Filter # A value indicating that the enum field is not set. UNDEFINED_FILTER = 0 # Export logs for all (successful and unsuccessful) connections. ALL = 64_897 # Export logs for connection failures only. ERRORS_ONLY = 307_484_672 # Export logs for successful connections only. TRANSLATIONS_ONLY = 357_212_649 end end |