Class: Google::Cloud::Compute::V1::RouterStatusBgpPeerStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::RouterStatusBgpPeerStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Status, StatusReason
Instance Attribute Summary collapse
-
#advertised_routes ⇒ ::Array<::Google::Cloud::Compute::V1::Route>
Routes that were advertised to the remote BGP peer.
- #bfd_status ⇒ ::Google::Cloud::Compute::V1::BfdStatus
-
#enable_ipv4 ⇒ ::Boolean
Output only.
-
#enable_ipv6 ⇒ ::Boolean
Output only.
-
#ip_address ⇒ ::String
Output only.
-
#ipv4_nexthop_address ⇒ ::String
Output only.
-
#ipv6_nexthop_address ⇒ ::String
Output only.
-
#linked_vpn_tunnel ⇒ ::String
Output only.
-
#md5_auth_enabled ⇒ ::Boolean
Informs whether MD5 authentication is enabled on this BGP peer.
-
#name ⇒ ::String
Output only.
-
#num_learned_routes ⇒ ::Integer
Output only.
-
#peer_ip_address ⇒ ::String
Output only.
-
#peer_ipv4_nexthop_address ⇒ ::String
Output only.
-
#peer_ipv6_nexthop_address ⇒ ::String
Output only.
-
#router_appliance_instance ⇒ ::String
Output only.
-
#state ⇒ ::String
Output only.
-
#status ⇒ ::String
Output only.
-
#status_reason ⇒ ::String
Indicates why particular status was returned.
-
#uptime ⇒ ::String
Output only.
-
#uptime_seconds ⇒ ::String
Output only.
Instance Attribute Details
#advertised_routes ⇒ ::Array<::Google::Cloud::Compute::V1::Route>
Returns Routes that were advertised to the remote BGP peer.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#bfd_status ⇒ ::Google::Cloud::Compute::V1::BfdStatus
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#enable_ipv4 ⇒ ::Boolean
Returns Output only. Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#enable_ipv6 ⇒ ::Boolean
Returns Output only. Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#ip_address ⇒ ::String
Returns Output only. IP address of the local BGP interface.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#ipv4_nexthop_address ⇒ ::String
Returns Output only. IPv4 address of the local BGP interface.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#ipv6_nexthop_address ⇒ ::String
Returns Output only. IPv6 address of the local BGP interface.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#linked_vpn_tunnel ⇒ ::String
Returns Output only. URL of the VPN tunnel that this BGP peer controls.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#md5_auth_enabled ⇒ ::Boolean
Returns Informs whether MD5 authentication is enabled on this BGP peer.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#name ⇒ ::String
Returns Output only. Name of this BGP peer. Unique within the Routers resource.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#num_learned_routes ⇒ ::Integer
Returns Output only. Number of routes learned from the remote BGP Peer.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#peer_ip_address ⇒ ::String
Returns Output only. IP address of the remote BGP interface.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#peer_ipv4_nexthop_address ⇒ ::String
Returns Output only. IPv4 address of the remote BGP interface.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#peer_ipv6_nexthop_address ⇒ ::String
Returns Output only. IPv6 address of the remote BGP interface.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#router_appliance_instance ⇒ ::String
Returns Output only. [Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#state ⇒ ::String
Returns Output only. The state of the BGP session. For a list of possible values for this field, seeBGP session states.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#status ⇒ ::String
Returns Output only. Status of the BGP peer: {UP, DOWN} Check the Status enum for the list of possible values.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#status_reason ⇒ ::String
Returns Indicates why particular status was returned. Check the StatusReason enum for the list of possible values.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#uptime ⇒ ::String
Returns Output only. Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |
#uptime_seconds ⇒ ::String
Returns Output only. Time this session has been up, in seconds. Format: 145.
70162 70163 70164 70165 70166 70167 70168 70169 70170 70171 70172 70173 70174 70175 70176 70177 70178 70179 70180 70181 70182 70183 70184 70185 70186 70187 70188 70189 70190 70191 70192 70193 70194 70195 70196 70197 70198 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70162 class RouterStatusBgpPeerStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. Status of the BGP peer: \\{UP, DOWN} module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UNKNOWN = 433_141_802 UP = 2715 end # Indicates why particular status was returned. module StatusReason # A value indicating that the enum field is not set. UNDEFINED_STATUS_REASON = 0 # BGP peer disabled because it requires IPv4 but the underlying # connection is IPv6-only. IPV4_PEER_ON_IPV6_ONLY_CONNECTION = 435_936_662 # BGP peer disabled because it requires IPv6 but the underlying # connection is IPv4-only. IPV6_PEER_ON_IPV4_ONLY_CONNECTION = 436_304_082 # Indicates internal problems with configuration of MD5 authentication. # This particular reason can only be returned when md5AuthEnabled is true # and status is DOWN. MD5_AUTH_INTERNAL_PROBLEM = 140_462_259 STATUS_REASON_UNSPECIFIED = 394_331_913 end end |