Class: Google::Cloud::Compute::V1::SavedAttachedDisk
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SavedAttachedDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.
Defined Under Namespace
Modules: Interface, Mode, StorageBytesStatus, Type
Instance Attribute Summary collapse
-
#auto_delete ⇒ ::Boolean
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
-
#boot ⇒ ::Boolean
Indicates that this is a boot disk.
-
#device_name ⇒ ::String
Specifies the name of the disk attached to the source instance.
-
#disk_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
The encryption key for the disk.
-
#disk_size_gb ⇒ ::Integer
The size of the disk in base-2 GB.
-
#disk_type ⇒ ::String
Output only.
-
#guest_os_features ⇒ ::Array<::Google::Cloud::Compute::V1::GuestOsFeature>
A list of features to enable on the guest operating system.
-
#index ⇒ ::Integer
Output only.
-
#interface ⇒ ::String
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
-
#kind ⇒ ::String
Output only.
-
#licenses ⇒ ::Array<::String>
Output only.
-
#mode ⇒ ::String
The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
-
#source ⇒ ::String
Specifies a URL of the disk attached to the source instance.
-
#storage_bytes ⇒ ::Integer
Output only.
-
#storage_bytes_status ⇒ ::String
Output only.
-
#type ⇒ ::String
Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
Instance Attribute Details
#auto_delete ⇒ ::Boolean
Returns Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#boot ⇒ ::Boolean
Returns Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#device_name ⇒ ::String
Returns Specifies the name of the disk attached to the source instance.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#disk_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Returns The encryption key for the disk.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#disk_size_gb ⇒ ::Integer
Returns The size of the disk in base-2 GB.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#disk_type ⇒ ::String
Returns Output only. [Output Only] URL of the disk type resource. For example:projects/project/zones/zone/diskTypes/pd-standard or pd-ssd.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#guest_os_features ⇒ ::Array<::Google::Cloud::Compute::V1::GuestOsFeature>
Returns A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#index ⇒ ::Integer
Returns Output only. Specifies zero-based index of the disk that is attached to the source instance.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#interface ⇒ ::String
Returns Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Check the Interface enum for the list of possible values.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#licenses ⇒ ::Array<::String>
Returns Output only. [Output Only] Any valid publicly visible licenses.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#mode ⇒ ::String
Returns The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Check the Mode enum for the list of possible values.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#source ⇒ ::String
Returns Specifies a URL of the disk attached to the source instance.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#storage_bytes ⇒ ::Integer
Returns Output only. [Output Only] A size of the storage used by the disk's snapshot by this machine image.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#storage_bytes_status ⇒ ::String
Returns Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#type ⇒ ::String
Returns Specifies the type of the attached disk, either SCRATCH orPERSISTENT. Check the Type enum for the list of possible values.
69785 69786 69787 69788 69789 69790 69791 69792 69793 69794 69795 69796 69797 69798 69799 69800 69801 69802 69803 69804 69805 69806 69807 69808 69809 69810 69811 69812 69813 69814 69815 69816 69817 69818 69819 69820 69821 69822 69823 69824 69825 69826 69827 69828 69829 69830 69831 69832 69833 69834 69835 69836 69837 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69785 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |