Class: Google::Cloud::Compute::V1::SavedAttachedDisk
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SavedAttachedDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.
Defined Under Namespace
Modules: Interface, Mode, StorageBytesStatus, Type
Instance Attribute Summary collapse
-
#auto_delete ⇒ ::Boolean
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
-
#boot ⇒ ::Boolean
Indicates that this is a boot disk.
-
#device_name ⇒ ::String
Specifies the name of the disk attached to the source instance.
-
#disk_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
The encryption key for the disk.
-
#disk_size_gb ⇒ ::Integer
The size of the disk in base-2 GB.
-
#disk_type ⇒ ::String
Output only.
-
#guest_os_features ⇒ ::Array<::Google::Cloud::Compute::V1::GuestOsFeature>
A list of features to enable on the guest operating system.
-
#index ⇒ ::Integer
Output only.
-
#interface ⇒ ::String
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
-
#kind ⇒ ::String
Output only.
-
#licenses ⇒ ::Array<::String>
Output only.
-
#mode ⇒ ::String
The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
-
#source ⇒ ::String
Specifies a URL of the disk attached to the source instance.
-
#storage_bytes ⇒ ::Integer
Output only.
-
#storage_bytes_status ⇒ ::String
Output only.
-
#type ⇒ ::String
Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
Instance Attribute Details
#auto_delete ⇒ ::Boolean
Returns Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#boot ⇒ ::Boolean
Returns Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#device_name ⇒ ::String
Returns Specifies the name of the disk attached to the source instance.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#disk_encryption_key ⇒ ::Google::Cloud::Compute::V1::CustomerEncryptionKey
Returns The encryption key for the disk.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#disk_size_gb ⇒ ::Integer
Returns The size of the disk in base-2 GB.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#disk_type ⇒ ::String
Returns Output only. [Output Only] URL of the disk type resource. For example:projects/project/zones/zone/diskTypes/pd-standard or pd-ssd.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#guest_os_features ⇒ ::Array<::Google::Cloud::Compute::V1::GuestOsFeature>
Returns A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#index ⇒ ::Integer
Returns Output only. Specifies zero-based index of the disk that is attached to the source instance.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#interface ⇒ ::String
Returns Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Check the Interface enum for the list of possible values.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#licenses ⇒ ::Array<::String>
Returns Output only. [Output Only] Any valid publicly visible licenses.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#mode ⇒ ::String
Returns The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Check the Mode enum for the list of possible values.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#source ⇒ ::String
Returns Specifies a URL of the disk attached to the source instance.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#storage_bytes ⇒ ::Integer
Returns Output only. [Output Only] A size of the storage used by the disk's snapshot by this machine image.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#storage_bytes_status ⇒ ::String
Returns Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |
#type ⇒ ::String
Returns Specifies the type of the attached disk, either SCRATCH orPERSISTENT. Check the Type enum for the list of possible values.
68132 68133 68134 68135 68136 68137 68138 68139 68140 68141 68142 68143 68144 68145 68146 68147 68148 68149 68150 68151 68152 68153 68154 68155 68156 68157 68158 68159 68160 68161 68162 68163 68164 68165 68166 68167 68168 68169 68170 68171 68172 68173 68174 68175 68176 68177 68178 68179 68180 68181 68182 68183 68184 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68132 class SavedAttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the disk interface to use for attaching this disk, which is # either SCSI or NVME. module Interface # A value indicating that the enum field is not set. UNDEFINED_INTERFACE = 0 NVME = 2_408_800 SCSI = 2_539_686 end # The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. module Mode # A value indicating that the enum field is not set. UNDEFINED_MODE = 0 # Attaches this disk in read-only mode. Multiple virtual machines can use # a disk in read-only mode at a time. READ_ONLY = 91_950_261 # *[Default]* Attaches this disk in read-write mode. Only one # virtual machine at a time can be attached to a disk in read-write mode. READ_WRITE = 173_607_894 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end # Specifies the type of the attached disk, either SCRATCH orPERSISTENT. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PERSISTENT = 460_683_927 SCRATCH = 496_778_970 end end |