Class: Google::Cloud::Compute::V1::SavedDisk
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SavedDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
An instance-attached disk resource.
Defined Under Namespace
Modules: Architecture, StorageBytesStatus
Instance Attribute Summary collapse
-
#architecture ⇒ ::String
Output only.
-
#kind ⇒ ::String
Output only.
-
#source_disk ⇒ ::String
Output only.
-
#storage_bytes ⇒ ::Integer
Output only.
-
#storage_bytes_status ⇒ ::String
Output only.
Instance Attribute Details
#architecture ⇒ ::String
Returns Output only. [Output Only] The architecture of the attached disk. Check the Architecture enum for the list of possible values.
70663 70664 70665 70666 70667 70668 70669 70670 70671 70672 70673 70674 70675 70676 70677 70678 70679 70680 70681 70682 70683 70684 70685 70686 70687 70688 70689 70690 70691 70692 70693 70694 70695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70663 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#savedDisk for attached disks.
70663 70664 70665 70666 70667 70668 70669 70670 70671 70672 70673 70674 70675 70676 70677 70678 70679 70680 70681 70682 70683 70684 70685 70686 70687 70688 70689 70690 70691 70692 70693 70694 70695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70663 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |
#source_disk ⇒ ::String
Returns Output only. Specifies a URL of the disk attached to the source instance.
70663 70664 70665 70666 70667 70668 70669 70670 70671 70672 70673 70674 70675 70676 70677 70678 70679 70680 70681 70682 70683 70684 70685 70686 70687 70688 70689 70690 70691 70692 70693 70694 70695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70663 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |
#storage_bytes ⇒ ::Integer
Returns Output only. [Output Only] Size of the individual disk snapshot used by this machine image.
70663 70664 70665 70666 70667 70668 70669 70670 70671 70672 70673 70674 70675 70676 70677 70678 70679 70680 70681 70682 70683 70684 70685 70686 70687 70688 70689 70690 70691 70692 70693 70694 70695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70663 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |
#storage_bytes_status ⇒ ::String
Returns Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.
70663 70664 70665 70666 70667 70668 70669 70670 70671 70672 70673 70674 70675 70676 70677 70678 70679 70680 70681 70682 70683 70684 70685 70686 70687 70688 70689 70690 70691 70692 70693 70694 70695 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70663 class SavedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The architecture of the attached disk. module Architecture # A value indicating that the enum field is not set. UNDEFINED_ARCHITECTURE = 0 # Default value indicating Architecture is not set. ARCHITECTURE_UNSPECIFIED = 394_750_507 # Machines with architecture ARM64 ARM64 = 62_547_450 # Machines with architecture X86_64 X86_64 = 425_300_551 end # Output only. [Output Only] An indicator whether storageBytes is in a # stable state or it is being adjusted as a result of shared storage # reallocation. This status can either be UPDATING, meaning # the size of the snapshot is being updated, or UP_TO_DATE, # meaning the size of the snapshot is up-to-date. module StorageBytesStatus # A value indicating that the enum field is not set. UNDEFINED_STORAGE_BYTES_STATUS = 0 UPDATING = 494_614_342 UP_TO_DATE = 101_306_702 end end |