Class: Google::Cloud::Compute::V1::SavedDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

An instance-attached disk resource.

Defined Under Namespace

Modules: Architecture, StorageBytesStatus

Instance Attribute Summary collapse

Instance Attribute Details

#architecture::String

Returns Output only. [Output Only] The architecture of the attached disk. Check the Architecture enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The architecture of the attached disk. Check the Architecture enum for the list of possible values.



69863
69864
69865
69866
69867
69868
69869
69870
69871
69872
69873
69874
69875
69876
69877
69878
69879
69880
69881
69882
69883
69884
69885
69886
69887
69888
69889
69890
69891
69892
69893
69894
69895
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69863

class SavedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The architecture of the attached disk.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Always compute#savedDisk for attached disks.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Always compute#savedDisk for attached disks.



69863
69864
69865
69866
69867
69868
69869
69870
69871
69872
69873
69874
69875
69876
69877
69878
69879
69880
69881
69882
69883
69884
69885
69886
69887
69888
69889
69890
69891
69892
69893
69894
69895
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69863

class SavedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The architecture of the attached disk.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end
end

#source_disk::String

Returns Output only. Specifies a URL of the disk attached to the source instance.

Returns:

  • (::String)

    Output only. Specifies a URL of the disk attached to the source instance.



69863
69864
69865
69866
69867
69868
69869
69870
69871
69872
69873
69874
69875
69876
69877
69878
69879
69880
69881
69882
69883
69884
69885
69886
69887
69888
69889
69890
69891
69892
69893
69894
69895
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69863

class SavedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The architecture of the attached disk.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end
end

#storage_bytes::Integer

Returns Output only. [Output Only] Size of the individual disk snapshot used by this machine image.

Returns:

  • (::Integer)

    Output only. [Output Only] Size of the individual disk snapshot used by this machine image.



69863
69864
69865
69866
69867
69868
69869
69870
69871
69872
69873
69874
69875
69876
69877
69878
69879
69880
69881
69882
69883
69884
69885
69886
69887
69888
69889
69890
69891
69892
69893
69894
69895
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69863

class SavedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The architecture of the attached disk.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end
end

#storage_bytes_status::String

Returns Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Check the StorageBytesStatus enum for the list of possible values.



69863
69864
69865
69866
69867
69868
69869
69870
69871
69872
69873
69874
69875
69876
69877
69878
69879
69880
69881
69882
69883
69884
69885
69886
69887
69888
69889
69890
69891
69892
69893
69894
69895
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69863

class SavedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The architecture of the attached disk.
  module Architecture
    # A value indicating that the enum field is not set.
    UNDEFINED_ARCHITECTURE = 0

    # Default value indicating Architecture is not set.
    ARCHITECTURE_UNSPECIFIED = 394_750_507

    # Machines with architecture ARM64
    ARM64 = 62_547_450

    # Machines with architecture X86_64
    X86_64 = 425_300_551
  end

  # Output only. [Output Only] An indicator whether storageBytes is in a
  # stable state or it is being adjusted as a result of shared storage
  # reallocation. This status can either be UPDATING, meaning
  # the size of the snapshot is being updated, or UP_TO_DATE,
  # meaning the size of the snapshot is up-to-date.
  module StorageBytesStatus
    # A value indicating that the enum field is not set.
    UNDEFINED_STORAGE_BYTES_STATUS = 0

    UPDATING = 494_614_342

    UP_TO_DATE = 101_306_702
  end
end