Class: Google::Cloud::Compute::V1::ScalingScheduleStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ScalingScheduleStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#last_start_time ⇒ ::String
[Output Only] The last time the scaling schedule became active.
-
#next_start_time ⇒ ::String
[Output Only] The next time the scaling schedule is to become active.
-
#state ⇒ ::String
[Output Only] The current state of a scaling schedule.
Instance Attribute Details
#last_start_time ⇒ ::String
Returns [Output Only] The last time the scaling schedule became active. Note: this is a timestamp when a schedule actually became active, not when it was planned to do so. The timestamp is in RFC3339 text format.
69915 69916 69917 69918 69919 69920 69921 69922 69923 69924 69925 69926 69927 69928 69929 69930 69931 69932 69933 69934 69935 69936 69937 69938 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69915 class ScalingScheduleStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The current state of a scaling schedule. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The current autoscaling recommendation is influenced by this scaling # schedule. ACTIVE = 314_733_318 # This scaling schedule has been disabled by the user. DISABLED = 516_696_700 # This scaling schedule will never become active again. OBSOLETE = 66_532_761 # The current autoscaling recommendation is not influenced by this scaling # schedule. READY = 77_848_963 end end |
#next_start_time ⇒ ::String
Returns [Output Only] The next time the scaling schedule is to become active. Note: this is a timestamp when a schedule is planned to run, but the actual time might be slightly different. The timestamp is in RFC3339 text format.
69915 69916 69917 69918 69919 69920 69921 69922 69923 69924 69925 69926 69927 69928 69929 69930 69931 69932 69933 69934 69935 69936 69937 69938 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69915 class ScalingScheduleStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The current state of a scaling schedule. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The current autoscaling recommendation is influenced by this scaling # schedule. ACTIVE = 314_733_318 # This scaling schedule has been disabled by the user. DISABLED = 516_696_700 # This scaling schedule will never become active again. OBSOLETE = 66_532_761 # The current autoscaling recommendation is not influenced by this scaling # schedule. READY = 77_848_963 end end |
#state ⇒ ::String
Returns [Output Only] The current state of a scaling schedule. Check the State enum for the list of possible values.
69915 69916 69917 69918 69919 69920 69921 69922 69923 69924 69925 69926 69927 69928 69929 69930 69931 69932 69933 69934 69935 69936 69937 69938 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69915 class ScalingScheduleStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The current state of a scaling schedule. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The current autoscaling recommendation is influenced by this scaling # schedule. ACTIVE = 314_733_318 # This scaling schedule has been disabled by the user. DISABLED = 516_696_700 # This scaling schedule will never become active again. OBSOLETE = 66_532_761 # The current autoscaling recommendation is not influenced by this scaling # schedule. READY = 77_848_963 end end |