Class: Google::Cloud::Compute::V1::Scheduling

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Sets the scheduling options for an Instance.

Defined Under Namespace

Modules: InstanceTerminationAction, OnHostMaintenance, ProvisioningModel

Instance Attribute Summary collapse

Instance Attribute Details

#automatic_restart::Boolean

Returns Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances.Preemptible instances cannot be automatically restarted.

By default, this is set to true so an instance is automatically restarted if it is terminated by Compute Engine.

Returns:

  • (::Boolean)

    Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances.Preemptible instances cannot be automatically restarted.

    By default, this is set to true so an instance is automatically restarted if it is terminated by Compute Engine.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#availability_domain::Integer

Returns Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance.

Returns:

  • (::Integer)

    Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#host_error_timeout_seconds::Integer

Returns Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used.

Returns:

  • (::Integer)

    Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#instance_termination_action::String

Returns Specifies the termination action for the instance. Check the InstanceTerminationAction enum for the list of possible values.

Returns:

  • (::String)

    Specifies the termination action for the instance. Check the InstanceTerminationAction enum for the list of possible values.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#local_ssd_recovery_timeout::Google::Cloud::Compute::V1::Duration

Returns Specifies the maximum amount of time a Local Ssd Vm should wait while recovery of the Local Ssd state is attempted. Its value should be in between 0 and 168 hours with hour granularity and the default value being 1 hour.

Returns:

  • (::Google::Cloud::Compute::V1::Duration)

    Specifies the maximum amount of time a Local Ssd Vm should wait while recovery of the Local Ssd state is attempted. Its value should be in between 0 and 168 hours with hour granularity and the default value being 1 hour.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#location_hint::String

Returns An opaque location hint used to place the instance close to other resources. This field is for use by internal tools that use the public API.

Returns:

  • (::String)

    An opaque location hint used to place the instance close to other resources. This field is for use by internal tools that use the public API.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#max_run_duration::Google::Cloud::Compute::V1::Duration

Returns Specifies the max run duration for the given instance. If specified, the instance termination action will be performed at the end of the run duration.

Returns:

  • (::Google::Cloud::Compute::V1::Duration)

    Specifies the max run duration for the given instance. If specified, the instance termination action will be performed at the end of the run duration.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#min_node_cpus::Integer

Returns The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.

Returns:

  • (::Integer)

    The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#node_affinities::Array<::Google::Cloud::Compute::V1::SchedulingNodeAffinity>

Returns A set of node affinity and anti-affinity configurations. Refer toConfiguring node affinity for more information. Overrides reservationAffinity.

Returns:



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#on_host_maintenance::String

Returns Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. Forpreemptible instances, the default and only possible behavior is TERMINATE. For more information, see Set VM host maintenance policy. Check the OnHostMaintenance enum for the list of possible values.

Returns:

  • (::String)

    Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. Forpreemptible instances, the default and only possible behavior is TERMINATE. For more information, see Set VM host maintenance policy. Check the OnHostMaintenance enum for the list of possible values.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#on_instance_stop_action::Google::Cloud::Compute::V1::SchedulingOnInstanceStopAction



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#preemptible::Boolean

Returns Defines whether the instance is preemptible. This can only be set during instance creation or while the instance isstopped and therefore, in a TERMINATED state. SeeInstance Life Cycle for more information on the possible instance states.

Returns:

  • (::Boolean)

    Defines whether the instance is preemptible. This can only be set during instance creation or while the instance isstopped and therefore, in a TERMINATED state. SeeInstance Life Cycle for more information on the possible instance states.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#provisioning_model::String

Returns Specifies the provisioning model of the instance. Check the ProvisioningModel enum for the list of possible values.

Returns:

  • (::String)

    Specifies the provisioning model of the instance. Check the ProvisioningModel enum for the list of possible values.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#skip_guest_os_shutdown::Boolean

Returns Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs.

Returns:

  • (::Boolean)

    Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end

#termination_time::String

Returns Specifies the timestamp, when the instance will be terminated, inRFC3339 text format. If specified, the instance termination action will be performed at the termination time.

Returns:

  • (::String)

    Specifies the timestamp, when the instance will be terminated, inRFC3339 text format. If specified, the instance termination action will be performed at the termination time.



70019
70020
70021
70022
70023
70024
70025
70026
70027
70028
70029
70030
70031
70032
70033
70034
70035
70036
70037
70038
70039
70040
70041
70042
70043
70044
70045
70046
70047
70048
70049
70050
70051
70052
70053
70054
70055
70056
70057
70058
70059
70060
70061
70062
70063
70064
70065
70066
70067
70068
70069
70070
70071
70072
70073
70074
70075
70076
70077
70078
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70019

class Scheduling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the termination action for the instance.
  module InstanceTerminationAction
    # A value indicating that the enum field is not set.
    UNDEFINED_INSTANCE_TERMINATION_ACTION = 0

    # Delete the VM.
    DELETE = 402_225_579

    # Default value. This value is unused.
    INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803

    # Stop the VM without storing in-memory content. default action.
    STOP = 2_555_906
  end

  # Defines the maintenance behavior for this instance. For standard instances,
  # the default behavior is MIGRATE. Forpreemptible instances,
  # the default and only possible behavior is TERMINATE. For more
  # information, see
  #  Set
  #  VM host maintenance policy.
  module OnHostMaintenance
    # A value indicating that the enum field is not set.
    UNDEFINED_ON_HOST_MAINTENANCE = 0

    # *[Default]* Allows Compute Engine to automatically migrate instances
    # out of the way of maintenance events.
    MIGRATE = 165_699_979

    # Tells Compute Engine to terminate and (optionally) restart the instance
    # away from the maintenance activity. If you would like your instance to be
    # restarted, set the automaticRestart flag to true. Your
    # instance may be restarted more than once, and it may be restarted outside
    # the window of maintenance events.
    TERMINATE = 527_617_601
  end

  # Specifies the provisioning model of the instance.
  module ProvisioningModel
    # A value indicating that the enum field is not set.
    UNDEFINED_PROVISIONING_MODEL = 0

    # Instance is provisioned using the Flex Start provisioning model and
    # has a limited runtime.
    FLEX_START = 101_746_812

    # Bound to the lifecycle of the reservation in which it is provisioned.
    RESERVATION_BOUND = 293_538_571

    # Heavily discounted, no guaranteed runtime.
    SPOT = 2_552_066

    # Standard provisioning with user controlled runtime, no discounts.
    STANDARD = 484_642_493
  end
end