Class: Google::Cloud::Compute::V1::Scheduling
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Scheduling
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Sets the scheduling options for an Instance.
Defined Under Namespace
Modules: InstanceTerminationAction, OnHostMaintenance, ProvisioningModel
Instance Attribute Summary collapse
-
#automatic_restart ⇒ ::Boolean
Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user).
-
#availability_domain ⇒ ::Integer
Specifies the availability domain to place the instance in.
-
#expose_host_topology ⇒ ::Boolean
This optional flag exposes the hashed physical host ID in the ResourceStatus resource of the VM.
- #graceful_shutdown ⇒ ::Google::Cloud::Compute::V1::SchedulingGracefulShutdown
-
#host_error_timeout_seconds ⇒ ::Integer
Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used.
-
#instance_termination_action ⇒ ::String
Specifies the termination action for the instance.
-
#local_ssd_recovery_timeout ⇒ ::Google::Cloud::Compute::V1::Duration
Specifies the maximum amount of time a Local Ssd Vm should wait while recovery of the Local Ssd state is attempted.
-
#location_hint ⇒ ::String
An opaque location hint used to place the instance close to other resources.
-
#max_run_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Specifies the max run duration for the given instance.
-
#min_node_cpus ⇒ ::Integer
The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
-
#node_affinities ⇒ ::Array<::Google::Cloud::Compute::V1::SchedulingNodeAffinity>
A set of node affinity and anti-affinity configurations.
-
#on_host_maintenance ⇒ ::String
Defines the maintenance behavior for this instance.
- #on_instance_stop_action ⇒ ::Google::Cloud::Compute::V1::SchedulingOnInstanceStopAction
-
#preemptible ⇒ ::Boolean
Defines whether the instance is preemptible.
-
#preemption_notice_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Specifies the Metadata Service preemption notice duration before the GCE ACPI G2 Soft Off signal is triggered for Spot VMs only.
-
#provisioning_model ⇒ ::String
Specifies the provisioning model of the instance.
-
#skip_guest_os_shutdown ⇒ ::Boolean
Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs.
-
#termination_time ⇒ ::String
Specifies the timestamp, when the instance will be terminated, inRFC3339 text format.
Instance Attribute Details
#automatic_restart ⇒ ::Boolean
Returns Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances.Preemptible instances cannot be automatically restarted.
By default, this is set to true so an instance is automatically restarted if it is terminated by Compute Engine.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#availability_domain ⇒ ::Integer
Returns Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#expose_host_topology ⇒ ::Boolean
Returns This optional flag exposes the hashed physical host ID in the ResourceStatus resource of the VM.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#graceful_shutdown ⇒ ::Google::Cloud::Compute::V1::SchedulingGracefulShutdown
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#host_error_timeout_seconds ⇒ ::Integer
Returns Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#instance_termination_action ⇒ ::String
Returns Specifies the termination action for the instance. Check the InstanceTerminationAction enum for the list of possible values.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#local_ssd_recovery_timeout ⇒ ::Google::Cloud::Compute::V1::Duration
Returns Specifies the maximum amount of time a Local Ssd Vm should wait while recovery of the Local Ssd state is attempted. Its value should be in between 0 and 168 hours with hour granularity and the default value being 1 hour.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#location_hint ⇒ ::String
Returns An opaque location hint used to place the instance close to other resources. This field is for use by internal tools that use the public API.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#max_run_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Returns Specifies the max run duration for the given instance. If specified, the instance termination action will be performed at the end of the run duration.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#min_node_cpus ⇒ ::Integer
Returns The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#node_affinities ⇒ ::Array<::Google::Cloud::Compute::V1::SchedulingNodeAffinity>
Returns A set of node affinity and anti-affinity configurations. Refer toConfiguring node affinity for more information. Overrides reservationAffinity.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#on_host_maintenance ⇒ ::String
Returns Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. Forpreemptible instances, the default and only possible behavior is TERMINATE. For more information, see Set VM host maintenance policy. Check the OnHostMaintenance enum for the list of possible values.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#on_instance_stop_action ⇒ ::Google::Cloud::Compute::V1::SchedulingOnInstanceStopAction
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#preemptible ⇒ ::Boolean
Returns Defines whether the instance is preemptible. This can only be set during
instance creation or while the instance isstopped and
therefore, in a TERMINATED state. SeeInstance Life
Cycle for more information on the possible instance states.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#preemption_notice_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Returns Specifies the Metadata Service preemption notice duration before the GCE ACPI G2 Soft Off signal is triggered for Spot VMs only. If not specified, there will be no wait before the G2 Soft Off signal is triggered.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#provisioning_model ⇒ ::String
Returns Specifies the provisioning model of the instance. Check the ProvisioningModel enum for the list of possible values.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#skip_guest_os_shutdown ⇒ ::Boolean
Returns Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |
#termination_time ⇒ ::String
Returns Specifies the timestamp, when the instance will be terminated, inRFC3339 text format. If specified, the instance termination action will be performed at the termination time.
72533 72534 72535 72536 72537 72538 72539 72540 72541 72542 72543 72544 72545 72546 72547 72548 72549 72550 72551 72552 72553 72554 72555 72556 72557 72558 72559 72560 72561 72562 72563 72564 72565 72566 72567 72568 72569 72570 72571 72572 72573 72574 72575 72576 72577 72578 72579 72580 72581 72582 72583 72584 72585 72586 72587 72588 72589 72590 72591 72592 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72533 class Scheduling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the termination action for the instance. module InstanceTerminationAction # A value indicating that the enum field is not set. UNDEFINED_INSTANCE_TERMINATION_ACTION = 0 # Delete the VM. DELETE = 402_225_579 # Default value. This value is unused. INSTANCE_TERMINATION_ACTION_UNSPECIFIED = 92_954_803 # Stop the VM without storing in-memory content. default action. STOP = 2_555_906 end # Defines the maintenance behavior for this instance. For standard instances, # the default behavior is MIGRATE. Forpreemptible instances, # the default and only possible behavior is TERMINATE. For more # information, see # Set # VM host maintenance policy. module OnHostMaintenance # A value indicating that the enum field is not set. UNDEFINED_ON_HOST_MAINTENANCE = 0 # *[Default]* Allows Compute Engine to automatically migrate instances # out of the way of maintenance events. MIGRATE = 165_699_979 # Tells Compute Engine to terminate and (optionally) restart the instance # away from the maintenance activity. If you would like your instance to be # restarted, set the automaticRestart flag to true. Your # instance may be restarted more than once, and it may be restarted outside # the window of maintenance events. TERMINATE = 527_617_601 end # Specifies the provisioning model of the instance. module ProvisioningModel # A value indicating that the enum field is not set. UNDEFINED_PROVISIONING_MODEL = 0 # Instance is provisioned using the Flex Start provisioning model and # has a limited runtime. FLEX_START = 101_746_812 # Bound to the lifecycle of the reservation in which it is provisioned. RESERVATION_BOUND = 293_538_571 # Heavily discounted, no guaranteed runtime. SPOT = 2_552_066 # Standard provisioning with user controlled runtime, no discounts. STANDARD = 484_642_493 end end |