Class: Google::Cloud::Compute::V1::SchedulingGracefulShutdown
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SchedulingGracefulShutdown
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The configuration for gracefully shutting down the instance.
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
Opts-in for graceful shutdown.
-
#max_duration ⇒ ::Google::Cloud::Compute::V1::Duration
The time allotted for the instance to gracefully shut down.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns Opts-in for graceful shutdown.
72603 72604 72605 72606 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72603 class SchedulingGracefulShutdown include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_duration ⇒ ::Google::Cloud::Compute::V1::Duration
Returns The time allotted for the instance to gracefully shut down. If the graceful shutdown isn't complete after this time, then the instance transitions to the STOPPING state.
72603 72604 72605 72606 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72603 class SchedulingGracefulShutdown include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |