Class: Google::Cloud::Compute::V1::SchedulingOnInstanceStopAction
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SchedulingOnInstanceStopAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Defines the behaviour for instances with the instance_termination_actionSTOP.
Instance Attribute Summary collapse
-
#discard_local_ssd ⇒ ::Boolean
If true, the contents of any attached Local SSD disks will be discarded else, the Local SSD data will be preserved when the instance is stopped at the end of the run duration/termination time.
Instance Attribute Details
#discard_local_ssd ⇒ ::Boolean
Returns If true, the contents of any attached Local SSD disks will be discarded else, the Local SSD data will be preserved when the instance is stopped at the end of the run duration/termination time.
70117 70118 70119 70120 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70117 class SchedulingOnInstanceStopAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |