Class: Google::Cloud::Compute::V1::SecurityPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Google Cloud Armor security policy resource.
Only external backend services that use load balancers can reference a security policy. For more information, see Google Cloud Armor security policy overview.
Defined Under Namespace
Modules: Type Classes: LabelsEntry
Instance Attribute Summary collapse
- #adaptive_protection_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyAdaptiveProtectionConfig
- #advanced_options_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfig
-
#associations ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyAssociation>
A list of associations that belong to this policy.
-
#creation_timestamp ⇒ ::String
Output only.
- #ddos_protection_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyDdosProtectionConfig
-
#description ⇒ ::String
An optional description of this resource.
-
#fingerprint ⇒ ::String
Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#label_fingerprint ⇒ ::String
A fingerprint for the labels being applied to this security policy, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels for this resource.
-
#name ⇒ ::String
Name of the resource.
-
#parent ⇒ ::String
Output only.
- #recaptcha_options_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyRecaptchaOptionsConfig
-
#region ⇒ ::String
Output only.
-
#rules ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRule>
A list of rules that belong to this policy.
-
#self_link ⇒ ::String
Output only.
-
#short_name ⇒ ::String
User-provided name of the organization security policy.
-
#type ⇒ ::String
The type indicates the intended use of the security policy.
-
#user_defined_fields ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyUserDefinedField>
Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies.
Instance Attribute Details
#adaptive_protection_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyAdaptiveProtectionConfig
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#advanced_options_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfig
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#associations ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyAssociation>
Returns A list of associations that belong to this policy.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#ddos_protection_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyDdosProtectionConfig
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#fingerprint ⇒ ::String
Returns Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make get() request to the security policy.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#kind ⇒ ::String
Returns Output only. [Output only] Type of the resource. Alwayscompute#securityPolicyfor security policies.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#label_fingerprint ⇒ ::String
Returns A fingerprint for the labels being applied to this security policy, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels.
To see the latest fingerprint, make get() request to the security policy.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#parent ⇒ ::String
Returns Output only. [Output Only] The parent of the security policy.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#recaptcha_options_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyRecaptchaOptionsConfig
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the regional security policy resides. This field is not applicable to global security policies.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#rules ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyRule>
Returns A list of rules that belong to this policy. There must always be a default rule which is a rule with priority 2147483647 and match all condition (for the match condition this means match "" for srcIpRanges and for the networkMatch condition every field must be either match "" or not set). If no rules are provided when creating a security policy, a default rule with action "allow" will be added.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#short_name ⇒ ::String
Returns User-provided name of the organization security policy. The name should be
unique in the organization in which the security policy is created. This
should only be used when SecurityPolicyType is CLOUD_ARMOR.
The name must be 1-63 characters long, and comply with
https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be 1-63
characters long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a
lowercase letter, and all following characters must be a dash, lowercase
letter, or digit, except the last character, which cannot be a dash.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#type ⇒ ::String
Returns The type indicates the intended use of the security policy.
- CLOUD_ARMOR: Cloud Armor backend security policies can be configured to filter incoming HTTP requests targeting backend services. They filter requests before they hit the origin servers.
- CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can be configured to filter incoming HTTP requests targeting backend services (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). They filter requests before the request is served from Google's cache.
CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor internal service policies can be configured to filter HTTP requests targeting services managed by Traffic Director in a service mesh. They filter requests before the request is served from the application.
- CLOUD_ARMOR_NETWORK: Cloud Armor network policies can be configured to filter packets targeting network load balancing resources such as backend services, target pools, target instances, and instances with external IPs. They filter requests before the request is served from the application.
This field can be set only at resource creation time. Check the Type enum for the list of possible values.
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |
#user_defined_fields ⇒ ::Array<::Google::Cloud::Compute::V1::SecurityPolicyUserDefinedField>
Returns Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies. A user-defined field consists of up to 4 bytes extracted from a fixed offset in the packet, relative to the IPv4, IPv6, TCP, or UDP header, with an optional mask to select certain bits. Rules may then specify matching values for these fields.
Example:
userDefinedFields:
- name: "ipv4_fragment_offset" base: IPV4 offset: 6 size: 2 mask: "0x1fff".
68686 68687 68688 68689 68690 68691 68692 68693 68694 68695 68696 68697 68698 68699 68700 68701 68702 68703 68704 68705 68706 68707 68708 68709 68710 68711 68712 68713 68714 68715 68716 68717 68718 68719 68720 68721 68722 68723 68724 68725 68726 68727 68728 68729 68730 68731 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68686 class SecurityPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type indicates the intended use of the security policy. # # - CLOUD_ARMOR: Cloud Armor backend security policies can # be configured to filter incoming HTTP requests targeting backend services. # They filter requests before they hit the origin servers. # - CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can # be configured to filter incoming HTTP requests targeting backend services # (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). # They filter requests before the request is served from Google's cache. # - CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor # internal service policies can be configured to filter HTTP requests # targeting services managed by Traffic Director in a service mesh. They # filter requests before the request is served from the application. # # - CLOUD_ARMOR_NETWORK: Cloud Armor network policies # can be configured to filter packets targeting network load balancing # resources such as backend services, target pools, target instances, and # instances with external IPs. They filter requests before the request is # served from the application. # # # This field can be set only at resource creation time. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 CLOUD_ARMOR = 260_640_373 CLOUD_ARMOR_EDGE = 250_728_775 CLOUD_ARMOR_NETWORK = 488_527_428 end end |