Class: Google::Cloud::Compute::V1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configurations to specifc granular traffic units processed by Adaptive Protection.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#enable_each_unique_value ⇒ ::Boolean
If enabled, traffic matching each unique value for the specified type constitutes a separate traffic unit.
-
#type ⇒ ::String
Type of this configuration.
-
#value ⇒ ::String
Requests that match this value constitute a granular traffic unit.
Instance Attribute Details
#enable_each_unique_value ⇒ ::Boolean
Returns If enabled, traffic matching each unique value for the specified type constitutes a separate traffic unit. It can only be set to true if value is empty.
29964 29965 29966 29967 29968 29969 29970 29971 29972 29973 29974 29975 29976 29977 29978 29979 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29964 class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of this configuration. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HTTP_HEADER_HOST = 374_321_891 HTTP_PATH = 311_503_228 UNSPECIFIED_TYPE = 53_933_922 end end |
#type ⇒ ::String
Returns Type of this configuration. Check the Type enum for the list of possible values.
29964 29965 29966 29967 29968 29969 29970 29971 29972 29973 29974 29975 29976 29977 29978 29979 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29964 class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of this configuration. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HTTP_HEADER_HOST = 374_321_891 HTTP_PATH = 311_503_228 UNSPECIFIED_TYPE = 53_933_922 end end |
#value ⇒ ::String
Returns Requests that match this value constitute a granular traffic unit.
29964 29965 29966 29967 29968 29969 29970 29971 29972 29973 29974 29975 29976 29977 29978 29979 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29964 class SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of this configuration. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 HTTP_HEADER_HOST = 374_321_891 HTTP_PATH = 311_503_228 UNSPECIFIED_TYPE = 53_933_922 end end |