Class: Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: JsonParsing, LogLevel

Instance Attribute Summary collapse

Instance Attribute Details

#json_custom_config::Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig

Returns Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD.

Returns:



68858
68859
68860
68861
68862
68863
68864
68865
68866
68867
68868
68869
68870
68871
68872
68873
68874
68875
68876
68877
68878
68879
68880
68881
68882
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68858

class SecurityPolicyAdvancedOptionsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module JsonParsing
    # A value indicating that the enum field is not set.
    UNDEFINED_JSON_PARSING = 0

    DISABLED = 516_696_700

    STANDARD = 484_642_493

    STANDARD_WITH_GRAPHQL = 106_979_218
  end

  module LogLevel
    # A value indicating that the enum field is not set.
    UNDEFINED_LOG_LEVEL = 0

    NORMAL = 161_067_239

    VERBOSE = 532_219_234
  end
end

#json_parsing::String

Returns Check the JsonParsing enum for the list of possible values.

Returns:

  • (::String)

    Check the JsonParsing enum for the list of possible values.



68858
68859
68860
68861
68862
68863
68864
68865
68866
68867
68868
68869
68870
68871
68872
68873
68874
68875
68876
68877
68878
68879
68880
68881
68882
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68858

class SecurityPolicyAdvancedOptionsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module JsonParsing
    # A value indicating that the enum field is not set.
    UNDEFINED_JSON_PARSING = 0

    DISABLED = 516_696_700

    STANDARD = 484_642_493

    STANDARD_WITH_GRAPHQL = 106_979_218
  end

  module LogLevel
    # A value indicating that the enum field is not set.
    UNDEFINED_LOG_LEVEL = 0

    NORMAL = 161_067_239

    VERBOSE = 532_219_234
  end
end

#log_level::String

Returns Check the LogLevel enum for the list of possible values.

Returns:

  • (::String)

    Check the LogLevel enum for the list of possible values.



68858
68859
68860
68861
68862
68863
68864
68865
68866
68867
68868
68869
68870
68871
68872
68873
68874
68875
68876
68877
68878
68879
68880
68881
68882
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68858

class SecurityPolicyAdvancedOptionsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module JsonParsing
    # A value indicating that the enum field is not set.
    UNDEFINED_JSON_PARSING = 0

    DISABLED = 516_696_700

    STANDARD = 484_642_493

    STANDARD_WITH_GRAPHQL = 106_979_218
  end

  module LogLevel
    # A value indicating that the enum field is not set.
    UNDEFINED_LOG_LEVEL = 0

    NORMAL = 161_067_239

    VERBOSE = 532_219_234
  end
end

#request_body_inspection_size::String

Returns The maximum request size chosen by the customer with Waf enabled. Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB". Values are case insensitive.

Returns:

  • (::String)

    The maximum request size chosen by the customer with Waf enabled. Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB". Values are case insensitive.



68858
68859
68860
68861
68862
68863
68864
68865
68866
68867
68868
68869
68870
68871
68872
68873
68874
68875
68876
68877
68878
68879
68880
68881
68882
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68858

class SecurityPolicyAdvancedOptionsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module JsonParsing
    # A value indicating that the enum field is not set.
    UNDEFINED_JSON_PARSING = 0

    DISABLED = 516_696_700

    STANDARD = 484_642_493

    STANDARD_WITH_GRAPHQL = 106_979_218
  end

  module LogLevel
    # A value indicating that the enum field is not set.
    UNDEFINED_LOG_LEVEL = 0

    NORMAL = 161_067_239

    VERBOSE = 532_219_234
  end
end

#user_ip_request_headers::Array<::String>

Returns An optional list of case-insensitive request header names to use for resolving the callers client IP address.

Returns:

  • (::Array<::String>)

    An optional list of case-insensitive request header names to use for resolving the callers client IP address.



68858
68859
68860
68861
68862
68863
68864
68865
68866
68867
68868
68869
68870
68871
68872
68873
68874
68875
68876
68877
68878
68879
68880
68881
68882
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68858

class SecurityPolicyAdvancedOptionsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module JsonParsing
    # A value indicating that the enum field is not set.
    UNDEFINED_JSON_PARSING = 0

    DISABLED = 516_696_700

    STANDARD = 484_642_493

    STANDARD_WITH_GRAPHQL = 106_979_218
  end

  module LogLevel
    # A value indicating that the enum field is not set.
    UNDEFINED_LOG_LEVEL = 0

    NORMAL = 161_067_239

    VERBOSE = 532_219_234
  end
end