Class: Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: JsonParsing, LogLevel

Instance Attribute Summary collapse

Instance Attribute Details

#json_custom_config::Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig

Returns Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD.

Returns:



30503
30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
30517
30518
30519
30520
30521
30522
30523
30524
30525
30526
30527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30503

class SecurityPolicyAdvancedOptionsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module JsonParsing
    # A value indicating that the enum field is not set.
    UNDEFINED_JSON_PARSING = 0

    DISABLED = 516_696_700

    STANDARD = 484_642_493

    STANDARD_WITH_GRAPHQL = 106_979_218
  end

  module LogLevel
    # A value indicating that the enum field is not set.
    UNDEFINED_LOG_LEVEL = 0

    NORMAL = 161_067_239

    VERBOSE = 532_219_234
  end
end

#json_parsing::String

Returns Check the JsonParsing enum for the list of possible values.

Returns:

  • (::String)

    Check the JsonParsing enum for the list of possible values.



30503
30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
30517
30518
30519
30520
30521
30522
30523
30524
30525
30526
30527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30503

class SecurityPolicyAdvancedOptionsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module JsonParsing
    # A value indicating that the enum field is not set.
    UNDEFINED_JSON_PARSING = 0

    DISABLED = 516_696_700

    STANDARD = 484_642_493

    STANDARD_WITH_GRAPHQL = 106_979_218
  end

  module LogLevel
    # A value indicating that the enum field is not set.
    UNDEFINED_LOG_LEVEL = 0

    NORMAL = 161_067_239

    VERBOSE = 532_219_234
  end
end

#log_level::String

Returns Check the LogLevel enum for the list of possible values.

Returns:

  • (::String)

    Check the LogLevel enum for the list of possible values.



30503
30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
30517
30518
30519
30520
30521
30522
30523
30524
30525
30526
30527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30503

class SecurityPolicyAdvancedOptionsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module JsonParsing
    # A value indicating that the enum field is not set.
    UNDEFINED_JSON_PARSING = 0

    DISABLED = 516_696_700

    STANDARD = 484_642_493

    STANDARD_WITH_GRAPHQL = 106_979_218
  end

  module LogLevel
    # A value indicating that the enum field is not set.
    UNDEFINED_LOG_LEVEL = 0

    NORMAL = 161_067_239

    VERBOSE = 532_219_234
  end
end

#user_ip_request_headers::Array<::String>

Returns An optional list of case-insensitive request header names to use for resolving the callers client IP address.

Returns:

  • (::Array<::String>)

    An optional list of case-insensitive request header names to use for resolving the callers client IP address.



30503
30504
30505
30506
30507
30508
30509
30510
30511
30512
30513
30514
30515
30516
30517
30518
30519
30520
30521
30522
30523
30524
30525
30526
30527
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30503

class SecurityPolicyAdvancedOptionsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module JsonParsing
    # A value indicating that the enum field is not set.
    UNDEFINED_JSON_PARSING = 0

    DISABLED = 516_696_700

    STANDARD = 484_642_493

    STANDARD_WITH_GRAPHQL = 106_979_218
  end

  module LogLevel
    # A value indicating that the enum field is not set.
    UNDEFINED_LOG_LEVEL = 0

    NORMAL = 161_067_239

    VERBOSE = 532_219_234
  end
end