Class: Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: JsonParsing, LogLevel
Instance Attribute Summary collapse
-
#json_custom_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Custom configuration to apply the JSON parsing.
-
#json_parsing ⇒ ::String
Check the JsonParsing enum for the list of possible values.
-
#log_level ⇒ ::String
Check the LogLevel enum for the list of possible values.
-
#user_ip_request_headers ⇒ ::Array<::String>
An optional list of case-insensitive request header names to use for resolving the callers client IP address.
Instance Attribute Details
#json_custom_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Returns Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD.
30023 30024 30025 30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30023 class SecurityPolicyAdvancedOptionsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module JsonParsing # A value indicating that the enum field is not set. UNDEFINED_JSON_PARSING = 0 DISABLED = 516_696_700 STANDARD = 484_642_493 STANDARD_WITH_GRAPHQL = 106_979_218 end module LogLevel # A value indicating that the enum field is not set. UNDEFINED_LOG_LEVEL = 0 NORMAL = 161_067_239 VERBOSE = 532_219_234 end end |
#json_parsing ⇒ ::String
Returns Check the JsonParsing enum for the list of possible values.
30023 30024 30025 30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30023 class SecurityPolicyAdvancedOptionsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module JsonParsing # A value indicating that the enum field is not set. UNDEFINED_JSON_PARSING = 0 DISABLED = 516_696_700 STANDARD = 484_642_493 STANDARD_WITH_GRAPHQL = 106_979_218 end module LogLevel # A value indicating that the enum field is not set. UNDEFINED_LOG_LEVEL = 0 NORMAL = 161_067_239 VERBOSE = 532_219_234 end end |
#log_level ⇒ ::String
Returns Check the LogLevel enum for the list of possible values.
30023 30024 30025 30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30023 class SecurityPolicyAdvancedOptionsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module JsonParsing # A value indicating that the enum field is not set. UNDEFINED_JSON_PARSING = 0 DISABLED = 516_696_700 STANDARD = 484_642_493 STANDARD_WITH_GRAPHQL = 106_979_218 end module LogLevel # A value indicating that the enum field is not set. UNDEFINED_LOG_LEVEL = 0 NORMAL = 161_067_239 VERBOSE = 532_219_234 end end |
#user_ip_request_headers ⇒ ::Array<::String>
Returns An optional list of case-insensitive request header names to use for resolving the callers client IP address.
30023 30024 30025 30026 30027 30028 30029 30030 30031 30032 30033 30034 30035 30036 30037 30038 30039 30040 30041 30042 30043 30044 30045 30046 30047 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30023 class SecurityPolicyAdvancedOptionsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module JsonParsing # A value indicating that the enum field is not set. UNDEFINED_JSON_PARSING = 0 DISABLED = 516_696_700 STANDARD = 484_642_493 STANDARD_WITH_GRAPHQL = 106_979_218 end module LogLevel # A value indicating that the enum field is not set. UNDEFINED_LOG_LEVEL = 0 NORMAL = 161_067_239 VERBOSE = 532_219_234 end end |