Class: Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: JsonParsing, LogLevel
Instance Attribute Summary collapse
-
#json_custom_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Custom configuration to apply the JSON parsing.
-
#json_parsing ⇒ ::String
Check the JsonParsing enum for the list of possible values.
-
#log_level ⇒ ::String
Check the LogLevel enum for the list of possible values.
-
#user_ip_request_headers ⇒ ::Array<::String>
An optional list of case-insensitive request header names to use for resolving the callers client IP address.
Instance Attribute Details
#json_custom_config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Returns Custom configuration to apply the JSON parsing. Only applicable when json_parsing is set to STANDARD.
29984 29985 29986 29987 29988 29989 29990 29991 29992 29993 29994 29995 29996 29997 29998 29999 30000 30001 30002 30003 30004 30005 30006 30007 30008 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29984 class SecurityPolicyAdvancedOptionsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module JsonParsing # A value indicating that the enum field is not set. UNDEFINED_JSON_PARSING = 0 DISABLED = 516_696_700 STANDARD = 484_642_493 STANDARD_WITH_GRAPHQL = 106_979_218 end module LogLevel # A value indicating that the enum field is not set. UNDEFINED_LOG_LEVEL = 0 NORMAL = 161_067_239 VERBOSE = 532_219_234 end end |
#json_parsing ⇒ ::String
Returns Check the JsonParsing enum for the list of possible values.
29984 29985 29986 29987 29988 29989 29990 29991 29992 29993 29994 29995 29996 29997 29998 29999 30000 30001 30002 30003 30004 30005 30006 30007 30008 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29984 class SecurityPolicyAdvancedOptionsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module JsonParsing # A value indicating that the enum field is not set. UNDEFINED_JSON_PARSING = 0 DISABLED = 516_696_700 STANDARD = 484_642_493 STANDARD_WITH_GRAPHQL = 106_979_218 end module LogLevel # A value indicating that the enum field is not set. UNDEFINED_LOG_LEVEL = 0 NORMAL = 161_067_239 VERBOSE = 532_219_234 end end |
#log_level ⇒ ::String
Returns Check the LogLevel enum for the list of possible values.
29984 29985 29986 29987 29988 29989 29990 29991 29992 29993 29994 29995 29996 29997 29998 29999 30000 30001 30002 30003 30004 30005 30006 30007 30008 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29984 class SecurityPolicyAdvancedOptionsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module JsonParsing # A value indicating that the enum field is not set. UNDEFINED_JSON_PARSING = 0 DISABLED = 516_696_700 STANDARD = 484_642_493 STANDARD_WITH_GRAPHQL = 106_979_218 end module LogLevel # A value indicating that the enum field is not set. UNDEFINED_LOG_LEVEL = 0 NORMAL = 161_067_239 VERBOSE = 532_219_234 end end |
#user_ip_request_headers ⇒ ::Array<::String>
Returns An optional list of case-insensitive request header names to use for resolving the callers client IP address.
29984 29985 29986 29987 29988 29989 29990 29991 29992 29993 29994 29995 29996 29997 29998 29999 30000 30001 30002 30003 30004 30005 30006 30007 30008 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 29984 class SecurityPolicyAdvancedOptionsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module JsonParsing # A value indicating that the enum field is not set. UNDEFINED_JSON_PARSING = 0 DISABLED = 516_696_700 STANDARD = 484_642_493 STANDARD_WITH_GRAPHQL = 106_979_218 end module LogLevel # A value indicating that the enum field is not set. UNDEFINED_LOG_LEVEL = 0 NORMAL = 161_067_239 VERBOSE = 532_219_234 end end |