Class: Google::Cloud::Compute::V1::SecurityPolicyAssociation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Instance Attribute Summary collapse

Instance Attribute Details

#attachment_id::String

Returns The resource that the security policy is attached to.

Returns:

  • (::String)

    The resource that the security policy is attached to.



68921
68922
68923
68924
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921

class SecurityPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Output only. [Output Only] The display name of the security policy of the association.

Returns:

  • (::String)

    Output only. [Output Only] The display name of the security policy of the association.



68921
68922
68923
68924
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921

class SecurityPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#excluded_folders::Array<::String>

Returns A list of folders to exclude from the security policy.

Returns:

  • (::Array<::String>)

    A list of folders to exclude from the security policy.



68921
68922
68923
68924
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921

class SecurityPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#excluded_projects::Array<::String>

Returns A list of projects to exclude from the security policy.

Returns:

  • (::Array<::String>)

    A list of projects to exclude from the security policy.



68921
68922
68923
68924
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921

class SecurityPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns The name for an association.

Returns:

  • (::String)

    The name for an association.



68921
68922
68923
68924
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921

class SecurityPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#security_policy_id::String

Returns Output only. [Output Only] The security policy ID of the association.

Returns:

  • (::String)

    Output only. [Output Only] The security policy ID of the association.



68921
68922
68923
68924
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921

class SecurityPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#short_name::String

Returns Output only. [Output Only] The short name of the security policy of the association.

Returns:

  • (::String)

    Output only. [Output Only] The short name of the security policy of the association.



68921
68922
68923
68924
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921

class SecurityPolicyAssociation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end