Class: Google::Cloud::Compute::V1::SecurityPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyAssociation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#attachment_id ⇒ ::String
The resource that the security policy is attached to.
-
#display_name ⇒ ::String
Output only.
-
#excluded_folders ⇒ ::Array<::String>
A list of folders to exclude from the security policy.
-
#excluded_projects ⇒ ::Array<::String>
A list of projects to exclude from the security policy.
-
#name ⇒ ::String
The name for an association.
-
#security_policy_id ⇒ ::String
Output only.
-
#short_name ⇒ ::String
Output only.
Instance Attribute Details
#attachment_id ⇒ ::String
Returns The resource that the security policy is attached to.
68921 68922 68923 68924 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921 class SecurityPolicyAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Output only. [Output Only] The display name of the security policy of the association.
68921 68922 68923 68924 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921 class SecurityPolicyAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#excluded_folders ⇒ ::Array<::String>
Returns A list of folders to exclude from the security policy.
68921 68922 68923 68924 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921 class SecurityPolicyAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#excluded_projects ⇒ ::Array<::String>
Returns A list of projects to exclude from the security policy.
68921 68922 68923 68924 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921 class SecurityPolicyAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns The name for an association.
68921 68922 68923 68924 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921 class SecurityPolicyAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#security_policy_id ⇒ ::String
Returns Output only. [Output Only] The security policy ID of the association.
68921 68922 68923 68924 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921 class SecurityPolicyAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#short_name ⇒ ::String
Returns Output only. [Output Only] The short name of the security policy of the association.
68921 68922 68923 68924 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 68921 class SecurityPolicyAssociation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |