Class: Google::Cloud::Compute::V1::SecurityPolicyDdosProtectionConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: DdosAdaptiveProtection, DdosProtection

Instance Attribute Summary collapse

Instance Attribute Details

#ddos_adaptive_protection::String

Returns Check the DdosAdaptiveProtection enum for the list of possible values.

Returns:

  • (::String)

    Check the DdosAdaptiveProtection enum for the list of possible values.



71402
71403
71404
71405
71406
71407
71408
71409
71410
71411
71412
71413
71414
71415
71416
71417
71418
71419
71420
71421
71422
71423
71424
71425
71426
71427
71428
71429
71430
71431
71432
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71402

class SecurityPolicyDdosProtectionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module DdosAdaptiveProtection
    # A value indicating that the enum field is not set.
    UNDEFINED_DDOS_ADAPTIVE_PROTECTION = 0

    DDOS_ADAPTIVE_PROTECTION_UNSPECIFIED = 314_527_935

    DISABLED = 516_696_700

    ENABLED = 182_130_465

    PREVIEW = 399_798_184

    UNSPECIFIED_ADAPTIVE_PROTECTION = 86_330_138
  end

  module DdosProtection
    # A value indicating that the enum field is not set.
    UNDEFINED_DDOS_PROTECTION = 0

    ADVANCED = 63_789_090

    ADVANCED_PREVIEW = 40_905_867

    STANDARD = 484_642_493
  end
end

#ddos_impacted_baseline_threshold::Float

Returns DDoS Protection for Network Load Balancers (and VMs with public IPs) builds DDoS mitigations that minimize collateral damage. It quantifies this as the fraction of a non-abuse baseline that's inadvertently blocked.

Rules whose collateral damage exceeds ddosImpactedBaselineThreshold will not be deployed. Using a lower value will prioritize keeping collateral damage low, possibly at the cost of its effectiveness in rate limiting some or all of the attack. It should typically be unset, so Advanced DDoS (and Adaptive Protection) uses the best mitigation it can find. Setting the threshold is advised if there are logs for false positive detections with high collateral damage, and will cause Advanced DDoS to attempt to find a less aggressive rule that satisfies the constraint. If a suitable rule cannot be found, the system falls back to either no mitigation for smaller attacks or broader network throttles for larger ones.

Returns:

  • (::Float)

    DDoS Protection for Network Load Balancers (and VMs with public IPs) builds DDoS mitigations that minimize collateral damage. It quantifies this as the fraction of a non-abuse baseline that's inadvertently blocked.

    Rules whose collateral damage exceeds ddosImpactedBaselineThreshold will not be deployed. Using a lower value will prioritize keeping collateral damage low, possibly at the cost of its effectiveness in rate limiting some or all of the attack. It should typically be unset, so Advanced DDoS (and Adaptive Protection) uses the best mitigation it can find. Setting the threshold is advised if there are logs for false positive detections with high collateral damage, and will cause Advanced DDoS to attempt to find a less aggressive rule that satisfies the constraint. If a suitable rule cannot be found, the system falls back to either no mitigation for smaller attacks or broader network throttles for larger ones.



71402
71403
71404
71405
71406
71407
71408
71409
71410
71411
71412
71413
71414
71415
71416
71417
71418
71419
71420
71421
71422
71423
71424
71425
71426
71427
71428
71429
71430
71431
71432
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71402

class SecurityPolicyDdosProtectionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module DdosAdaptiveProtection
    # A value indicating that the enum field is not set.
    UNDEFINED_DDOS_ADAPTIVE_PROTECTION = 0

    DDOS_ADAPTIVE_PROTECTION_UNSPECIFIED = 314_527_935

    DISABLED = 516_696_700

    ENABLED = 182_130_465

    PREVIEW = 399_798_184

    UNSPECIFIED_ADAPTIVE_PROTECTION = 86_330_138
  end

  module DdosProtection
    # A value indicating that the enum field is not set.
    UNDEFINED_DDOS_PROTECTION = 0

    ADVANCED = 63_789_090

    ADVANCED_PREVIEW = 40_905_867

    STANDARD = 484_642_493
  end
end

#ddos_protection::String

Returns Check the DdosProtection enum for the list of possible values.

Returns:

  • (::String)

    Check the DdosProtection enum for the list of possible values.



71402
71403
71404
71405
71406
71407
71408
71409
71410
71411
71412
71413
71414
71415
71416
71417
71418
71419
71420
71421
71422
71423
71424
71425
71426
71427
71428
71429
71430
71431
71432
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71402

class SecurityPolicyDdosProtectionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module DdosAdaptiveProtection
    # A value indicating that the enum field is not set.
    UNDEFINED_DDOS_ADAPTIVE_PROTECTION = 0

    DDOS_ADAPTIVE_PROTECTION_UNSPECIFIED = 314_527_935

    DISABLED = 516_696_700

    ENABLED = 182_130_465

    PREVIEW = 399_798_184

    UNSPECIFIED_ADAPTIVE_PROTECTION = 86_330_138
  end

  module DdosProtection
    # A value indicating that the enum field is not set.
    UNDEFINED_DDOS_PROTECTION = 0

    ADVANCED = 63_789_090

    ADVANCED_PREVIEW = 40_905_867

    STANDARD = 484_642_493
  end
end