Class: Google::Cloud::Compute::V1::SecurityPolicyRuleMatcher
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyRuleMatcher
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
Defined Under Namespace
Modules: VersionedExpr
Instance Attribute Summary collapse
-
#config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyRuleMatcherConfig
The configuration options available when specifying versioned_expr.
-
#expr ⇒ ::Google::Cloud::Compute::V1::Expr
User defined CEVAL expression.
-
#expr_options ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyRuleMatcherExprOptions
The configuration options available when specifying a user defined CEVAL expression (i.e., 'expr').
-
#versioned_expr ⇒ ::String
Preconfigured versioned expression.
Instance Attribute Details
#config ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyRuleMatcherConfig
Returns The configuration options available when specifying versioned_expr. This field must be specified if versioned_expr is specified and cannot be specified if versioned_expr is not specified.
69153 69154 69155 69156 69157 69158 69159 69160 69161 69162 69163 69164 69165 69166 69167 69168 69169 69170 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69153 class SecurityPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preconfigured versioned expression. # If this field is specified, config must also be specified. # Available preconfigured expressions along with their requirements are: # SRC_IPS_V1 - must specify the corresponding src_ip_range field in # config. module VersionedExpr # A value indicating that the enum field is not set. UNDEFINED_VERSIONED_EXPR = 0 # Matches the source IP address of a request to the IP ranges supplied # in config. SRC_IPS_V1 = 70_925_961 end end |
#expr ⇒ ::Google::Cloud::Compute::V1::Expr
Returns User defined CEVAL expression.
A CEVAL expression is used to specify match criteria such as origin.ip,
source.region_code and contents in the request header.
Expressions containing evaluateThreatIntelligence require a Cloud
Armor Enterprise subscription and are not supported in Edge Policies
nor in Regional Policies. Expressions containing
evaluatePreconfiguredExpr('sourceiplist-*') require a Cloud Armor
Enterprise subscription and are only supported in Global Security
Policies.
69153 69154 69155 69156 69157 69158 69159 69160 69161 69162 69163 69164 69165 69166 69167 69168 69169 69170 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69153 class SecurityPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preconfigured versioned expression. # If this field is specified, config must also be specified. # Available preconfigured expressions along with their requirements are: # SRC_IPS_V1 - must specify the corresponding src_ip_range field in # config. module VersionedExpr # A value indicating that the enum field is not set. UNDEFINED_VERSIONED_EXPR = 0 # Matches the source IP address of a request to the IP ranges supplied # in config. SRC_IPS_V1 = 70_925_961 end end |
#expr_options ⇒ ::Google::Cloud::Compute::V1::SecurityPolicyRuleMatcherExprOptions
Returns The configuration options available when specifying a user defined CEVAL expression (i.e., 'expr').
69153 69154 69155 69156 69157 69158 69159 69160 69161 69162 69163 69164 69165 69166 69167 69168 69169 69170 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69153 class SecurityPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preconfigured versioned expression. # If this field is specified, config must also be specified. # Available preconfigured expressions along with their requirements are: # SRC_IPS_V1 - must specify the corresponding src_ip_range field in # config. module VersionedExpr # A value indicating that the enum field is not set. UNDEFINED_VERSIONED_EXPR = 0 # Matches the source IP address of a request to the IP ranges supplied # in config. SRC_IPS_V1 = 70_925_961 end end |
#versioned_expr ⇒ ::String
Returns Preconfigured versioned expression. If this field is specified, config must also be specified. Available preconfigured expressions along with their requirements are: SRC_IPS_V1 - must specify the corresponding src_ip_range field in config. Check the VersionedExpr enum for the list of possible values.
69153 69154 69155 69156 69157 69158 69159 69160 69161 69162 69163 69164 69165 69166 69167 69168 69169 69170 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69153 class SecurityPolicyRuleMatcher include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Preconfigured versioned expression. # If this field is specified, config must also be specified. # Available preconfigured expressions along with their requirements are: # SRC_IPS_V1 - must specify the corresponding src_ip_range field in # config. module VersionedExpr # A value indicating that the enum field is not set. UNDEFINED_VERSIONED_EXPR = 0 # Matches the source IP address of a request to the IP ranges supplied # in config. SRC_IPS_V1 = 70_925_961 end end |