Class: Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Op

Instance Attribute Summary collapse

Instance Attribute Details

#op::String

Returns The match operator for the field. Check the Op enum for the list of possible values.

Returns:

  • (::String)

    The match operator for the field. Check the Op enum for the list of possible values.



71793
71794
71795
71796
71797
71798
71799
71800
71801
71802
71803
71804
71805
71806
71807
71808
71809
71810
71811
71812
71813
71814
71815
71816
71817
71818
71819
71820
71821
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71793

class SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The match operator for the field.
  module Op
    # A value indicating that the enum field is not set.
    UNDEFINED_OP = 0

    # The operator matches if the field value contains the specified
    # value.
    CONTAINS = 215_180_831

    # The operator matches if the field value ends with the specified
    # value.
    ENDS_WITH = 490_402_221

    # The operator matches if the field value equals the specified
    # value.
    EQUALS = 442_201_023

    # The operator matches if the field value is any value.
    EQUALS_ANY = 337_226_060

    # The operator matches if the field value starts with the specified
    # value.
    STARTS_WITH = 139_505_652
  end
end

#val::String

Returns The value of the field.

Returns:

  • (::String)

    The value of the field.



71793
71794
71795
71796
71797
71798
71799
71800
71801
71802
71803
71804
71805
71806
71807
71808
71809
71810
71811
71812
71813
71814
71815
71816
71817
71818
71819
71820
71821
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71793

class SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The match operator for the field.
  module Op
    # A value indicating that the enum field is not set.
    UNDEFINED_OP = 0

    # The operator matches if the field value contains the specified
    # value.
    CONTAINS = 215_180_831

    # The operator matches if the field value ends with the specified
    # value.
    ENDS_WITH = 490_402_221

    # The operator matches if the field value equals the specified
    # value.
    EQUALS = 442_201_023

    # The operator matches if the field value is any value.
    EQUALS_ANY = 337_226_060

    # The operator matches if the field value starts with the specified
    # value.
    STARTS_WITH = 139_505_652
  end
end