Class: Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Op

Instance Attribute Summary collapse

Instance Attribute Details

#op::String

Returns The match operator for the field. Check the Op enum for the list of possible values.

Returns:

  • (::String)

    The match operator for the field. Check the Op enum for the list of possible values.



70958
70959
70960
70961
70962
70963
70964
70965
70966
70967
70968
70969
70970
70971
70972
70973
70974
70975
70976
70977
70978
70979
70980
70981
70982
70983
70984
70985
70986
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70958

class SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The match operator for the field.
  module Op
    # A value indicating that the enum field is not set.
    UNDEFINED_OP = 0

    # The operator matches if the field value contains the specified
    # value.
    CONTAINS = 215_180_831

    # The operator matches if the field value ends with the specified
    # value.
    ENDS_WITH = 490_402_221

    # The operator matches if the field value equals the specified
    # value.
    EQUALS = 442_201_023

    # The operator matches if the field value is any value.
    EQUALS_ANY = 337_226_060

    # The operator matches if the field value starts with the specified
    # value.
    STARTS_WITH = 139_505_652
  end
end

#val::String

Returns The value of the field.

Returns:

  • (::String)

    The value of the field.



70958
70959
70960
70961
70962
70963
70964
70965
70966
70967
70968
70969
70970
70971
70972
70973
70974
70975
70976
70977
70978
70979
70980
70981
70982
70983
70984
70985
70986
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70958

class SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The match operator for the field.
  module Op
    # A value indicating that the enum field is not set.
    UNDEFINED_OP = 0

    # The operator matches if the field value contains the specified
    # value.
    CONTAINS = 215_180_831

    # The operator matches if the field value ends with the specified
    # value.
    ENDS_WITH = 490_402_221

    # The operator matches if the field value equals the specified
    # value.
    EQUALS = 442_201_023

    # The operator matches if the field value is any value.
    EQUALS_ANY = 337_226_060

    # The operator matches if the field value starts with the specified
    # value.
    STARTS_WITH = 139_505_652
  end
end