Class: Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Op
Instance Attribute Summary collapse
-
#op ⇒ ::String
The match operator for the field.
-
#val ⇒ ::String
The value of the field.
Instance Attribute Details
#op ⇒ ::String
Returns The match operator for the field. Check the Op enum for the list of possible values.
69305 69306 69307 69308 69309 69310 69311 69312 69313 69314 69315 69316 69317 69318 69319 69320 69321 69322 69323 69324 69325 69326 69327 69328 69329 69330 69331 69332 69333 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69305 class SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The match operator for the field. module Op # A value indicating that the enum field is not set. UNDEFINED_OP = 0 # The operator matches if the field value contains the specified # value. CONTAINS = 215_180_831 # The operator matches if the field value ends with the specified # value. ENDS_WITH = 490_402_221 # The operator matches if the field value equals the specified # value. EQUALS = 442_201_023 # The operator matches if the field value is any value. EQUALS_ANY = 337_226_060 # The operator matches if the field value starts with the specified # value. STARTS_WITH = 139_505_652 end end |
#val ⇒ ::String
Returns The value of the field.
69305 69306 69307 69308 69309 69310 69311 69312 69313 69314 69315 69316 69317 69318 69319 69320 69321 69322 69323 69324 69325 69326 69327 69328 69329 69330 69331 69332 69333 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69305 class SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The match operator for the field. module Op # A value indicating that the enum field is not set. UNDEFINED_OP = 0 # The operator matches if the field value contains the specified # value. CONTAINS = 215_180_831 # The operator matches if the field value ends with the specified # value. ENDS_WITH = 490_402_221 # The operator matches if the field value equals the specified # value. EQUALS = 442_201_023 # The operator matches if the field value is any value. EQUALS_ANY = 337_226_060 # The operator matches if the field value starts with the specified # value. STARTS_WITH = 139_505_652 end end |