Class: Google::Cloud::Compute::V1::SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: EnforceOnKeyType

Instance Attribute Summary collapse

Instance Attribute Details

#enforce_on_key_name::String

Returns Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.

Returns:

  • (::String)

    Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.



71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
71228
71229
71230
71231
71232
71233
71234
71235
71236
71237
71238
71239
71240
71241
71242
71243
71244
71245
71246
71247
71248
71249
71250
71251
71252
71253
71254
71255
71256
71257
71258
71259
71260
71261
71262
71263
71264
71265
71266
71267
71268
71269
71270
71271
71272
71273
71274
71275
71276
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71206

class SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines the key to enforce the rate_limit_threshold on. Possible
  # values are:
  #
  #    - ALL: A single rate limit threshold is applied to all
  #    the requests matching this rule. This is the default value if
  #    "enforceOnKeyConfigs" is not configured.
  #    - IP: The source IP address of
  #    the request is the key. Each IP has this limit enforced
  #    separately.
  #    - HTTP_HEADER: The value of the HTTP
  #    header whose name is configured under "enforceOnKeyName". The key
  #    value is truncated to the first 128 bytes of the header value. If no
  #    such header is present in the request, the key type defaults toALL.
  #    - XFF_IP: The first IP address (i.e. the
  #    originating client IP address) specified in the list of IPs under
  #    X-Forwarded-For HTTP header. If no such header is present or the
  #    value is not a valid IP, the key defaults to the source IP address of
  #    the request i.e. key type IP.
  #    - HTTP_COOKIE: The value of the HTTP
  #    cookie whose name is configured under "enforceOnKeyName". The key
  #    value is truncated to the first 128 bytes of the cookie value. If no
  #    such cookie is present in the request, the key type defaults toALL.
  #    - HTTP_PATH: The URL path of the HTTP request. The key
  #    value is truncated to the first 128 bytes.
  #    - SNI: Server name indication in the TLS session of
  #    the HTTPS request. The key value is truncated to the first 128 bytes.
  #    The key type defaults to ALL on a HTTP session.
  #    - REGION_CODE: The country/region from which the
  #    request originates.
  #    - TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the
  #    client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
  #    key type defaults to ALL.
  #    - USER_IP: The IP address of the originating client,
  #    which is resolved based on "userIpRequestHeaders" configured with the
  #    security policy. If there is no "userIpRequestHeaders" configuration
  #    or an IP address cannot be resolved from it, the key type defaults toIP.
  #
  # - TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the
  # client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
  # key type defaults to ALL.
  module EnforceOnKeyType
    # A value indicating that the enum field is not set.
    UNDEFINED_ENFORCE_ON_KEY_TYPE = 0

    ALL = 64_897

    HTTP_COOKIE = 494_981_627

    HTTP_HEADER = 91_597_348

    HTTP_PATH = 311_503_228

    IP = 2343

    REGION_CODE = 79_559_768

    SNI = 82_254

    TLS_JA3_FINGERPRINT = 327_127_933

    TLS_JA4_FINGERPRINT = 33_724_926

    USER_IP = 34_009_627

    XFF_IP = 438_707_118
  end
end

#enforce_on_key_type::String

Returns Determines the key to enforce the rate_limit_threshold on. Possible values are:

  • ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKeyConfigs" is not configured.
  • IP: The source IP address of the request is the key. Each IP has this limit enforced separately.
  • HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults toALL.
  • XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP.
  • HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults toALL.
  • HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes.
  • SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session.
  • REGION_CODE: The country/region from which the request originates.
  • TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.
  • USER_IP: The IP address of the originating client, which is resolved based on "userIpRequestHeaders" configured with the security policy. If there is no "userIpRequestHeaders" configuration or an IP address cannot be resolved from it, the key type defaults toIP.

    • TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL. Check the EnforceOnKeyType enum for the list of possible values.

Returns:

  • (::String)

    Determines the key to enforce the rate_limit_threshold on. Possible values are:

    • ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKeyConfigs" is not configured.
    • IP: The source IP address of the request is the key. Each IP has this limit enforced separately.
    • HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults toALL.
    • XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP.
    • HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults toALL.
    • HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes.
    • SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session.
    • REGION_CODE: The country/region from which the request originates.
    • TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.
    • USER_IP: The IP address of the originating client, which is resolved based on "userIpRequestHeaders" configured with the security policy. If there is no "userIpRequestHeaders" configuration or an IP address cannot be resolved from it, the key type defaults toIP.

      • TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL. Check the EnforceOnKeyType enum for the list of possible values.


71206
71207
71208
71209
71210
71211
71212
71213
71214
71215
71216
71217
71218
71219
71220
71221
71222
71223
71224
71225
71226
71227
71228
71229
71230
71231
71232
71233
71234
71235
71236
71237
71238
71239
71240
71241
71242
71243
71244
71245
71246
71247
71248
71249
71250
71251
71252
71253
71254
71255
71256
71257
71258
71259
71260
71261
71262
71263
71264
71265
71266
71267
71268
71269
71270
71271
71272
71273
71274
71275
71276
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71206

class SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines the key to enforce the rate_limit_threshold on. Possible
  # values are:
  #
  #    - ALL: A single rate limit threshold is applied to all
  #    the requests matching this rule. This is the default value if
  #    "enforceOnKeyConfigs" is not configured.
  #    - IP: The source IP address of
  #    the request is the key. Each IP has this limit enforced
  #    separately.
  #    - HTTP_HEADER: The value of the HTTP
  #    header whose name is configured under "enforceOnKeyName". The key
  #    value is truncated to the first 128 bytes of the header value. If no
  #    such header is present in the request, the key type defaults toALL.
  #    - XFF_IP: The first IP address (i.e. the
  #    originating client IP address) specified in the list of IPs under
  #    X-Forwarded-For HTTP header. If no such header is present or the
  #    value is not a valid IP, the key defaults to the source IP address of
  #    the request i.e. key type IP.
  #    - HTTP_COOKIE: The value of the HTTP
  #    cookie whose name is configured under "enforceOnKeyName". The key
  #    value is truncated to the first 128 bytes of the cookie value. If no
  #    such cookie is present in the request, the key type defaults toALL.
  #    - HTTP_PATH: The URL path of the HTTP request. The key
  #    value is truncated to the first 128 bytes.
  #    - SNI: Server name indication in the TLS session of
  #    the HTTPS request. The key value is truncated to the first 128 bytes.
  #    The key type defaults to ALL on a HTTP session.
  #    - REGION_CODE: The country/region from which the
  #    request originates.
  #    - TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the
  #    client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
  #    key type defaults to ALL.
  #    - USER_IP: The IP address of the originating client,
  #    which is resolved based on "userIpRequestHeaders" configured with the
  #    security policy. If there is no "userIpRequestHeaders" configuration
  #    or an IP address cannot be resolved from it, the key type defaults toIP.
  #
  # - TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the
  # client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
  # key type defaults to ALL.
  module EnforceOnKeyType
    # A value indicating that the enum field is not set.
    UNDEFINED_ENFORCE_ON_KEY_TYPE = 0

    ALL = 64_897

    HTTP_COOKIE = 494_981_627

    HTTP_HEADER = 91_597_348

    HTTP_PATH = 311_503_228

    IP = 2343

    REGION_CODE = 79_559_768

    SNI = 82_254

    TLS_JA3_FINGERPRINT = 327_127_933

    TLS_JA4_FINGERPRINT = 33_724_926

    USER_IP = 34_009_627

    XFF_IP = 438_707_118
  end
end