Class: Google::Cloud::Compute::V1::SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: EnforceOnKeyType

Instance Attribute Summary collapse

Instance Attribute Details

#enforce_on_key_name::String

Returns Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.

Returns:

  • (::String)

    Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.



69553
69554
69555
69556
69557
69558
69559
69560
69561
69562
69563
69564
69565
69566
69567
69568
69569
69570
69571
69572
69573
69574
69575
69576
69577
69578
69579
69580
69581
69582
69583
69584
69585
69586
69587
69588
69589
69590
69591
69592
69593
69594
69595
69596
69597
69598
69599
69600
69601
69602
69603
69604
69605
69606
69607
69608
69609
69610
69611
69612
69613
69614
69615
69616
69617
69618
69619
69620
69621
69622
69623
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69553

class SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines the key to enforce the rate_limit_threshold on. Possible
  # values are:
  #
  #    - ALL: A single rate limit threshold is applied to all
  #    the requests matching this rule. This is the default value if
  #    "enforceOnKeyConfigs" is not configured.
  #    - IP: The source IP address of
  #    the request is the key. Each IP has this limit enforced
  #    separately.
  #    - HTTP_HEADER: The value of the HTTP
  #    header whose name is configured under "enforceOnKeyName". The key
  #    value is truncated to the first 128 bytes of the header value. If no
  #    such header is present in the request, the key type defaults toALL.
  #    - XFF_IP: The first IP address (i.e. the
  #    originating client IP address) specified in the list of IPs under
  #    X-Forwarded-For HTTP header. If no such header is present or the
  #    value is not a valid IP, the key defaults to the source IP address of
  #    the request i.e. key type IP.
  #    - HTTP_COOKIE: The value of the HTTP
  #    cookie whose name is configured under "enforceOnKeyName". The key
  #    value is truncated to the first 128 bytes of the cookie value. If no
  #    such cookie is present in the request, the key type defaults toALL.
  #    - HTTP_PATH: The URL path of the HTTP request. The key
  #    value is truncated to the first 128 bytes.
  #    - SNI: Server name indication in the TLS session of
  #    the HTTPS request. The key value is truncated to the first 128 bytes.
  #    The key type defaults to ALL on a HTTP session.
  #    - REGION_CODE: The country/region from which the
  #    request originates.
  #    - TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the
  #    client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
  #    key type defaults to ALL.
  #    - USER_IP: The IP address of the originating client,
  #    which is resolved based on "userIpRequestHeaders" configured with the
  #    security policy. If there is no "userIpRequestHeaders" configuration
  #    or an IP address cannot be resolved from it, the key type defaults toIP.
  #
  # - TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the
  # client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
  # key type defaults to ALL.
  module EnforceOnKeyType
    # A value indicating that the enum field is not set.
    UNDEFINED_ENFORCE_ON_KEY_TYPE = 0

    ALL = 64_897

    HTTP_COOKIE = 494_981_627

    HTTP_HEADER = 91_597_348

    HTTP_PATH = 311_503_228

    IP = 2343

    REGION_CODE = 79_559_768

    SNI = 82_254

    TLS_JA3_FINGERPRINT = 327_127_933

    TLS_JA4_FINGERPRINT = 33_724_926

    USER_IP = 34_009_627

    XFF_IP = 438_707_118
  end
end

#enforce_on_key_type::String

Returns Determines the key to enforce the rate_limit_threshold on. Possible values are:

  • ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKeyConfigs" is not configured.
  • IP: The source IP address of the request is the key. Each IP has this limit enforced separately.
  • HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults toALL.
  • XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP.
  • HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults toALL.
  • HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes.
  • SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session.
  • REGION_CODE: The country/region from which the request originates.
  • TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.
  • USER_IP: The IP address of the originating client, which is resolved based on "userIpRequestHeaders" configured with the security policy. If there is no "userIpRequestHeaders" configuration or an IP address cannot be resolved from it, the key type defaults toIP.

    • TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL. Check the EnforceOnKeyType enum for the list of possible values.

Returns:

  • (::String)

    Determines the key to enforce the rate_limit_threshold on. Possible values are:

    • ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKeyConfigs" is not configured.
    • IP: The source IP address of the request is the key. Each IP has this limit enforced separately.
    • HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults toALL.
    • XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP.
    • HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults toALL.
    • HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes.
    • SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session.
    • REGION_CODE: The country/region from which the request originates.
    • TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.
    • USER_IP: The IP address of the originating client, which is resolved based on "userIpRequestHeaders" configured with the security policy. If there is no "userIpRequestHeaders" configuration or an IP address cannot be resolved from it, the key type defaults toIP.

      • TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL. Check the EnforceOnKeyType enum for the list of possible values.


69553
69554
69555
69556
69557
69558
69559
69560
69561
69562
69563
69564
69565
69566
69567
69568
69569
69570
69571
69572
69573
69574
69575
69576
69577
69578
69579
69580
69581
69582
69583
69584
69585
69586
69587
69588
69589
69590
69591
69592
69593
69594
69595
69596
69597
69598
69599
69600
69601
69602
69603
69604
69605
69606
69607
69608
69609
69610
69611
69612
69613
69614
69615
69616
69617
69618
69619
69620
69621
69622
69623
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69553

class SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines the key to enforce the rate_limit_threshold on. Possible
  # values are:
  #
  #    - ALL: A single rate limit threshold is applied to all
  #    the requests matching this rule. This is the default value if
  #    "enforceOnKeyConfigs" is not configured.
  #    - IP: The source IP address of
  #    the request is the key. Each IP has this limit enforced
  #    separately.
  #    - HTTP_HEADER: The value of the HTTP
  #    header whose name is configured under "enforceOnKeyName". The key
  #    value is truncated to the first 128 bytes of the header value. If no
  #    such header is present in the request, the key type defaults toALL.
  #    - XFF_IP: The first IP address (i.e. the
  #    originating client IP address) specified in the list of IPs under
  #    X-Forwarded-For HTTP header. If no such header is present or the
  #    value is not a valid IP, the key defaults to the source IP address of
  #    the request i.e. key type IP.
  #    - HTTP_COOKIE: The value of the HTTP
  #    cookie whose name is configured under "enforceOnKeyName". The key
  #    value is truncated to the first 128 bytes of the cookie value. If no
  #    such cookie is present in the request, the key type defaults toALL.
  #    - HTTP_PATH: The URL path of the HTTP request. The key
  #    value is truncated to the first 128 bytes.
  #    - SNI: Server name indication in the TLS session of
  #    the HTTPS request. The key value is truncated to the first 128 bytes.
  #    The key type defaults to ALL on a HTTP session.
  #    - REGION_CODE: The country/region from which the
  #    request originates.
  #    - TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the
  #    client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
  #    key type defaults to ALL.
  #    - USER_IP: The IP address of the originating client,
  #    which is resolved based on "userIpRequestHeaders" configured with the
  #    security policy. If there is no "userIpRequestHeaders" configuration
  #    or an IP address cannot be resolved from it, the key type defaults toIP.
  #
  # - TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the
  # client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
  # key type defaults to ALL.
  module EnforceOnKeyType
    # A value indicating that the enum field is not set.
    UNDEFINED_ENFORCE_ON_KEY_TYPE = 0

    ALL = 64_897

    HTTP_COOKIE = 494_981_627

    HTTP_HEADER = 91_597_348

    HTTP_PATH = 311_503_228

    IP = 2343

    REGION_CODE = 79_559_768

    SNI = 82_254

    TLS_JA3_FINGERPRINT = 327_127_933

    TLS_JA4_FINGERPRINT = 33_724_926

    USER_IP = 34_009_627

    XFF_IP = 438_707_118
  end
end