Class: Google::Cloud::Compute::V1::SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: EnforceOnKeyType
Instance Attribute Summary collapse
-
#enforce_on_key_name ⇒ ::String
Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value.
-
#enforce_on_key_type ⇒ ::String
Determines the key to enforce the rate_limit_threshold on.
Instance Attribute Details
#enforce_on_key_name ⇒ ::String
Returns Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value.
73778 73779 73780 73781 73782 73783 73784 73785 73786 73787 73788 73789 73790 73791 73792 73793 73794 73795 73796 73797 73798 73799 73800 73801 73802 73803 73804 73805 73806 73807 73808 73809 73810 73811 73812 73813 73814 73815 73816 73817 73818 73819 73820 73821 73822 73823 73824 73825 73826 73827 73828 73829 73830 73831 73832 73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73778 class SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Determines the key to enforce the rate_limit_threshold on. Possible # values are: # # - ALL: A single rate limit threshold is applied to all # the requests matching this rule. This is the default value if # "enforceOnKeyConfigs" is not configured. # - IP: The source IP address of # the request is the key. Each IP has this limit enforced # separately. # - HTTP_HEADER: The value of the HTTP # header whose name is configured under "enforceOnKeyName". The key # value is truncated to the first 128 bytes of the header value. If no # such header is present in the request, the key type defaults toALL. # - XFF_IP: The first IP address (i.e. the # originating client IP address) specified in the list of IPs under # X-Forwarded-For HTTP header. If no such header is present or the # value is not a valid IP, the key defaults to the source IP address of # the request i.e. key type IP. # - HTTP_COOKIE: The value of the HTTP # cookie whose name is configured under "enforceOnKeyName". The key # value is truncated to the first 128 bytes of the cookie value. If no # such cookie is present in the request, the key type defaults toALL. # - HTTP_PATH: The URL path of the HTTP request. The key # value is truncated to the first 128 bytes. # - SNI: Server name indication in the TLS session of # the HTTPS request. The key value is truncated to the first 128 bytes. # The key type defaults to ALL on a HTTP session. # - REGION_CODE: The country/region from which the # request originates. # - TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the # client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the # key type defaults to ALL. # - USER_IP: The IP address of the originating client, # which is resolved based on "userIpRequestHeaders" configured with the # security policy. If there is no "userIpRequestHeaders" configuration # or an IP address cannot be resolved from it, the key type defaults toIP. # - ASN: The autonomous system number of the originating # client. If not available, the key type defaults toALL. # - TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the # client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the # key type defaults to ALL. module EnforceOnKeyType # A value indicating that the enum field is not set. UNDEFINED_ENFORCE_ON_KEY_TYPE = 0 ALL = 64_897 ASN = 65_116 HTTP_COOKIE = 494_981_627 HTTP_HEADER = 91_597_348 HTTP_PATH = 311_503_228 IP = 2343 REGION_CODE = 79_559_768 SNI = 82_254 TLS_JA3_FINGERPRINT = 327_127_933 TLS_JA4_FINGERPRINT = 33_724_926 USER_IP = 34_009_627 XFF_IP = 438_707_118 end end |
#enforce_on_key_type ⇒ ::String
Returns Determines the key to enforce the rate_limit_threshold on. Possible values are:
- ALL: A single rate limit threshold is applied to all
the requests matching this rule. This is the default value if
"enforceOnKeyConfigs" is not configured.
- IP: The source IP address of
the request is the key. Each IP has this limit enforced
separately.
- HTTP_HEADER: The value of the HTTP
header whose name is configured under "enforceOnKeyName". The key
value is truncated to the first 128 bytes of the header value. If no
such header is present in the request, the key type defaults toALL.
- XFF_IP: The first IP address (i.e. the
originating client IP address) specified in the list of IPs under
X-Forwarded-For HTTP header. If no such header is present or the
value is not a valid IP, the key defaults to the source IP address of
the request i.e. key type IP.
- HTTP_COOKIE: The value of the HTTP
whose name is configured under "enforceOnKeyName". The key
value is truncated to the first 128 bytes of the value. If no
such is present in the request, the key type defaults toALL.
- HTTP_PATH: The URL path of the HTTP request. The key
value is truncated to the first 128 bytes.
- SNI: Server name indication in the TLS session of
the HTTPS request. The key value is truncated to the first 128 bytes.
The key type defaults to ALL on a HTTP session.
- REGION_CODE: The country/region from which the
request originates.
- TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the
client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
key type defaults to ALL.
- USER_IP: The IP address of the originating client,
which is resolved based on "userIpRequestHeaders" configured with the
security policy. If there is no "userIpRequestHeaders" configuration
or an IP address cannot be resolved from it, the key type defaults toIP.
- ASN: The autonomous system number of the originating
client. If not available, the key type defaults toALL.
- TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the
client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
key type defaults to ALL.
Check the EnforceOnKeyType enum for the list of possible values.
73778 73779 73780 73781 73782 73783 73784 73785 73786 73787 73788 73789 73790 73791 73792 73793 73794 73795 73796 73797 73798 73799 73800 73801 73802 73803 73804 73805 73806 73807 73808 73809 73810 73811 73812 73813 73814 73815 73816 73817 73818 73819 73820 73821 73822 73823 73824 73825 73826 73827 73828 73829 73830 73831 73832 73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73778 class SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Determines the key to enforce the rate_limit_threshold on. Possible # values are: # # - ALL: A single rate limit threshold is applied to all # the requests matching this rule. This is the default value if # "enforceOnKeyConfigs" is not configured. # - IP: The source IP address of # the request is the key. Each IP has this limit enforced # separately. # - HTTP_HEADER: The value of the HTTP # header whose name is configured under "enforceOnKeyName". The key # value is truncated to the first 128 bytes of the header value. If no # such header is present in the request, the key type defaults toALL. # - XFF_IP: The first IP address (i.e. the # originating client IP address) specified in the list of IPs under # X-Forwarded-For HTTP header. If no such header is present or the # value is not a valid IP, the key defaults to the source IP address of # the request i.e. key type IP. # - HTTP_COOKIE: The value of the HTTP # cookie whose name is configured under "enforceOnKeyName". The key # value is truncated to the first 128 bytes of the cookie value. If no # such cookie is present in the request, the key type defaults toALL. # - HTTP_PATH: The URL path of the HTTP request. The key # value is truncated to the first 128 bytes. # - SNI: Server name indication in the TLS session of # the HTTPS request. The key value is truncated to the first 128 bytes. # The key type defaults to ALL on a HTTP session. # - REGION_CODE: The country/region from which the # request originates. # - TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the # client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the # key type defaults to ALL. # - USER_IP: The IP address of the originating client, # which is resolved based on "userIpRequestHeaders" configured with the # security policy. If there is no "userIpRequestHeaders" configuration # or an IP address cannot be resolved from it, the key type defaults toIP. # - ASN: The autonomous system number of the originating # client. If not available, the key type defaults toALL. # - TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the # client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the # key type defaults to ALL. module EnforceOnKeyType # A value indicating that the enum field is not set. UNDEFINED_ENFORCE_ON_KEY_TYPE = 0 ALL = 64_897 ASN = 65_116 HTTP_COOKIE = 494_981_627 HTTP_HEADER = 91_597_348 HTTP_PATH = 311_503_228 IP = 2343 REGION_CODE = 79_559_768 SNI = 82_254 TLS_JA3_FINGERPRINT = 327_127_933 TLS_JA4_FINGERPRINT = 33_724_926 USER_IP = 34_009_627 XFF_IP = 438_707_118 end end |