Class: Google::Cloud::Compute::V1::SecurityPolicyRuleRedirectOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyRuleRedirectOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#target ⇒ ::String
Target for the redirect action.
-
#type ⇒ ::String
Type of the redirect action.
Instance Attribute Details
#target ⇒ ::String
Returns Target for the redirect action. This is required if the type is EXTERNAL_302 and cannot be specified for GOOGLE_RECAPTCHA.
33133 33134 33135 33136 33137 33138 33139 33140 33141 33142 33143 33144 33145 33146 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33133 class SecurityPolicyRuleRedirectOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the redirect action. Possible values are: - GOOGLE_RECAPTCHA: redirect to reCAPTCHA for manual challenge assessment. - EXTERNAL_302: redirect to a different URL via a 302 response. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 EXTERNAL_302 = 395_733_761 GOOGLE_RECAPTCHA = 518_803_009 end end |
#type ⇒ ::String
Returns Type of the redirect action. Possible values are: - GOOGLE_RECAPTCHA: redirect to reCAPTCHA for manual challenge assessment. - EXTERNAL_302: redirect to a different URL via a 302 response. Check the Type enum for the list of possible values.
33133 33134 33135 33136 33137 33138 33139 33140 33141 33142 33143 33144 33145 33146 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33133 class SecurityPolicyRuleRedirectOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the redirect action. Possible values are: - GOOGLE_RECAPTCHA: redirect to reCAPTCHA for manual challenge assessment. - EXTERNAL_302: redirect to a different URL via a 302 response. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 EXTERNAL_302 = 395_733_761 GOOGLE_RECAPTCHA = 518_803_009 end end |