Class: Google::Cloud::Compute::V1::SecurityPolicyUserDefinedField
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyUserDefinedField
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Base
Instance Attribute Summary collapse
-
#base ⇒ ::String
The base relative to which 'offset' is measured.
-
#mask ⇒ ::String
If specified, apply this mask (bitwise AND) to the field to ignore bits before matching.
-
#name ⇒ ::String
The name of this field.
-
#offset ⇒ ::Integer
Offset of the first byte of the field (in network byte order) relative to 'base'.
-
#size ⇒ ::Integer
Size of the field in bytes.
Instance Attribute Details
#base ⇒ ::String
Returns The base relative to which 'offset' is measured. Possible values are:
- IPV4: Points to the beginning of the IPv4 header.
- IPV6: Points to the beginning of the IPv6 header.
- TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
- UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
required Check the Base enum for the list of possible values.
72189 72190 72191 72192 72193 72194 72195 72196 72197 72198 72199 72200 72201 72202 72203 72204 72205 72206 72207 72208 72209 72210 72211 72212 72213 72214 72215 72216 72217 72218 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72189 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |
#mask ⇒ ::String
Returns If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask.
72189 72190 72191 72192 72193 72194 72195 72196 72197 72198 72199 72200 72201 72202 72203 72204 72205 72206 72207 72208 72209 72210 72211 72212 72213 72214 72215 72216 72217 72218 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72189 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |
#name ⇒ ::String
Returns The name of this field. Must be unique within the policy.
72189 72190 72191 72192 72193 72194 72195 72196 72197 72198 72199 72200 72201 72202 72203 72204 72205 72206 72207 72208 72209 72210 72211 72212 72213 72214 72215 72216 72217 72218 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72189 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |
#offset ⇒ ::Integer
Returns Offset of the first byte of the field (in network byte order) relative to 'base'.
72189 72190 72191 72192 72193 72194 72195 72196 72197 72198 72199 72200 72201 72202 72203 72204 72205 72206 72207 72208 72209 72210 72211 72212 72213 72214 72215 72216 72217 72218 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72189 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |
#size ⇒ ::Integer
Returns Size of the field in bytes. Valid values: 1-4.
72189 72190 72191 72192 72193 72194 72195 72196 72197 72198 72199 72200 72201 72202 72203 72204 72205 72206 72207 72208 72209 72210 72211 72212 72213 72214 72215 72216 72217 72218 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72189 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |