Class: Google::Cloud::Compute::V1::SecurityPolicyUserDefinedField

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Base

Instance Attribute Summary collapse

Instance Attribute Details

#base::String

Returns The base relative to which 'offset' is measured. Possible values are:

  • IPV4: Points to the beginning of the IPv4 header.
  • IPV6: Points to the beginning of the IPv6 header.
  • TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
  • UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.

required Check the Base enum for the list of possible values.

Returns:

  • (::String)

    The base relative to which 'offset' is measured. Possible values are:

    • IPV4: Points to the beginning of the IPv4 header.
    • IPV6: Points to the beginning of the IPv6 header.
    • TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
    • UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.

    required Check the Base enum for the list of possible values.



71354
71355
71356
71357
71358
71359
71360
71361
71362
71363
71364
71365
71366
71367
71368
71369
71370
71371
71372
71373
71374
71375
71376
71377
71378
71379
71380
71381
71382
71383
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71354

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end

#mask::String

Returns If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask.

Returns:

  • (::String)

    If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask.



71354
71355
71356
71357
71358
71359
71360
71361
71362
71363
71364
71365
71366
71367
71368
71369
71370
71371
71372
71373
71374
71375
71376
71377
71378
71379
71380
71381
71382
71383
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71354

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end

#name::String

Returns The name of this field. Must be unique within the policy.

Returns:

  • (::String)

    The name of this field. Must be unique within the policy.



71354
71355
71356
71357
71358
71359
71360
71361
71362
71363
71364
71365
71366
71367
71368
71369
71370
71371
71372
71373
71374
71375
71376
71377
71378
71379
71380
71381
71382
71383
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71354

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end

#offset::Integer

Returns Offset of the first byte of the field (in network byte order) relative to 'base'.

Returns:

  • (::Integer)

    Offset of the first byte of the field (in network byte order) relative to 'base'.



71354
71355
71356
71357
71358
71359
71360
71361
71362
71363
71364
71365
71366
71367
71368
71369
71370
71371
71372
71373
71374
71375
71376
71377
71378
71379
71380
71381
71382
71383
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71354

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end

#size::Integer

Returns Size of the field in bytes. Valid values: 1-4.

Returns:

  • (::Integer)

    Size of the field in bytes. Valid values: 1-4.



71354
71355
71356
71357
71358
71359
71360
71361
71362
71363
71364
71365
71366
71367
71368
71369
71370
71371
71372
71373
71374
71375
71376
71377
71378
71379
71380
71381
71382
71383
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71354

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end