Class: Google::Cloud::Compute::V1::SecurityPolicyUserDefinedField

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Base

Instance Attribute Summary collapse

Instance Attribute Details

#base::String

Returns The base relative to which 'offset' is measured. Possible values are:

  • IPV4: Points to the beginning of the IPv4 header.
  • IPV6: Points to the beginning of the IPv6 header.
  • TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
  • UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.

required Check the Base enum for the list of possible values.

Returns:

  • (::String)

    The base relative to which 'offset' is measured. Possible values are:

    • IPV4: Points to the beginning of the IPv4 header.
    • IPV6: Points to the beginning of the IPv6 header.
    • TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
    • UDP: Points to the beginning of the UDP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.

    required Check the Base enum for the list of possible values.



69701
69702
69703
69704
69705
69706
69707
69708
69709
69710
69711
69712
69713
69714
69715
69716
69717
69718
69719
69720
69721
69722
69723
69724
69725
69726
69727
69728
69729
69730
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69701

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end

#mask::String

Returns If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask.

Returns:

  • (::String)

    If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask.



69701
69702
69703
69704
69705
69706
69707
69708
69709
69710
69711
69712
69713
69714
69715
69716
69717
69718
69719
69720
69721
69722
69723
69724
69725
69726
69727
69728
69729
69730
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69701

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end

#name::String

Returns The name of this field. Must be unique within the policy.

Returns:

  • (::String)

    The name of this field. Must be unique within the policy.



69701
69702
69703
69704
69705
69706
69707
69708
69709
69710
69711
69712
69713
69714
69715
69716
69717
69718
69719
69720
69721
69722
69723
69724
69725
69726
69727
69728
69729
69730
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69701

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end

#offset::Integer

Returns Offset of the first byte of the field (in network byte order) relative to 'base'.

Returns:

  • (::Integer)

    Offset of the first byte of the field (in network byte order) relative to 'base'.



69701
69702
69703
69704
69705
69706
69707
69708
69709
69710
69711
69712
69713
69714
69715
69716
69717
69718
69719
69720
69721
69722
69723
69724
69725
69726
69727
69728
69729
69730
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69701

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end

#size::Integer

Returns Size of the field in bytes. Valid values: 1-4.

Returns:

  • (::Integer)

    Size of the field in bytes. Valid values: 1-4.



69701
69702
69703
69704
69705
69706
69707
69708
69709
69710
69711
69712
69713
69714
69715
69716
69717
69718
69719
69720
69721
69722
69723
69724
69725
69726
69727
69728
69729
69730
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69701

class SecurityPolicyUserDefinedField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The base relative to which 'offset' is measured. Possible values are:
  #
  #    - IPV4: Points to the beginning of the IPv4 header.
  #    - IPV6: Points to the beginning of the IPv6 header.
  #    - TCP: Points to the beginning of the TCP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #    - UDP: Points to the beginning of the UDP header, skipping
  #    over any IPv4 options or IPv6 extension headers. Not present for
  #    non-first fragments.
  #
  #
  # required
  module Base
    # A value indicating that the enum field is not set.
    UNDEFINED_BASE = 0

    IPV4 = 2_254_341

    IPV6 = 2_254_343

    TCP = 82_881

    UDP = 83_873
  end
end