Class: Google::Cloud::Compute::V1::SecurityPolicyUserDefinedField
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SecurityPolicyUserDefinedField
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Base
Instance Attribute Summary collapse
-
#base ⇒ ::String
The base relative to which 'offset' is measured.
-
#mask ⇒ ::String
If specified, apply this mask (bitwise AND) to the field to ignore bits before matching.
-
#name ⇒ ::String
The name of this field.
-
#offset ⇒ ::Integer
Offset of the first byte of the field (in network byte order) relative to 'base'.
-
#size ⇒ ::Integer
Size of the field in bytes.
Instance Attribute Details
#base ⇒ ::String
Returns The base relative to which 'offset' is measured. Possible values are:
- IPV4: Points to the beginning of the IPv4 header.
- IPV6: Points to the beginning of the IPv6 header.
- TCP: Points to the beginning of the TCP header, skipping
over any IPv4 options or IPv6 extension headers. Not present for
non-first fragments.
- UDP: Points to the beginning of the UDP header, skipping
over any IPv4 options or IPv6 extension headers. Not present for
non-first fragments.
required Check the Base enum for the list of possible values.
73929 73930 73931 73932 73933 73934 73935 73936 73937 73938 73939 73940 73941 73942 73943 73944 73945 73946 73947 73948 73949 73950 73951 73952 73953 73954 73955 73956 73957 73958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73929 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |
#mask ⇒ ::String
Returns If specified, apply this mask (bitwise AND) to the field to ignore bits before matching. Encoded as a hexadecimal number (starting with "0x"). The last byte of the field (in network byte order) corresponds to the least significant byte of the mask.
73929 73930 73931 73932 73933 73934 73935 73936 73937 73938 73939 73940 73941 73942 73943 73944 73945 73946 73947 73948 73949 73950 73951 73952 73953 73954 73955 73956 73957 73958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73929 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |
#name ⇒ ::String
Returns The name of this field. Must be unique within the policy.
73929 73930 73931 73932 73933 73934 73935 73936 73937 73938 73939 73940 73941 73942 73943 73944 73945 73946 73947 73948 73949 73950 73951 73952 73953 73954 73955 73956 73957 73958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73929 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |
#offset ⇒ ::Integer
Returns Offset of the first byte of the field (in network byte order) relative to 'base'.
73929 73930 73931 73932 73933 73934 73935 73936 73937 73938 73939 73940 73941 73942 73943 73944 73945 73946 73947 73948 73949 73950 73951 73952 73953 73954 73955 73956 73957 73958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73929 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |
#size ⇒ ::Integer
Returns Size of the field in bytes. Valid values: 1-4.
73929 73930 73931 73932 73933 73934 73935 73936 73937 73938 73939 73940 73941 73942 73943 73944 73945 73946 73947 73948 73949 73950 73951 73952 73953 73954 73955 73956 73957 73958 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73929 class SecurityPolicyUserDefinedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The base relative to which 'offset' is measured. Possible values are: # # - IPV4: Points to the beginning of the IPv4 header. # - IPV6: Points to the beginning of the IPv6 header. # - TCP: Points to the beginning of the TCP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # - UDP: Points to the beginning of the UDP header, skipping # over any IPv4 options or IPv6 extension headers. Not present for # non-first fragments. # # # required module Base # A value indicating that the enum field is not set. UNDEFINED_BASE = 0 IPV4 = 2_254_341 IPV6 = 2_254_343 TCP = 82_881 UDP = 83_873 end end |