Class: Google::Cloud::Compute::V1::ServerBinding

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#type::String

Returns Check the Type enum for the list of possible values.

Returns:

  • (::String)

    Check the Type enum for the list of possible values.



69822
69823
69824
69825
69826
69827
69828
69829
69830
69831
69832
69833
69834
69835
69836
69837
69838
69839
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 69822

class ServerBinding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods


  module Type
    # A value indicating that the enum field is not set.
    UNDEFINED_TYPE = 0

    # Node may associate with any physical server over its lifetime.
    RESTART_NODE_ON_ANY_SERVER = 502_950_985

    # Node may associate with minimal physical servers over its lifetime.
    RESTART_NODE_ON_MINIMAL_SERVERS = 204_166_495

    SERVER_BINDING_TYPE_UNSPECIFIED = 180_825_512
  end
end