Class: Google::Cloud::Compute::V1::ServiceAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] A connection connected to this service attachment.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#consumer_network::String

Returns The url of the consumer network.

Returns:

  • (::String)

    The url of the consumer network.



72574
72575
72576
72577
72578
72579
72580
72581
72582
72583
72584
72585
72586
72587
72588
72589
72590
72591
72592
72593
72594
72595
72596
72597
72598
72599
72600
72601
72602
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72574

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#endpoint::String

Returns The url of a connected endpoint.

Returns:

  • (::String)

    The url of a connected endpoint.



72574
72575
72576
72577
72578
72579
72580
72581
72582
72583
72584
72585
72586
72587
72588
72589
72590
72591
72592
72593
72594
72595
72596
72597
72598
72599
72600
72601
72602
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72574

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#endpoint_with_id::String

Returns The url of a connected endpoint with resource id.

Returns:

  • (::String)

    The url of a connected endpoint with resource id.



72574
72575
72576
72577
72578
72579
72580
72581
72582
72583
72584
72585
72586
72587
72588
72589
72590
72591
72592
72593
72594
72595
72596
72597
72598
72599
72600
72601
72602
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72574

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#nat_ips::Array<::String>

Returns NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.

Returns:

  • (::Array<::String>)

    NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.



72574
72575
72576
72577
72578
72579
72580
72581
72582
72583
72584
72585
72586
72587
72588
72589
72590
72591
72592
72593
72594
72595
72596
72597
72598
72599
72600
72601
72602
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72574

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#propagated_connection_count::Integer

Returns The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.

Returns:

  • (::Integer)

    The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.



72574
72575
72576
72577
72578
72579
72580
72581
72582
72583
72584
72585
72586
72587
72588
72589
72590
72591
72592
72593
72594
72595
72596
72597
72598
72599
72600
72601
72602
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72574

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#psc_connection_id::Integer

Returns The PSC connection id of the connected endpoint.

Returns:

  • (::Integer)

    The PSC connection id of the connected endpoint.



72574
72575
72576
72577
72578
72579
72580
72581
72582
72583
72584
72585
72586
72587
72588
72589
72590
72591
72592
72593
72594
72595
72596
72597
72598
72599
72600
72601
72602
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72574

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#status::String

Returns The status of a connected endpoint to this service attachment. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    The status of a connected endpoint to this service attachment. Check the Status enum for the list of possible values.



72574
72575
72576
72577
72578
72579
72580
72581
72582
72583
72584
72585
72586
72587
72588
72589
72590
72591
72592
72593
72594
72595
72596
72597
72598
72599
72600
72601
72602
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72574

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end