Class: Google::Cloud::Compute::V1::ServiceAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] A connection connected to this service attachment.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#consumer_network::String

Returns The url of the consumer network.

Returns:

  • (::String)

    The url of the consumer network.



71735
71736
71737
71738
71739
71740
71741
71742
71743
71744
71745
71746
71747
71748
71749
71750
71751
71752
71753
71754
71755
71756
71757
71758
71759
71760
71761
71762
71763
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71735

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#endpoint::String

Returns The url of a connected endpoint.

Returns:

  • (::String)

    The url of a connected endpoint.



71735
71736
71737
71738
71739
71740
71741
71742
71743
71744
71745
71746
71747
71748
71749
71750
71751
71752
71753
71754
71755
71756
71757
71758
71759
71760
71761
71762
71763
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71735

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#endpoint_with_id::String

Returns The url of a connected endpoint with resource id.

Returns:

  • (::String)

    The url of a connected endpoint with resource id.



71735
71736
71737
71738
71739
71740
71741
71742
71743
71744
71745
71746
71747
71748
71749
71750
71751
71752
71753
71754
71755
71756
71757
71758
71759
71760
71761
71762
71763
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71735

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#nat_ips::Array<::String>

Returns NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.

Returns:

  • (::Array<::String>)

    NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.



71735
71736
71737
71738
71739
71740
71741
71742
71743
71744
71745
71746
71747
71748
71749
71750
71751
71752
71753
71754
71755
71756
71757
71758
71759
71760
71761
71762
71763
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71735

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#propagated_connection_count::Integer

Returns The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.

Returns:

  • (::Integer)

    The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.



71735
71736
71737
71738
71739
71740
71741
71742
71743
71744
71745
71746
71747
71748
71749
71750
71751
71752
71753
71754
71755
71756
71757
71758
71759
71760
71761
71762
71763
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71735

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#psc_connection_id::Integer

Returns The PSC connection id of the connected endpoint.

Returns:

  • (::Integer)

    The PSC connection id of the connected endpoint.



71735
71736
71737
71738
71739
71740
71741
71742
71743
71744
71745
71746
71747
71748
71749
71750
71751
71752
71753
71754
71755
71756
71757
71758
71759
71760
71761
71762
71763
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71735

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end

#status::String

Returns The status of a connected endpoint to this service attachment. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    The status of a connected endpoint to this service attachment. Check the Status enum for the list of possible values.



71735
71736
71737
71738
71739
71740
71741
71742
71743
71744
71745
71746
71747
71748
71749
71750
71751
71752
71753
71754
71755
71756
71757
71758
71759
71760
71761
71762
71763
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 71735

class ServiceAttachmentConnectedEndpoint
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of a connected endpoint to this service attachment.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The connection has been accepted by the producer.
    ACCEPTED = 246_714_279

    # The connection has been closed by the producer.
    CLOSED = 380_163_436

    # The connection has been accepted by the producer, but the producer
    # needs to take further action before the forwarding rule can serve
    # traffic.
    NEEDS_ATTENTION = 344_491_452

    # The connection is pending acceptance by the producer.
    PENDING = 35_394_935

    # The consumer is still connected but not using the connection.
    REJECTED = 174_130_302

    STATUS_UNSPECIFIED = 42_133_066
  end
end