Class: Google::Cloud::Compute::V1::ServiceAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ServiceAttachmentConnectedEndpoint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] A connection connected to this service attachment.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#consumer_network ⇒ ::String
The url of the consumer network.
-
#endpoint ⇒ ::String
The url of a connected endpoint.
-
#endpoint_with_id ⇒ ::String
The url of a connected endpoint with resource id.
-
#nat_ips ⇒ ::Array<::String>
NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
-
#propagated_connection_count ⇒ ::Integer
The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
-
#psc_connection_id ⇒ ::Integer
The PSC connection id of the connected endpoint.
-
#status ⇒ ::String
The status of a connected endpoint to this service attachment.
Instance Attribute Details
#consumer_network ⇒ ::String
Returns The url of the consumer network.
70082 70083 70084 70085 70086 70087 70088 70089 70090 70091 70092 70093 70094 70095 70096 70097 70098 70099 70100 70101 70102 70103 70104 70105 70106 70107 70108 70109 70110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70082 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#endpoint ⇒ ::String
Returns The url of a connected endpoint.
70082 70083 70084 70085 70086 70087 70088 70089 70090 70091 70092 70093 70094 70095 70096 70097 70098 70099 70100 70101 70102 70103 70104 70105 70106 70107 70108 70109 70110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70082 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#endpoint_with_id ⇒ ::String
Returns The url of a connected endpoint with resource id.
70082 70083 70084 70085 70086 70087 70088 70089 70090 70091 70092 70093 70094 70095 70096 70097 70098 70099 70100 70101 70102 70103 70104 70105 70106 70107 70108 70109 70110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70082 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#nat_ips ⇒ ::Array<::String>
Returns NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
70082 70083 70084 70085 70086 70087 70088 70089 70090 70091 70092 70093 70094 70095 70096 70097 70098 70099 70100 70101 70102 70103 70104 70105 70106 70107 70108 70109 70110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70082 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#propagated_connection_count ⇒ ::Integer
Returns The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
70082 70083 70084 70085 70086 70087 70088 70089 70090 70091 70092 70093 70094 70095 70096 70097 70098 70099 70100 70101 70102 70103 70104 70105 70106 70107 70108 70109 70110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70082 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#psc_connection_id ⇒ ::Integer
Returns The PSC connection id of the connected endpoint.
70082 70083 70084 70085 70086 70087 70088 70089 70090 70091 70092 70093 70094 70095 70096 70097 70098 70099 70100 70101 70102 70103 70104 70105 70106 70107 70108 70109 70110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70082 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |
#status ⇒ ::String
Returns The status of a connected endpoint to this service attachment. Check the Status enum for the list of possible values.
70082 70083 70084 70085 70086 70087 70088 70089 70090 70091 70092 70093 70094 70095 70096 70097 70098 70099 70100 70101 70102 70103 70104 70105 70106 70107 70108 70109 70110 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70082 class ServiceAttachmentConnectedEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a connected endpoint to this service attachment. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The connection has been accepted by the producer. ACCEPTED = 246_714_279 # The connection has been closed by the producer. CLOSED = 380_163_436 # The connection has been accepted by the producer, but the producer # needs to take further action before the forwarding rule can serve # traffic. NEEDS_ATTENTION = 344_491_452 # The connection is pending acceptance by the producer. PENDING = 35_394_935 # The consumer is still connected but not using the connection. REJECTED = 174_130_302 STATUS_UNSPECIFIED = 42_133_066 end end |