Class: Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#error ⇒ ::Google::Cloud::Compute::V1::Status
[Output Only] If state is
ABANDONEDorFAILED, this field is populated. -
#state ⇒ ::String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Attribute Details
#error ⇒ ::Google::Cloud::Compute::V1::Status
Returns [Output Only] If state is ABANDONED or FAILED, this field is
populated.
72878 72879 72880 72881 72882 72883 72884 72885 72886 72887 72888 72889 72890 72891 72892 72893 72894 72895 72896 72897 72898 72899 72900 72901 72902 72903 72904 72905 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72878 class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the action, which can be one of the following: # `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Operation not tracked in this location e.g. zone is marked as DOWN. ABANDONED = 81_797_556 # Operation has completed successfully. DONE = 2_104_194 # Operation is in an error state. FAILED = 455_706_685 # Operation is confirmed to be in the location. PROPAGATED = 507_550_299 # Operation is not yet confirmed to have been created in the location. PROPAGATING = 164_807_046 UNSPECIFIED = 526_786_327 end end |
#state ⇒ ::String
Returns [Output Only] Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Check the State enum for the list of possible values.
72878 72879 72880 72881 72882 72883 72884 72885 72886 72887 72888 72889 72890 72891 72892 72893 72894 72895 72896 72897 72898 72899 72900 72901 72902 72903 72904 72905 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72878 class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the action, which can be one of the following: # `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Operation not tracked in this location e.g. zone is marked as DOWN. ABANDONED = 81_797_556 # Operation has completed successfully. DONE = 2_104_194 # Operation is in an error state. FAILED = 455_706_685 # Operation is confirmed to be in the location. PROPAGATED = 507_550_299 # Operation is not yet confirmed to have been created in the location. PROPAGATING = 164_807_046 UNSPECIFIED = 526_786_327 end end |