Class: Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#error ⇒ ::Google::Cloud::Compute::V1::Status
[Output Only] If state is
ABANDONEDorFAILED, this field is populated. -
#state ⇒ ::String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Attribute Details
#error ⇒ ::Google::Cloud::Compute::V1::Status
Returns [Output Only] If state is ABANDONED or FAILED, this field is
populated.
70386 70387 70388 70389 70390 70391 70392 70393 70394 70395 70396 70397 70398 70399 70400 70401 70402 70403 70404 70405 70406 70407 70408 70409 70410 70411 70412 70413 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70386 class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the action, which can be one of the following: # `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Operation not tracked in this location e.g. zone is marked as DOWN. ABANDONED = 81_797_556 # Operation has completed successfully. DONE = 2_104_194 # Operation is in an error state. FAILED = 455_706_685 # Operation is confirmed to be in the location. PROPAGATED = 507_550_299 # Operation is not yet confirmed to have been created in the location. PROPAGATING = 164_807_046 UNSPECIFIED = 526_786_327 end end |
#state ⇒ ::String
Returns [Output Only] Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Check the State enum for the list of possible values.
70386 70387 70388 70389 70390 70391 70392 70393 70394 70395 70396 70397 70398 70399 70400 70401 70402 70403 70404 70405 70406 70407 70408 70409 70410 70411 70412 70413 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 70386 class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the action, which can be one of the following: # `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Operation not tracked in this location e.g. zone is marked as DOWN. ABANDONED = 81_797_556 # Operation has completed successfully. DONE = 2_104_194 # Operation is in an error state. FAILED = 455_706_685 # Operation is confirmed to be in the location. PROPAGATED = 507_550_299 # Operation is not yet confirmed to have been created in the location. PROPAGATING = 164_807_046 UNSPECIFIED = 526_786_327 end end |