Class: Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#error::Google::Cloud::Compute::V1::Status

Returns [Output Only] If state is ABANDONED or FAILED, this field is populated.

Returns:



31416
31417
31418
31419
31420
31421
31422
31423
31424
31425
31426
31427
31428
31429
31430
31431
31432
31433
31434
31435
31436
31437
31438
31439
31440
31441
31442
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31416

class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the action, which can be one of the following: `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Operation not tracked in this location e.g. zone is marked as DOWN.
    ABANDONED = 81_797_556

    # Operation has completed successfully.
    DONE = 2_104_194

    # Operation is in an error state.
    FAILED = 455_706_685

    # Operation is confirmed to be in the location.
    PROPAGATED = 507_550_299

    # Operation is not yet confirmed to have been created in the location.
    PROPAGATING = 164_807_046

    UNSPECIFIED = 526_786_327
  end
end

#state::String

Returns [Output Only] Status of the action, which can be one of the following: PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE. Check the State enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] Status of the action, which can be one of the following: PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE. Check the State enum for the list of possible values.



31416
31417
31418
31419
31420
31421
31422
31423
31424
31425
31426
31427
31428
31429
31430
31431
31432
31433
31434
31435
31436
31437
31438
31439
31440
31441
31442
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 31416

class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the action, which can be one of the following: `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Operation not tracked in this location e.g. zone is marked as DOWN.
    ABANDONED = 81_797_556

    # Operation has completed successfully.
    DONE = 2_104_194

    # Operation is in an error state.
    FAILED = 455_706_685

    # Operation is confirmed to be in the location.
    PROPAGATED = 507_550_299

    # Operation is not yet confirmed to have been created in the location.
    PROPAGATING = 164_807_046

    UNSPECIFIED = 526_786_327
  end
end