Class: Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#error ⇒ ::Google::Cloud::Compute::V1::Status
[Output Only] If state is
ABANDONEDorFAILED, this field is populated. -
#state ⇒ ::String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Attribute Details
#error ⇒ ::Google::Cloud::Compute::V1::Status
30936 30937 30938 30939 30940 30941 30942 30943 30944 30945 30946 30947 30948 30949 30950 30951 30952 30953 30954 30955 30956 30957 30958 30959 30960 30961 30962 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30936 class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the action, which can be one of the following: `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Operation not tracked in this location e.g. zone is marked as DOWN. ABANDONED = 81_797_556 # Operation has completed successfully. DONE = 2_104_194 # Operation is in an error state. FAILED = 455_706_685 # Operation is confirmed to be in the location. PROPAGATED = 507_550_299 # Operation is not yet confirmed to have been created in the location. PROPAGATING = 164_807_046 UNSPECIFIED = 526_786_327 end end |
#state ⇒ ::String
30936 30937 30938 30939 30940 30941 30942 30943 30944 30945 30946 30947 30948 30949 30950 30951 30952 30953 30954 30955 30956 30957 30958 30959 30960 30961 30962 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30936 class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the action, which can be one of the following: `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Operation not tracked in this location e.g. zone is marked as DOWN. ABANDONED = 81_797_556 # Operation has completed successfully. DONE = 2_104_194 # Operation is in an error state. FAILED = 455_706_685 # Operation is confirmed to be in the location. PROPAGATED = 507_550_299 # Operation is not yet confirmed to have been created in the location. PROPAGATING = 164_807_046 UNSPECIFIED = 526_786_327 end end |