Class: Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#error::Google::Cloud::Compute::V1::Status

Returns [Output Only] If state is ABANDONED or FAILED, this field is populated.

Returns:



30906
30907
30908
30909
30910
30911
30912
30913
30914
30915
30916
30917
30918
30919
30920
30921
30922
30923
30924
30925
30926
30927
30928
30929
30930
30931
30932
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30906

class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the action, which can be one of the following: `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Operation not tracked in this location e.g. zone is marked as DOWN.
    ABANDONED = 81_797_556

    # Operation has completed successfully.
    DONE = 2_104_194

    # Operation is in an error state.
    FAILED = 455_706_685

    # Operation is confirmed to be in the location.
    PROPAGATED = 507_550_299

    # Operation is not yet confirmed to have been created in the location.
    PROPAGATING = 164_807_046

    UNSPECIFIED = 526_786_327
  end
end

#state::String

Returns [Output Only] Status of the action, which can be one of the following: PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE. Check the State enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] Status of the action, which can be one of the following: PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE. Check the State enum for the list of possible values.



30906
30907
30908
30909
30910
30911
30912
30913
30914
30915
30916
30917
30918
30919
30920
30921
30922
30923
30924
30925
30926
30927
30928
30929
30930
30931
30932
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 30906

class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the action, which can be one of the following: `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # Operation not tracked in this location e.g. zone is marked as DOWN.
    ABANDONED = 81_797_556

    # Operation has completed successfully.
    DONE = 2_104_194

    # Operation is in an error state.
    FAILED = 455_706_685

    # Operation is confirmed to be in the location.
    PROPAGATED = 507_550_299

    # Operation is not yet confirmed to have been created in the location.
    PROPAGATING = 164_807_046

    UNSPECIFIED = 526_786_327
  end
end