Class: Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#error ⇒ ::Google::Cloud::Compute::V1::Status
[Output Only] If state is
ABANDONEDorFAILED, this field is populated. -
#state ⇒ ::String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Attribute Details
#error ⇒ ::Google::Cloud::Compute::V1::Status
Returns [Output Only] If state is ABANDONED or FAILED, this field is
populated.
74618 74619 74620 74621 74622 74623 74624 74625 74626 74627 74628 74629 74630 74631 74632 74633 74634 74635 74636 74637 74638 74639 74640 74641 74642 74643 74644 74645 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74618 class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the action, which can be one of the following: # `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Operation not tracked in this location e.g. zone is marked as DOWN. ABANDONED = 81_797_556 # Operation has completed successfully. DONE = 2_104_194 # Operation is in an error state. FAILED = 455_706_685 # Operation is confirmed to be in the location. PROPAGATED = 507_550_299 # Operation is not yet confirmed to have been created in the location. PROPAGATING = 164_807_046 UNSPECIFIED = 526_786_327 end end |
#state ⇒ ::String
Returns [Output Only] Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Check the State enum for the list of possible values.
74618 74619 74620 74621 74622 74623 74624 74625 74626 74627 74628 74629 74630 74631 74632 74633 74634 74635 74636 74637 74638 74639 74640 74641 74642 74643 74644 74645 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74618 class SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the action, which can be one of the following: # `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # Operation not tracked in this location e.g. zone is marked as DOWN. ABANDONED = 81_797_556 # Operation has completed successfully. DONE = 2_104_194 # Operation is in an error state. FAILED = 455_706_685 # Operation is confirmed to be in the location. PROPAGATED = 507_550_299 # Operation is not yet confirmed to have been created in the location. PROPAGATING = 164_807_046 UNSPECIFIED = 526_786_327 end end |