Class: Google::Cloud::Compute::V1::ShareSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The share setting for reservations and sole tenancy node groups.

Defined Under Namespace

Modules: ShareType Classes: ProjectMapEntry

Instance Attribute Summary collapse

Instance Attribute Details

#project_map::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::ShareSettingsProjectConfig}

Returns A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS.

Returns:



75409
75410
75411
75412
75413
75414
75415
75416
75417
75418
75419
75420
75421
75422
75423
75424
75425
75426
75427
75428
75429
75430
75431
75432
75433
75434
75435
75436
75437
75438
75439
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75409

class ShareSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ShareSettingsProjectConfig]
  class ProjectMapEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of sharing for this shared-reservation
  module ShareType
    # A value indicating that the enum field is not set.
    UNDEFINED_SHARE_TYPE = 0

    # Default value.
    LOCAL = 72_607_563

    # Shared-reservation is open to entire Organization
    ORGANIZATION = 274_978_099

    # Default value. This value is unused.
    SHARE_TYPE_UNSPECIFIED = 494_771_730

    # Shared-reservation is open to specific projects
    SPECIFIC_PROJECTS = 347_838_695
  end
end

#share_type::String

Returns Type of sharing for this shared-reservation Check the ShareType enum for the list of possible values.

Returns:

  • (::String)

    Type of sharing for this shared-reservation Check the ShareType enum for the list of possible values.



75409
75410
75411
75412
75413
75414
75415
75416
75417
75418
75419
75420
75421
75422
75423
75424
75425
75426
75427
75428
75429
75430
75431
75432
75433
75434
75435
75436
75437
75438
75439
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75409

class ShareSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::ShareSettingsProjectConfig]
  class ProjectMapEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Type of sharing for this shared-reservation
  module ShareType
    # A value indicating that the enum field is not set.
    UNDEFINED_SHARE_TYPE = 0

    # Default value.
    LOCAL = 72_607_563

    # Shared-reservation is open to entire Organization
    ORGANIZATION = 274_978_099

    # Default value. This value is unused.
    SHARE_TYPE_UNSPECIFIED = 494_771_730

    # Shared-reservation is open to specific projects
    SPECIFIC_PROJECTS = 347_838_695
  end
end