Class: Google::Cloud::Compute::V1::ShareSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ShareSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The share setting for reservations and sole tenancy node groups.
Defined Under Namespace
Modules: ShareType Classes: ProjectMapEntry
Instance Attribute Summary collapse
-
#project_map ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::ShareSettingsProjectConfig}
A map of project id and project config.
-
#share_type ⇒ ::String
Type of sharing for this shared-reservation Check the ShareType enum for the list of possible values.
Instance Attribute Details
#project_map ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::ShareSettingsProjectConfig}
Returns A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS.
74570 74571 74572 74573 74574 74575 74576 74577 74578 74579 74580 74581 74582 74583 74584 74585 74586 74587 74588 74589 74590 74591 74592 74593 74594 74595 74596 74597 74598 74599 74600 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74570 class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::ShareSettingsProjectConfig] class ProjectMapEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of sharing for this shared-reservation module ShareType # A value indicating that the enum field is not set. UNDEFINED_SHARE_TYPE = 0 # Default value. LOCAL = 72_607_563 # Shared-reservation is open to entire Organization ORGANIZATION = 274_978_099 # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 494_771_730 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 347_838_695 end end |
#share_type ⇒ ::String
Returns Type of sharing for this shared-reservation Check the ShareType enum for the list of possible values.
74570 74571 74572 74573 74574 74575 74576 74577 74578 74579 74580 74581 74582 74583 74584 74585 74586 74587 74588 74589 74590 74591 74592 74593 74594 74595 74596 74597 74598 74599 74600 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74570 class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::ShareSettingsProjectConfig] class ProjectMapEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of sharing for this shared-reservation module ShareType # A value indicating that the enum field is not set. UNDEFINED_SHARE_TYPE = 0 # Default value. LOCAL = 72_607_563 # Shared-reservation is open to entire Organization ORGANIZATION = 274_978_099 # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 494_771_730 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 347_838_695 end end |