Class: Google::Cloud::Compute::V1::ShareSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ShareSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The share setting for reservations and sole tenancy node groups.
Defined Under Namespace
Modules: ShareType Classes: ProjectMapEntry
Instance Attribute Summary collapse
-
#project_map ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::ShareSettingsProjectConfig}
A map of project id and project config.
-
#share_type ⇒ ::String
Type of sharing for this shared-reservation Check the ShareType enum for the list of possible values.
Instance Attribute Details
#project_map ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::ShareSettingsProjectConfig}
Returns A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS.
72902 72903 72904 72905 72906 72907 72908 72909 72910 72911 72912 72913 72914 72915 72916 72917 72918 72919 72920 72921 72922 72923 72924 72925 72926 72927 72928 72929 72930 72931 72932 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72902 class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::ShareSettingsProjectConfig] class ProjectMapEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of sharing for this shared-reservation module ShareType # A value indicating that the enum field is not set. UNDEFINED_SHARE_TYPE = 0 # Default value. LOCAL = 72_607_563 # Shared-reservation is open to entire Organization ORGANIZATION = 274_978_099 # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 494_771_730 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 347_838_695 end end |
#share_type ⇒ ::String
Returns Type of sharing for this shared-reservation Check the ShareType enum for the list of possible values.
72902 72903 72904 72905 72906 72907 72908 72909 72910 72911 72912 72913 72914 72915 72916 72917 72918 72919 72920 72921 72922 72923 72924 72925 72926 72927 72928 72929 72930 72931 72932 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 72902 class ShareSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::ShareSettingsProjectConfig] class ProjectMapEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of sharing for this shared-reservation module ShareType # A value indicating that the enum field is not set. UNDEFINED_SHARE_TYPE = 0 # Default value. LOCAL = 72_607_563 # Shared-reservation is open to entire Organization ORGANIZATION = 274_978_099 # Default value. This value is unused. SHARE_TYPE_UNSPECIFIED = 494_771_730 # Shared-reservation is open to specific projects SPECIFIC_PROJECTS = 347_838_695 end end |