Class: Google::Cloud::Compute::V1::SnapshotGroupParameters
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SnapshotGroupParameters
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#replica_zones ⇒ ::Array<::String>
URLs of the zones where disks should be replicated to.
-
#source_snapshot_group ⇒ ::String
The source snapshot group used to create disks.
-
#type ⇒ ::String
URL of the disk type resource describing which disk type to use to create disks.
Instance Attribute Details
#replica_zones ⇒ ::Array<::String>
Returns URLs of the zones where disks should be replicated to. Only applicable for regional resources.
73404 73405 73406 73407 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73404 class SnapshotGroupParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_snapshot_group ⇒ ::String
Returns The source snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/global/snapshotGroups/snapshotGroup
- projects/project/global/snapshotGroups/snapshotGroup
- global/snapshotGroups/snapshotGroup.
73404 73405 73406 73407 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73404 class SnapshotGroupParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#type ⇒ ::String
Returns URL of the disk type resource describing which disk type to use to create disks. Provide this when creating the disk. For example:projects/project/zones/zone/diskTypes/pd-ssd. See Persistent disk types.
73404 73405 73406 73407 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73404 class SnapshotGroupParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |