Class: Google::Cloud::Compute::V1::SnapshotParams
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SnapshotParams
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Additional snapshot params.
Defined Under Namespace
Classes: ResourceManagerTagsEntry
Instance Attribute Summary collapse
Instance Attribute Details
#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Input only. Resource manager tags to be bound to the snapshot. Tag keys and values have
the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/{tag_key_id} and tagValues/{tag_value_id} or in
namespaced format such as {org_id|project_id}/{tag_key_short_name} and
{tag_value_short_name}. The field is ignored (both PUT &
PATCH) when empty.
75115 75116 75117 75118 75119 75120 75121 75122 75123 75124 75125 75126 75127 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75115 class SnapshotParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |