Class: Google::Cloud::Compute::V1::SnapshotSettingsAccessLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SnapshotSettingsAccessLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Policy Classes: LocationsEntry
Instance Attribute Summary collapse
-
#locations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SnapshotSettingsAccessLocationAccessLocationPreference}
List of regions that can restore a regional snapshot from the current region.
-
#policy ⇒ ::String
Policy of which location is allowed to access snapshot.
Instance Attribute Details
#locations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SnapshotSettingsAccessLocationAccessLocationPreference}
Returns List of regions that can restore a regional snapshot from the current region.
73482 73483 73484 73485 73486 73487 73488 73489 73490 73491 73492 73493 73494 73495 73496 73497 73498 73499 73500 73501 73502 73503 73504 73505 73506 73507 73508 73509 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73482 class SnapshotSettingsAccessLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::SnapshotSettingsAccessLocationAccessLocationPreference] class LocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Policy of which location is allowed to access snapshot. module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Any regions will be able to access the source location. ALL_REGIONS = 273_143_585 POLICY_UNSPECIFIED = 197_974_922 # Only allowlisted regions will be able to restore region scoped # snapshots SPECIFIC_REGIONS = 454_128_082 end end |
#policy ⇒ ::String
Returns Policy of which location is allowed to access snapshot. Check the Policy enum for the list of possible values.
73482 73483 73484 73485 73486 73487 73488 73489 73490 73491 73492 73493 73494 73495 73496 73497 73498 73499 73500 73501 73502 73503 73504 73505 73506 73507 73508 73509 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73482 class SnapshotSettingsAccessLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::SnapshotSettingsAccessLocationAccessLocationPreference] class LocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Policy of which location is allowed to access snapshot. module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Any regions will be able to access the source location. ALL_REGIONS = 273_143_585 POLICY_UNSPECIFIED = 197_974_922 # Only allowlisted regions will be able to restore region scoped # snapshots SPECIFIC_REGIONS = 454_128_082 end end |