Class: Google::Cloud::Compute::V1::SnapshotSettingsAccessLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SnapshotSettingsAccessLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Policy Classes: LocationsEntry
Instance Attribute Summary collapse
-
#locations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SnapshotSettingsAccessLocationAccessLocationPreference}
List of regions that can restore a regional snapshot from the current region.
-
#policy ⇒ ::String
Policy of which location is allowed to access snapshot.
Instance Attribute Details
#locations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SnapshotSettingsAccessLocationAccessLocationPreference}
Returns List of regions that can restore a regional snapshot from the current region.
77733 77734 77735 77736 77737 77738 77739 77740 77741 77742 77743 77744 77745 77746 77747 77748 77749 77750 77751 77752 77753 77754 77755 77756 77757 77758 77759 77760 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77733 class SnapshotSettingsAccessLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::SnapshotSettingsAccessLocationAccessLocationPreference] class LocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Policy of which location is allowed to access snapshot. module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Any regions will be able to access the source location. ALL_REGIONS = 273_143_585 POLICY_UNSPECIFIED = 197_974_922 # Only allowlisted regions will be able to restore region scoped # snapshots SPECIFIC_REGIONS = 454_128_082 end end |
#policy ⇒ ::String
Returns Policy of which location is allowed to access snapshot. Check the Policy enum for the list of possible values.
77733 77734 77735 77736 77737 77738 77739 77740 77741 77742 77743 77744 77745 77746 77747 77748 77749 77750 77751 77752 77753 77754 77755 77756 77757 77758 77759 77760 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77733 class SnapshotSettingsAccessLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::SnapshotSettingsAccessLocationAccessLocationPreference] class LocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Policy of which location is allowed to access snapshot. module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Any regions will be able to access the source location. ALL_REGIONS = 273_143_585 POLICY_UNSPECIFIED = 197_974_922 # Only allowlisted regions will be able to restore region scoped # snapshots SPECIFIC_REGIONS = 454_128_082 end end |