Module: Google::Cloud::Compute::V1::SnapshotSettingsAccessLocation::Policy
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Policy of which location is allowed to access snapshot.
Constant Summary collapse
- UNDEFINED_POLICY =
A value indicating that the enum field is not set.
0- ALL_REGIONS =
Any regions will be able to access the source location.
273_143_585- POLICY_UNSPECIFIED =
197_974_922- SPECIFIC_REGIONS =
Only allowlisted regions will be able to restore region scoped snapshots
454_128_082