Class: Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Policy Classes: LocationsEntry
Instance Attribute Summary collapse
-
#locations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference}
When the policy is SPECIFIC_LOCATIONS, snapshots will be stored in the locations listed in this field.
-
#policy ⇒ ::String
The chosen location policy.
Instance Attribute Details
#locations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference}
Returns When the policy is SPECIFIC_LOCATIONS, snapshots will be stored in the locations listed in this field. Keys are Cloud Storage bucket locations. Only one location can be specified.
76040 76041 76042 76043 76044 76045 76046 76047 76048 76049 76050 76051 76052 76053 76054 76055 76056 76057 76058 76059 76060 76061 76062 76063 76064 76065 76066 76067 76068 76069 76070 76071 76072 76073 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76040 class SnapshotSettingsStorageLocationSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference] class LocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The chosen location policy. module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Store snapshot in the same region as with the originating disk. # No additional parameters are needed. LOCAL_REGION = 403_535_464 # Store snapshot in the nearest multi region Cloud Storage bucket, # relative to the originating disk. No additional parameters are needed. NEAREST_MULTI_REGION = 212_467_515 # Store snapshot in the specific locations, as specified by the user. # The list of regions to store must be defined under the `locations` # field. SPECIFIC_LOCATIONS = 280_093_809 STORAGE_LOCATION_POLICY_UNSPECIFIED = 250_644_592 end end |
#policy ⇒ ::String
Returns The chosen location policy. Check the Policy enum for the list of possible values.
76040 76041 76042 76043 76044 76045 76046 76047 76048 76049 76050 76051 76052 76053 76054 76055 76056 76057 76058 76059 76060 76061 76062 76063 76064 76065 76066 76067 76068 76069 76070 76071 76072 76073 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76040 class SnapshotSettingsStorageLocationSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference] class LocationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The chosen location policy. module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Store snapshot in the same region as with the originating disk. # No additional parameters are needed. LOCAL_REGION = 403_535_464 # Store snapshot in the nearest multi region Cloud Storage bucket, # relative to the originating disk. No additional parameters are needed. NEAREST_MULTI_REGION = 212_467_515 # Store snapshot in the specific locations, as specified by the user. # The list of regions to store must be defined under the `locations` # field. SPECIFIC_LOCATIONS = 280_093_809 STORAGE_LOCATION_POLICY_UNSPECIFIED = 250_644_592 end end |