Class: Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Policy Classes: LocationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#locations::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference}

Returns When the policy is SPECIFIC_LOCATIONS, snapshots will be stored in the locations listed in this field. Keys are Cloud Storage bucket locations. Only one location can be specified.

Returns:



75197
75198
75199
75200
75201
75202
75203
75204
75205
75206
75207
75208
75209
75210
75211
75212
75213
75214
75215
75216
75217
75218
75219
75220
75221
75222
75223
75224
75225
75226
75227
75228
75229
75230
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75197

class SnapshotSettingsStorageLocationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference]
  class LocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The chosen location policy.
  module Policy
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY = 0

    # Store snapshot in the same region as with the originating disk.
    # No additional parameters are needed.
    LOCAL_REGION = 403_535_464

    # Store snapshot in the nearest multi region Cloud Storage bucket,
    # relative to the originating disk. No additional parameters are needed.
    NEAREST_MULTI_REGION = 212_467_515

    # Store snapshot in the specific locations, as specified by the user.
    # The list of regions to store must be defined under the `locations`
    # field.
    SPECIFIC_LOCATIONS = 280_093_809

    STORAGE_LOCATION_POLICY_UNSPECIFIED = 250_644_592
  end
end

#policy::String

Returns The chosen location policy. Check the Policy enum for the list of possible values.

Returns:

  • (::String)

    The chosen location policy. Check the Policy enum for the list of possible values.



75197
75198
75199
75200
75201
75202
75203
75204
75205
75206
75207
75208
75209
75210
75211
75212
75213
75214
75215
75216
75217
75218
75219
75220
75221
75222
75223
75224
75225
75226
75227
75228
75229
75230
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75197

class SnapshotSettingsStorageLocationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference]
  class LocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The chosen location policy.
  module Policy
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY = 0

    # Store snapshot in the same region as with the originating disk.
    # No additional parameters are needed.
    LOCAL_REGION = 403_535_464

    # Store snapshot in the nearest multi region Cloud Storage bucket,
    # relative to the originating disk. No additional parameters are needed.
    NEAREST_MULTI_REGION = 212_467_515

    # Store snapshot in the specific locations, as specified by the user.
    # The list of regions to store must be defined under the `locations`
    # field.
    SPECIFIC_LOCATIONS = 280_093_809

    STORAGE_LOCATION_POLICY_UNSPECIFIED = 250_644_592
  end
end