Class: Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Policy Classes: LocationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#locations::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference}

Returns When the policy is SPECIFIC_LOCATIONS, snapshots will be stored in the locations listed in this field. Keys are Cloud Storage bucket locations. Only one location can be specified.

Returns:



73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
73540
73541
73542
73543
73544
73545
73546
73547
73548
73549
73550
73551
73552
73553
73554
73555
73556
73557
73558
73559
73560
73561
73562
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73529

class SnapshotSettingsStorageLocationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference]
  class LocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The chosen location policy.
  module Policy
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY = 0

    # Store snapshot in the same region as with the originating disk.
    # No additional parameters are needed.
    LOCAL_REGION = 403_535_464

    # Store snapshot in the nearest multi region Cloud Storage bucket,
    # relative to the originating disk. No additional parameters are needed.
    NEAREST_MULTI_REGION = 212_467_515

    # Store snapshot in the specific locations, as specified by the user.
    # The list of regions to store must be defined under the `locations`
    # field.
    SPECIFIC_LOCATIONS = 280_093_809

    STORAGE_LOCATION_POLICY_UNSPECIFIED = 250_644_592
  end
end

#policy::String

Returns The chosen location policy. Check the Policy enum for the list of possible values.

Returns:

  • (::String)

    The chosen location policy. Check the Policy enum for the list of possible values.



73529
73530
73531
73532
73533
73534
73535
73536
73537
73538
73539
73540
73541
73542
73543
73544
73545
73546
73547
73548
73549
73550
73551
73552
73553
73554
73555
73556
73557
73558
73559
73560
73561
73562
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73529

class SnapshotSettingsStorageLocationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::SnapshotSettingsStorageLocationSettingsStorageLocationPreference]
  class LocationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The chosen location policy.
  module Policy
    # A value indicating that the enum field is not set.
    UNDEFINED_POLICY = 0

    # Store snapshot in the same region as with the originating disk.
    # No additional parameters are needed.
    LOCAL_REGION = 403_535_464

    # Store snapshot in the nearest multi region Cloud Storage bucket,
    # relative to the originating disk. No additional parameters are needed.
    NEAREST_MULTI_REGION = 212_467_515

    # Store snapshot in the specific locations, as specified by the user.
    # The list of regions to store must be defined under the `locations`
    # field.
    SPECIFIC_LOCATIONS = 280_093_809

    STORAGE_LOCATION_POLICY_UNSPECIFIED = 250_644_592
  end
end