Class: Google::Cloud::Compute::V1::SourceInstanceProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.

Defined Under Namespace

Modules: KeyRevocationActionType, PostKeyRevocationActionType Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#can_ip_forward::Boolean

Returns Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information.

Returns:

  • (::Boolean)

    Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#deletion_protection::Boolean

Returns Whether the instance created from this machine image should be protected against deletion.

Returns:

  • (::Boolean)

    Whether the instance created from this machine image should be protected against deletion.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#description::String

Returns An optional text description for the instances that are created from this machine image.

Returns:

  • (::String)

    An optional text description for the instances that are created from this machine image.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#disks::Array<::Google::Cloud::Compute::V1::SavedAttachedDisk>

Returns An array of disks that are associated with the instances that are created from this machine image.

Returns:



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#guest_accelerators::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>

Returns A list of guest accelerator cards' type and count to use for instances created from this machine image.

Returns:



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#key_revocation_action_type::String

Returns KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Check the KeyRevocationActionType enum for the list of possible values.

Returns:

  • (::String)

    KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Check the KeyRevocationActionType enum for the list of possible values.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Labels to apply to instances that are created from this machine image.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Labels to apply to instances that are created from this machine image.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#machine_type::String

Returns The machine type to use for instances that are created from this machine image.

Returns:

  • (::String)

    The machine type to use for instances that are created from this machine image.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#metadata::Google::Cloud::Compute::V1::Metadata

Returns The metadata key/value pairs to assign to instances that are created from this machine image. These pairs can consist of custom metadata or predefined keys. SeeProject and instance metadata for more information.

Returns:

  • (::Google::Cloud::Compute::V1::Metadata)

    The metadata key/value pairs to assign to instances that are created from this machine image. These pairs can consist of custom metadata or predefined keys. SeeProject and instance metadata for more information.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#min_cpu_platform::String

Returns Minimum cpu/platform to be used by instances created from this machine image. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform.

Returns:

  • (::String)

    Minimum cpu/platform to be used by instances created from this machine image. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#network_interfaces::Array<::Google::Cloud::Compute::V1::NetworkInterface>

Returns An array of network access configurations for this interface.

Returns:



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#post_key_revocation_action_type::String

Returns PostKeyRevocationActionType of the instance. Check the PostKeyRevocationActionType enum for the list of possible values.

Returns:

  • (::String)

    PostKeyRevocationActionType of the instance. Check the PostKeyRevocationActionType enum for the list of possible values.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#scheduling::Google::Cloud::Compute::V1::Scheduling

Returns Specifies the scheduling options for the instances that are created from this machine image.

Returns:



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#service_accounts::Array<::Google::Cloud::Compute::V1::ServiceAccount>

Returns A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from this machine image. Use metadata queries to obtain the access tokens for these instances.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::ServiceAccount>)

    A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from this machine image. Use metadata queries to obtain the access tokens for these instances.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end

#tags::Google::Cloud::Compute::V1::Tags

Returns A list of tags to apply to the instances that are created from this machine image. The tags identify valid sources or targets for network firewalls. The setTags method can modify this list of tags. Each tag within the list must comply withRFC1035.

Returns:

  • (::Google::Cloud::Compute::V1::Tags)

    A list of tags to apply to the instances that are created from this machine image. The tags identify valid sources or targets for network firewalls. The setTags method can modify this list of tags. Each tag within the list must comply withRFC1035.



73696
73697
73698
73699
73700
73701
73702
73703
73704
73705
73706
73707
73708
73709
73710
73711
73712
73713
73714
73715
73716
73717
73718
73719
73720
73721
73722
73723
73724
73725
73726
73727
73728
73729
73730
73731
73732
73733
73734
73735
73736
73737
73738
73739
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73696

class SourceInstanceProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # KeyRevocationActionType of the instance. Supported options are "STOP" and
  # "NONE". The default value is "NONE" if it is not specified.
  module KeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0

    # Default value. This value is unused.
    KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106

    # Indicates user chose no operation.
    NONE = 2_402_104

    # Indicates user chose to opt for VM shutdown on key revocation.
    STOP = 2_555_906
  end

  # PostKeyRevocationActionType of the instance.
  module PostKeyRevocationActionType
    # A value indicating that the enum field is not set.
    UNDEFINED_POST_KEY_REVOCATION_ACTION_TYPE = 0

    # Indicates user chose no operation.
    NOOP = 2_402_146

    # Default value. This value is unused.
    POST_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 228_738_393

    # Indicates user chose to opt for VM shutdown on key revocation.
    SHUTDOWN = 76_412_502
  end
end