Class: Google::Cloud::Compute::V1::SourceInstanceProperties
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SourceInstanceProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.
Defined Under Namespace
Modules: KeyRevocationActionType Classes: LabelsEntry
Instance Attribute Summary collapse
-
#can_ip_forward ⇒ ::Boolean
Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own.
-
#deletion_protection ⇒ ::Boolean
Whether the instance created from this machine image should be protected against deletion.
-
#description ⇒ ::String
An optional text description for the instances that are created from this machine image.
-
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::SavedAttachedDisk>
An array of disks that are associated with the instances that are created from this machine image.
-
#guest_accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances created from this machine image.
-
#key_revocation_action_type ⇒ ::String
KeyRevocationActionType of the instance.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels to apply to instances that are created from this machine image.
-
#machine_type ⇒ ::String
The machine type to use for instances that are created from this machine image.
-
#metadata ⇒ ::Google::Cloud::Compute::V1::Metadata
The metadata key/value pairs to assign to instances that are created from this machine image.
-
#min_cpu_platform ⇒ ::String
Minimum cpu/platform to be used by instances created from this machine image.
-
#network_interfaces ⇒ ::Array<::Google::Cloud::Compute::V1::NetworkInterface>
An array of network access configurations for this interface.
-
#scheduling ⇒ ::Google::Cloud::Compute::V1::Scheduling
Specifies the scheduling options for the instances that are created from this machine image.
-
#service_accounts ⇒ ::Array<::Google::Cloud::Compute::V1::ServiceAccount>
A list of service accounts with specified scopes.
-
#tags ⇒ ::Google::Cloud::Compute::V1::Tags
A list of tags to apply to the instances that are created from this machine image.
Instance Attribute Details
#can_ip_forward ⇒ ::Boolean
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#deletion_protection ⇒ ::Boolean
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#description ⇒ ::String
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#disks ⇒ ::Array<::Google::Cloud::Compute::V1::SavedAttachedDisk>
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#guest_accelerators ⇒ ::Array<::Google::Cloud::Compute::V1::AcceleratorConfig>
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#key_revocation_action_type ⇒ ::String
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#machine_type ⇒ ::String
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#metadata ⇒ ::Google::Cloud::Compute::V1::Metadata
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#min_cpu_platform ⇒ ::String
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#network_interfaces ⇒ ::Array<::Google::Cloud::Compute::V1::NetworkInterface>
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#scheduling ⇒ ::Google::Cloud::Compute::V1::Scheduling
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#service_accounts ⇒ ::Array<::Google::Cloud::Compute::V1::ServiceAccount>
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |
#tags ⇒ ::Google::Cloud::Compute::V1::Tags
35799 35800 35801 35802 35803 35804 35805 35806 35807 35808 35809 35810 35811 35812 35813 35814 35815 35816 35817 35818 35819 35820 35821 35822 35823 35824 35825 35826 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35799 class SourceInstanceProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. module KeyRevocationActionType # A value indicating that the enum field is not set. UNDEFINED_KEY_REVOCATION_ACTION_TYPE = 0 # Default value. This value is unused. KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED = 467_110_106 # Indicates user chose no operation. NONE = 2_402_104 # Indicates user chose to opt for VM shutdown on key revocation. STOP = 2_555_906 end end |