Class: Google::Cloud::Compute::V1::SslCertificate
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SslCertificate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents an SSL certificate resource.
Google Compute Engine has two SSL certificate resources:
The global SSL certificates (sslCertificates) are used by:
- Global external Application Load Balancers
- Classic Application Load Balancers
- Proxy Network Load Balancers (with target SSL proxies)
The regional SSL certificates (regionSslCertificates) are used by:
- Regional external Application Load Balancers
- Regional internal Application Load Balancers
Optionally, certificate file contents that you upload can contain a set of up to five PEM-encoded certificates. The API call creates an object (sslCertificate) that holds this data. You can use SSL keys and certificates to secure connections to a load balancer. For more information, read Creating and using SSL certificates,SSL certificates quotas and limits, and Troubleshooting SSL certificates.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#certificate ⇒ ::String
A value read into memory from a certificate file.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp inRFC3339 text format.
-
#description ⇒ ::String
An optional description of this resource.
-
#expire_time ⇒ ::String
Output only.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
Output only.
-
#managed ⇒ ::Google::Cloud::Compute::V1::SslCertificateManagedSslCertificate
Configuration and status of a managed SSL certificate.
-
#name ⇒ ::String
Name of the resource.
-
#private_key ⇒ ::String
A value read into memory from a write-only private key file.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
[Output only] Server-defined URL for the resource.
-
#self_managed ⇒ ::Google::Cloud::Compute::V1::SslCertificateSelfManagedSslCertificate
Configuration and status of a self-managed SSL certificate.
-
#subject_alternative_names ⇒ ::Array<::String>
Output only.
-
#type ⇒ ::String
(Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or "MANAGED".
Instance Attribute Details
#certificate ⇒ ::String
Returns A value read into memory from a certificate file. The certificate file must be in PEM format. The certificate chain must be no greater than 5 certs long. The chain must include at least one intermediate cert.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#creation_timestamp ⇒ ::String
Returns [Output Only] Creation timestamp inRFC3339 text format.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#expire_time ⇒ ::String
Returns Output only. [Output Only] Expire time of the certificate. RFC3339.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#sslCertificate for SSL certificates.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#managed ⇒ ::Google::Cloud::Compute::V1::SslCertificateManagedSslCertificate
Returns Configuration and status of a managed SSL certificate.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#private_key ⇒ ::String
Returns A value read into memory from a write-only private key file. The private key file must be in PEM format. For security, only insert requests include this field.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the regional SSL Certificate resides. This field is not applicable to global SSL Certificate.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#self_link ⇒ ::String
Returns [Output only] Server-defined URL for the resource.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#self_managed ⇒ ::Google::Cloud::Compute::V1::SslCertificateSelfManagedSslCertificate
Returns Configuration and status of a self-managed SSL certificate.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#subject_alternative_names ⇒ ::Array<::String>
Returns Output only. [Output Only] Domains associated with the certificate via Subject Alternative Name.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |
#type ⇒ ::String
Returns (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. Check the Type enum for the list of possible values.
73833 73834 73835 73836 73837 73838 73839 73840 73841 73842 73843 73844 73845 73846 73847 73848 73849 73850 73851 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73833 class SslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or # "MANAGED". If not specified, the certificate is self-managed and the fieldscertificate and private_key are used. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Google-managed SSLCertificate. MANAGED = 479_501_183 # Certificate uploaded by user. SELF_MANAGED = 434_437_516 TYPE_UNSPECIFIED = 437_714_322 end end |