Class: Google::Cloud::Compute::V1::SslCertificateManagedSslCertificate

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Configuration and status of a managed SSL certificate.

Defined Under Namespace

Modules: Status Classes: DomainStatusEntry

Instance Attribute Summary collapse

Instance Attribute Details

#domain_status::Google::Protobuf::Map{::String => ::String}

Returns Output only. [Output only] Detailed statuses of the domains specified for managed certificate resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Output only. [Output only] Detailed statuses of the domains specified for managed certificate resource.



76447
76448
76449
76450
76451
76452
76453
76454
76455
76456
76457
76458
76459
76460
76461
76462
76463
76464
76465
76466
76467
76468
76469
76470
76471
76472
76473
76474
76475
76476
76477
76478
76479
76480
76481
76482
76483
76484
76485
76486
76487
76488
76489
76490
76491
76492
76493
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76447

class SslCertificateManagedSslCertificate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DomainStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output only] Status of the managed certificate resource.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The certificate management is working, and a certificate has been
    # provisioned.
    ACTIVE = 314_733_318

    MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474_800_850

    # The certificate management is working. GCP will attempt to provision
    # the first certificate.
    PROVISIONING = 290_896_621

    # Certificate provisioning failed due to an issue with the DNS
    # or load balancing configuration.
    # For details of which domain failed, consult domain_status field.
    PROVISIONING_FAILED = 76_813_775

    # Certificate provisioning failed due to an issue with the DNS
    # or load balancing configuration. It won't be retried. To try again
    # delete and create a new managed SslCertificate resource.
    # For details of which domain failed, consult domain_status field.
    PROVISIONING_FAILED_PERMANENTLY = 275_036_203

    # Renewal of the certificate has failed due to an issue with the DNS
    # or load balancing configuration. The existing cert is still serving;
    # however, it will expire shortly. To provision a renewed certificate,
    # delete and create a new managed SslCertificate resource.
    # For details on which domain failed, consult domain_status field.
    RENEWAL_FAILED = 434_659_076
  end
end

#domains::Array<::String>

Returns The domains for which a managed SSL certificate will be generated. Each Google-managed SSL certificate supports up to the maximum number of domains per Google-managed SSL certificate.

Returns:



76447
76448
76449
76450
76451
76452
76453
76454
76455
76456
76457
76458
76459
76460
76461
76462
76463
76464
76465
76466
76467
76468
76469
76470
76471
76472
76473
76474
76475
76476
76477
76478
76479
76480
76481
76482
76483
76484
76485
76486
76487
76488
76489
76490
76491
76492
76493
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76447

class SslCertificateManagedSslCertificate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DomainStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output only] Status of the managed certificate resource.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The certificate management is working, and a certificate has been
    # provisioned.
    ACTIVE = 314_733_318

    MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474_800_850

    # The certificate management is working. GCP will attempt to provision
    # the first certificate.
    PROVISIONING = 290_896_621

    # Certificate provisioning failed due to an issue with the DNS
    # or load balancing configuration.
    # For details of which domain failed, consult domain_status field.
    PROVISIONING_FAILED = 76_813_775

    # Certificate provisioning failed due to an issue with the DNS
    # or load balancing configuration. It won't be retried. To try again
    # delete and create a new managed SslCertificate resource.
    # For details of which domain failed, consult domain_status field.
    PROVISIONING_FAILED_PERMANENTLY = 275_036_203

    # Renewal of the certificate has failed due to an issue with the DNS
    # or load balancing configuration. The existing cert is still serving;
    # however, it will expire shortly. To provision a renewed certificate,
    # delete and create a new managed SslCertificate resource.
    # For details on which domain failed, consult domain_status field.
    RENEWAL_FAILED = 434_659_076
  end
end

#status::String

Returns Output only. [Output only] Status of the managed certificate resource. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output only] Status of the managed certificate resource. Check the Status enum for the list of possible values.



76447
76448
76449
76450
76451
76452
76453
76454
76455
76456
76457
76458
76459
76460
76461
76462
76463
76464
76465
76466
76467
76468
76469
76470
76471
76472
76473
76474
76475
76476
76477
76478
76479
76480
76481
76482
76483
76484
76485
76486
76487
76488
76489
76490
76491
76492
76493
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76447

class SslCertificateManagedSslCertificate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DomainStatusEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Output only. [Output only] Status of the managed certificate resource.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # The certificate management is working, and a certificate has been
    # provisioned.
    ACTIVE = 314_733_318

    MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474_800_850

    # The certificate management is working. GCP will attempt to provision
    # the first certificate.
    PROVISIONING = 290_896_621

    # Certificate provisioning failed due to an issue with the DNS
    # or load balancing configuration.
    # For details of which domain failed, consult domain_status field.
    PROVISIONING_FAILED = 76_813_775

    # Certificate provisioning failed due to an issue with the DNS
    # or load balancing configuration. It won't be retried. To try again
    # delete and create a new managed SslCertificate resource.
    # For details of which domain failed, consult domain_status field.
    PROVISIONING_FAILED_PERMANENTLY = 275_036_203

    # Renewal of the certificate has failed due to an issue with the DNS
    # or load balancing configuration. The existing cert is still serving;
    # however, it will expire shortly. To provision a renewed certificate,
    # delete and create a new managed SslCertificate resource.
    # For details on which domain failed, consult domain_status field.
    RENEWAL_FAILED = 434_659_076
  end
end