Class: Google::Cloud::Compute::V1::SslCertificateManagedSslCertificate
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SslCertificateManagedSslCertificate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configuration and status of a managed SSL certificate.
Defined Under Namespace
Modules: Status Classes: DomainStatusEntry
Instance Attribute Summary collapse
-
#domain_status ⇒ ::Google::Protobuf::Map{::String => ::String}
Output only.
-
#domains ⇒ ::Array<::String>
The domains for which a managed SSL certificate will be generated.
-
#status ⇒ ::String
Output only.
Instance Attribute Details
#domain_status ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Output only. [Output only] Detailed statuses of the domains specified for managed certificate resource.
75604 75605 75606 75607 75608 75609 75610 75611 75612 75613 75614 75615 75616 75617 75618 75619 75620 75621 75622 75623 75624 75625 75626 75627 75628 75629 75630 75631 75632 75633 75634 75635 75636 75637 75638 75639 75640 75641 75642 75643 75644 75645 75646 75647 75648 75649 75650 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75604 class SslCertificateManagedSslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DomainStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output only] Status of the managed certificate resource. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The certificate management is working, and a certificate has been # provisioned. ACTIVE = 314_733_318 MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474_800_850 # The certificate management is working. GCP will attempt to provision # the first certificate. PROVISIONING = 290_896_621 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED = 76_813_775 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. It won't be retried. To try again # delete and create a new managed SslCertificate resource. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED_PERMANENTLY = 275_036_203 # Renewal of the certificate has failed due to an issue with the DNS # or load balancing configuration. The existing cert is still serving; # however, it will expire shortly. To provision a renewed certificate, # delete and create a new managed SslCertificate resource. # For details on which domain failed, consult domain_status field. RENEWAL_FAILED = 434_659_076 end end |
#domains ⇒ ::Array<::String>
Returns The domains for which a managed SSL certificate will be generated. Each Google-managed SSL certificate supports up to the maximum number of domains per Google-managed SSL certificate.
75604 75605 75606 75607 75608 75609 75610 75611 75612 75613 75614 75615 75616 75617 75618 75619 75620 75621 75622 75623 75624 75625 75626 75627 75628 75629 75630 75631 75632 75633 75634 75635 75636 75637 75638 75639 75640 75641 75642 75643 75644 75645 75646 75647 75648 75649 75650 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75604 class SslCertificateManagedSslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DomainStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output only] Status of the managed certificate resource. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The certificate management is working, and a certificate has been # provisioned. ACTIVE = 314_733_318 MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474_800_850 # The certificate management is working. GCP will attempt to provision # the first certificate. PROVISIONING = 290_896_621 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED = 76_813_775 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. It won't be retried. To try again # delete and create a new managed SslCertificate resource. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED_PERMANENTLY = 275_036_203 # Renewal of the certificate has failed due to an issue with the DNS # or load balancing configuration. The existing cert is still serving; # however, it will expire shortly. To provision a renewed certificate, # delete and create a new managed SslCertificate resource. # For details on which domain failed, consult domain_status field. RENEWAL_FAILED = 434_659_076 end end |
#status ⇒ ::String
Returns Output only. [Output only] Status of the managed certificate resource. Check the Status enum for the list of possible values.
75604 75605 75606 75607 75608 75609 75610 75611 75612 75613 75614 75615 75616 75617 75618 75619 75620 75621 75622 75623 75624 75625 75626 75627 75628 75629 75630 75631 75632 75633 75634 75635 75636 75637 75638 75639 75640 75641 75642 75643 75644 75645 75646 75647 75648 75649 75650 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75604 class SslCertificateManagedSslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DomainStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output only] Status of the managed certificate resource. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The certificate management is working, and a certificate has been # provisioned. ACTIVE = 314_733_318 MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474_800_850 # The certificate management is working. GCP will attempt to provision # the first certificate. PROVISIONING = 290_896_621 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED = 76_813_775 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. It won't be retried. To try again # delete and create a new managed SslCertificate resource. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED_PERMANENTLY = 275_036_203 # Renewal of the certificate has failed due to an issue with the DNS # or load balancing configuration. The existing cert is still serving; # however, it will expire shortly. To provision a renewed certificate, # delete and create a new managed SslCertificate resource. # For details on which domain failed, consult domain_status field. RENEWAL_FAILED = 434_659_076 end end |