Class: Google::Cloud::Compute::V1::SslCertificateManagedSslCertificate
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SslCertificateManagedSslCertificate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configuration and status of a managed SSL certificate.
Defined Under Namespace
Modules: Status Classes: DomainStatusEntry
Instance Attribute Summary collapse
-
#domain_status ⇒ ::Google::Protobuf::Map{::String => ::String}
Output only.
-
#domains ⇒ ::Array<::String>
The domains for which a managed SSL certificate will be generated.
-
#status ⇒ ::String
Output only.
Instance Attribute Details
#domain_status ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Output only. [Output only] Detailed statuses of the domains specified for managed certificate resource.
73936 73937 73938 73939 73940 73941 73942 73943 73944 73945 73946 73947 73948 73949 73950 73951 73952 73953 73954 73955 73956 73957 73958 73959 73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 73980 73981 73982 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73936 class SslCertificateManagedSslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DomainStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output only] Status of the managed certificate resource. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The certificate management is working, and a certificate has been # provisioned. ACTIVE = 314_733_318 MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474_800_850 # The certificate management is working. GCP will attempt to provision # the first certificate. PROVISIONING = 290_896_621 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED = 76_813_775 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. It won't be retried. To try again # delete and create a new managed SslCertificate resource. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED_PERMANENTLY = 275_036_203 # Renewal of the certificate has failed due to an issue with the DNS # or load balancing configuration. The existing cert is still serving; # however, it will expire shortly. To provision a renewed certificate, # delete and create a new managed SslCertificate resource. # For details on which domain failed, consult domain_status field. RENEWAL_FAILED = 434_659_076 end end |
#domains ⇒ ::Array<::String>
Returns The domains for which a managed SSL certificate will be generated. Each Google-managed SSL certificate supports up to the maximum number of domains per Google-managed SSL certificate.
73936 73937 73938 73939 73940 73941 73942 73943 73944 73945 73946 73947 73948 73949 73950 73951 73952 73953 73954 73955 73956 73957 73958 73959 73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 73980 73981 73982 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73936 class SslCertificateManagedSslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DomainStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output only] Status of the managed certificate resource. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The certificate management is working, and a certificate has been # provisioned. ACTIVE = 314_733_318 MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474_800_850 # The certificate management is working. GCP will attempt to provision # the first certificate. PROVISIONING = 290_896_621 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED = 76_813_775 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. It won't be retried. To try again # delete and create a new managed SslCertificate resource. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED_PERMANENTLY = 275_036_203 # Renewal of the certificate has failed due to an issue with the DNS # or load balancing configuration. The existing cert is still serving; # however, it will expire shortly. To provision a renewed certificate, # delete and create a new managed SslCertificate resource. # For details on which domain failed, consult domain_status field. RENEWAL_FAILED = 434_659_076 end end |
#status ⇒ ::String
Returns Output only. [Output only] Status of the managed certificate resource. Check the Status enum for the list of possible values.
73936 73937 73938 73939 73940 73941 73942 73943 73944 73945 73946 73947 73948 73949 73950 73951 73952 73953 73954 73955 73956 73957 73958 73959 73960 73961 73962 73963 73964 73965 73966 73967 73968 73969 73970 73971 73972 73973 73974 73975 73976 73977 73978 73979 73980 73981 73982 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 73936 class SslCertificateManagedSslCertificate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DomainStatusEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Output only. [Output only] Status of the managed certificate resource. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # The certificate management is working, and a certificate has been # provisioned. ACTIVE = 314_733_318 MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 474_800_850 # The certificate management is working. GCP will attempt to provision # the first certificate. PROVISIONING = 290_896_621 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED = 76_813_775 # Certificate provisioning failed due to an issue with the DNS # or load balancing configuration. It won't be retried. To try again # delete and create a new managed SslCertificate resource. # For details of which domain failed, consult domain_status field. PROVISIONING_FAILED_PERMANENTLY = 275_036_203 # Renewal of the certificate has failed due to an issue with the DNS # or load balancing configuration. The existing cert is still serving; # however, it will expire shortly. To provision a renewed certificate, # delete and create a new managed SslCertificate resource. # For details on which domain failed, consult domain_status field. RENEWAL_FAILED = 434_659_076 end end |