Class: Google::Cloud::Compute::V1::SslPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SslPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents an SSL Policy resource.
Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers. For more information, read SSL policies overview.
Defined Under Namespace
Modules: MinTlsVersion, PostQuantumKeyExchange, Profile
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#custom_features ⇒ ::Array<::String>
A list of features enabled when the selected profile is CUSTOM.
-
#description ⇒ ::String
An optional description of this resource.
-
#enabled_features ⇒ ::Array<::String>
Output only.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#id ⇒ ::Integer
Output only.
-
#kind ⇒ ::String
Output only.
-
#min_tls_version ⇒ ::String
The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer.
-
#name ⇒ ::String
Name of the resource.
-
#post_quantum_key_exchange ⇒ ::String
One of DEFAULT, ENABLED, orDEFERRED.
-
#profile ⇒ ::String
Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients.
-
#region ⇒ ::String
Output only.
-
#self_link ⇒ ::String
Output only.
-
#warnings ⇒ ::Array<::Google::Cloud::Compute::V1::Warnings>
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#custom_features ⇒ ::Array<::String>
Returns A list of features enabled when the selected profile is CUSTOM. The method returns the set of features that can be specified in this list. This field must be empty if the profile is notCUSTOM.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#enabled_features ⇒ ::Array<::String>
Returns Output only. [Output Only] The list of features enabled in the SSL policy.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#fingerprint ⇒ ::String
Returns Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a SslPolicy. An up-to-date fingerprint must be provided in order to update the SslPolicy, otherwise the request will fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to retrieve an SslPolicy.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#kind ⇒ ::String
Returns Output only. [Output only] Type of the resource. Alwayscompute#sslPolicyfor SSL policies.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#min_tls_version ⇒ ::String
Returns The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field must be set to RESTRICTED. Check the MinTlsVersion enum for the list of possible values.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#name ⇒ ::String
Returns Name of the resource. The name must be 1-63 characters long, and comply
with RFC1035. Specifically, the name must be 1-63 characters
long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#post_quantum_key_exchange ⇒ ::String
Returns One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates X25519MLKEM768 key exchange when clients advertise support for it. When set to DEFAULT, or if no SSL Policy is attached to the target proxy, the load balancer disallows X25519MLKEM768 key exchange before October 2026, and allows it afterward. When set to ENABLED, the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key exchange until October 2027, and allows it afterward. Check the PostQuantumKeyExchange enum for the list of possible values.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#profile ⇒ ::String
Returns Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in the customFeatures field. If using FIPS_202205, the min_tls_version field must be set to TLS_1_2. Check the Profile enum for the list of possible values.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the regional SSL policy resides. This field is not applicable to global SSL policies.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for the resource.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |
#warnings ⇒ ::Array<::Google::Cloud::Compute::V1::Warnings>
Returns Output only. [Output Only] If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages.
76691 76692 76693 76694 76695 76696 76697 76698 76699 76700 76701 76702 76703 76704 76705 76706 76707 76708 76709 76710 76711 76712 76713 76714 76715 76716 76717 76718 76719 76720 76721 76722 76723 76724 76725 76726 76727 76728 76729 76730 76731 76732 76733 76734 76735 76736 76737 76738 76739 76740 76741 76742 76743 76744 76745 76746 76747 76748 76749 76750 76751 76752 76753 76754 76755 76756 76757 76758 76759 76760 76761 76762 76763 76764 76765 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76691 class SslPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The minimum version of SSL protocol that can be used by the clients to # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field # must be set to RESTRICTED. module MinTlsVersion # A value indicating that the enum field is not set. UNDEFINED_MIN_TLS_VERSION = 0 # TLS 1.0 TLS_1_0 = 33_116_734 # TLS 1.1 TLS_1_1 = 33_116_735 # TLS 1.2 TLS_1_2 = 33_116_736 # TLS 1.3 TLS_1_3 = 33_116_737 end # One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer negotiates # X25519MLKEM768 key exchange when clients advertise support for it. When set # to DEFAULT, or if no SSL Policy is attached to the target # proxy, the load balancer disallows X25519MLKEM768 key exchange before # October 2026, and allows it afterward. When set to ENABLED, # the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the load balancer disallows X25519MLKEM768 key # exchange until October 2027, and allows it afterward. module PostQuantumKeyExchange # A value indicating that the enum field is not set. UNDEFINED_POST_QUANTUM_KEY_EXCHANGE = 0 # Default behavior: disabled until October 2026, enabled afterward. DEFAULT = 115_302_945 # Disabled until October 2027, enabled afterward. DEFERRED = 356_775_903 # Enabled now. ENABLED = 182_130_465 end # Profile specifies the set of SSL features that can be used by the load # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in # the customFeatures field. If using FIPS_202205, # the min_tls_version field must be set to TLS_1_2. module Profile # A value indicating that the enum field is not set. UNDEFINED_PROFILE = 0 # Compatible profile. Allows the broadset set of clients, even those which # support only out-of-date SSL features to negotiate with the load # balancer. COMPATIBLE = 179_357_396 # Custom profile. Allow only the set of allowed SSL features specified in # the customFeatures field. CUSTOM = 388_595_569 # FIPS compatible profile. Supports a reduced set of SSL features, # intended to meet FIPS 140-3 compliance requirements. FIPS_202205 = 475_828_188 # Modern profile. Supports a wide set of SSL features, allowing modern # clients to negotiate SSL with the load balancer. MODERN = 132_013_855 # Restricted profile. Supports a reduced set of SSL features, intended to # meet stricter compliance requirements. RESTRICTED = 261_551_195 end end |