Class: Google::Cloud::Compute::V1::SslPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents an SSL Policy resource.

Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers. For more information, read SSL policies overview.

Defined Under Namespace

Modules: MinTlsVersion, Profile

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#custom_features::Array<::String>

Returns A list of features enabled when the selected profile is CUSTOM. The method returns the set of features that can be specified in this list. This field must be empty if the profile is notCUSTOM.

Returns:

  • (::Array<::String>)

    A list of features enabled when the selected profile is CUSTOM. The method returns the set of features that can be specified in this list. This field must be empty if the profile is notCUSTOM.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#description::String

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (::String)

    An optional description of this resource. Provide this property when you create the resource.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#enabled_features::Array<::String>

Returns Output only. [Output Only] The list of features enabled in the SSL policy.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] The list of features enabled in the SSL policy.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#fingerprint::String

Returns Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a SslPolicy. An up-to-date fingerprint must be provided in order to update the SslPolicy, otherwise the request will fail with error 412 conditionNotMet.

To see the latest fingerprint, make a get() request to retrieve an SslPolicy.

Returns:

  • (::String)

    Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a SslPolicy. An up-to-date fingerprint must be provided in order to update the SslPolicy, otherwise the request will fail with error 412 conditionNotMet.

    To see the latest fingerprint, make a get() request to retrieve an SslPolicy.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#id::Integer

Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#kind::String

Returns Output only. [Output only] Type of the resource. Alwayscompute#sslPolicyfor SSL policies.

Returns:

  • (::String)

    Output only. [Output only] Type of the resource. Alwayscompute#sslPolicyfor SSL policies.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#min_tls_version::String

Returns The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field must be set to RESTRICTED. Check the MinTlsVersion enum for the list of possible values.

Returns:

  • (::String)

    The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field must be set to RESTRICTED. Check the MinTlsVersion enum for the list of possible values.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#name::String

Returns Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (::String)

    Name of the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#profile::String

Returns Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in the customFeatures field. If using FIPS_202205, the min_tls_version field must be set to TLS_1_2. Check the Profile enum for the list of possible values.

Returns:

  • (::String)

    Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in the customFeatures field. If using FIPS_202205, the min_tls_version field must be set to TLS_1_2. Check the Profile enum for the list of possible values.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#region::String

Returns Output only. [Output Only] URL of the region where the regional SSL policy resides. This field is not applicable to global SSL policies.

Returns:

  • (::String)

    Output only. [Output Only] URL of the region where the regional SSL policy resides. This field is not applicable to global SSL policies.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

Returns Output only. [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for the resource.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end

#warnings::Array<::Google::Cloud::Compute::V1::Warnings>

Returns Output only. [Output Only] If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages.

Returns:

  • (::Array<::Google::Cloud::Compute::V1::Warnings>)

    Output only. [Output Only] If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages.



74170
74171
74172
74173
74174
74175
74176
74177
74178
74179
74180
74181
74182
74183
74184
74185
74186
74187
74188
74189
74190
74191
74192
74193
74194
74195
74196
74197
74198
74199
74200
74201
74202
74203
74204
74205
74206
74207
74208
74209
74210
74211
74212
74213
74214
74215
74216
74217
74218
74219
74220
74221
74222
74223
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74170

class SslPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum version of SSL protocol that can be used by the clients to
  # establish a connection with the load balancer. This can be one ofTLS_1_0, TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
  # must be set to RESTRICTED.
  module MinTlsVersion
    # A value indicating that the enum field is not set.
    UNDEFINED_MIN_TLS_VERSION = 0

    # TLS 1.0
    TLS_1_0 = 33_116_734

    # TLS 1.1
    TLS_1_1 = 33_116_735

    # TLS 1.2
    TLS_1_2 = 33_116_736

    # TLS 1.3
    TLS_1_3 = 33_116_737
  end

  # Profile specifies the set of SSL features that can be used by the load
  # balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in
  # the customFeatures field. If using FIPS_202205,
  # the min_tls_version field must be set to TLS_1_2.
  module Profile
    # A value indicating that the enum field is not set.
    UNDEFINED_PROFILE = 0

    # Compatible profile. Allows the broadset set of clients, even those which
    # support only out-of-date SSL features to negotiate with the load
    # balancer.
    COMPATIBLE = 179_357_396

    # Custom profile. Allow only the set of allowed SSL features specified in
    # the customFeatures field.
    CUSTOM = 388_595_569

    # FIPS compatible profile. Supports a reduced set of SSL features,
    # intended to meet FIPS 140-3 compliance requirements.
    FIPS_202205 = 475_828_188

    # Modern profile. Supports a wide set of SSL features, allowing modern
    # clients to negotiate SSL with the load balancer.
    MODERN = 132_013_855

    # Restricted profile. Supports a reduced set of SSL features, intended to
    # meet stricter compliance requirements.
    RESTRICTED = 261_551_195
  end
end