Module: Google::Cloud::Compute::V1::SslPolicy::Profile
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE, MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL features to enable must be specified in the customFeatures field. If using FIPS_202205, the min_tls_version field must be set to TLS_1_2.
Constant Summary collapse
- UNDEFINED_PROFILE =
A value indicating that the enum field is not set.
0- COMPATIBLE =
Compatible profile. Allows the broadset set of clients, even those which support only out-of-date SSL features to negotiate with the load balancer.
179_357_396- CUSTOM =
Custom profile. Allow only the set of allowed SSL features specified in the customFeatures field.
388_595_569- FIPS_202205 =
FIPS compatible profile. Supports a reduced set of SSL features, intended to meet FIPS 140-3 compliance requirements.
475_828_188- MODERN =
Modern profile. Supports a wide set of SSL features, allowing modern clients to negotiate SSL with the load balancer.
132_013_855- RESTRICTED =
Restricted profile. Supports a reduced set of SSL features, intended to meet stricter compliance requirements.
261_551_195