Class: Google::Cloud::Compute::V1::StatefulPolicyPreservedState
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StatefulPolicyPreservedState
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configuration of preserved resources.
Defined Under Namespace
Classes: DisksEntry, ExternalIPsEntry, InternalIPsEntry
Instance Attribute Summary collapse
-
#disks ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice}
Disks created on the instances that will be preserved on instance delete, update, etc.
-
#external_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp}
External network IPs assigned to the instances that will be preserved on instance delete, update, etc.
-
#internal_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp}
Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc.
Instance Attribute Details
#disks ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice}
Returns Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks.
76993 76994 76995 76996 76997 76998 76999 77000 77001 77002 77003 77004 77005 77006 77007 77008 77009 77010 77011 77012 77013 77014 77015 77016 77017 77018 77019 77020 77021 77022 77023 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76993 class StatefulPolicyPreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#external_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp}
Returns External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name.
76993 76994 76995 76996 76997 76998 76999 77000 77001 77002 77003 77004 77005 77006 77007 77008 77009 77010 77011 77012 77013 77014 77015 77016 77017 77018 77019 77020 77021 77022 77023 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76993 class StatefulPolicyPreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#internal_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp}
Returns Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name.
76993 76994 76995 76996 76997 76998 76999 77000 77001 77002 77003 77004 77005 77006 77007 77008 77009 77010 77011 77012 77013 77014 77015 77016 77017 77018 77019 77020 77021 77022 77023 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76993 class StatefulPolicyPreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |