Class: Google::Cloud::Compute::V1::StatefulPolicyPreservedState
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StatefulPolicyPreservedState
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Configuration of preserved resources.
Defined Under Namespace
Classes: DisksEntry, ExternalIPsEntry, InternalIPsEntry
Instance Attribute Summary collapse
-
#disks ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice}
Disks created on the instances that will be preserved on instance delete, update, etc.
-
#external_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp}
External network IPs assigned to the instances that will be preserved on instance delete, update, etc.
-
#internal_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp}
Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc.
Instance Attribute Details
#disks ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice}
Returns Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks.
76152 76153 76154 76155 76156 76157 76158 76159 76160 76161 76162 76163 76164 76165 76166 76167 76168 76169 76170 76171 76172 76173 76174 76175 76176 76177 76178 76179 76180 76181 76182 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76152 class StatefulPolicyPreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#external_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp}
Returns External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name.
76152 76153 76154 76155 76156 76157 76158 76159 76160 76161 76162 76163 76164 76165 76166 76167 76168 76169 76170 76171 76172 76173 76174 76175 76176 76177 76178 76179 76180 76181 76182 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76152 class StatefulPolicyPreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#internal_i_ps ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp}
Returns Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name.
76152 76153 76154 76155 76156 76157 76158 76159 76160 76161 76162 76163 76164 76165 76166 76167 76168 76169 76170 76171 76172 76173 76174 76175 76176 76177 76178 76179 76180 76181 76182 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76152 class StatefulPolicyPreservedState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice] class DisksEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class ExternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp] class InternalIPsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |