Class: Google::Cloud::Compute::V1::StatefulPolicyPreservedStateDiskDevice

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: AutoDelete

Instance Attribute Summary collapse

Instance Attribute Details

#auto_delete::String

Returns These stateful disks will never be deleted during autohealing, update or VM instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Note: disks attached inREAD_ONLY mode cannot be auto-deleted. Check the AutoDelete enum for the list of possible values.

Returns:

  • (::String)

    These stateful disks will never be deleted during autohealing, update or VM instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Note: disks attached inREAD_ONLY mode cannot be auto-deleted. Check the AutoDelete enum for the list of possible values.



76192
76193
76194
76195
76196
76197
76198
76199
76200
76201
76202
76203
76204
76205
76206
76207
76208
76209
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76192

class StatefulPolicyPreservedStateDiskDevice
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These stateful disks will never be deleted during autohealing,
  # update or VM instance recreate operations.
  # This flag is used to configure if the disk should be deleted after it
  # is no longer used by the group, e.g. when the given instance or
  # the whole group is deleted. Note: disks attached inREAD_ONLY mode cannot be auto-deleted.
  module AutoDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_AUTO_DELETE = 0

    NEVER = 74_175_084

    ON_PERMANENT_INSTANCE_DELETION = 95_727_719
  end
end