Class: Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: AutoDelete

Instance Attribute Summary collapse

Instance Attribute Details

#auto_delete::String

Returns These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Check the AutoDelete enum for the list of possible values.

Returns:

  • (::String)

    These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Check the AutoDelete enum for the list of possible values.



77060
77061
77062
77063
77064
77065
77066
77067
77068
77069
77070
77071
77072
77073
77074
77075
77076
77077
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77060

class StatefulPolicyPreservedStateNetworkIp
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These stateful IPs will never be released during autohealing,
  # update or VM instance recreate operations.
  # This flag is used to configure if the IP reservation should be deleted
  # after it is no longer used by the group, e.g. when the given instance
  # or the whole group is deleted.
  module AutoDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_AUTO_DELETE = 0

    NEVER = 74_175_084

    ON_PERMANENT_INSTANCE_DELETION = 95_727_719
  end
end