Class: Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: AutoDelete

Instance Attribute Summary collapse

Instance Attribute Details

#auto_delete::String

Returns These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Check the AutoDelete enum for the list of possible values.

Returns:

  • (::String)

    These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Check the AutoDelete enum for the list of possible values.



76219
76220
76221
76222
76223
76224
76225
76226
76227
76228
76229
76230
76231
76232
76233
76234
76235
76236
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76219

class StatefulPolicyPreservedStateNetworkIp
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # These stateful IPs will never be released during autohealing,
  # update or VM instance recreate operations.
  # This flag is used to configure if the IP reservation should be deleted
  # after it is no longer used by the group, e.g. when the given instance
  # or the whole group is deleted.
  module AutoDelete
    # A value indicating that the enum field is not set.
    UNDEFINED_AUTO_DELETE = 0

    NEVER = 74_175_084

    ON_PERMANENT_INSTANCE_DELETION = 95_727_719
  end
end