Class: Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StatefulPolicyPreservedStateNetworkIp
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: AutoDelete
Instance Attribute Summary collapse
-
#auto_delete ⇒ ::String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
Instance Attribute Details
#auto_delete ⇒ ::String
Returns These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Check the AutoDelete enum for the list of possible values.
74520 74521 74522 74523 74524 74525 74526 74527 74528 74529 74530 74531 74532 74533 74534 74535 74536 74537 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74520 class StatefulPolicyPreservedStateNetworkIp include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # These stateful IPs will never be released during autohealing, # update or VM instance recreate operations. # This flag is used to configure if the IP reservation should be deleted # after it is no longer used by the group, e.g. when the given instance # or the whole group is deleted. module AutoDelete # A value indicating that the enum field is not set. UNDEFINED_AUTO_DELETE = 0 NEVER = 74_175_084 ON_PERMANENT_INSTANCE_DELETION = 95_727_719 end end |