Class: Google::Cloud::Compute::V1::StoragePool
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StoragePool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a zonal storage pool resource.
Defined Under Namespace
Modules: CapacityProvisioningType, PerformanceProvisioningType, State Classes: LabelsEntry
Instance Attribute Summary collapse
-
#capacity_provisioning_type ⇒ ::String
Provisioning type of the byte capacity of the pool.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ ::String
An optional description of this resource.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
[Output Only] Type of the resource.
-
#label_fingerprint ⇒ ::String
A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels to apply to this storage pool.
-
#name ⇒ ::String
Name of the resource.
-
#performance_provisioning_type ⇒ ::String
Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS.
-
#pool_provisioned_capacity_gb ⇒ ::Integer
Size, in GiB, of the storage pool.
-
#pool_provisioned_iops ⇒ ::Integer
Provisioned IOPS of the storage pool.
-
#pool_provisioned_throughput ⇒ ::Integer
Provisioned throughput of the storage pool.
-
#resource_status ⇒ ::Google::Cloud::Compute::V1::StoragePoolResourceStatus
[Output Only] Status information for the storage pool resource.
-
#self_link ⇒ ::String
[Output Only] Server-defined fully-qualified URL for this resource.
-
#self_link_with_id ⇒ ::String
[Output Only] Server-defined URL for this resource's resource id.
-
#state ⇒ ::String
[Output Only] The status of storage pool creation.
-
#status ⇒ ::Google::Cloud::Compute::V1::StoragePoolResourceStatus
[Output Only] Status information for the storage pool resource.
-
#storage_pool_type ⇒ ::String
Type of the storage pool.
-
#zone ⇒ ::String
[Output Only] URL of the zone where the storage pool resides.
Instance Attribute Details
#capacity_provisioning_type ⇒ ::String
Returns Provisioning type of the byte capacity of the pool. Check the CapacityProvisioningType enum for the list of possible values.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#creation_timestamp ⇒ ::String
Returns [Output Only] Creation timestamp in RFC3339 text format.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#kind ⇒ ::String
Returns [Output Only] Type of the resource. Always compute#storagePool for storage pools.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#label_fingerprint ⇒ ::String
Returns A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a storage pool.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels to apply to this storage pool. These can be later modified by the setLabels method.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#performance_provisioning_type ⇒ ::String
Returns Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. Check the PerformanceProvisioningType enum for the list of possible values.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#pool_provisioned_capacity_gb ⇒ ::Integer
Returns Size, in GiB, of the storage pool. For more information about the size limits, see https://cloud.google.com/compute/docs/disks/storage-pools.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#pool_provisioned_iops ⇒ ::Integer
Returns Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#pool_provisioned_throughput ⇒ ::Integer
Returns Provisioned throughput of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#resource_status ⇒ ::Google::Cloud::Compute::V1::StoragePoolResourceStatus
Returns [Output Only] Status information for the storage pool resource.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined fully-qualified URL for this resource.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#self_link_with_id ⇒ ::String
Returns [Output Only] Server-defined URL for this resource's resource id.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#state ⇒ ::String
Returns [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. Check the State enum for the list of possible values.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#status ⇒ ::Google::Cloud::Compute::V1::StoragePoolResourceStatus
Returns [Output Only] Status information for the storage pool resource.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#storage_pool_type ⇒ ::String
Returns Type of the storage pool.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |
#zone ⇒ ::String
Returns [Output Only] URL of the zone where the storage pool resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
34359 34360 34361 34362 34363 34364 34365 34366 34367 34368 34369 34370 34371 34372 34373 34374 34375 34376 34377 34378 34379 34380 34381 34382 34383 34384 34385 34386 34387 34388 34389 34390 34391 34392 34393 34394 34395 34396 34397 34398 34399 34400 34401 34402 34403 34404 34405 34406 34407 34408 34409 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34359 class StoragePool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisioning type of the byte capacity of the pool. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module CapacityProvisioningType # A value indicating that the enum field is not set. UNDEFINED_CAPACITY_PROVISIONING_TYPE = 0 end # Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. # Additional supported values which may be not listed in the enum directly due to technical reasons: # ADVANCED # STANDARD # UNSPECIFIED module PerformanceProvisioningType # A value indicating that the enum field is not set. UNDEFINED_PERFORMANCE_PROVISIONING_TYPE = 0 end # [Output Only] The status of storage pool creation. - CREATING: Storage pool is provisioning. storagePool. - FAILED: Storage pool creation failed. - READY: Storage pool is ready for use. - DELETING: Storage pool is deleting. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # StoragePool is provisioning CREATING = 455_564_985 # StoragePool is deleting. DELETING = 528_602_024 # StoragePool creation failed. FAILED = 455_706_685 # StoragePool is ready for use. READY = 77_848_963 end end |