Class: Google::Cloud::Compute::V1::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns:

  • (::String)


77523
77524
77525
77526
77527
77528
77529
77530
77531
77532
77533
77534
77535
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77523

class StoragePoolAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    [Output Only] Unique identifier for the resource; defined by the server.



77523
77524
77525
77526
77527
77528
77529
77530
77531
77532
77533
77534
77535
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77523

class StoragePoolAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StoragePoolsScopedList}

Returns A list of StoragePoolsScopedList resources.

Returns:



77523
77524
77525
77526
77527
77528
77529
77530
77531
77532
77533
77534
77535
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77523

class StoragePoolAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns Output only. [Output Only] Type of resource. Alwayscompute#storagePoolAggregatedList for aggregated lists of storage pools.

Returns:

  • (::String)

    Output only. [Output Only] Type of resource. Alwayscompute#storagePoolAggregatedList for aggregated lists of storage pools.



77523
77524
77525
77526
77527
77528
77529
77530
77531
77532
77533
77534
77535
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77523

class StoragePoolAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



77523
77524
77525
77526
77527
77528
77529
77530
77531
77532
77533
77534
77535
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77523

class StoragePoolAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns Output only. [Output Only] Server-defined URL for this resource.

Returns:

  • (::String)

    Output only. [Output Only] Server-defined URL for this resource.



77523
77524
77525
77526
77527
77528
77529
77530
77531
77532
77533
77534
77535
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77523

class StoragePoolAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables::Array<::String>

Returns Output only. [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Unreachable resources.



77523
77524
77525
77526
77527
77528
77529
77530
77531
77532
77533
77534
77535
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77523

class StoragePoolAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#warning::Google::Cloud::Compute::V1::Warning

Returns [Output Only] Informational warning message.

Returns:



77523
77524
77525
77526
77527
77528
77529
77530
77531
77532
77533
77534
77535
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77523

class StoragePoolAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end