Class: Google::Cloud::Compute::V1::StoragePoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StoragePoolAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
- #etag ⇒ ::String
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StoragePoolsScopedList}
A list of StoragePoolsScopedList resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#etag ⇒ ::String
74975 74976 74977 74978 74979 74980 74981 74982 74983 74984 74985 74986 74987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74975 class StoragePoolAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
74975 74976 74977 74978 74979 74980 74981 74982 74983 74984 74985 74986 74987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74975 class StoragePoolAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::StoragePoolsScopedList}
Returns A list of StoragePoolsScopedList resources.
74975 74976 74977 74978 74979 74980 74981 74982 74983 74984 74985 74986 74987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74975 class StoragePoolAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Alwayscompute#storagePoolAggregatedList for aggregated lists of storage pools.
74975 74976 74977 74978 74979 74980 74981 74982 74983 74984 74985 74986 74987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74975 class StoragePoolAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
74975 74976 74977 74978 74979 74980 74981 74982 74983 74984 74985 74986 74987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74975 class StoragePoolAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
74975 74976 74977 74978 74979 74980 74981 74982 74983 74984 74985 74986 74987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74975 class StoragePoolAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
74975 74976 74977 74978 74979 74980 74981 74982 74983 74984 74985 74986 74987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74975 class StoragePoolAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
74975 74976 74977 74978 74979 74980 74981 74982 74983 74984 74985 74986 74987 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 74975 class StoragePoolAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::StoragePoolsScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |