Class: Google::Cloud::Compute::V1::StoragePoolDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#attached_instances::Array<::String>

Returns Output only. [Output Only] Instances this disk is attached to.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Instances this disk is attached to.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#disk::String

Returns Output only. [Output Only] The URL of the disk.

Returns:

  • (::String)

    Output only. [Output Only] The URL of the disk.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#name::String

Returns Output only. [Output Only] The name of the disk.

Returns:

  • (::String)

    Output only. [Output Only] The name of the disk.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#provisioned_iops::Integer

Returns Output only. [Output Only] The number of IOPS provisioned for the disk.

Returns:

  • (::Integer)

    Output only. [Output Only] The number of IOPS provisioned for the disk.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#provisioned_throughput::Integer

Returns Output only. [Output Only] The throughput provisioned for the disk.

Returns:

  • (::Integer)

    Output only. [Output Only] The throughput provisioned for the disk.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#resource_policies::Array<::String>

Returns Output only. [Output Only] Resource policies applied to disk for automatic snapshot creations.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Resource policies applied to disk for automatic snapshot creations.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#size_gb::Integer

Returns Output only. [Output Only] The disk size, in GB.

Returns:

  • (::Integer)

    Output only. [Output Only] The disk size, in GB.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#status::String

Returns Output only. [Output Only] The disk status. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The disk status. Check the Status enum for the list of possible values.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#type::String

Returns Output only. [Output Only] The disk type.

Returns:

  • (::String)

    Output only. [Output Only] The disk type.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#used_bytes::Integer

Returns Output only. [Output Only] Amount of disk space used.

Returns:

  • (::Integer)

    Output only. [Output Only] Amount of disk space used.



77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
77588
77589
77590
77591
77592
77593
77594
77595
77596
77597
77598
77599
77600
77601
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77573

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end