Class: Google::Cloud::Compute::V1::StoragePoolDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#attached_instances::Array<::String>

Returns Output only. [Output Only] Instances this disk is attached to.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Instances this disk is attached to.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#creation_timestamp::String

Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    Output only. [Output Only] Creation timestamp inRFC3339 text format.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#disk::String

Returns Output only. [Output Only] The URL of the disk.

Returns:

  • (::String)

    Output only. [Output Only] The URL of the disk.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#name::String

Returns Output only. [Output Only] The name of the disk.

Returns:

  • (::String)

    Output only. [Output Only] The name of the disk.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#provisioned_iops::Integer

Returns Output only. [Output Only] The number of IOPS provisioned for the disk.

Returns:

  • (::Integer)

    Output only. [Output Only] The number of IOPS provisioned for the disk.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#provisioned_throughput::Integer

Returns Output only. [Output Only] The throughput provisioned for the disk.

Returns:

  • (::Integer)

    Output only. [Output Only] The throughput provisioned for the disk.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#resource_policies::Array<::String>

Returns Output only. [Output Only] Resource policies applied to disk for automatic snapshot creations.

Returns:

  • (::Array<::String>)

    Output only. [Output Only] Resource policies applied to disk for automatic snapshot creations.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#size_gb::Integer

Returns Output only. [Output Only] The disk size, in GB.

Returns:

  • (::Integer)

    Output only. [Output Only] The disk size, in GB.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#status::String

Returns Output only. [Output Only] The disk status. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    Output only. [Output Only] The disk status. Check the Status enum for the list of possible values.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#type::String

Returns Output only. [Output Only] The disk type.

Returns:

  • (::String)

    Output only. [Output Only] The disk type.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end

#used_bytes::Integer

Returns Output only. [Output Only] Amount of disk space used.

Returns:

  • (::Integer)

    Output only. [Output Only] Amount of disk space used.



76724
76725
76726
76727
76728
76729
76730
76731
76732
76733
76734
76735
76736
76737
76738
76739
76740
76741
76742
76743
76744
76745
76746
76747
76748
76749
76750
76751
76752
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 76724

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Output only. [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or
    # detached.
    UNAVAILABLE = 413_756_464
  end
end