Class: Google::Cloud::Compute::V1::StoragePoolDisk
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StoragePoolDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#attached_instances ⇒ ::Array<::String>
Output only.
-
#creation_timestamp ⇒ ::String
Output only.
-
#disk ⇒ ::String
Output only.
-
#name ⇒ ::String
Output only.
-
#provisioned_iops ⇒ ::Integer
Output only.
-
#provisioned_throughput ⇒ ::Integer
Output only.
-
#resource_policies ⇒ ::Array<::String>
Output only.
-
#size_gb ⇒ ::Integer
Output only.
-
#status ⇒ ::String
Output only.
-
#type ⇒ ::String
Output only.
-
#used_bytes ⇒ ::Integer
Output only.
Instance Attribute Details
#attached_instances ⇒ ::Array<::String>
Returns Output only. [Output Only] Instances this disk is attached to.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#disk ⇒ ::String
Returns Output only. [Output Only] The URL of the disk.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#name ⇒ ::String
Returns Output only. [Output Only] The name of the disk.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#provisioned_iops ⇒ ::Integer
Returns Output only. [Output Only] The number of IOPS provisioned for the disk.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#provisioned_throughput ⇒ ::Integer
Returns Output only. [Output Only] The throughput provisioned for the disk.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#resource_policies ⇒ ::Array<::String>
Returns Output only. [Output Only] Resource policies applied to disk for automatic snapshot creations.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#size_gb ⇒ ::Integer
Returns Output only. [Output Only] The disk size, in GB.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#status ⇒ ::String
Returns Output only. [Output Only] The disk status. Check the Status enum for the list of possible values.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#type ⇒ ::String
Returns Output only. [Output Only] The disk type.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |
#used_bytes ⇒ ::Integer
Returns Output only. [Output Only] Amount of disk space used.
75025 75026 75027 75028 75029 75030 75031 75032 75033 75034 75035 75036 75037 75038 75039 75040 75041 75042 75043 75044 75045 75046 75047 75048 75049 75050 75051 75052 75053 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75025 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Output only. [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or # detached. UNAVAILABLE = 413_756_464 end end |