Class: Google::Cloud::Compute::V1::StoragePoolDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#attached_instances::Array<::String>

Returns [Output Only] Instances this disk is attached to.

Returns:

  • (::Array<::String>)

    [Output Only] Instances this disk is attached to.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#creation_timestamp::String

Returns [Output Only] Creation timestamp in RFC3339 text format.

Returns:

  • (::String)

    [Output Only] Creation timestamp in RFC3339 text format.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#disk::String

Returns [Output Only] The URL of the disk.

Returns:

  • (::String)

    [Output Only] The URL of the disk.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#name::String

Returns [Output Only] The name of the disk.

Returns:

  • (::String)

    [Output Only] The name of the disk.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#provisioned_iops::Integer

Returns [Output Only] The number of IOPS provisioned for the disk.

Returns:

  • (::Integer)

    [Output Only] The number of IOPS provisioned for the disk.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#provisioned_throughput::Integer

Returns [Output Only] The throughput provisioned for the disk.

Returns:

  • (::Integer)

    [Output Only] The throughput provisioned for the disk.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#resource_policies::Array<::String>

Returns [Output Only] Resource policies applied to disk for automatic snapshot creations.

Returns:

  • (::Array<::String>)

    [Output Only] Resource policies applied to disk for automatic snapshot creations.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#size_gb::Integer

Returns [Output Only] The disk size, in GB.

Returns:

  • (::Integer)

    [Output Only] The disk size, in GB.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#status::String

Returns [Output Only] The disk status. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] The disk status. Check the Status enum for the list of possible values.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#type::String

Returns [Output Only] The disk type.

Returns:

  • (::String)

    [Output Only] The disk type.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end

#used_bytes::Integer

Returns [Output Only] Amount of disk space used.

Returns:

  • (::Integer)

    [Output Only] Amount of disk space used.



33984
33985
33986
33987
33988
33989
33990
33991
33992
33993
33994
33995
33996
33997
33998
33999
34000
34001
34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33984

class StoragePoolDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] The disk status.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    # Disk is provisioning
    CREATING = 455_564_985

    # Disk is deleting.
    DELETING = 528_602_024

    # Disk creation failed.
    FAILED = 455_706_685

    # Disk is ready for use.
    READY = 77_848_963

    # Source data is being copied into the disk.
    RESTORING = 404_263_851

    # Disk is currently unavailable and cannot be accessed, attached or detached.
    UNAVAILABLE = 413_756_464
  end
end