Class: Google::Cloud::Compute::V1::StoragePoolDisk
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StoragePoolDisk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#attached_instances ⇒ ::Array<::String>
[Output Only] Instances this disk is attached to.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#disk ⇒ ::String
[Output Only] The URL of the disk.
-
#name ⇒ ::String
[Output Only] The name of the disk.
-
#provisioned_iops ⇒ ::Integer
[Output Only] The number of IOPS provisioned for the disk.
-
#provisioned_throughput ⇒ ::Integer
[Output Only] The throughput provisioned for the disk.
-
#resource_policies ⇒ ::Array<::String>
[Output Only] Resource policies applied to disk for automatic snapshot creations.
-
#size_gb ⇒ ::Integer
[Output Only] The disk size, in GB.
-
#status ⇒ ::String
[Output Only] The disk status.
-
#type ⇒ ::String
[Output Only] The disk type.
-
#used_bytes ⇒ ::Integer
[Output Only] Amount of disk space used.
Instance Attribute Details
#attached_instances ⇒ ::Array<::String>
Returns [Output Only] Instances this disk is attached to.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#creation_timestamp ⇒ ::String
Returns [Output Only] Creation timestamp in RFC3339 text format.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#disk ⇒ ::String
Returns [Output Only] The URL of the disk.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#name ⇒ ::String
Returns [Output Only] The name of the disk.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#provisioned_iops ⇒ ::Integer
Returns [Output Only] The number of IOPS provisioned for the disk.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#provisioned_throughput ⇒ ::Integer
Returns [Output Only] The throughput provisioned for the disk.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#resource_policies ⇒ ::Array<::String>
Returns [Output Only] Resource policies applied to disk for automatic snapshot creations.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#size_gb ⇒ ::Integer
Returns [Output Only] The disk size, in GB.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#status ⇒ ::String
Returns [Output Only] The disk status. Check the Status enum for the list of possible values.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#type ⇒ ::String
Returns [Output Only] The disk type.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |
#used_bytes ⇒ ::Integer
Returns [Output Only] Amount of disk space used.
33954 33955 33956 33957 33958 33959 33960 33961 33962 33963 33964 33965 33966 33967 33968 33969 33970 33971 33972 33973 33974 33975 33976 33977 33978 33979 33980 33981 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 33954 class StoragePoolDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] The disk status. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 # Disk is provisioning CREATING = 455_564_985 # Disk is deleting. DELETING = 528_602_024 # Disk creation failed. FAILED = 455_706_685 # Disk is ready for use. READY = 77_848_963 # Source data is being copied into the disk. RESTORING = 404_263_851 # Disk is currently unavailable and cannot be accessed, attached or detached. UNAVAILABLE = 413_756_464 end end |