Class: Google::Cloud::Compute::V1::StoragePoolParams
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StoragePoolParams
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Additional storage pool params.
Defined Under Namespace
Classes: ResourceManagerTagsEntry
Instance Attribute Summary collapse
Instance Attribute Details
#resource_manager_tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Input only. Resource manager tags to be bound to the storage pool. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/{tag_key_id} and tagValues/456 or in namespaced
format such as {org_id|project_id}/{tag_key_short_name} and
{tag_value_short_name}. The field is ignored (both PUT &
PATCH) when empty.
75149 75150 75151 75152 75153 75154 75155 75156 75157 75158 75159 75160 75161 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75149 class StoragePoolParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceManagerTagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |