Class: Google::Cloud::Compute::V1::StoragePoolResourceStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StoragePoolResourceStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#disk_count ⇒ ::Integer
[Output Only] Number of disks used.
-
#exapool_max_read_iops ⇒ ::Integer
Output only.
-
#exapool_max_read_throughput ⇒ ::Integer
Output only.
-
#exapool_max_write_iops ⇒ ::Integer
Output only.
-
#exapool_max_write_throughput ⇒ ::Integer
Output only.
-
#last_resize_timestamp ⇒ ::String
Output only.
-
#max_total_provisioned_disk_capacity_gb ⇒ ::Integer
[Output Only] Maximum allowed aggregate disk size in GiB.
-
#pool_used_capacity_bytes ⇒ ::Integer
[Output Only] Space used by data stored in disks within the storage pool (in bytes).
-
#pool_used_iops ⇒ ::Integer
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity.
-
#pool_used_throughput ⇒ ::Integer
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
-
#pool_user_written_bytes ⇒ ::Integer
[Output Only] Amount of data written into the pool, before it is compacted.
-
#total_provisioned_disk_capacity_gb ⇒ ::Integer
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool.
-
#total_provisioned_disk_iops ⇒ ::Integer
[Output Only] Sum of all the disks' provisioned IOPS.
-
#total_provisioned_disk_throughput ⇒ ::Integer
[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
Instance Attribute Details
#disk_count ⇒ ::Integer
Returns [Output Only] Number of disks used.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exapool_max_read_iops ⇒ ::Integer
Returns Output only. [Output Only] Maximum allowed read IOPS for this Exapool.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exapool_max_read_throughput ⇒ ::Integer
Returns Output only. [Output Only] Maximum allowed read throughput in MiB/s for this Exapool.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exapool_max_write_iops ⇒ ::Integer
Returns Output only. [Output Only] Maximum allowed write IOPS for this Exapool.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exapool_max_write_throughput ⇒ ::Integer
Returns Output only. [Output Only] Maximum allowed write throughput in MiB/s for this Exapool.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_resize_timestamp ⇒ ::String
Returns Output only. [Output Only] Timestamp of the last successful resize inRFC3339 text format.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_total_provisioned_disk_capacity_gb ⇒ ::Integer
Returns [Output Only] Maximum allowed aggregate disk size in GiB.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_used_capacity_bytes ⇒ ::Integer
Returns [Output Only] Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_used_iops ⇒ ::Integer
Returns [Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity. For more information, see https://cloud.google.com/compute/docs/disks/storage-pools.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_used_throughput ⇒ ::Integer
Returns [Output Only] Sum of all the disks' provisioned throughput in MiB/s.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_user_written_bytes ⇒ ::Integer
Returns [Output Only] Amount of data written into the pool, before it is compacted.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_provisioned_disk_capacity_gb ⇒ ::Integer
Returns [Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool. A disk's provisioned capacity is the same as its total capacity.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_provisioned_disk_iops ⇒ ::Integer
Returns [Output Only] Sum of all the disks' provisioned IOPS.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_provisioned_disk_throughput ⇒ ::Integer
Returns [Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
75218 75219 75220 75221 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75218 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |