Class: Google::Cloud::Compute::V1::StoragePoolResourceStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

[Output Only] Contains output only fields.

Instance Attribute Summary collapse

Instance Attribute Details

#disk_count::Integer

Returns [Output Only] Number of disks used.

Returns:

  • (::Integer)

    [Output Only] Number of disks used.



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#last_resize_timestamp::String

Returns [Output Only] Timestamp of the last successful resize in RFC3339 text format.

Returns:

  • (::String)

    [Output Only] Timestamp of the last successful resize in RFC3339 text format.



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#max_total_provisioned_disk_capacity_gb::Integer

Returns [Output Only] Maximum allowed aggregate disk size in gigabytes.

Returns:

  • (::Integer)

    [Output Only] Maximum allowed aggregate disk size in gigabytes.



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pool_used_capacity_bytes::Integer

Returns [Output Only] Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks.

Returns:

  • (::Integer)

    [Output Only] Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks.



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pool_used_iops::Integer

Returns [Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity. For more information, see https://cloud.google.com/compute/docs/disks/storage-pools.

Returns:



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pool_used_throughput::Integer

Returns [Output Only] Sum of all the disks' provisioned throughput in MB/s.

Returns:

  • (::Integer)

    [Output Only] Sum of all the disks' provisioned throughput in MB/s.



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pool_user_written_bytes::Integer

Returns [Output Only] Amount of data written into the pool, before it is compacted.

Returns:

  • (::Integer)

    [Output Only] Amount of data written into the pool, before it is compacted.



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_provisioned_disk_capacity_gb::Integer

Returns [Output Only] Sum of all the capacity provisioned in disks in this storage pool. A disk's provisioned capacity is the same as its total capacity.

Returns:

  • (::Integer)

    [Output Only] Sum of all the capacity provisioned in disks in this storage pool. A disk's provisioned capacity is the same as its total capacity.



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_provisioned_disk_iops::Integer

Returns [Output Only] Sum of all the disks' provisioned IOPS.

Returns:

  • (::Integer)

    [Output Only] Sum of all the disks' provisioned IOPS.



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_provisioned_disk_throughput::Integer

Returns [Output Only] Sum of all the disks' provisioned throughput in MB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.

Returns:

  • (::Integer)

    [Output Only] Sum of all the disks' provisioned throughput in MB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.



34101
34102
34103
34104
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34101

class StoragePoolResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end