Class: Google::Cloud::Compute::V1::StoragePoolResourceStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::StoragePoolResourceStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#disk_count ⇒ ::Integer
[Output Only] Number of disks used.
-
#last_resize_timestamp ⇒ ::String
[Output Only] Timestamp of the last successful resize in RFC3339 text format.
-
#max_total_provisioned_disk_capacity_gb ⇒ ::Integer
[Output Only] Maximum allowed aggregate disk size in gigabytes.
-
#pool_used_capacity_bytes ⇒ ::Integer
[Output Only] Space used by data stored in disks within the storage pool (in bytes).
-
#pool_used_iops ⇒ ::Integer
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity.
-
#pool_used_throughput ⇒ ::Integer
[Output Only] Sum of all the disks' provisioned throughput in MB/s.
-
#pool_user_written_bytes ⇒ ::Integer
[Output Only] Amount of data written into the pool, before it is compacted.
-
#total_provisioned_disk_capacity_gb ⇒ ::Integer
[Output Only] Sum of all the capacity provisioned in disks in this storage pool.
-
#total_provisioned_disk_iops ⇒ ::Integer
[Output Only] Sum of all the disks' provisioned IOPS.
-
#total_provisioned_disk_throughput ⇒ ::Integer
[Output Only] Sum of all the disks' provisioned throughput in MB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
Instance Attribute Details
#disk_count ⇒ ::Integer
Returns [Output Only] Number of disks used.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_resize_timestamp ⇒ ::String
Returns [Output Only] Timestamp of the last successful resize in RFC3339 text format.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_total_provisioned_disk_capacity_gb ⇒ ::Integer
Returns [Output Only] Maximum allowed aggregate disk size in gigabytes.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_used_capacity_bytes ⇒ ::Integer
Returns [Output Only] Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_used_iops ⇒ ::Integer
Returns [Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity. For more information, see https://cloud.google.com/compute/docs/disks/storage-pools.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_used_throughput ⇒ ::Integer
Returns [Output Only] Sum of all the disks' provisioned throughput in MB/s.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_user_written_bytes ⇒ ::Integer
Returns [Output Only] Amount of data written into the pool, before it is compacted.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_provisioned_disk_capacity_gb ⇒ ::Integer
Returns [Output Only] Sum of all the capacity provisioned in disks in this storage pool. A disk's provisioned capacity is the same as its total capacity.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_provisioned_disk_iops ⇒ ::Integer
Returns [Output Only] Sum of all the disks' provisioned IOPS.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_provisioned_disk_throughput ⇒ ::Integer
Returns [Output Only] Sum of all the disks' provisioned throughput in MB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
34062 34063 34064 34065 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34062 class StoragePoolResourceStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |