Class: Google::Cloud::Compute::V1::SubnetworkLogConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The available logging options for this subnetwork.

Defined Under Namespace

Modules: AggregationInterval, Metadata

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_interval::String

Returns Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. Check the AggregationInterval enum for the list of possible values.

Returns:

  • (::String)

    Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. Check the AggregationInterval enum for the list of possible values.



77549
77550
77551
77552
77553
77554
77555
77556
77557
77558
77559
77560
77561
77562
77563
77564
77565
77566
77567
77568
77569
77570
77571
77572
77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77549

class SubnetworkLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Can only be specified if VPC flow logging for this subnetwork is enabled.
  # Toggles the aggregation interval for collecting flow logs. Increasing the
  # interval time will reduce the amount of generated flow logs for long
  # lasting connections. Default is an interval of 5 seconds per connection.
  module AggregationInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_AGGREGATION_INTERVAL = 0

    INTERVAL_10_MIN = 487_155_916

    INTERVAL_15_MIN = 491_773_521

    INTERVAL_1_MIN = 69_052_714

    INTERVAL_30_SEC = 7_548_937

    INTERVAL_5_MIN = 72_746_798

    INTERVAL_5_SEC = 72_752_429
  end

  # Can only be specified if VPC flow logs for this subnetwork is enabled.
  # Configures whether all, none or a subset of metadata fields should be
  # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA.
  module Metadata
    # A value indicating that the enum field is not set.
    UNDEFINED_METADATA = 0

    CUSTOM_METADATA = 62_450_749

    EXCLUDE_ALL_METADATA = 334_519_954

    INCLUDE_ALL_METADATA = 164_619_908
  end
end

#enable::Boolean

Returns Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. Flow logging isn't supported if the subnet purpose field is set to REGIONAL_MANAGED_PROXY.

Returns:

  • (::Boolean)

    Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. Flow logging isn't supported if the subnet purpose field is set to REGIONAL_MANAGED_PROXY.



77549
77550
77551
77552
77553
77554
77555
77556
77557
77558
77559
77560
77561
77562
77563
77564
77565
77566
77567
77568
77569
77570
77571
77572
77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77549

class SubnetworkLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Can only be specified if VPC flow logging for this subnetwork is enabled.
  # Toggles the aggregation interval for collecting flow logs. Increasing the
  # interval time will reduce the amount of generated flow logs for long
  # lasting connections. Default is an interval of 5 seconds per connection.
  module AggregationInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_AGGREGATION_INTERVAL = 0

    INTERVAL_10_MIN = 487_155_916

    INTERVAL_15_MIN = 491_773_521

    INTERVAL_1_MIN = 69_052_714

    INTERVAL_30_SEC = 7_548_937

    INTERVAL_5_MIN = 72_746_798

    INTERVAL_5_SEC = 72_752_429
  end

  # Can only be specified if VPC flow logs for this subnetwork is enabled.
  # Configures whether all, none or a subset of metadata fields should be
  # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA.
  module Metadata
    # A value indicating that the enum field is not set.
    UNDEFINED_METADATA = 0

    CUSTOM_METADATA = 62_450_749

    EXCLUDE_ALL_METADATA = 334_519_954

    INCLUDE_ALL_METADATA = 164_619_908
  end
end

#filter_expr::String

Returns Can only be specified if VPC flow logs for this subnetwork is enabled. The filter expression is used to define which VPC flow logs should be exported to Cloud Logging.

Returns:

  • (::String)

    Can only be specified if VPC flow logs for this subnetwork is enabled. The filter expression is used to define which VPC flow logs should be exported to Cloud Logging.



77549
77550
77551
77552
77553
77554
77555
77556
77557
77558
77559
77560
77561
77562
77563
77564
77565
77566
77567
77568
77569
77570
77571
77572
77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77549

class SubnetworkLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Can only be specified if VPC flow logging for this subnetwork is enabled.
  # Toggles the aggregation interval for collecting flow logs. Increasing the
  # interval time will reduce the amount of generated flow logs for long
  # lasting connections. Default is an interval of 5 seconds per connection.
  module AggregationInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_AGGREGATION_INTERVAL = 0

    INTERVAL_10_MIN = 487_155_916

    INTERVAL_15_MIN = 491_773_521

    INTERVAL_1_MIN = 69_052_714

    INTERVAL_30_SEC = 7_548_937

    INTERVAL_5_MIN = 72_746_798

    INTERVAL_5_SEC = 72_752_429
  end

  # Can only be specified if VPC flow logs for this subnetwork is enabled.
  # Configures whether all, none or a subset of metadata fields should be
  # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA.
  module Metadata
    # A value indicating that the enum field is not set.
    UNDEFINED_METADATA = 0

    CUSTOM_METADATA = 62_450_749

    EXCLUDE_ALL_METADATA = 334_519_954

    INCLUDE_ALL_METADATA = 164_619_908
  end
end

#flow_sampling::Float

Returns Can only be specified if VPC flow logging for this subnetwork is enabled. The value of the field must be in [0, 1]. Set the sampling rate of VPC flow logs within the subnetwork where 1.0 means all collected logs are reported and 0.0 means no logs are reported. Default is 0.5 unless otherwise specified by the org policy, which means half of all collected logs are reported.

Returns:

  • (::Float)

    Can only be specified if VPC flow logging for this subnetwork is enabled. The value of the field must be in [0, 1]. Set the sampling rate of VPC flow logs within the subnetwork where 1.0 means all collected logs are reported and 0.0 means no logs are reported. Default is 0.5 unless otherwise specified by the org policy, which means half of all collected logs are reported.



77549
77550
77551
77552
77553
77554
77555
77556
77557
77558
77559
77560
77561
77562
77563
77564
77565
77566
77567
77568
77569
77570
77571
77572
77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77549

class SubnetworkLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Can only be specified if VPC flow logging for this subnetwork is enabled.
  # Toggles the aggregation interval for collecting flow logs. Increasing the
  # interval time will reduce the amount of generated flow logs for long
  # lasting connections. Default is an interval of 5 seconds per connection.
  module AggregationInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_AGGREGATION_INTERVAL = 0

    INTERVAL_10_MIN = 487_155_916

    INTERVAL_15_MIN = 491_773_521

    INTERVAL_1_MIN = 69_052_714

    INTERVAL_30_SEC = 7_548_937

    INTERVAL_5_MIN = 72_746_798

    INTERVAL_5_SEC = 72_752_429
  end

  # Can only be specified if VPC flow logs for this subnetwork is enabled.
  # Configures whether all, none or a subset of metadata fields should be
  # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA.
  module Metadata
    # A value indicating that the enum field is not set.
    UNDEFINED_METADATA = 0

    CUSTOM_METADATA = 62_450_749

    EXCLUDE_ALL_METADATA = 334_519_954

    INCLUDE_ALL_METADATA = 164_619_908
  end
end

#metadata::String

Returns Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. Check the Metadata enum for the list of possible values.

Returns:

  • (::String)

    Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. Check the Metadata enum for the list of possible values.



77549
77550
77551
77552
77553
77554
77555
77556
77557
77558
77559
77560
77561
77562
77563
77564
77565
77566
77567
77568
77569
77570
77571
77572
77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77549

class SubnetworkLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Can only be specified if VPC flow logging for this subnetwork is enabled.
  # Toggles the aggregation interval for collecting flow logs. Increasing the
  # interval time will reduce the amount of generated flow logs for long
  # lasting connections. Default is an interval of 5 seconds per connection.
  module AggregationInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_AGGREGATION_INTERVAL = 0

    INTERVAL_10_MIN = 487_155_916

    INTERVAL_15_MIN = 491_773_521

    INTERVAL_1_MIN = 69_052_714

    INTERVAL_30_SEC = 7_548_937

    INTERVAL_5_MIN = 72_746_798

    INTERVAL_5_SEC = 72_752_429
  end

  # Can only be specified if VPC flow logs for this subnetwork is enabled.
  # Configures whether all, none or a subset of metadata fields should be
  # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA.
  module Metadata
    # A value indicating that the enum field is not set.
    UNDEFINED_METADATA = 0

    CUSTOM_METADATA = 62_450_749

    EXCLUDE_ALL_METADATA = 334_519_954

    INCLUDE_ALL_METADATA = 164_619_908
  end
end

#metadata_fields::Array<::String>

Returns Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" was set to CUSTOM_METADATA.

Returns:

  • (::Array<::String>)

    Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" was set to CUSTOM_METADATA.



77549
77550
77551
77552
77553
77554
77555
77556
77557
77558
77559
77560
77561
77562
77563
77564
77565
77566
77567
77568
77569
77570
77571
77572
77573
77574
77575
77576
77577
77578
77579
77580
77581
77582
77583
77584
77585
77586
77587
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77549

class SubnetworkLogConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Can only be specified if VPC flow logging for this subnetwork is enabled.
  # Toggles the aggregation interval for collecting flow logs. Increasing the
  # interval time will reduce the amount of generated flow logs for long
  # lasting connections. Default is an interval of 5 seconds per connection.
  module AggregationInterval
    # A value indicating that the enum field is not set.
    UNDEFINED_AGGREGATION_INTERVAL = 0

    INTERVAL_10_MIN = 487_155_916

    INTERVAL_15_MIN = 491_773_521

    INTERVAL_1_MIN = 69_052_714

    INTERVAL_30_SEC = 7_548_937

    INTERVAL_5_MIN = 72_746_798

    INTERVAL_5_SEC = 72_752_429
  end

  # Can only be specified if VPC flow logs for this subnetwork is enabled.
  # Configures whether all, none or a subset of metadata fields should be
  # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA.
  module Metadata
    # A value indicating that the enum field is not set.
    UNDEFINED_METADATA = 0

    CUSTOM_METADATA = 62_450_749

    EXCLUDE_ALL_METADATA = 334_519_954

    INCLUDE_ALL_METADATA = 164_619_908
  end
end