Class: Google::Cloud::Compute::V1::SubnetworkLogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SubnetworkLogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The available logging options for this subnetwork.
Defined Under Namespace
Modules: AggregationInterval, Metadata
Instance Attribute Summary collapse
-
#aggregation_interval ⇒ ::String
Can only be specified if VPC flow logging for this subnetwork is enabled.
-
#enable ⇒ ::Boolean
Whether to enable flow logging for this subnetwork.
-
#filter_expr ⇒ ::String
Can only be specified if VPC flow logs for this subnetwork is enabled.
-
#flow_sampling ⇒ ::Float
Can only be specified if VPC flow logging for this subnetwork is enabled.
-
#metadata ⇒ ::String
Can only be specified if VPC flow logs for this subnetwork is enabled.
-
#metadata_fields ⇒ ::Array<::String>
Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" was set to CUSTOM_METADATA.
Instance Attribute Details
#aggregation_interval ⇒ ::String
Returns Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. Check the AggregationInterval enum for the list of possible values.
75850 75851 75852 75853 75854 75855 75856 75857 75858 75859 75860 75861 75862 75863 75864 75865 75866 75867 75868 75869 75870 75871 75872 75873 75874 75875 75876 75877 75878 75879 75880 75881 75882 75883 75884 75885 75886 75887 75888 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75850 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. # Toggles the aggregation interval for collecting flow logs. Increasing the # interval time will reduce the amount of generated flow logs for long # lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. # Configures whether all, none or a subset of metadata fields should be # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#enable ⇒ ::Boolean
Returns Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. Flow logging isn't supported if the subnet purpose field is set to REGIONAL_MANAGED_PROXY.
75850 75851 75852 75853 75854 75855 75856 75857 75858 75859 75860 75861 75862 75863 75864 75865 75866 75867 75868 75869 75870 75871 75872 75873 75874 75875 75876 75877 75878 75879 75880 75881 75882 75883 75884 75885 75886 75887 75888 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75850 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. # Toggles the aggregation interval for collecting flow logs. Increasing the # interval time will reduce the amount of generated flow logs for long # lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. # Configures whether all, none or a subset of metadata fields should be # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#filter_expr ⇒ ::String
Returns Can only be specified if VPC flow logs for this subnetwork is enabled. The filter expression is used to define which VPC flow logs should be exported to Cloud Logging.
75850 75851 75852 75853 75854 75855 75856 75857 75858 75859 75860 75861 75862 75863 75864 75865 75866 75867 75868 75869 75870 75871 75872 75873 75874 75875 75876 75877 75878 75879 75880 75881 75882 75883 75884 75885 75886 75887 75888 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75850 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. # Toggles the aggregation interval for collecting flow logs. Increasing the # interval time will reduce the amount of generated flow logs for long # lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. # Configures whether all, none or a subset of metadata fields should be # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#flow_sampling ⇒ ::Float
Returns Can only be specified if VPC flow logging for this subnetwork is enabled. The value of the field must be in [0, 1]. Set the sampling rate of VPC flow logs within the subnetwork where 1.0 means all collected logs are reported and 0.0 means no logs are reported. Default is 0.5 unless otherwise specified by the org policy, which means half of all collected logs are reported.
75850 75851 75852 75853 75854 75855 75856 75857 75858 75859 75860 75861 75862 75863 75864 75865 75866 75867 75868 75869 75870 75871 75872 75873 75874 75875 75876 75877 75878 75879 75880 75881 75882 75883 75884 75885 75886 75887 75888 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75850 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. # Toggles the aggregation interval for collecting flow logs. Increasing the # interval time will reduce the amount of generated flow logs for long # lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. # Configures whether all, none or a subset of metadata fields should be # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#metadata ⇒ ::String
Returns Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. Check the Metadata enum for the list of possible values.
75850 75851 75852 75853 75854 75855 75856 75857 75858 75859 75860 75861 75862 75863 75864 75865 75866 75867 75868 75869 75870 75871 75872 75873 75874 75875 75876 75877 75878 75879 75880 75881 75882 75883 75884 75885 75886 75887 75888 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75850 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. # Toggles the aggregation interval for collecting flow logs. Increasing the # interval time will reduce the amount of generated flow logs for long # lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. # Configures whether all, none or a subset of metadata fields should be # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#metadata_fields ⇒ ::Array<::String>
Returns Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" was set to CUSTOM_METADATA.
75850 75851 75852 75853 75854 75855 75856 75857 75858 75859 75860 75861 75862 75863 75864 75865 75866 75867 75868 75869 75870 75871 75872 75873 75874 75875 75876 75877 75878 75879 75880 75881 75882 75883 75884 75885 75886 75887 75888 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75850 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. # Toggles the aggregation interval for collecting flow logs. Increasing the # interval time will reduce the amount of generated flow logs for long # lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. # Configures whether all, none or a subset of metadata fields should be # added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |