Class: Google::Cloud::Compute::V1::SubnetworkLogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SubnetworkLogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The available logging options for this subnetwork.
Defined Under Namespace
Modules: AggregationInterval, Metadata
Instance Attribute Summary collapse
-
#aggregation_interval ⇒ ::String
Can only be specified if VPC flow logging for this subnetwork is enabled.
-
#enable ⇒ ::Boolean
Whether to enable flow logging for this subnetwork.
-
#filter_expr ⇒ ::String
Can only be specified if VPC flow logs for this subnetwork is enabled.
-
#flow_sampling ⇒ ::Float
Can only be specified if VPC flow logging for this subnetwork is enabled.
-
#metadata ⇒ ::String
Can only be specified if VPC flow logs for this subnetwork is enabled.
-
#metadata_fields ⇒ ::Array<::String>
Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" was set to CUSTOM_METADATA.
Instance Attribute Details
#aggregation_interval ⇒ ::String
34485 34486 34487 34488 34489 34490 34491 34492 34493 34494 34495 34496 34497 34498 34499 34500 34501 34502 34503 34504 34505 34506 34507 34508 34509 34510 34511 34512 34513 34514 34515 34516 34517 34518 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34485 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#enable ⇒ ::Boolean
34485 34486 34487 34488 34489 34490 34491 34492 34493 34494 34495 34496 34497 34498 34499 34500 34501 34502 34503 34504 34505 34506 34507 34508 34509 34510 34511 34512 34513 34514 34515 34516 34517 34518 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34485 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#filter_expr ⇒ ::String
34485 34486 34487 34488 34489 34490 34491 34492 34493 34494 34495 34496 34497 34498 34499 34500 34501 34502 34503 34504 34505 34506 34507 34508 34509 34510 34511 34512 34513 34514 34515 34516 34517 34518 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34485 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#flow_sampling ⇒ ::Float
34485 34486 34487 34488 34489 34490 34491 34492 34493 34494 34495 34496 34497 34498 34499 34500 34501 34502 34503 34504 34505 34506 34507 34508 34509 34510 34511 34512 34513 34514 34515 34516 34517 34518 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34485 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#metadata ⇒ ::String
34485 34486 34487 34488 34489 34490 34491 34492 34493 34494 34495 34496 34497 34498 34499 34500 34501 34502 34503 34504 34505 34506 34507 34508 34509 34510 34511 34512 34513 34514 34515 34516 34517 34518 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34485 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |
#metadata_fields ⇒ ::Array<::String>
34485 34486 34487 34488 34489 34490 34491 34492 34493 34494 34495 34496 34497 34498 34499 34500 34501 34502 34503 34504 34505 34506 34507 34508 34509 34510 34511 34512 34513 34514 34515 34516 34517 34518 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34485 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487_155_916 INTERVAL_15_MIN = 491_773_521 INTERVAL_1_MIN = 69_052_714 INTERVAL_30_SEC = 7_548_937 INTERVAL_5_MIN = 72_746_798 INTERVAL_5_SEC = 72_752_429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62_450_749 EXCLUDE_ALL_METADATA = 334_519_954 INCLUDE_ALL_METADATA = 164_619_908 end end |