Class: Google::Cloud::Compute::V1::SubnetworkLogConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::SubnetworkLogConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The available logging options for this subnetwork.
Defined Under Namespace
Modules: AggregationInterval, Metadata
Instance Attribute Summary collapse
-
#aggregation_interval ⇒ ::String
Can only be specified if VPC flow logging for this subnetwork is enabled.
-
#enable ⇒ ::Boolean
Whether to enable flow logging for this subnetwork.
-
#filter_expr ⇒ ::String
Can only be specified if VPC flow logs for this subnetwork is enabled.
-
#flow_sampling ⇒ ::Float
Can only be specified if VPC flow logging for this subnetwork is enabled.
-
#metadata ⇒ ::String
Can only be specified if VPC flow logs for this subnetwork is enabled.
-
#metadata_fields ⇒ ::Array<::String>
Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" was set to CUSTOM_METADATA.
Instance Attribute Details
#aggregation_interval ⇒ ::String
Returns Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. Check the AggregationInterval enum for the list of possible values.
28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 28093 28094 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28061 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487155916 INTERVAL_15_MIN = 491773521 INTERVAL_1_MIN = 69052714 INTERVAL_30_SEC = 7548937 INTERVAL_5_MIN = 72746798 INTERVAL_5_SEC = 72752429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62450749 EXCLUDE_ALL_METADATA = 334519954 INCLUDE_ALL_METADATA = 164619908 end end |
#enable ⇒ ::Boolean
Returns Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled.
28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 28093 28094 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28061 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487155916 INTERVAL_15_MIN = 491773521 INTERVAL_1_MIN = 69052714 INTERVAL_30_SEC = 7548937 INTERVAL_5_MIN = 72746798 INTERVAL_5_SEC = 72752429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62450749 EXCLUDE_ALL_METADATA = 334519954 INCLUDE_ALL_METADATA = 164619908 end end |
#filter_expr ⇒ ::String
Returns Can only be specified if VPC flow logs for this subnetwork is enabled. The filter expression is used to define which VPC flow logs should be exported to Cloud Logging.
28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 28093 28094 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28061 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487155916 INTERVAL_15_MIN = 491773521 INTERVAL_1_MIN = 69052714 INTERVAL_30_SEC = 7548937 INTERVAL_5_MIN = 72746798 INTERVAL_5_SEC = 72752429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62450749 EXCLUDE_ALL_METADATA = 334519954 INCLUDE_ALL_METADATA = 164619908 end end |
#flow_sampling ⇒ ::Float
Returns Can only be specified if VPC flow logging for this subnetwork is enabled. The value of the field must be in [0, 1]. Set the sampling rate of VPC flow logs within the subnetwork where 1.0 means all collected logs are reported and 0.0 means no logs are reported. Default is 0.5 unless otherwise specified by the org policy, which means half of all collected logs are reported.
28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 28093 28094 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28061 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487155916 INTERVAL_15_MIN = 491773521 INTERVAL_1_MIN = 69052714 INTERVAL_30_SEC = 7548937 INTERVAL_5_MIN = 72746798 INTERVAL_5_SEC = 72752429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62450749 EXCLUDE_ALL_METADATA = 334519954 INCLUDE_ALL_METADATA = 164619908 end end |
#metadata ⇒ ::String
Returns Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. Check the Metadata enum for the list of possible values.
28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 28093 28094 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28061 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487155916 INTERVAL_15_MIN = 491773521 INTERVAL_1_MIN = 69052714 INTERVAL_30_SEC = 7548937 INTERVAL_5_MIN = 72746798 INTERVAL_5_SEC = 72752429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62450749 EXCLUDE_ALL_METADATA = 334519954 INCLUDE_ALL_METADATA = 164619908 end end |
#metadata_fields ⇒ ::Array<::String>
Returns Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" was set to CUSTOM_METADATA.
28061 28062 28063 28064 28065 28066 28067 28068 28069 28070 28071 28072 28073 28074 28075 28076 28077 28078 28079 28080 28081 28082 28083 28084 28085 28086 28087 28088 28089 28090 28091 28092 28093 28094 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 28061 class SubnetworkLogConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. module AggregationInterval # A value indicating that the enum field is not set. UNDEFINED_AGGREGATION_INTERVAL = 0 INTERVAL_10_MIN = 487155916 INTERVAL_15_MIN = 491773521 INTERVAL_1_MIN = 69052714 INTERVAL_30_SEC = 7548937 INTERVAL_5_MIN = 72746798 INTERVAL_5_SEC = 72752429 end # Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA. module Metadata # A value indicating that the enum field is not set. UNDEFINED_METADATA = 0 CUSTOM_METADATA = 62450749 EXCLUDE_ALL_METADATA = 334519954 INCLUDE_ALL_METADATA = 164619908 end end |