Class: Google::Cloud::Compute::V1::SubnetworkSecondaryRange

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a secondary IP range of a subnetwork.

Instance Attribute Summary collapse

Instance Attribute Details

#ip_cidr_range::String

Returns The range of IP addresses belonging to this subnetwork secondary range. Provide this property when you create the subnetwork. Ranges must be unique and non-overlapping with all primary and secondary IP ranges within a network. Both IPv4 and IPv6 ranges are supported. For IPv4, the range can be any range listed in theValid ranges list.

For IPv6: The range must have a /64 prefix length. The range must be omitted, for auto-allocation from Google-defined ULA IPv6 range. For BYOGUA internal IPv6 secondary range, the range may be specified along with the ipCollection field. If an ipCollection is specified, the requested ip_cidr_range must lie within the range of the PDP referenced by the ipCollection field for allocation. If ipCollection field is specified, but ip_cidr_range is not, the range is auto-allocated from the PDP referenced by the ipCollection field.

Returns:

  • (::String)

    The range of IP addresses belonging to this subnetwork secondary range. Provide this property when you create the subnetwork. Ranges must be unique and non-overlapping with all primary and secondary IP ranges within a network. Both IPv4 and IPv6 ranges are supported. For IPv4, the range can be any range listed in theValid ranges list.

    For IPv6: The range must have a /64 prefix length. The range must be omitted, for auto-allocation from Google-defined ULA IPv6 range. For BYOGUA internal IPv6 secondary range, the range may be specified along with the ipCollection field. If an ipCollection is specified, the requested ip_cidr_range must lie within the range of the PDP referenced by the ipCollection field for allocation. If ipCollection field is specified, but ip_cidr_range is not, the range is auto-allocated from the PDP referenced by the ipCollection field.



75950
75951
75952
75953
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75950

class SubnetworkSecondaryRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#range_name::String

Returns The name associated with this subnetwork secondary range, used when adding an alias IP/IPv6 range to a VM instance. The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the subnetwork.

Returns:

  • (::String)

    The name associated with this subnetwork secondary range, used when adding an alias IP/IPv6 range to a VM instance. The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the subnetwork.



75950
75951
75952
75953
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75950

class SubnetworkSecondaryRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reserved_internal_range::String

Returns The URL of the reserved internal range. Only IPv4 is supported.

Returns:

  • (::String)

    The URL of the reserved internal range. Only IPv4 is supported.



75950
75951
75952
75953
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 75950

class SubnetworkSecondaryRange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end