Class: Google::Cloud::Compute::V1::Subsetting
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Subsetting
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director.
Defined Under Namespace
Modules: Policy
Instance Attribute Summary collapse
-
#policy ⇒ ::String
Check the Policy enum for the list of possible values.
Instance Attribute Details
#policy ⇒ ::String
Returns Check the Policy enum for the list of possible values.
78618 78619 78620 78621 78622 78623 78624 78625 78626 78627 78628 78629 78630 78631 78632 78633 78634 78635 78636 78637 78638 78639 78640 78641 78642 78643 78644 78645 78646 78647 78648 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78618 class Subsetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Subsetting based on consistent hashing. # # For Traffic Director, the number of backends per backend group # (the subset size) is based on the `subset_size` parameter. # # For Internal HTTP(S) load balancing, the number of backends per backend # group (the subset size) is dynamically adjusted in two cases: # - As the number of proxy instances participating in Internal HTTP(S) load # balancing increases, the subset size decreases. # - When the total number of backends in a network exceeds the capacity of # a single proxy instance, subset sizes are reduced automatically for # each service that has backend subsetting enabled. CONSISTENT_HASH_SUBSETTING = 108_989_492 # No Subsetting. # # Clients may open connections and send traffic to all backends of this # backend service. This can lead to performance issues if there is # substantial imbalance in the count of clients and backends. NONE = 2_402_104 end end |