Class: Google::Cloud::Compute::V1::Subsetting
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Subsetting
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director.
Defined Under Namespace
Modules: Policy
Instance Attribute Summary collapse
-
#policy ⇒ ::String
Check the Policy enum for the list of possible values.
Instance Attribute Details
#policy ⇒ ::String
Returns Check the Policy enum for the list of possible values.
77744 77745 77746 77747 77748 77749 77750 77751 77752 77753 77754 77755 77756 77757 77758 77759 77760 77761 77762 77763 77764 77765 77766 77767 77768 77769 77770 77771 77772 77773 77774 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77744 class Subsetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Subsetting based on consistent hashing. # # For Traffic Director, the number of backends per backend group # (the subset size) is based on the `subset_size` parameter. # # For Internal HTTP(S) load balancing, the number of backends per backend # group (the subset size) is dynamically adjusted in two cases: # - As the number of proxy instances participating in Internal HTTP(S) load # balancing increases, the subset size decreases. # - When the total number of backends in a network exceeds the capacity of # a single proxy instance, subset sizes are reduced automatically for # each service that has backend subsetting enabled. CONSISTENT_HASH_SUBSETTING = 108_989_492 # No Subsetting. # # Clients may open connections and send traffic to all backends of this # backend service. This can lead to performance issues if there is # substantial imbalance in the count of clients and backends. NONE = 2_402_104 end end |