Class: Google::Cloud::Compute::V1::Subsetting
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Subsetting
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director.
Defined Under Namespace
Modules: Policy
Instance Attribute Summary collapse
-
#policy ⇒ ::String
Check the Policy enum for the list of possible values.
Instance Attribute Details
#policy ⇒ ::String
Returns Check the Policy enum for the list of possible values.
34604 34605 34606 34607 34608 34609 34610 34611 34612 34613 34614 34615 34616 34617 34618 34619 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34604 class Subsetting include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module Policy # A value indicating that the enum field is not set. UNDEFINED_POLICY = 0 # Subsetting based on consistent hashing. For Traffic Director, the number of backends per backend group (the subset size) is based on the `subset_size` parameter. For Internal HTTP(S) load balancing, the number of backends per backend group (the subset size) is dynamically adjusted in two cases: - As the number of proxy instances participating in Internal HTTP(S) load balancing increases, the subset size decreases. - When the total number of backends in a network exceeds the capacity of a single proxy instance, subset sizes are reduced automatically for each service that has backend subsetting enabled. CONSISTENT_HASH_SUBSETTING = 108_989_492 # No Subsetting. Clients may open connections and send traffic to all backends of this backend service. This can lead to performance issues if there is substantial imbalance in the count of clients and backends. NONE = 2_402_104 end end |