Class: Google::Cloud::Compute::V1::TargetGrpcProxy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Target gRPC Proxy resource. A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic. Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String



34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String



34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#fingerprint::String



34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id::Integer



34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#kind::String



34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String



34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end


34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end


34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#url_map::String



34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_for_proxyless::Boolean



34753
34754
34755
34756
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753

class TargetGrpcProxy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end