Class: Google::Cloud::Compute::V1::TargetGrpcProxy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetGrpcProxy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Target gRPC Proxy resource. A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic. Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ ::String
An optional description of this resource.
-
#fingerprint ⇒ ::String
Fingerprint of this resource.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource type.
-
#kind ⇒ ::String
[Output Only] Type of the resource.
-
#name ⇒ ::String
Name of the resource.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#self_link_with_id ⇒ ::String
[Output Only] Server-defined URL with id for the resource.
-
#url_map ⇒ ::String
URL to the UrlMap resource that defines the mapping from URL to the BackendService.
-
#validate_for_proxyless ⇒ ::Boolean
If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy.
Instance Attribute Details
#creation_timestamp ⇒ ::String
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fingerprint ⇒ ::String
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::Integer
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link_with_id ⇒ ::String
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#url_map ⇒ ::String
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_for_proxyless ⇒ ::Boolean
34753 34754 34755 34756 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34753 class TargetGrpcProxy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |