Class: Google::Cloud::Compute::V1::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Classes: ItemsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#id::String

Returns [Output Only] Unique identifier for the resource; defined by the server.

Returns:

  • (::String)

    [Output Only] Unique identifier for the resource; defined by the server.



35384
35385
35386
35387
35388
35389
35390
35391
35392
35393
35394
35395
35396
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35384

class TargetHttpProxyAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#items::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList}

Returns A list of TargetHttpProxiesScopedList resources.

Returns:



35384
35385
35386
35387
35388
35389
35390
35391
35392
35393
35394
35395
35396
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35384

class TargetHttpProxyAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#kind::String

Returns [Output Only] Type of resource. Always compute#targetHttpProxyAggregatedList for lists of Target HTTP Proxies.

Returns:

  • (::String)

    [Output Only] Type of resource. Always compute#targetHttpProxyAggregatedList for lists of Target HTTP Proxies.



35384
35385
35386
35387
35388
35389
35390
35391
35392
35393
35394
35395
35396
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35384

class TargetHttpProxyAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.

Returns:

  • (::String)

    [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.



35384
35385
35386
35387
35388
35389
35390
35391
35392
35393
35394
35395
35396
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35384

class TargetHttpProxyAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns [Output Only] Server-defined URL for this resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for this resource.



35384
35385
35386
35387
35388
35389
35390
35391
35392
35393
35394
35395
35396
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35384

class TargetHttpProxyAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unreachables::Array<::String>

Returns [Output Only] Unreachable resources.

Returns:

  • (::Array<::String>)

    [Output Only] Unreachable resources.



35384
35385
35386
35387
35388
35389
35390
35391
35392
35393
35394
35395
35396
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35384

class TargetHttpProxyAggregatedList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList]
  class ItemsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end