Class: Google::Cloud::Compute::V1::TargetHttpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetHttpProxyAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList}
A list of TargetHttpProxiesScopedList resources.
-
#kind ⇒ ::String
[Output Only] Type of resource.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ ::Array<::String>
[Output Only] Unreachable resources.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
34858 34859 34860 34861 34862 34863 34864 34865 34866 34867 34868 34869 34870 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34858 class TargetHttpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList}
Returns A list of TargetHttpProxiesScopedList resources.
34858 34859 34860 34861 34862 34863 34864 34865 34866 34867 34868 34869 34870 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34858 class TargetHttpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns [Output Only] Type of resource. Always compute#targetHttpProxyAggregatedList for lists of Target HTTP Proxies.
34858 34859 34860 34861 34862 34863 34864 34865 34866 34867 34868 34869 34870 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34858 class TargetHttpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
34858 34859 34860 34861 34862 34863 34864 34865 34866 34867 34868 34869 34870 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34858 class TargetHttpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for this resource.
34858 34859 34860 34861 34862 34863 34864 34865 34866 34867 34868 34869 34870 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34858 class TargetHttpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns [Output Only] Unreachable resources.
34858 34859 34860 34861 34862 34863 34864 34865 34866 34867 34868 34869 34870 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 34858 class TargetHttpProxyAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::TargetHttpProxiesScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |