Class: Google::Cloud::Compute::V1::TargetInstance

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Target Instance resource. You can use a target instance to handle traffic for one or more forwarding rules, which is ideal for forwarding protocol traffic that is managed by a single source. For example, ESP, AH, TCP, or UDP. For more information, read Target instances.

Defined Under Namespace

Modules: NatPolicy

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timestamp::String



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end

#description::String



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end

#id::Integer



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end

#instance::String



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end

#kind::String



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end

#name::String



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end

#nat_policy::String



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end

#network::String



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end

#security_policy::String



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end


35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end

#zone::String



35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
35673
35674
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35662

class TargetInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Must have a value of NO_NAT. Protocol forwarding delivers packets while preserving the destination IP address of the forwarding rule referencing the target instance.
  module NatPolicy
    # A value indicating that the enum field is not set.
    UNDEFINED_NAT_POLICY = 0

    # No NAT performed.
    NO_NAT = 161_455_491
  end
end