Class: Google::Cloud::Compute::V1::TargetPool
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetPool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Target Pool resource.
Target pools are used with external passthrough Network Load Balancers. A target pool references member instances, an associated legacy HttpHealthCheck resource, and, optionally, a backup target pool. For more information, readUsing target pools.
Defined Under Namespace
Modules: SessionAffinity
Instance Attribute Summary collapse
-
#backup_pool ⇒ ::String
The server-defined URL for the resource.
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#failover_ratio ⇒ ::Float
This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool).
-
#health_checks ⇒ ::Array<::String>
The URL of the HttpHealthCheck resource.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#instances ⇒ ::Array<::String>
A list of resource URLs to the virtual machine instances serving this pool.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
Name of the resource.
-
#region ⇒ ::String
Output only.
-
#security_policy ⇒ ::String
[Output Only] The resource URL for the security policy associated with this target pool.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#session_affinity ⇒ ::String
Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool.
Instance Attribute Details
#backup_pool ⇒ ::String
Returns The server-defined URL for the resource. This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool, and its failoverRatio field is properly set to a value between [0, 1].backupPool and failoverRatio together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or belowfailoverRatio, traffic arriving at the load-balanced IP will be directed to the backup pool.
In case where failoverRatio and backupPool are not set, or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the "force" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#failover_ratio ⇒ ::Float
Returns This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool). The value of the field must be in [0, 1].
If set, backupPool must also be set. They together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below this number, traffic arriving at the load-balanced IP will be directed to the backup pool.
In case where failoverRatio is not set or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the "force" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#health_checks ⇒ ::Array<::String>
Returns The URL of the HttpHealthCheck resource. A member instance in this pool is considered healthy if and only if the health checks pass. Only legacy HttpHealthChecks are supported. Only one health check may be specified.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#instances ⇒ ::Array<::String>
Returns A list of resource URLs to the virtual machine instances serving this pool. They must live in zones contained in the same region as this pool.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#targetPool for target pools.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#region ⇒ ::String
Returns Output only. [Output Only] URL of the region where the target pool resides.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#security_policy ⇒ ::String
Returns [Output Only] The resource URL for the security policy associated with this target pool.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#session_affinity ⇒ ::String
Returns Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. Check the SessionAffinity enum for the list of possible values.
78961 78962 78963 78964 78965 78966 78967 78968 78969 78970 78971 78972 78973 78974 78975 78976 78977 78978 78979 78980 78981 78982 78983 78984 78985 78986 78987 78988 78989 78990 78991 78992 78993 78994 78995 78996 78997 78998 78999 79000 79001 79002 79003 79004 79005 79006 79007 79008 79009 79010 79011 79012 79013 79014 79015 79016 79017 79018 79019 79020 79021 79022 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 78961 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: # NONE: Connections from the same client IP may go to any # instance in the pool. # CLIENT_IP: Connections from the same client IP will go # to the same instance in # the pool while that instance remains healthy. # CLIENT_IP_PROTO: Connections from the same client IP # with the same IP protocol will go to the same instance in the # pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections # from the same source IP address to the same destination IP address will be # served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the # same source IP address will be served by the same backend VM while that VM # remains healthy. This option can only be used for Internal TCP/UDP # Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, # and source and destination ports. Connections for the same IP protocol # from the same source IP address and port to the same destination IP address # and port will be served by the same backend VM while that VM remains # healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP # protocol. Connections for the same IP protocol from the same source IP # address to the same destination IP address will be served by the same # backend VM while that VM remains healthy. This option cannot be used for # HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. # Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go # to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be # served by the same backend VM while that VM remains healthy, as long as the # cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |