Class: Google::Cloud::Compute::V1::TargetPool
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetPool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Target Pool resource. Target pools are used with external passthrough Network Load Balancers. A target pool references member instances, an associated legacy HttpHealthCheck resource, and, optionally, a backup target pool. For more information, read Using target pools.
Defined Under Namespace
Modules: SessionAffinity
Instance Attribute Summary collapse
-
#backup_pool ⇒ ::String
The server-defined URL for the resource.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ ::String
An optional description of this resource.
-
#failover_ratio ⇒ ::Float
This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool).
-
#health_checks ⇒ ::Array<::String>
The URL of the HttpHealthCheck resource.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#instances ⇒ ::Array<::String>
A list of resource URLs to the virtual machine instances serving this pool.
-
#kind ⇒ ::String
[Output Only] Type of the resource.
-
#name ⇒ ::String
Name of the resource.
-
#region ⇒ ::String
[Output Only] URL of the region where the target pool resides.
-
#security_policy ⇒ ::String
[Output Only] The resource URL for the security policy associated with this target pool.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#session_affinity ⇒ ::String
Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool.
Instance Attribute Details
#backup_pool ⇒ ::String
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#creation_timestamp ⇒ ::String
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#description ⇒ ::String
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#failover_ratio ⇒ ::Float
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#health_checks ⇒ ::Array<::String>
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#id ⇒ ::Integer
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#instances ⇒ ::Array<::String>
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#kind ⇒ ::String
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#name ⇒ ::String
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#region ⇒ ::String
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#security_policy ⇒ ::String
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#self_link ⇒ ::String
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |
#session_affinity ⇒ ::String
35252 35253 35254 35255 35256 35257 35258 35259 35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 35285 35286 35287 35288 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 35252 class TargetPool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. module SessionAffinity # A value indicating that the enum field is not set. UNDEFINED_SESSION_AFFINITY = 0 # 2-tuple hash on packet's source and destination IP addresses. Connections from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. CLIENT_IP = 345_665_051 # 1-tuple hash only on packet's source IP address. Connections from the same source IP address will be served by the same backend VM while that VM remains healthy. This option can only be used for Internal TCP/UDP Load Balancing. CLIENT_IP_NO_DESTINATION = 106_122_516 # 5-tuple hash on packet's source and destination IP addresses, IP protocol, and source and destination ports. Connections for the same IP protocol from the same source IP address and port to the same destination IP address and port will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PORT_PROTO = 221_722_926 # 3-tuple hash on packet's source and destination IP addresses, and IP protocol. Connections for the same IP protocol from the same source IP address to the same destination IP address will be served by the same backend VM while that VM remains healthy. This option cannot be used for HTTP(S) load balancing. CLIENT_IP_PROTO = 25_322_148 # Hash based on a cookie generated by the L7 loadbalancer. Only valid for HTTP(S) load balancing. GENERATED_COOKIE = 370_321_204 # The hash is based on a user specified header field. HEADER_FIELD = 200_737_960 # The hash is based on a user provided cookie. HTTP_COOKIE = 494_981_627 # No session affinity. Connections from the same client IP may go to any instance in the pool. NONE = 2_402_104 # Strong cookie-based affinity. Connections bearing the same cookie will be served by the same backend VM while that VM remains healthy, as long as the cookie has not expired. STRONG_COOKIE_AFFINITY = 438_628_091 end end |