Class: Google::Cloud::Compute::V1::TargetSslProxiesSetProxyHeaderRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Defined Under Namespace

Modules: ProxyHeader

Instance Attribute Summary collapse

Instance Attribute Details

#proxy_header::String

Returns The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed. Check the ProxyHeader enum for the list of possible values.

Returns:

  • (::String)

    The new type of proxy header to append before sending data to the backend. NONE or PROXY_V1 are allowed. Check the ProxyHeader enum for the list of possible values.



77489
77490
77491
77492
77493
77494
77495
77496
77497
77498
77499
77500
77501
77502
77503
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 77489

class TargetSslProxiesSetProxyHeaderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The new type of proxy header to append before sending data to the
  # backend.  NONE or PROXY_V1 are allowed.
  module ProxyHeader
    # A value indicating that the enum field is not set.
    UNDEFINED_PROXY_HEADER = 0

    NONE = 2_402_104

    PROXY_V1 = 334_352_940
  end
end