Module: Google::Cloud::Compute::V1::TargetTcpProxy::LoadBalancingScheme
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Specifies the type of load balancing scheme used by this target proxy.
Constant Summary collapse
- UNDEFINED_LOAD_BALANCING_SCHEME =
A value indicating that the enum field is not set.
0- EXTERNAL =
35_607_499- EXTERNAL_MANAGED =
512_006_923- INTERNAL_MANAGED =
37_350_397- LOAD_BALANCING_SCHEME_UNSPECIFIED =
526_507_452