Class: Google::Cloud::Compute::V1::TargetVpnGateway
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::TargetVpnGateway
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Target VPN Gateway resource.
The target VPN gateway resource represents a Classic Cloud VPN gateway. For more information, read thethe Cloud VPN Overview.
Defined Under Namespace
Modules: Status Classes: LabelsEntry
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#forwarding_rules ⇒ ::Array<::String>
[Output Only] A list of URLs to the ForwardingRule resources.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
Output only.
-
#label_fingerprint ⇒ ::String
A fingerprint for the labels being applied to this TargetVpnGateway, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels for this resource.
-
#name ⇒ ::String
Name of the resource.
-
#network ⇒ ::String
URL of the network to which this VPN gateway is attached.
-
#params ⇒ ::Google::Cloud::Compute::V1::TargetVpnGatewayParams
Input only.
-
#region ⇒ ::String
[Output Only] URL of the region where the target VPN gateway resides.
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ ::String
[Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING.
-
#tunnels ⇒ ::Array<::String>
[Output Only] A list of URLs to VpnTunnel resources.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#description ⇒ ::String
Returns An optional description of this resource. Provide this property when you create the resource.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#forwarding_rules ⇒ ::Array<::String>
Returns [Output Only] A list of URLs to the ForwardingRule resources. ForwardingRules are created usingcompute.forwardingRules.insert and associated with a VPN gateway.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#label_fingerprint ⇒ ::String
Returns A fingerprint for the labels being applied to this TargetVpnGateway, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to retrieve a TargetVpnGateway.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#network ⇒ ::String
Returns URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#params ⇒ ::Google::Cloud::Compute::V1::TargetVpnGatewayParams
Returns Input only. [Input Only] Additional params passed with the request, but not persisted as part of resource payload.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#region ⇒ ::String
Returns [Output Only] URL of the region where the target VPN gateway resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#status ⇒ ::String
Returns [Output Only] The status of the VPN gateway, which can be one of the following: CREATING, READY, FAILED, or DELETING. Check the Status enum for the list of possible values.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |
#tunnels ⇒ ::Array<::String>
Returns [Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are created using the compute.vpntunnels.insert method and associated with a VPN gateway.
79581 79582 79583 79584 79585 79586 79587 79588 79589 79590 79591 79592 79593 79594 79595 79596 79597 79598 79599 79600 79601 79602 79603 79604 79605 79606 79607 79608 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79581 class TargetVpnGateway include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # [Output Only] The status of the VPN gateway, # which can be one of the following: CREATING, READY, FAILED, or DELETING. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 CREATING = 455_564_985 DELETING = 528_602_024 FAILED = 455_706_685 READY = 77_848_963 end end |