Class: Google::Cloud::Compute::V1::UpcomingMaintenance
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UpcomingMaintenance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Upcoming Maintenance notification information.
Defined Under Namespace
Modules: MaintenanceReasons, MaintenanceStatus, Type
Instance Attribute Summary collapse
-
#can_reschedule ⇒ ::Boolean
Indicates if the maintenance can be customer triggered.
-
#latest_window_start_time ⇒ ::String
The latest time for the planned maintenance window to start.
-
#maintenance_on_shutdown ⇒ ::Boolean
Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
-
#maintenance_reasons ⇒ ::Array<::String>
The reasons for the maintenance.
-
#maintenance_status ⇒ ::String
Check the MaintenanceStatus enum for the list of possible values.
-
#type ⇒ ::String
Defines the type of maintenance.
-
#window_end_time ⇒ ::String
The time by which the maintenance disruption will be completed.
-
#window_start_time ⇒ ::String
The current start time of the maintenance window.
Instance Attribute Details
#can_reschedule ⇒ ::Boolean
Returns Indicates if the maintenance can be customer triggered.
81688 81689 81690 81691 81692 81693 81694 81695 81696 81697 81698 81699 81700 81701 81702 81703 81704 81705 81706 81707 81708 81709 81710 81711 81712 81713 81714 81715 81716 81717 81718 81719 81720 81721 81722 81723 81724 81725 81726 81727 81728 81729 81730 81731 81732 81733 81734 81735 81736 81737 81738 81739 81740 81741 81742 81743 81744 81745 81746 81747 81748 81749 81750 81751 81752 81753 81754 81755 81756 81757 81758 81759 81760 81761 81762 81763 81764 81765 81766 81767 81768 81769 81770 81771 81772 81773 81774 81775 81776 81777 81778 81779 81780 81781 81782 81783 81784 81785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81688 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#latest_window_start_time ⇒ ::String
Returns The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format.
81688 81689 81690 81691 81692 81693 81694 81695 81696 81697 81698 81699 81700 81701 81702 81703 81704 81705 81706 81707 81708 81709 81710 81711 81712 81713 81714 81715 81716 81717 81718 81719 81720 81721 81722 81723 81724 81725 81726 81727 81728 81729 81730 81731 81732 81733 81734 81735 81736 81737 81738 81739 81740 81741 81742 81743 81744 81745 81746 81747 81748 81749 81750 81751 81752 81753 81754 81755 81756 81757 81758 81759 81760 81761 81762 81763 81764 81765 81766 81767 81768 81769 81770 81771 81772 81773 81774 81775 81776 81777 81778 81779 81780 81781 81782 81783 81784 81785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81688 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#maintenance_on_shutdown ⇒ ::Boolean
Returns Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
81688 81689 81690 81691 81692 81693 81694 81695 81696 81697 81698 81699 81700 81701 81702 81703 81704 81705 81706 81707 81708 81709 81710 81711 81712 81713 81714 81715 81716 81717 81718 81719 81720 81721 81722 81723 81724 81725 81726 81727 81728 81729 81730 81731 81732 81733 81734 81735 81736 81737 81738 81739 81740 81741 81742 81743 81744 81745 81746 81747 81748 81749 81750 81751 81752 81753 81754 81755 81756 81757 81758 81759 81760 81761 81762 81763 81764 81765 81766 81767 81768 81769 81770 81771 81772 81773 81774 81775 81776 81777 81778 81779 81780 81781 81782 81783 81784 81785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81688 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#maintenance_reasons ⇒ ::Array<::String>
Returns The reasons for the maintenance. Only valid for vms. Check the MaintenanceReasons enum for the list of possible values.
81688 81689 81690 81691 81692 81693 81694 81695 81696 81697 81698 81699 81700 81701 81702 81703 81704 81705 81706 81707 81708 81709 81710 81711 81712 81713 81714 81715 81716 81717 81718 81719 81720 81721 81722 81723 81724 81725 81726 81727 81728 81729 81730 81731 81732 81733 81734 81735 81736 81737 81738 81739 81740 81741 81742 81743 81744 81745 81746 81747 81748 81749 81750 81751 81752 81753 81754 81755 81756 81757 81758 81759 81760 81761 81762 81763 81764 81765 81766 81767 81768 81769 81770 81771 81772 81773 81774 81775 81776 81777 81778 81779 81780 81781 81782 81783 81784 81785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81688 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#maintenance_status ⇒ ::String
Returns Check the MaintenanceStatus enum for the list of possible values.
81688 81689 81690 81691 81692 81693 81694 81695 81696 81697 81698 81699 81700 81701 81702 81703 81704 81705 81706 81707 81708 81709 81710 81711 81712 81713 81714 81715 81716 81717 81718 81719 81720 81721 81722 81723 81724 81725 81726 81727 81728 81729 81730 81731 81732 81733 81734 81735 81736 81737 81738 81739 81740 81741 81742 81743 81744 81745 81746 81747 81748 81749 81750 81751 81752 81753 81754 81755 81756 81757 81758 81759 81760 81761 81762 81763 81764 81765 81766 81767 81768 81769 81770 81771 81772 81773 81774 81775 81776 81777 81778 81779 81780 81781 81782 81783 81784 81785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81688 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#type ⇒ ::String
Returns Defines the type of maintenance. Check the Type enum for the list of possible values.
81688 81689 81690 81691 81692 81693 81694 81695 81696 81697 81698 81699 81700 81701 81702 81703 81704 81705 81706 81707 81708 81709 81710 81711 81712 81713 81714 81715 81716 81717 81718 81719 81720 81721 81722 81723 81724 81725 81726 81727 81728 81729 81730 81731 81732 81733 81734 81735 81736 81737 81738 81739 81740 81741 81742 81743 81744 81745 81746 81747 81748 81749 81750 81751 81752 81753 81754 81755 81756 81757 81758 81759 81760 81761 81762 81763 81764 81765 81766 81767 81768 81769 81770 81771 81772 81773 81774 81775 81776 81777 81778 81779 81780 81781 81782 81783 81784 81785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81688 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#window_end_time ⇒ ::String
Returns The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format.
81688 81689 81690 81691 81692 81693 81694 81695 81696 81697 81698 81699 81700 81701 81702 81703 81704 81705 81706 81707 81708 81709 81710 81711 81712 81713 81714 81715 81716 81717 81718 81719 81720 81721 81722 81723 81724 81725 81726 81727 81728 81729 81730 81731 81732 81733 81734 81735 81736 81737 81738 81739 81740 81741 81742 81743 81744 81745 81746 81747 81748 81749 81750 81751 81752 81753 81754 81755 81756 81757 81758 81759 81760 81761 81762 81763 81764 81765 81766 81767 81768 81769 81770 81771 81772 81773 81774 81775 81776 81777 81778 81779 81780 81781 81782 81783 81784 81785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81688 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#window_start_time ⇒ ::String
Returns The current start time of the maintenance window. This timestamp value is in RFC3339 text format.
81688 81689 81690 81691 81692 81693 81694 81695 81696 81697 81698 81699 81700 81701 81702 81703 81704 81705 81706 81707 81708 81709 81710 81711 81712 81713 81714 81715 81716 81717 81718 81719 81720 81721 81722 81723 81724 81725 81726 81727 81728 81729 81730 81731 81732 81733 81734 81735 81736 81737 81738 81739 81740 81741 81742 81743 81744 81745 81746 81747 81748 81749 81750 81751 81752 81753 81754 81755 81756 81757 81758 81759 81760 81761 81762 81763 81764 81765 81766 81767 81768 81769 81770 81771 81772 81773 81774 81775 81776 81777 81778 81779 81780 81781 81782 81783 81784 81785 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81688 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |