Class: Google::Cloud::Compute::V1::UpcomingMaintenance
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UpcomingMaintenance
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Upcoming Maintenance notification information.
Defined Under Namespace
Modules: MaintenanceReasons, MaintenanceStatus, Type
Instance Attribute Summary collapse
-
#can_reschedule ⇒ ::Boolean
Indicates if the maintenance can be customer triggered.
-
#latest_window_start_time ⇒ ::String
The latest time for the planned maintenance window to start.
-
#maintenance_on_shutdown ⇒ ::Boolean
Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
-
#maintenance_reasons ⇒ ::Array<::String>
The reasons for the maintenance.
-
#maintenance_status ⇒ ::String
Check the MaintenanceStatus enum for the list of possible values.
-
#type ⇒ ::String
Defines the type of maintenance.
-
#window_end_time ⇒ ::String
The time by which the maintenance disruption will be completed.
-
#window_start_time ⇒ ::String
The current start time of the maintenance window.
Instance Attribute Details
#can_reschedule ⇒ ::Boolean
Returns Indicates if the maintenance can be customer triggered.
79084 79085 79086 79087 79088 79089 79090 79091 79092 79093 79094 79095 79096 79097 79098 79099 79100 79101 79102 79103 79104 79105 79106 79107 79108 79109 79110 79111 79112 79113 79114 79115 79116 79117 79118 79119 79120 79121 79122 79123 79124 79125 79126 79127 79128 79129 79130 79131 79132 79133 79134 79135 79136 79137 79138 79139 79140 79141 79142 79143 79144 79145 79146 79147 79148 79149 79150 79151 79152 79153 79154 79155 79156 79157 79158 79159 79160 79161 79162 79163 79164 79165 79166 79167 79168 79169 79170 79171 79172 79173 79174 79175 79176 79177 79178 79179 79180 79181 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79084 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#latest_window_start_time ⇒ ::String
Returns The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format.
79084 79085 79086 79087 79088 79089 79090 79091 79092 79093 79094 79095 79096 79097 79098 79099 79100 79101 79102 79103 79104 79105 79106 79107 79108 79109 79110 79111 79112 79113 79114 79115 79116 79117 79118 79119 79120 79121 79122 79123 79124 79125 79126 79127 79128 79129 79130 79131 79132 79133 79134 79135 79136 79137 79138 79139 79140 79141 79142 79143 79144 79145 79146 79147 79148 79149 79150 79151 79152 79153 79154 79155 79156 79157 79158 79159 79160 79161 79162 79163 79164 79165 79166 79167 79168 79169 79170 79171 79172 79173 79174 79175 79176 79177 79178 79179 79180 79181 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79084 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#maintenance_on_shutdown ⇒ ::Boolean
Returns Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
79084 79085 79086 79087 79088 79089 79090 79091 79092 79093 79094 79095 79096 79097 79098 79099 79100 79101 79102 79103 79104 79105 79106 79107 79108 79109 79110 79111 79112 79113 79114 79115 79116 79117 79118 79119 79120 79121 79122 79123 79124 79125 79126 79127 79128 79129 79130 79131 79132 79133 79134 79135 79136 79137 79138 79139 79140 79141 79142 79143 79144 79145 79146 79147 79148 79149 79150 79151 79152 79153 79154 79155 79156 79157 79158 79159 79160 79161 79162 79163 79164 79165 79166 79167 79168 79169 79170 79171 79172 79173 79174 79175 79176 79177 79178 79179 79180 79181 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79084 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#maintenance_reasons ⇒ ::Array<::String>
Returns The reasons for the maintenance. Only valid for vms. Check the MaintenanceReasons enum for the list of possible values.
79084 79085 79086 79087 79088 79089 79090 79091 79092 79093 79094 79095 79096 79097 79098 79099 79100 79101 79102 79103 79104 79105 79106 79107 79108 79109 79110 79111 79112 79113 79114 79115 79116 79117 79118 79119 79120 79121 79122 79123 79124 79125 79126 79127 79128 79129 79130 79131 79132 79133 79134 79135 79136 79137 79138 79139 79140 79141 79142 79143 79144 79145 79146 79147 79148 79149 79150 79151 79152 79153 79154 79155 79156 79157 79158 79159 79160 79161 79162 79163 79164 79165 79166 79167 79168 79169 79170 79171 79172 79173 79174 79175 79176 79177 79178 79179 79180 79181 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79084 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#maintenance_status ⇒ ::String
Returns Check the MaintenanceStatus enum for the list of possible values.
79084 79085 79086 79087 79088 79089 79090 79091 79092 79093 79094 79095 79096 79097 79098 79099 79100 79101 79102 79103 79104 79105 79106 79107 79108 79109 79110 79111 79112 79113 79114 79115 79116 79117 79118 79119 79120 79121 79122 79123 79124 79125 79126 79127 79128 79129 79130 79131 79132 79133 79134 79135 79136 79137 79138 79139 79140 79141 79142 79143 79144 79145 79146 79147 79148 79149 79150 79151 79152 79153 79154 79155 79156 79157 79158 79159 79160 79161 79162 79163 79164 79165 79166 79167 79168 79169 79170 79171 79172 79173 79174 79175 79176 79177 79178 79179 79180 79181 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79084 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#type ⇒ ::String
Returns Defines the type of maintenance. Check the Type enum for the list of possible values.
79084 79085 79086 79087 79088 79089 79090 79091 79092 79093 79094 79095 79096 79097 79098 79099 79100 79101 79102 79103 79104 79105 79106 79107 79108 79109 79110 79111 79112 79113 79114 79115 79116 79117 79118 79119 79120 79121 79122 79123 79124 79125 79126 79127 79128 79129 79130 79131 79132 79133 79134 79135 79136 79137 79138 79139 79140 79141 79142 79143 79144 79145 79146 79147 79148 79149 79150 79151 79152 79153 79154 79155 79156 79157 79158 79159 79160 79161 79162 79163 79164 79165 79166 79167 79168 79169 79170 79171 79172 79173 79174 79175 79176 79177 79178 79179 79180 79181 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79084 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#window_end_time ⇒ ::String
Returns The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format.
79084 79085 79086 79087 79088 79089 79090 79091 79092 79093 79094 79095 79096 79097 79098 79099 79100 79101 79102 79103 79104 79105 79106 79107 79108 79109 79110 79111 79112 79113 79114 79115 79116 79117 79118 79119 79120 79121 79122 79123 79124 79125 79126 79127 79128 79129 79130 79131 79132 79133 79134 79135 79136 79137 79138 79139 79140 79141 79142 79143 79144 79145 79146 79147 79148 79149 79150 79151 79152 79153 79154 79155 79156 79157 79158 79159 79160 79161 79162 79163 79164 79165 79166 79167 79168 79169 79170 79171 79172 79173 79174 79175 79176 79177 79178 79179 79180 79181 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79084 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |
#window_start_time ⇒ ::String
Returns The current start time of the maintenance window. This timestamp value is in RFC3339 text format.
79084 79085 79086 79087 79088 79089 79090 79091 79092 79093 79094 79095 79096 79097 79098 79099 79100 79101 79102 79103 79104 79105 79106 79107 79108 79109 79110 79111 79112 79113 79114 79115 79116 79117 79118 79119 79120 79121 79122 79123 79124 79125 79126 79127 79128 79129 79130 79131 79132 79133 79134 79135 79136 79137 79138 79139 79140 79141 79142 79143 79144 79145 79146 79147 79148 79149 79150 79151 79152 79153 79154 79155 79156 79157 79158 79159 79160 79161 79162 79163 79164 79165 79166 79167 79168 79169 79170 79171 79172 79173 79174 79175 79176 79177 79178 79179 79180 79181 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 79084 class UpcomingMaintenance include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module MaintenanceReasons # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_REASONS = 0 # Maintenance due to disk errors. FAILURE_DISK = 8_573_778 # Maintenance due to GPU errors. FAILURE_GPU = 467_876_919 # Maintenance due to customer reported multiple faulty hosts via R&R # Subblock API. FAILURE_GPU_MULTIPLE_FAULTY_HOSTS_CUSTOMER_REPORTED = 223_284_959 # Maintenance due to customer reported NVLink switch failure via R&R # Subblock API. FAILURE_GPU_NVLINK_SWITCH_CUSTOMER_REPORTED = 88_487_838 # Maintenance due to high GPU temperature. FAILURE_GPU_TEMPERATURE = 24_926_540 # Maintenance due to GPU xid failure. FAILURE_GPU_XID = 51_956_587 # Maintenance due to infrastructure errors. FAILURE_INFRA = 270_541_467 # Maintenance due to interface errors. FAILURE_INTERFACE = 390_068_356 # Maintenance due to memory errors. FAILURE_MEMORY = 440_132_982 # Maintenance due to network errors. FAILURE_NETWORK = 42_811_449 # Maintenance due to NVLink failure. FAILURE_NVLINK = 484_426_295 # Maintenance due to redundant hardware fault. FAILURE_REDUNDANT_HARDWARE_FAULT = 31_000_530 # Maintenance due to TPU errors. FAILURE_TPU = 467_889_412 # Maintenance due to infrastructure relocation. INFRASTRUCTURE_RELOCATION = 359_845_636 # Unknown maintenance reason. Do not use this value. MAINTENANCE_REASON_UNKNOWN = 50_570_235 # Maintenance due to planned network update. PLANNED_NETWORK_UPDATE = 135_494_677 # Maintenance due to planned update to the instance. PLANNED_UPDATE = 161_733_572 end module MaintenanceStatus # A value indicating that the enum field is not set. UNDEFINED_MAINTENANCE_STATUS = 0 # There is ongoing maintenance on this VM. ONGOING = 473_158_491 # There is pending maintenance. PENDING = 35_394_935 # Unknown maintenance status. Do not use this value. UNKNOWN = 433_141_802 end # Defines the type of maintenance. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 # Multiple maintenance types in one window. # This is only intended to be used for groups. MULTIPLE = 362_714_640 # Scheduled maintenance (e.g. maintenance after uptime guarantee is # complete). SCHEDULED = 478_400_653 # No type specified. Do not use this value. UNKNOWN_TYPE = 490_705_455 # Unscheduled maintenance (e.g. emergency maintenance during # uptime guarantee). UNSCHEDULED = 450_077_204 end end |