Class: Google::Cloud::Compute::V1::UpdateInstanceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UpdateInstanceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A request message for Instances.Update. See the method description for details.
Defined Under Namespace
Modules: MinimalAction, MostDisruptiveAllowedAction
Instance Attribute Summary collapse
-
#discard_local_ssd ⇒ ::Boolean
Whether to discard local SSDs from the instance during restart default value is false.
-
#instance ⇒ ::String
Name of the instance resource to update.
-
#instance_resource ⇒ ::Google::Cloud::Compute::V1::Instance
The body resource for this request.
-
#minimal_action ⇒ ::String
Specifies the action to take when updating an instance even if the updated properties do not require it.
-
#most_disruptive_allowed_action ⇒ ::String
Specifies the most disruptive action that can be taken on the instance as part of the update.
-
#project ⇒ ::String
Project ID for this request.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#zone ⇒ ::String
The name of the zone for this request.
Instance Attribute Details
#discard_local_ssd ⇒ ::Boolean
Returns Whether to discard local SSDs from the instance during restart default value is false.
82160 82161 82162 82163 82164 82165 82166 82167 82168 82169 82170 82171 82172 82173 82174 82175 82176 82177 82178 82179 82180 82181 82182 82183 82184 82185 82186 82187 82188 82189 82190 82191 82192 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82160 class UpdateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the action to take when updating an instance even if the # updated properties do not require it. If not specified, then # Compute Engine acts based on the minimum action that the updated # properties require. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Specifies the most disruptive action that can be taken on the instance # as part of the update. Compute Engine returns an error if the # instance properties require a more disruptive action as part of the # instance update. Valid options from lowest to highest are # NO_EFFECT, REFRESH, and RESTART. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#instance ⇒ ::String
Returns Name of the instance resource to update.
82160 82161 82162 82163 82164 82165 82166 82167 82168 82169 82170 82171 82172 82173 82174 82175 82176 82177 82178 82179 82180 82181 82182 82183 82184 82185 82186 82187 82188 82189 82190 82191 82192 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82160 class UpdateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the action to take when updating an instance even if the # updated properties do not require it. If not specified, then # Compute Engine acts based on the minimum action that the updated # properties require. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Specifies the most disruptive action that can be taken on the instance # as part of the update. Compute Engine returns an error if the # instance properties require a more disruptive action as part of the # instance update. Valid options from lowest to highest are # NO_EFFECT, REFRESH, and RESTART. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#instance_resource ⇒ ::Google::Cloud::Compute::V1::Instance
Returns The body resource for this request.
82160 82161 82162 82163 82164 82165 82166 82167 82168 82169 82170 82171 82172 82173 82174 82175 82176 82177 82178 82179 82180 82181 82182 82183 82184 82185 82186 82187 82188 82189 82190 82191 82192 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82160 class UpdateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the action to take when updating an instance even if the # updated properties do not require it. If not specified, then # Compute Engine acts based on the minimum action that the updated # properties require. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Specifies the most disruptive action that can be taken on the instance # as part of the update. Compute Engine returns an error if the # instance properties require a more disruptive action as part of the # instance update. Valid options from lowest to highest are # NO_EFFECT, REFRESH, and RESTART. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#minimal_action ⇒ ::String
Returns Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require. Check the MinimalAction enum for the list of possible values.
82160 82161 82162 82163 82164 82165 82166 82167 82168 82169 82170 82171 82172 82173 82174 82175 82176 82177 82178 82179 82180 82181 82182 82183 82184 82185 82186 82187 82188 82189 82190 82191 82192 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82160 class UpdateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the action to take when updating an instance even if the # updated properties do not require it. If not specified, then # Compute Engine acts based on the minimum action that the updated # properties require. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Specifies the most disruptive action that can be taken on the instance # as part of the update. Compute Engine returns an error if the # instance properties require a more disruptive action as part of the # instance update. Valid options from lowest to highest are # NO_EFFECT, REFRESH, and RESTART. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#most_disruptive_allowed_action ⇒ ::String
Returns Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART. Check the MostDisruptiveAllowedAction enum for the list of possible values.
82160 82161 82162 82163 82164 82165 82166 82167 82168 82169 82170 82171 82172 82173 82174 82175 82176 82177 82178 82179 82180 82181 82182 82183 82184 82185 82186 82187 82188 82189 82190 82191 82192 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82160 class UpdateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the action to take when updating an instance even if the # updated properties do not require it. If not specified, then # Compute Engine acts based on the minimum action that the updated # properties require. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Specifies the most disruptive action that can be taken on the instance # as part of the update. Compute Engine returns an error if the # instance properties require a more disruptive action as part of the # instance update. Valid options from lowest to highest are # NO_EFFECT, REFRESH, and RESTART. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#project ⇒ ::String
Returns Project ID for this request.
82160 82161 82162 82163 82164 82165 82166 82167 82168 82169 82170 82171 82172 82173 82174 82175 82176 82177 82178 82179 82180 82181 82182 82183 82184 82185 82186 82187 82188 82189 82190 82191 82192 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82160 class UpdateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the action to take when updating an instance even if the # updated properties do not require it. If not specified, then # Compute Engine acts based on the minimum action that the updated # properties require. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Specifies the most disruptive action that can be taken on the instance # as part of the update. Compute Engine returns an error if the # instance properties require a more disruptive action as part of the # instance update. Valid options from lowest to highest are # NO_EFFECT, REFRESH, and RESTART. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
82160 82161 82162 82163 82164 82165 82166 82167 82168 82169 82170 82171 82172 82173 82174 82175 82176 82177 82178 82179 82180 82181 82182 82183 82184 82185 82186 82187 82188 82189 82190 82191 82192 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82160 class UpdateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the action to take when updating an instance even if the # updated properties do not require it. If not specified, then # Compute Engine acts based on the minimum action that the updated # properties require. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Specifies the most disruptive action that can be taken on the instance # as part of the update. Compute Engine returns an error if the # instance properties require a more disruptive action as part of the # instance update. Valid options from lowest to highest are # NO_EFFECT, REFRESH, and RESTART. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |
#zone ⇒ ::String
Returns The name of the zone for this request.
82160 82161 82162 82163 82164 82165 82166 82167 82168 82169 82170 82171 82172 82173 82174 82175 82176 82177 82178 82179 82180 82181 82182 82183 82184 82185 82186 82187 82188 82189 82190 82191 82192 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82160 class UpdateInstanceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the action to take when updating an instance even if the # updated properties do not require it. If not specified, then # Compute Engine acts based on the minimum action that the updated # properties require. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MinimalAction # A value indicating that the enum field is not set. UNDEFINED_MINIMAL_ACTION = 0 end # Specifies the most disruptive action that can be taken on the instance # as part of the update. Compute Engine returns an error if the # instance properties require a more disruptive action as part of the # instance update. Valid options from lowest to highest are # NO_EFFECT, REFRESH, and RESTART. # Additional supported values which may be not listed in the enum directly due to technical reasons: # INVALID # NO_EFFECT # REFRESH # RESTART module MostDisruptiveAllowedAction # A value indicating that the enum field is not set. UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0 end end |