Class: Google::Cloud::Compute::V1::UpdateInstanceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for Instances.Update. See the method description for details.

Defined Under Namespace

Modules: MinimalAction, MostDisruptiveAllowedAction

Instance Attribute Summary collapse

Instance Attribute Details

#discard_local_ssd::Boolean

Returns Whether to discard local SSDs from the instance during restart default value is false.

Returns:

  • (::Boolean)

    Whether to discard local SSDs from the instance during restart default value is false.



81255
81256
81257
81258
81259
81260
81261
81262
81263
81264
81265
81266
81267
81268
81269
81270
81271
81272
81273
81274
81275
81276
81277
81278
81279
81280
81281
81282
81283
81284
81285
81286
81287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81255

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the
  # updated properties do not require it. If not specified, then
  # Compute Engine acts based on the minimum action that the updated
  # properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance
  # as part of the update. Compute Engine returns an error if the
  # instance properties require a more disruptive action as part of the
  # instance update. Valid options from lowest to highest are
  # NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#instance::String

Returns Name of the instance resource to update.

Returns:

  • (::String)

    Name of the instance resource to update.



81255
81256
81257
81258
81259
81260
81261
81262
81263
81264
81265
81266
81267
81268
81269
81270
81271
81272
81273
81274
81275
81276
81277
81278
81279
81280
81281
81282
81283
81284
81285
81286
81287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81255

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the
  # updated properties do not require it. If not specified, then
  # Compute Engine acts based on the minimum action that the updated
  # properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance
  # as part of the update. Compute Engine returns an error if the
  # instance properties require a more disruptive action as part of the
  # instance update. Valid options from lowest to highest are
  # NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#instance_resource::Google::Cloud::Compute::V1::Instance

Returns The body resource for this request.

Returns:



81255
81256
81257
81258
81259
81260
81261
81262
81263
81264
81265
81266
81267
81268
81269
81270
81271
81272
81273
81274
81275
81276
81277
81278
81279
81280
81281
81282
81283
81284
81285
81286
81287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81255

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the
  # updated properties do not require it. If not specified, then
  # Compute Engine acts based on the minimum action that the updated
  # properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance
  # as part of the update. Compute Engine returns an error if the
  # instance properties require a more disruptive action as part of the
  # instance update. Valid options from lowest to highest are
  # NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#minimal_action::String

Returns Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require. Check the MinimalAction enum for the list of possible values.

Returns:

  • (::String)

    Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require. Check the MinimalAction enum for the list of possible values.



81255
81256
81257
81258
81259
81260
81261
81262
81263
81264
81265
81266
81267
81268
81269
81270
81271
81272
81273
81274
81275
81276
81277
81278
81279
81280
81281
81282
81283
81284
81285
81286
81287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81255

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the
  # updated properties do not require it. If not specified, then
  # Compute Engine acts based on the minimum action that the updated
  # properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance
  # as part of the update. Compute Engine returns an error if the
  # instance properties require a more disruptive action as part of the
  # instance update. Valid options from lowest to highest are
  # NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#most_disruptive_allowed_action::String

Returns Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART. Check the MostDisruptiveAllowedAction enum for the list of possible values.

Returns:

  • (::String)

    Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART. Check the MostDisruptiveAllowedAction enum for the list of possible values.



81255
81256
81257
81258
81259
81260
81261
81262
81263
81264
81265
81266
81267
81268
81269
81270
81271
81272
81273
81274
81275
81276
81277
81278
81279
81280
81281
81282
81283
81284
81285
81286
81287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81255

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the
  # updated properties do not require it. If not specified, then
  # Compute Engine acts based on the minimum action that the updated
  # properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance
  # as part of the update. Compute Engine returns an error if the
  # instance properties require a more disruptive action as part of the
  # instance update. Valid options from lowest to highest are
  # NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#project::String

Returns Project ID for this request.

Returns:

  • (::String)

    Project ID for this request.



81255
81256
81257
81258
81259
81260
81261
81262
81263
81264
81265
81266
81267
81268
81269
81270
81271
81272
81273
81274
81275
81276
81277
81278
81279
81280
81281
81282
81283
81284
81285
81286
81287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81255

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the
  # updated properties do not require it. If not specified, then
  # Compute Engine acts based on the minimum action that the updated
  # properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance
  # as part of the update. Compute Engine returns an error if the
  # instance properties require a more disruptive action as part of the
  # instance update. Valid options from lowest to highest are
  # NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#request_id::String

Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



81255
81256
81257
81258
81259
81260
81261
81262
81263
81264
81265
81266
81267
81268
81269
81270
81271
81272
81273
81274
81275
81276
81277
81278
81279
81280
81281
81282
81283
81284
81285
81286
81287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81255

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the
  # updated properties do not require it. If not specified, then
  # Compute Engine acts based on the minimum action that the updated
  # properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance
  # as part of the update. Compute Engine returns an error if the
  # instance properties require a more disruptive action as part of the
  # instance update. Valid options from lowest to highest are
  # NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#zone::String

Returns The name of the zone for this request.

Returns:

  • (::String)

    The name of the zone for this request.



81255
81256
81257
81258
81259
81260
81261
81262
81263
81264
81265
81266
81267
81268
81269
81270
81271
81272
81273
81274
81275
81276
81277
81278
81279
81280
81281
81282
81283
81284
81285
81286
81287
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81255

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the
  # updated properties do not require it. If not specified, then
  # Compute Engine acts based on the minimum action that the updated
  # properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance
  # as part of the update. Compute Engine returns an error if the
  # instance properties require a more disruptive action as part of the
  # instance update. Valid options from lowest to highest are
  # NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end