Class: Google::Cloud::Compute::V1::UpdateInstanceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A request message for Instances.Update. See the method description for details.

Defined Under Namespace

Modules: MinimalAction, MostDisruptiveAllowedAction

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String



36595
36596
36597
36598
36599
36600
36601
36602
36603
36604
36605
36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36595

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#instance_resource::Google::Cloud::Compute::V1::Instance



36595
36596
36597
36598
36599
36600
36601
36602
36603
36604
36605
36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36595

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#minimal_action::String



36595
36596
36597
36598
36599
36600
36601
36602
36603
36604
36605
36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36595

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#most_disruptive_allowed_action::String



36595
36596
36597
36598
36599
36600
36601
36602
36603
36604
36605
36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36595

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#project::String



36595
36596
36597
36598
36599
36600
36601
36602
36603
36604
36605
36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36595

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#request_id::String



36595
36596
36597
36598
36599
36600
36601
36602
36603
36604
36605
36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36595

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end

#zone::String



36595
36596
36597
36598
36599
36600
36601
36602
36603
36604
36605
36606
36607
36608
36609
36610
36611
36612
36613
36614
36615
36616
36617
36618
36619
36620
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 36595

class UpdateInstanceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the action to take when updating an instance even if the updated properties do not require it. If not specified, then Compute Engine acts based on the minimum action that the updated properties require.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MinimalAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MINIMAL_ACTION = 0
  end

  # Specifies the most disruptive action that can be taken on the instance as part of the update. Compute Engine returns an error if the instance properties require a more disruptive action as part of the instance update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.
  # Additional supported values which may be not listed in the enum directly due to technical reasons:
  # INVALID
  # NO_EFFECT
  # REFRESH
  # RESTART
  module MostDisruptiveAllowedAction
    # A value indicating that the enum field is not set.
    UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION = 0
  end
end