Class: Google::Cloud::Compute::V1::UrlMapTest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UrlMapTest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Message for the expected URL mappings.
Instance Attribute Summary collapse
-
#description ⇒ ::String
Description of this test case.
-
#expected_output_url ⇒ ::String
The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ ::Integer
For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response.
-
#headers ⇒ ::Array<::Google::Cloud::Compute::V1::UrlMapTestHeader>
HTTP headers for this request.
-
#host ⇒ ::String
Host portion of the URL.
-
#path ⇒ ::String
Path portion of the URL.
-
#service ⇒ ::String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
Instance Attribute Details
#description ⇒ ::String
Returns Description of this test case.
80609 80610 80611 80612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80609 class UrlMapTest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#expected_output_url ⇒ ::String
Returns The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters.
For rules that forward requests to backends, the test passes only whenexpectedOutputUrl matches the request forwarded by the load balancer to backends. For rules with urlRewrite, the test verifies that the forwarded request matcheshostRewrite and pathPrefixRewrite in theurlRewrite action. When service is specified,expectedOutputUrl`s scheme is ignored.
For rules with urlRedirect, the test passes only ifexpectedOutputUrl matches the URL in the load balancer's redirect response. If urlRedirect specifieshttps_redirect, the test passes only if the scheme inexpectedOutputUrl is also set to HTTPS. If urlRedirect specifies strip_query, the test passes only if expectedOutputUrl does not contain any query parameters.
expectedOutputUrl is optional whenservice is specified.
80609 80610 80611 80612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80609 class UrlMapTest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#expected_redirect_response_code ⇒ ::Integer
Returns For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response.
expectedRedirectResponseCode cannot be set whenservice is set.
80609 80610 80611 80612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80609 class UrlMapTest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#headers ⇒ ::Array<::Google::Cloud::Compute::V1::UrlMapTestHeader>
Returns HTTP headers for this request. If headers contains a host header, then host must also match the header value.
80609 80610 80611 80612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80609 class UrlMapTest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#host ⇒ ::String
Returns Host portion of the URL. If headers contains a host header, then host must also match the header value.
80609 80610 80611 80612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80609 class UrlMapTest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#path ⇒ ::String
Returns Path portion of the URL.
80609 80610 80611 80612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80609 class UrlMapTest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service ⇒ ::String
Returns Expected BackendService or BackendBucket resource the given URL should be mapped to.
The service field cannot be set if expectedRedirectResponseCode is set.
80609 80610 80611 80612 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80609 class UrlMapTest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |