Class: Google::Cloud::Compute::V1::UrlMapsValidateRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UrlMapsValidateRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: LoadBalancingSchemes
Instance Attribute Summary collapse
-
#load_balancing_schemes ⇒ ::Array<::String>
Specifies the load balancer type(s) this validation request is for.
-
#resource ⇒ ::Google::Cloud::Compute::V1::UrlMap
Content of the UrlMap to be validated.
Instance Attribute Details
#load_balancing_schemes ⇒ ::Array<::String>
Returns Specifies the load balancer type(s) this validation request is for. UseEXTERNAL_MANAGED for global external Application Load Balancers and regional external Application Load Balancers. Use EXTERNAL for classic Application Load Balancers.
Use INTERNAL_MANAGED for internal Application Load Balancers. For more information, refer to Choosing a load balancer.
If unspecified, the load balancing scheme will be inferred from the backend service resources this URL map references. If that can not be inferred (for example, this URL map only references backend buckets, or this Url map is for rewrites and redirects only and doesn't reference any backends),EXTERNAL will be used as the default type.
If specified, the scheme(s) must not conflict with the load balancing scheme of the backend service resources this Url map references. Check the LoadBalancingSchemes enum for the list of possible values.
80716 80717 80718 80719 80720 80721 80722 80723 80724 80725 80726 80727 80728 80729 80730 80731 80732 80733 80734 80735 80736 80737 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80716 class UrlMapsValidateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module LoadBalancingSchemes # A value indicating that the enum field is not set. UNDEFINED_LOAD_BALANCING_SCHEMES = 0 # Signifies that this will be used for classic Application Load Balancers. EXTERNAL = 35_607_499 # Signifies that this will be used for Envoy-based global external # Application Load Balancers. EXTERNAL_MANAGED = 512_006_923 # If unspecified, the validation will try to infer the scheme from the # backend service resources this Url map references. If the inference is not # possible, EXTERNAL will be used as the default type. LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452 end end |
#resource ⇒ ::Google::Cloud::Compute::V1::UrlMap
Returns Content of the UrlMap to be validated.
80716 80717 80718 80719 80720 80721 80722 80723 80724 80725 80726 80727 80728 80729 80730 80731 80732 80733 80734 80735 80736 80737 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80716 class UrlMapsValidateRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods module LoadBalancingSchemes # A value indicating that the enum field is not set. UNDEFINED_LOAD_BALANCING_SCHEMES = 0 # Signifies that this will be used for classic Application Load Balancers. EXTERNAL = 35_607_499 # Signifies that this will be used for Envoy-based global external # Application Load Balancers. EXTERNAL_MANAGED = 512_006_923 # If unspecified, the validation will try to infer the scheme from the # backend service resources this Url map references. If the inference is not # possible, EXTERNAL will be used as the default type. LOAD_BALANCING_SCHEME_UNSPECIFIED = 526_507_452 end end |