Class: Google::Cloud::Compute::V1::UrlRewrite

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

The spec for modifying the path before sending the request to the matched backend service.

Instance Attribute Summary collapse

Instance Attribute Details

#host_rewrite::String

Returns Before forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.

The value must be from 1 to 255 characters.

Returns:

  • (::String)

    Before forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.

    The value must be from 1 to 255 characters.



80787
80788
80789
80790
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80787

class UrlRewrite
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path_prefix_rewrite::String

Returns Before forwarding the request to the selected backend service, the matching portion of the request's path is replaced bypathPrefixRewrite.

The value must be from 1 to 1024 characters.

Returns:

  • (::String)

    Before forwarding the request to the selected backend service, the matching portion of the request's path is replaced bypathPrefixRewrite.

    The value must be from 1 to 1024 characters.



80787
80788
80789
80790
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80787

class UrlRewrite
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path_template_rewrite::String

Returns If specified, the pattern rewrites the URL path (based on the :path header) using the HTTP template syntax.

A corresponding path_template_match must be specified. Any template variables must exist in the path_template_match field.

  - -At least one variable must be specified in the path_template_match
  field
  • You can omit variables from the rewritten URL
    • The * and ** operators cannot be matched unless they have a corresponding variable name - e.g. {format=} or {var=*}.

For example, a path_template_match of /static/{format=} could be rewritten as /static/content/{format} to prefix/content to the URL. Variables can also be re-ordered in a rewrite, so that /{country}/{format}/{suffix=} can be rewritten as /content/{format}/{country}/{suffix}.

At least one non-empty routeRules[].matchRules[].path_template_match is required.

Only one of path_prefix_rewrite orpath_template_rewrite may be specified.

Returns:

  • (::String)

    If specified, the pattern rewrites the URL path (based on the :path header) using the HTTP template syntax.

    A corresponding path_template_match must be specified. Any template variables must exist in the path_template_match field.

      - -At least one variable must be specified in the path_template_match
      field
    
    • You can omit variables from the rewritten URL
      • The * and ** operators cannot be matched unless they have a corresponding variable name - e.g. {format=} or {var=*}.

    For example, a path_template_match of /static/{format=} could be rewritten as /static/content/{format} to prefix/content to the URL. Variables can also be re-ordered in a rewrite, so that /{country}/{format}/{suffix=} can be rewritten as /content/{format}/{country}/{suffix}.

    At least one non-empty routeRules[].matchRules[].path_template_match is required.

    Only one of path_prefix_rewrite orpath_template_rewrite may be specified.



80787
80788
80789
80790
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80787

class UrlRewrite
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end