Class: Google::Cloud::Compute::V1::UsableSubnetwork

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Subnetwork which the current user has compute.subnetworks.use permission on.

Defined Under Namespace

Modules: Ipv6AccessType, Purpose, Role, StackType

Instance Attribute Summary collapse

Instance Attribute Details

#external_ipv6_prefix::String

Returns Output only. [Output Only] The external IPv6 address range that is assigned to this subnetwork.

Returns:

  • (::String)

    Output only. [Output Only] The external IPv6 address range that is assigned to this subnetwork.



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end

#internal_ipv6_prefix::String

Returns Output only. [Output Only] The internal IPv6 address range that is assigned to this subnetwork.

Returns:

  • (::String)

    Output only. [Output Only] The internal IPv6 address range that is assigned to this subnetwork.



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end

#ip_cidr_range::String

Returns The range of internal addresses that are owned by this subnetwork.

Returns:

  • (::String)

    The range of internal addresses that are owned by this subnetwork.



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end

#ipv6_access_type::String

Returns The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack. Check the Ipv6AccessType enum for the list of possible values.

Returns:

  • (::String)

    The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack. Check the Ipv6AccessType enum for the list of possible values.



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end

#network::String

Returns Network URL.

Returns:

  • (::String)

    Network URL.



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end

#purpose::String

Returns Check the Purpose enum for the list of possible values.

Returns:

  • (::String)

    Check the Purpose enum for the list of possible values.



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end

#role::String

Returns The role of subnetwork. Currently, this field is only used when purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request. Check the Role enum for the list of possible values.

Returns:

  • (::String)

    The role of subnetwork. Currently, this field is only used when purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request. Check the Role enum for the list of possible values.



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end

#secondary_ip_ranges::Array<::Google::Cloud::Compute::V1::UsableSubnetworkSecondaryRange>

Returns Secondary IP ranges.

Returns:



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end

#stack_type::String

Returns The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used.

This field can be both set at resource creation time and updated usingpatch. Check the StackType enum for the list of possible values.

Returns:

  • (::String)

    The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used.

    This field can be both set at resource creation time and updated usingpatch. Check the StackType enum for the list of possible values.



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end

#subnetwork::String

Returns Subnetwork URL.

Returns:

  • (::String)

    Subnetwork URL.



83506
83507
83508
83509
83510
83511
83512
83513
83514
83515
83516
83517
83518
83519
83520
83521
83522
83523
83524
83525
83526
83527
83528
83529
83530
83531
83532
83533
83534
83535
83536
83537
83538
83539
83540
83541
83542
83543
83544
83545
83546
83547
83548
83549
83550
83551
83552
83553
83554
83555
83556
83557
83558
83559
83560
83561
83562
83563
83564
83565
83566
83567
83568
83569
83570
83571
83572
83573
83574
83575
83576
83577
83578
83579
83580
83581
83582
83583
83584
83585
83586
83587
83588
83589
83590
83591
83592
83593
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83506

class UsableSubnetwork
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The access type of IPv6 address this subnet holds. It's immutable and can
  # only be specified during creation or the first time the subnet is updated
  # into IPV4_IPV6 dual stack.
  module Ipv6AccessType
    # A value indicating that the enum field is not set.
    UNDEFINED_IPV6_ACCESS_TYPE = 0

    # VMs on this subnet will be assigned IPv6 addresses that are accessible
    # via the Internet, as well as the VPC network.
    EXTERNAL = 35_607_499

    # VMs on this subnet will be assigned IPv6 addresses that are only
    # accessible over the VPC network.
    INTERNAL = 279_295_677
  end

  module Purpose
    # A value indicating that the enum field is not set.
    UNDEFINED_PURPOSE = 0

    # Subnet reserved for Global Envoy-based Load Balancing.
    GLOBAL_MANAGED_PROXY = 236_463_602

    # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy
    # purpose, please use REGIONAL_MANAGED_PROXY instead.
    INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889

    # Subnetwork will be used for Migration from one peered VPC to another.
    # (a transient state of subnetwork
    # while migrating resources from one project to another).
    PEER_MIGRATION = 491_902_225

    # Regular user created or automatically created subnet.
    PRIVATE = 403_485_027

    # Subnetwork used as source range for Private NAT Gateways.
    PRIVATE_NAT = 367_764_517

    # Regular user created or automatically created subnet.
    PRIVATE_RFC_1918 = 254_902_107

    # Subnetworks created for Private Service Connect in the producer network.
    PRIVATE_SERVICE_CONNECT = 48_134_724

    # Subnetwork used for Regional Envoy-based Load Balancing.
    REGIONAL_MANAGED_PROXY = 153_049_966
  end

  # The role of subnetwork. Currently, this field is only used when
  # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE
  # subnetwork is one that is currently being used for Envoy-based load
  # balancers in a region. A BACKUP subnetwork is one that is
  # ready to be promoted to ACTIVE or is currently draining.
  # This field can be updated with a patch request.
  module Role
    # A value indicating that the enum field is not set.
    UNDEFINED_ROLE = 0

    # The ACTIVE subnet that is currently used.
    ACTIVE = 314_733_318

    # The BACKUP subnet that could be promoted to ACTIVE.
    BACKUP = 341_010_882
  end

  # The stack type for the subnet. If set to IPV4_ONLY, new VMs
  # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and
  # IPv6 addresses. If not specified, IPV4_ONLY is used.
  #
  # This field can be both set at resource creation time and updated usingpatch.
  module StackType
    # A value indicating that the enum field is not set.
    UNDEFINED_STACK_TYPE = 0

    # New VMs in this subnet can have both IPv4 and IPv6 addresses.
    IPV4_IPV6 = 22_197_249

    # New VMs in this subnet will only be assigned IPv4 addresses.
    IPV4_ONLY = 22_373_798

    # New VMs in this subnet will only be assigned IPv6 addresses.
    IPV6_ONLY = 79_632_100
  end
end