Class: Google::Cloud::Compute::V1::UsableSubnetwork
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UsableSubnetwork
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Subnetwork which the current user has compute.subnetworks.use permission on.
Defined Under Namespace
Modules: Ipv6AccessType, Purpose, Role, StackType
Instance Attribute Summary collapse
-
#external_ipv6_prefix ⇒ ::String
Output only.
-
#internal_ipv6_prefix ⇒ ::String
Output only.
-
#ip_cidr_range ⇒ ::String
The range of internal addresses that are owned by this subnetwork.
-
#ipv6_access_type ⇒ ::String
The access type of IPv6 address this subnet holds.
-
#network ⇒ ::String
Network URL.
-
#purpose ⇒ ::String
Check the Purpose enum for the list of possible values.
-
#role ⇒ ::String
The role of subnetwork.
-
#secondary_ip_ranges ⇒ ::Array<::Google::Cloud::Compute::V1::UsableSubnetworkSecondaryRange>
Secondary IP ranges.
-
#stack_type ⇒ ::String
The stack type for the subnet.
-
#subnetwork ⇒ ::String
Subnetwork URL.
Instance Attribute Details
#external_ipv6_prefix ⇒ ::String
Returns Output only. [Output Only] The external IPv6 address range that is assigned to this subnetwork.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |
#internal_ipv6_prefix ⇒ ::String
Returns Output only. [Output Only] The internal IPv6 address range that is assigned to this subnetwork.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |
#ip_cidr_range ⇒ ::String
Returns The range of internal addresses that are owned by this subnetwork.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |
#ipv6_access_type ⇒ ::String
Returns The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack. Check the Ipv6AccessType enum for the list of possible values.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |
#network ⇒ ::String
Returns Network URL.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |
#purpose ⇒ ::String
Returns Check the Purpose enum for the list of possible values.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |
#role ⇒ ::String
Returns The role of subnetwork. Currently, this field is only used when purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request. Check the Role enum for the list of possible values.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |
#secondary_ip_ranges ⇒ ::Array<::Google::Cloud::Compute::V1::UsableSubnetworkSecondaryRange>
Returns Secondary IP ranges.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |
#stack_type ⇒ ::String
Returns The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used.
This field can be both set at resource creation time and updated usingpatch. Check the StackType enum for the list of possible values.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |
#subnetwork ⇒ ::String
Returns Subnetwork URL.
80839 80840 80841 80842 80843 80844 80845 80846 80847 80848 80849 80850 80851 80852 80853 80854 80855 80856 80857 80858 80859 80860 80861 80862 80863 80864 80865 80866 80867 80868 80869 80870 80871 80872 80873 80874 80875 80876 80877 80878 80879 80880 80881 80882 80883 80884 80885 80886 80887 80888 80889 80890 80891 80892 80893 80894 80895 80896 80897 80898 80899 80900 80901 80902 80903 80904 80905 80906 80907 80908 80909 80910 80911 80912 80913 80914 80915 80916 80917 80918 80919 80920 80921 80922 80923 80924 80925 80926 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80839 class UsableSubnetwork include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The access type of IPv6 address this subnet holds. It's immutable and can # only be specified during creation or the first time the subnet is updated # into IPV4_IPV6 dual stack. module Ipv6AccessType # A value indicating that the enum field is not set. UNDEFINED_IPV6_ACCESS_TYPE = 0 # VMs on this subnet will be assigned IPv6 addresses that are accessible # via the Internet, as well as the VPC network. EXTERNAL = 35_607_499 # VMs on this subnet will be assigned IPv6 addresses that are only # accessible over the VPC network. INTERNAL = 279_295_677 end module Purpose # A value indicating that the enum field is not set. UNDEFINED_PURPOSE = 0 # Subnet reserved for Global Envoy-based Load Balancing. GLOBAL_MANAGED_PROXY = 236_463_602 # Subnet reserved for Internal HTTP(S) Load Balancing. This is a legacy # purpose, please use REGIONAL_MANAGED_PROXY instead. INTERNAL_HTTPS_LOAD_BALANCER = 248_748_889 # Subnetwork will be used for Migration from one peered VPC to another. # (a transient state of subnetwork # while migrating resources from one project to another). PEER_MIGRATION = 491_902_225 # Regular user created or automatically created subnet. PRIVATE = 403_485_027 # Subnetwork used as source range for Private NAT Gateways. PRIVATE_NAT = 367_764_517 # Regular user created or automatically created subnet. PRIVATE_RFC_1918 = 254_902_107 # Subnetworks created for Private Service Connect in the producer network. PRIVATE_SERVICE_CONNECT = 48_134_724 # Subnetwork used for Regional Envoy-based Load Balancing. REGIONAL_MANAGED_PROXY = 153_049_966 end # The role of subnetwork. Currently, this field is only used when # purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE # subnetwork is one that is currently being used for Envoy-based load # balancers in a region. A BACKUP subnetwork is one that is # ready to be promoted to ACTIVE or is currently draining. # This field can be updated with a patch request. module Role # A value indicating that the enum field is not set. UNDEFINED_ROLE = 0 # The ACTIVE subnet that is currently used. ACTIVE = 314_733_318 # The BACKUP subnet that could be promoted to ACTIVE. BACKUP = 341_010_882 end # The stack type for the subnet. If set to IPV4_ONLY, new VMs # in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and # IPv6 addresses. If not specified, IPV4_ONLY is used. # # This field can be both set at resource creation time and updated usingpatch. module StackType # A value indicating that the enum field is not set. UNDEFINED_STACK_TYPE = 0 # New VMs in this subnet can have both IPv4 and IPv6 addresses. IPV4_IPV6 = 22_197_249 # New VMs in this subnet will only be assigned IPv4 addresses. IPV4_ONLY = 22_373_798 # New VMs in this subnet will only be assigned IPv6 addresses. IPV6_ONLY = 79_632_100 end end |