Class: Google::Cloud::Compute::V1::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::UsableSubnetworksAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] The unique identifier for the resource.
-
#items ⇒ ::Array<::Google::Cloud::Compute::V1::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ ::Array<::Google::Cloud::Compute::V1::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
80977 80978 80979 80980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80977 class UsableSubnetworksAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#items ⇒ ::Array<::Google::Cloud::Compute::V1::UsableSubnetwork>
Returns [Output] A list of usable subnetwork URLs.
80977 80978 80979 80980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80977 class UsableSubnetworksAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Alwayscompute#usableSubnetworksAggregatedList for aggregated lists of usable subnetworks.
80977 80978 80979 80980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80977 class UsableSubnetworksAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the next page of results.
80977 80978 80979 80980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80977 class UsableSubnetworksAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scoped_warnings ⇒ ::Array<::Google::Cloud::Compute::V1::SubnetworksScopedWarning>
Returns Output only. [Output Only] Informational warning messages for failures encountered from scopes.
80977 80978 80979 80980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80977 class UsableSubnetworksAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
80977 80978 80979 80980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80977 class UsableSubnetworksAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
80977 80978 80979 80980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80977 class UsableSubnetworksAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
80977 80978 80979 80980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 80977 class UsableSubnetworksAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |