Class: Google::Cloud::Compute::V1::VmExtensionPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::VmExtensionPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a VM extension policy.
Defined Under Namespace
Modules: State Classes: ExtensionPoliciesEntry
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ ::String
Output only.
-
#description ⇒ ::String
An optional description of this resource.
-
#extension_policies ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy}
Required.
-
#global_resource_link ⇒ ::String
Optional.
-
#id ⇒ ::Integer
Output only.
-
#instance_selectors ⇒ ::Array<::Google::Cloud::Compute::V1::VmExtensionPolicyInstanceSelector>
Optional.
-
#kind ⇒ ::String
Output only.
-
#managed_by_global ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Name of the resource.
-
#priority ⇒ ::Integer
Optional.
-
#self_link ⇒ ::String
Output only.
-
#self_link_with_id ⇒ ::String
Output only.
-
#state ⇒ ::String
Optional.
-
#update_timestamp ⇒ ::String
Output only.
Instance Attribute Details
#creation_timestamp ⇒ ::String
Returns Output only. [Output Only] Creation timestamp inRFC3339 text format.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#description ⇒ ::String
Returns An optional description of this resource.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#extension_policies ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy}
Returns Required. A map of extension names (for example, "ops-agent") to their corresponding policy configurations.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#global_resource_link ⇒ ::String
Returns Optional. Output only. [Output Only] Link to the global policy that manages this zone policy, if applicable.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#id ⇒ ::Integer
Returns Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#instance_selectors ⇒ ::Array<::Google::Cloud::Compute::V1::VmExtensionPolicyInstanceSelector>
Returns Optional. Selectors to target VMs for this policy. VMs are selected if they match any of the provided selectors (logical OR). If this list is empty, the policy applies to all VMs.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Alwayscompute#vmExtensionPolicy.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#managed_by_global ⇒ ::Boolean
Returns Optional. Output only. [Output Only] Indicates if this policy is managed by a global policy.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#name ⇒ ::String
Returns Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#priority ⇒ ::Integer
Returns Optional. Priority of this policy. Used to resolve conflicts when multiple policies apply to the same extension. The policy priority is an integer from 0 to 65535, inclusive. Lower integers indicate higher priorities. If you do not specify a priority when creating a rule, it is assigned a priority of 1000. If priorities are equal, the policy with the most recent creation timestamp takes precedence.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined fully-qualified URL for this resource.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#self_link_with_id ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource's resource id.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#state ⇒ ::String
Returns Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. Check the State enum for the list of possible values.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |
#update_timestamp ⇒ ::String
Returns Output only. [Output Only] Update timestamp inRFC3339 text format.
82950 82951 82952 82953 82954 82955 82956 82957 82958 82959 82960 82961 82962 82963 82964 82965 82966 82967 82968 82969 82970 82971 82972 82973 82974 82975 82976 82977 82978 82979 82980 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82950 class VmExtensionPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VmExtensionPolicyExtensionPolicy] class ExtensionPoliciesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Optional. Output only. [Output Only] Current state of the policy: ACTIVE or DELETING. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # The policy is active and applied to matching VMs. # Newly created VMs that match the policy will also receive the # extension policy. ACTIVE = 314_733_318 # The policy is in the process of being deleted. After the extension is # removed from all matching VMs, the policy will be deleted. DELETING = 528_602_024 # Default value. Do not use. STATE_UNSPECIFIED = 470_755_401 end end |