Class: Google::Cloud::Compute::V1::VmExtensionPolicyLabelSelector

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

A LabelSelector is applied to a VM only if it matches all the specified labels.

Defined Under Namespace

Classes: InclusionLabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#inclusion_labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. A map of key-value pairs representing VM labels. VMs must have all of the labels specified in this map to be selected (logical AND).

e.g. If the inclusion_labels are {("key1", "value1"), ("key2", "value2")}, the VM labels must contain both ("key1", "value1") and ("key2", "value2") to be selected. If the VM labels are ("key1", "value1") and ("something", "else"), it will not be selected.

If the map is empty, it's considered a match.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. A map of key-value pairs representing VM labels. VMs must have all of the labels specified in this map to be selected (logical AND).

    e.g. If the inclusion_labels are {("key1", "value1"), ("key2", "value2")}, the VM labels must contain both ("key1", "value1") and ("key2", "value2") to be selected. If the VM labels are ("key1", "value1") and ("something", "else"), it will not be selected.

    If the map is empty, it's considered a match.



81277
81278
81279
81280
81281
81282
81283
81284
81285
81286
81287
81288
81289
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81277

class VmExtensionPolicyLabelSelector
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InclusionLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end