Class: Google::Cloud::Compute::V1::VmExtensionPolicyLabelSelector
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::VmExtensionPolicyLabelSelector
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A LabelSelector is applied to a VM only if it matches all the specified labels.
Defined Under Namespace
Classes: InclusionLabelsEntry
Instance Attribute Summary collapse
Instance Attribute Details
#inclusion_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. A map of key-value pairs representing VM labels. VMs must have all of the labels specified in this map to be selected (logical AND).
e.g. If the inclusion_labels are {("key1", "value1"), ("key2",
"value2")}, the VM labels must contain both ("key1", "value1") and
("key2", "value2") to be selected. If the VM labels are ("key1",
"value1") and ("something", "else"), it will not be selected.
If the map is empty, it's considered a match.
85788 85789 85790 85791 85792 85793 85794 85795 85796 85797 85798 85799 85800 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85788 class VmExtensionPolicyLabelSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class InclusionLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |