Class: Google::Cloud::Compute::V1::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::VpnGatewayAggregatedList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: ItemsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::VpnGatewaysScopedList}
A list of VpnGateway resources.
-
#kind ⇒ ::String
Output only.
-
#next_page_token ⇒ ::String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ ::String
Output only.
-
#unreachables ⇒ ::Array<::String>
Output only.
-
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
[Output Only] Informational warning message.
Instance Attribute Details
#id ⇒ ::String
Returns [Output Only] Unique identifier for the resource; defined by the server.
81473 81474 81475 81476 81477 81478 81479 81480 81481 81482 81483 81484 81485 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81473 class VpnGatewayAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VpnGatewaysScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#items ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::VpnGatewaysScopedList}
Returns A list of VpnGateway resources.
81473 81474 81475 81476 81477 81478 81479 81480 81481 81482 81483 81484 81485 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81473 class VpnGatewayAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VpnGatewaysScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways.
81473 81474 81475 81476 81477 81478 81479 81480 81481 81482 81483 81484 81485 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81473 class VpnGatewayAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VpnGatewaysScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
81473 81474 81475 81476 81477 81478 81479 81480 81481 81482 81483 81484 81485 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81473 class VpnGatewayAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VpnGatewaysScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#self_link ⇒ ::String
Returns Output only. [Output Only] Server-defined URL for this resource.
81473 81474 81475 81476 81477 81478 81479 81480 81481 81482 81483 81484 81485 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81473 class VpnGatewayAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VpnGatewaysScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unreachables ⇒ ::Array<::String>
Returns Output only. [Output Only] Unreachable resources.
81473 81474 81475 81476 81477 81478 81479 81480 81481 81482 81483 81484 81485 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81473 class VpnGatewayAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VpnGatewaysScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#warning ⇒ ::Google::Cloud::Compute::V1::Warning
Returns [Output Only] Informational warning message.
81473 81474 81475 81476 81477 81478 81479 81480 81481 81482 81483 81484 81485 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81473 class VpnGatewayAggregatedList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::VpnGatewaysScopedList] class ItemsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |