Class: Google::Cloud::Compute::V1::VpnGatewayStatusHighAvailabilityRequirementState
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::VpnGatewayStatusHighAvailabilityRequirementState
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.
Defined Under Namespace
Modules: State, UnsatisfiedReason
Instance Attribute Summary collapse
-
#state ⇒ ::String
Indicates the high availability requirement state for the VPN connection.
-
#unsatisfied_reason ⇒ ::String
Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement.
Instance Attribute Details
#state ⇒ ::String
Returns Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Check the State enum for the list of possible values.
84289 84290 84291 84292 84293 84294 84295 84296 84297 84298 84299 84300 84301 84302 84303 84304 84305 84306 84307 84308 84309 84310 84311 84312 84313 84314 84315 84316 84317 84318 84319 84320 84321 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84289 class VpnGatewayStatusHighAvailabilityRequirementState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the high availability requirement state for the VPN connection. # Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # VPN tunnels are configured with adequate redundancy from Cloud VPN # gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP # connections, the adequate redundancy is a pre-requirement for users to # get 99.99% availability on GCP side; please note that for any # connection, end-to-end 99.99% availability is subject to proper # configuration on the peer VPN gateway. CONNECTION_REDUNDANCY_MET = 505_242_907 # VPN tunnels are not configured with adequate redundancy from the Cloud # VPN gateway to the peer gateway CONNECTION_REDUNDANCY_NOT_MET = 511_863_311 end # Indicates the reason why the VPN connection does not meet the high # availability redundancy criteria/requirement. # Valid values is INCOMPLETE_TUNNELS_COVERAGE. module UnsatisfiedReason # A value indicating that the enum field is not set. UNDEFINED_UNSATISFIED_REASON = 0 INCOMPLETE_TUNNELS_COVERAGE = 55_917_437 end end |
#unsatisfied_reason ⇒ ::String
Returns Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE. Check the UnsatisfiedReason enum for the list of possible values.
84289 84290 84291 84292 84293 84294 84295 84296 84297 84298 84299 84300 84301 84302 84303 84304 84305 84306 84307 84308 84309 84310 84311 84312 84313 84314 84315 84316 84317 84318 84319 84320 84321 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84289 class VpnGatewayStatusHighAvailabilityRequirementState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the high availability requirement state for the VPN connection. # Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # VPN tunnels are configured with adequate redundancy from Cloud VPN # gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP # connections, the adequate redundancy is a pre-requirement for users to # get 99.99% availability on GCP side; please note that for any # connection, end-to-end 99.99% availability is subject to proper # configuration on the peer VPN gateway. CONNECTION_REDUNDANCY_MET = 505_242_907 # VPN tunnels are not configured with adequate redundancy from the Cloud # VPN gateway to the peer gateway CONNECTION_REDUNDANCY_NOT_MET = 511_863_311 end # Indicates the reason why the VPN connection does not meet the high # availability redundancy criteria/requirement. # Valid values is INCOMPLETE_TUNNELS_COVERAGE. module UnsatisfiedReason # A value indicating that the enum field is not set. UNDEFINED_UNSATISFIED_REASON = 0 INCOMPLETE_TUNNELS_COVERAGE = 55_917_437 end end |