Class: Google::Cloud::Compute::V1::VpnGatewayStatusHighAvailabilityRequirementState

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.

Defined Under Namespace

Modules: State, UnsatisfiedReason

Instance Attribute Summary collapse

Instance Attribute Details

#state::String

Returns Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Check the State enum for the list of possible values.

Returns:

  • (::String)

    Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Check the State enum for the list of possible values.



83351
83352
83353
83354
83355
83356
83357
83358
83359
83360
83361
83362
83363
83364
83365
83366
83367
83368
83369
83370
83371
83372
83373
83374
83375
83376
83377
83378
83379
83380
83381
83382
83383
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83351

class VpnGatewayStatusHighAvailabilityRequirementState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the high availability requirement state for the VPN connection.
  # Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # VPN tunnels are configured with adequate redundancy from Cloud VPN
    # gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP
    # connections, the adequate redundancy is a pre-requirement for users to
    # get 99.99% availability on GCP side; please note that for any
    # connection, end-to-end 99.99% availability is subject to proper
    # configuration on the peer VPN gateway.
    CONNECTION_REDUNDANCY_MET = 505_242_907

    # VPN tunnels are not configured with adequate redundancy from the Cloud
    # VPN gateway to the peer gateway
    CONNECTION_REDUNDANCY_NOT_MET = 511_863_311
  end

  # Indicates the reason why the VPN connection does not meet the high
  # availability redundancy criteria/requirement.
  # Valid values is INCOMPLETE_TUNNELS_COVERAGE.
  module UnsatisfiedReason
    # A value indicating that the enum field is not set.
    UNDEFINED_UNSATISFIED_REASON = 0

    INCOMPLETE_TUNNELS_COVERAGE = 55_917_437
  end
end

#unsatisfied_reason::String

Returns Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE. Check the UnsatisfiedReason enum for the list of possible values.

Returns:

  • (::String)

    Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE. Check the UnsatisfiedReason enum for the list of possible values.



83351
83352
83353
83354
83355
83356
83357
83358
83359
83360
83361
83362
83363
83364
83365
83366
83367
83368
83369
83370
83371
83372
83373
83374
83375
83376
83377
83378
83379
83380
83381
83382
83383
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 83351

class VpnGatewayStatusHighAvailabilityRequirementState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the high availability requirement state for the VPN connection.
  # Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET.
  module State
    # A value indicating that the enum field is not set.
    UNDEFINED_STATE = 0

    # VPN tunnels are configured with adequate redundancy from Cloud VPN
    # gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP
    # connections, the adequate redundancy is a pre-requirement for users to
    # get 99.99% availability on GCP side; please note that for any
    # connection, end-to-end 99.99% availability is subject to proper
    # configuration on the peer VPN gateway.
    CONNECTION_REDUNDANCY_MET = 505_242_907

    # VPN tunnels are not configured with adequate redundancy from the Cloud
    # VPN gateway to the peer gateway
    CONNECTION_REDUNDANCY_NOT_MET = 511_863_311
  end

  # Indicates the reason why the VPN connection does not meet the high
  # availability redundancy criteria/requirement.
  # Valid values is INCOMPLETE_TUNNELS_COVERAGE.
  module UnsatisfiedReason
    # A value indicating that the enum field is not set.
    UNDEFINED_UNSATISFIED_REASON = 0

    INCOMPLETE_TUNNELS_COVERAGE = 55_917_437
  end
end