Class: Google::Cloud::Compute::V1::VpnGatewayStatusHighAvailabilityRequirementState
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::VpnGatewayStatusHighAvailabilityRequirementState
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.
Defined Under Namespace
Modules: State, UnsatisfiedReason
Instance Attribute Summary collapse
-
#state ⇒ ::String
Indicates the high availability requirement state for the VPN connection.
-
#unsatisfied_reason ⇒ ::String
Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement.
Instance Attribute Details
#state ⇒ ::String
Returns Indicates the high availability requirement state for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. Check the State enum for the list of possible values.
81567 81568 81569 81570 81571 81572 81573 81574 81575 81576 81577 81578 81579 81580 81581 81582 81583 81584 81585 81586 81587 81588 81589 81590 81591 81592 81593 81594 81595 81596 81597 81598 81599 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81567 class VpnGatewayStatusHighAvailabilityRequirementState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the high availability requirement state for the VPN connection. # Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # VPN tunnels are configured with adequate redundancy from Cloud VPN # gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP # connections, the adequate redundancy is a pre-requirement for users to # get 99.99% availability on GCP side; please note that for any # connection, end-to-end 99.99% availability is subject to proper # configuration on the peer VPN gateway. CONNECTION_REDUNDANCY_MET = 505_242_907 # VPN tunnels are not configured with adequate redundancy from the Cloud # VPN gateway to the peer gateway CONNECTION_REDUNDANCY_NOT_MET = 511_863_311 end # Indicates the reason why the VPN connection does not meet the high # availability redundancy criteria/requirement. # Valid values is INCOMPLETE_TUNNELS_COVERAGE. module UnsatisfiedReason # A value indicating that the enum field is not set. UNDEFINED_UNSATISFIED_REASON = 0 INCOMPLETE_TUNNELS_COVERAGE = 55_917_437 end end |
#unsatisfied_reason ⇒ ::String
Returns Indicates the reason why the VPN connection does not meet the high availability redundancy criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE. Check the UnsatisfiedReason enum for the list of possible values.
81567 81568 81569 81570 81571 81572 81573 81574 81575 81576 81577 81578 81579 81580 81581 81582 81583 81584 81585 81586 81587 81588 81589 81590 81591 81592 81593 81594 81595 81596 81597 81598 81599 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 81567 class VpnGatewayStatusHighAvailabilityRequirementState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the high availability requirement state for the VPN connection. # Valid values are CONNECTION_REDUNDANCY_MET,CONNECTION_REDUNDANCY_NOT_MET. module State # A value indicating that the enum field is not set. UNDEFINED_STATE = 0 # VPN tunnels are configured with adequate redundancy from Cloud VPN # gateway to the peer VPN gateway. For both GCP-to-non-GCP and GCP-to-GCP # connections, the adequate redundancy is a pre-requirement for users to # get 99.99% availability on GCP side; please note that for any # connection, end-to-end 99.99% availability is subject to proper # configuration on the peer VPN gateway. CONNECTION_REDUNDANCY_MET = 505_242_907 # VPN tunnels are not configured with adequate redundancy from the Cloud # VPN gateway to the peer gateway CONNECTION_REDUNDANCY_NOT_MET = 511_863_311 end # Indicates the reason why the VPN connection does not meet the high # availability redundancy criteria/requirement. # Valid values is INCOMPLETE_TUNNELS_COVERAGE. module UnsatisfiedReason # A value indicating that the enum field is not set. UNDEFINED_UNSATISFIED_REASON = 0 INCOMPLETE_TUNNELS_COVERAGE = 55_917_437 end end |