Class: Google::Cloud::Compute::V1::Warnings
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Warnings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Modules: Code
Instance Attribute Summary collapse
-
#code ⇒ ::String
[Output Only] A warning code, if applicable.
-
#data ⇒ ::Array<::Google::Cloud::Compute::V1::Data>
[Output Only] Metadata about this warning in key: value format.
-
#message ⇒ ::String
[Output Only] A human-readable description of the warning code.
Instance Attribute Details
#code ⇒ ::String
Returns [Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Check the Code enum for the list of possible values.
85063 85064 85065 85066 85067 85068 85069 85070 85071 85072 85073 85074 85075 85076 85077 85078 85079 85080 85081 85082 85083 85084 85085 85086 85087 85088 85089 85090 85091 85092 85093 85094 85095 85096 85097 85098 85099 85100 85101 85102 85103 85104 85105 85106 85107 85108 85109 85110 85111 85112 85113 85114 85115 85116 85117 85118 85119 85120 85121 85122 85123 85124 85125 85126 85127 85128 85129 85130 85131 85132 85133 85134 85135 85136 85137 85138 85139 85140 85141 85142 85143 85144 85145 85146 85147 85148 85149 85150 85151 85152 85153 85154 85155 85156 85157 85158 85159 85160 85161 85162 85163 85164 85165 85166 85167 85168 85169 85170 85171 85172 85173 85174 85175 85176 85177 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85063 class Warnings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] A warning code, if applicable. For example, Compute # Engine returns NO_RESULTS_ON_PAGE if there # are no results in the response. module Code # A value indicating that the enum field is not set. UNDEFINED_CODE = 0 # Warning about failed cleanup of transient changes made by a failed # operation. CLEANUP_FAILED = 150_308_440 # A link to a deprecated resource was created. DEPRECATED_RESOURCE_USED = 391_835_586 # When deploying and at least one of the resources has a type marked as # deprecated DEPRECATED_TYPE_USED = 346_526_230 # The user created a boot disk that is larger than image size. DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369_442_967 # When deploying and at least one of the resources has a type marked as # experimental EXPERIMENTAL_TYPE_USED = 451_954_443 # Warning that is present in an external api call EXTERNAL_API_WARNING = 175_546_307 # Warning that value of a field has been overridden. # Deprecated unused field. FIELD_VALUE_OVERRIDEN = 329_669_423 # The operation involved use of an injected kernel, which is deprecated. INJECTED_KERNELS_DEPRECATED = 417_377_419 # A WEIGHTED_MAGLEV backend service is associated with a health check that is # not of type HTTP/HTTPS/HTTP2. INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 401_542_606 # When deploying a deployment with a exceedingly large number of resources LARGE_DEPLOYMENT_WARNING = 481_440_678 # Resource can't be retrieved due to list overhead quota exceed # which captures the amount of resources filtered out by # user-defined list filter. LIST_OVERHEAD_QUOTA_EXCEED = 47_618_117 # A resource depends on a missing type MISSING_TYPE_DEPENDENCY = 344_505_463 # The route's nextHopIp address is not assigned to an instance on the # network. NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324_964_999 # The route's next hop instance cannot ip forward. NEXT_HOP_CANNOT_IP_FORWARD = 383_382_887 # The route's nextHopInstance URL refers to an instance that does not have an # ipv6 interface on the same network as the route. NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 146_748_434 # The route's nextHopInstance URL refers to an instance that does not exist. NEXT_HOP_INSTANCE_NOT_FOUND = 464_250_446 # The route's nextHopInstance URL refers to an instance that is not on the # same network as the route. NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243_758_146 # The route's next hop instance does not have a status of RUNNING. NEXT_HOP_NOT_RUNNING = 417_081_265 # Error which is not critical. We decided to continue the process despite # the mentioned error. NOT_CRITICAL_ERROR = 105_763_924 # No results are present on a particular list page. NO_RESULTS_ON_PAGE = 30_036_744 # Success is reported, but some results may be missing due to errors PARTIAL_SUCCESS = 39_966_469 # Quota information is not available to client requests (e.g: # regions.list). QUOTA_INFO_UNAVAILABLE = 304_294_182 # The user attempted to use a resource that requires a TOS they have not # accepted. REQUIRED_TOS_AGREEMENT = 3_745_539 # Warning that a resource is in use. RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496_728_641 # One or more of the resources set to auto-delete could not be deleted # because they were in use. RESOURCE_NOT_DELETED = 168_598_460 # When a resource schema validation is ignored. SCHEMA_VALIDATION_IGNORED = 275_245_642 # Instance template used in instance group manager is valid as such, but # its application does not make a lot of sense, because it allows only # single instance in instance group. SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268_305_617 # When undeclared properties in the schema are present UNDECLARED_PROPERTIES = 390_513_439 # A given scope cannot be reached. UNREACHABLE = 13_328_052 end end |
#data ⇒ ::Array<::Google::Cloud::Compute::V1::Data>
Returns [Output Only] Metadata about this warning in key: value format. For example:
"data": [ { "key": "scope", "value": "zones/us-east1-d" }.
85063 85064 85065 85066 85067 85068 85069 85070 85071 85072 85073 85074 85075 85076 85077 85078 85079 85080 85081 85082 85083 85084 85085 85086 85087 85088 85089 85090 85091 85092 85093 85094 85095 85096 85097 85098 85099 85100 85101 85102 85103 85104 85105 85106 85107 85108 85109 85110 85111 85112 85113 85114 85115 85116 85117 85118 85119 85120 85121 85122 85123 85124 85125 85126 85127 85128 85129 85130 85131 85132 85133 85134 85135 85136 85137 85138 85139 85140 85141 85142 85143 85144 85145 85146 85147 85148 85149 85150 85151 85152 85153 85154 85155 85156 85157 85158 85159 85160 85161 85162 85163 85164 85165 85166 85167 85168 85169 85170 85171 85172 85173 85174 85175 85176 85177 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85063 class Warnings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] A warning code, if applicable. For example, Compute # Engine returns NO_RESULTS_ON_PAGE if there # are no results in the response. module Code # A value indicating that the enum field is not set. UNDEFINED_CODE = 0 # Warning about failed cleanup of transient changes made by a failed # operation. CLEANUP_FAILED = 150_308_440 # A link to a deprecated resource was created. DEPRECATED_RESOURCE_USED = 391_835_586 # When deploying and at least one of the resources has a type marked as # deprecated DEPRECATED_TYPE_USED = 346_526_230 # The user created a boot disk that is larger than image size. DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369_442_967 # When deploying and at least one of the resources has a type marked as # experimental EXPERIMENTAL_TYPE_USED = 451_954_443 # Warning that is present in an external api call EXTERNAL_API_WARNING = 175_546_307 # Warning that value of a field has been overridden. # Deprecated unused field. FIELD_VALUE_OVERRIDEN = 329_669_423 # The operation involved use of an injected kernel, which is deprecated. INJECTED_KERNELS_DEPRECATED = 417_377_419 # A WEIGHTED_MAGLEV backend service is associated with a health check that is # not of type HTTP/HTTPS/HTTP2. INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 401_542_606 # When deploying a deployment with a exceedingly large number of resources LARGE_DEPLOYMENT_WARNING = 481_440_678 # Resource can't be retrieved due to list overhead quota exceed # which captures the amount of resources filtered out by # user-defined list filter. LIST_OVERHEAD_QUOTA_EXCEED = 47_618_117 # A resource depends on a missing type MISSING_TYPE_DEPENDENCY = 344_505_463 # The route's nextHopIp address is not assigned to an instance on the # network. NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324_964_999 # The route's next hop instance cannot ip forward. NEXT_HOP_CANNOT_IP_FORWARD = 383_382_887 # The route's nextHopInstance URL refers to an instance that does not have an # ipv6 interface on the same network as the route. NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 146_748_434 # The route's nextHopInstance URL refers to an instance that does not exist. NEXT_HOP_INSTANCE_NOT_FOUND = 464_250_446 # The route's nextHopInstance URL refers to an instance that is not on the # same network as the route. NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243_758_146 # The route's next hop instance does not have a status of RUNNING. NEXT_HOP_NOT_RUNNING = 417_081_265 # Error which is not critical. We decided to continue the process despite # the mentioned error. NOT_CRITICAL_ERROR = 105_763_924 # No results are present on a particular list page. NO_RESULTS_ON_PAGE = 30_036_744 # Success is reported, but some results may be missing due to errors PARTIAL_SUCCESS = 39_966_469 # Quota information is not available to client requests (e.g: # regions.list). QUOTA_INFO_UNAVAILABLE = 304_294_182 # The user attempted to use a resource that requires a TOS they have not # accepted. REQUIRED_TOS_AGREEMENT = 3_745_539 # Warning that a resource is in use. RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496_728_641 # One or more of the resources set to auto-delete could not be deleted # because they were in use. RESOURCE_NOT_DELETED = 168_598_460 # When a resource schema validation is ignored. SCHEMA_VALIDATION_IGNORED = 275_245_642 # Instance template used in instance group manager is valid as such, but # its application does not make a lot of sense, because it allows only # single instance in instance group. SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268_305_617 # When undeclared properties in the schema are present UNDECLARED_PROPERTIES = 390_513_439 # A given scope cannot be reached. UNREACHABLE = 13_328_052 end end |
#message ⇒ ::String
Returns [Output Only] A human-readable description of the warning code.
85063 85064 85065 85066 85067 85068 85069 85070 85071 85072 85073 85074 85075 85076 85077 85078 85079 85080 85081 85082 85083 85084 85085 85086 85087 85088 85089 85090 85091 85092 85093 85094 85095 85096 85097 85098 85099 85100 85101 85102 85103 85104 85105 85106 85107 85108 85109 85110 85111 85112 85113 85114 85115 85116 85117 85118 85119 85120 85121 85122 85123 85124 85125 85126 85127 85128 85129 85130 85131 85132 85133 85134 85135 85136 85137 85138 85139 85140 85141 85142 85143 85144 85145 85146 85147 85148 85149 85150 85151 85152 85153 85154 85155 85156 85157 85158 85159 85160 85161 85162 85163 85164 85165 85166 85167 85168 85169 85170 85171 85172 85173 85174 85175 85176 85177 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85063 class Warnings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] A warning code, if applicable. For example, Compute # Engine returns NO_RESULTS_ON_PAGE if there # are no results in the response. module Code # A value indicating that the enum field is not set. UNDEFINED_CODE = 0 # Warning about failed cleanup of transient changes made by a failed # operation. CLEANUP_FAILED = 150_308_440 # A link to a deprecated resource was created. DEPRECATED_RESOURCE_USED = 391_835_586 # When deploying and at least one of the resources has a type marked as # deprecated DEPRECATED_TYPE_USED = 346_526_230 # The user created a boot disk that is larger than image size. DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 369_442_967 # When deploying and at least one of the resources has a type marked as # experimental EXPERIMENTAL_TYPE_USED = 451_954_443 # Warning that is present in an external api call EXTERNAL_API_WARNING = 175_546_307 # Warning that value of a field has been overridden. # Deprecated unused field. FIELD_VALUE_OVERRIDEN = 329_669_423 # The operation involved use of an injected kernel, which is deprecated. INJECTED_KERNELS_DEPRECATED = 417_377_419 # A WEIGHTED_MAGLEV backend service is associated with a health check that is # not of type HTTP/HTTPS/HTTP2. INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB = 401_542_606 # When deploying a deployment with a exceedingly large number of resources LARGE_DEPLOYMENT_WARNING = 481_440_678 # Resource can't be retrieved due to list overhead quota exceed # which captures the amount of resources filtered out by # user-defined list filter. LIST_OVERHEAD_QUOTA_EXCEED = 47_618_117 # A resource depends on a missing type MISSING_TYPE_DEPENDENCY = 344_505_463 # The route's nextHopIp address is not assigned to an instance on the # network. NEXT_HOP_ADDRESS_NOT_ASSIGNED = 324_964_999 # The route's next hop instance cannot ip forward. NEXT_HOP_CANNOT_IP_FORWARD = 383_382_887 # The route's nextHopInstance URL refers to an instance that does not have an # ipv6 interface on the same network as the route. NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE = 146_748_434 # The route's nextHopInstance URL refers to an instance that does not exist. NEXT_HOP_INSTANCE_NOT_FOUND = 464_250_446 # The route's nextHopInstance URL refers to an instance that is not on the # same network as the route. NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 243_758_146 # The route's next hop instance does not have a status of RUNNING. NEXT_HOP_NOT_RUNNING = 417_081_265 # Error which is not critical. We decided to continue the process despite # the mentioned error. NOT_CRITICAL_ERROR = 105_763_924 # No results are present on a particular list page. NO_RESULTS_ON_PAGE = 30_036_744 # Success is reported, but some results may be missing due to errors PARTIAL_SUCCESS = 39_966_469 # Quota information is not available to client requests (e.g: # regions.list). QUOTA_INFO_UNAVAILABLE = 304_294_182 # The user attempted to use a resource that requires a TOS they have not # accepted. REQUIRED_TOS_AGREEMENT = 3_745_539 # Warning that a resource is in use. RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 496_728_641 # One or more of the resources set to auto-delete could not be deleted # because they were in use. RESOURCE_NOT_DELETED = 168_598_460 # When a resource schema validation is ignored. SCHEMA_VALIDATION_IGNORED = 275_245_642 # Instance template used in instance group manager is valid as such, but # its application does not make a lot of sense, because it allows only # single instance in instance group. SINGLE_INSTANCE_PROPERTY_TEMPLATE = 268_305_617 # When undeclared properties in the schema are present UNDECLARED_PROPERTIES = 390_513_439 # A given scope cannot be reached. UNREACHABLE = 13_328_052 end end |