Class: Google::Cloud::Compute::V1::WeightedBackendService
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::WeightedBackendService
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
In contrast to a single BackendService in HttpRouteAction to which all matching traffic is directed to,WeightedBackendService allows traffic to be split across multiple backend services. The volume of traffic for each backend service is proportional to the weight specified in each WeightedBackendService
Instance Attribute Summary collapse
-
#backend_service ⇒ ::String
The full or partial URL to the default BackendService resource.
-
#header_action ⇒ ::Google::Cloud::Compute::V1::HttpHeaderAction
Specifies changes to request and response headers that need to take effect for the selected backendService.
-
#weight ⇒ ::Integer
Specifies the fraction of traffic sent to a backend service, computed asweight / (sum of all weightedBackendService weights in routeAction).
Instance Attribute Details
#backend_service ⇒ ::String
Returns The full or partial URL to the default BackendService resource. Before forwarding the request to backendService, the load balancer applies any relevant headerActions specified as part of thisbackendServiceWeight.
82494 82495 82496 82497 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82494 class WeightedBackendService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#header_action ⇒ ::Google::Cloud::Compute::V1::HttpHeaderAction
Returns Specifies changes to request and response headers that need to take effect for the selected backendService.
headerAction specified here take effect beforeheaderAction in the enclosing HttpRouteRule,PathMatcher and UrlMap.
headerAction is not supported for load balancers that have their loadBalancingScheme set to EXTERNAL.
Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true.
82494 82495 82496 82497 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82494 class WeightedBackendService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#weight ⇒ ::Integer
Returns Specifies the fraction of traffic sent to a backend service, computed asweight / (sum of all weightedBackendService weights in routeAction).
The selection of a backend service is determined only for new traffic. Once a user's request has been directed to a backend service, subsequent requests are sent to the same backend service as determined by the backend service's session affinity policy. Don't configure session affinity if you're using weighted traffic splitting. If you do, the weighted traffic splitting configuration takes precedence.
The value must be from 0 to 1000.
82494 82495 82496 82497 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82494 class WeightedBackendService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |