Class: Google::Cloud::Compute::V1::WireGroupEndpoint
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::WireGroupEndpoint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
A logical endpoint for the wire group. An endpoint represents a metro that contains redundant Interconnect connections. A wire group is created between two endpoints.
Defined Under Namespace
Classes: InterconnectsEntry
Instance Attribute Summary collapse
-
#interconnects ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::WireGroupEndpointInterconnect}
A map that contains the redundant Interconnect connections.
Instance Attribute Details
#interconnects ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Compute::V1::WireGroupEndpointInterconnect}
Returns A map that contains the redundant Interconnect connections. Specify key-value pairs for the map as follows:
- Key: an RFC1035 user-specified label.
- Value: an Interconnect object.
82615 82616 82617 82618 82619 82620 82621 82622 82623 82624 82625 82626 82627 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82615 class WireGroupEndpoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Compute::V1::WireGroupEndpointInterconnect] class InterconnectsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |