Class: Google::Cloud::Compute::V1::WireProperties
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::WireProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The properties of a wire.
Defined Under Namespace
Modules: BandwidthAllocation, FaultResponse
Instance Attribute Summary collapse
-
#bandwidth_allocation ⇒ ::String
The configuration of the bandwidth allocation, one of the following:.
-
#bandwidth_unmetered ⇒ ::Integer
The unmetered bandwidth in Gigabits per second, using decimal units.
-
#fault_response ⇒ ::String
Response when a fault is detected in a pseudowire:.
Instance Attribute Details
#bandwidth_allocation ⇒ ::String
Returns The configuration of the bandwidth allocation, one of the following:
- ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
- SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures one unmetered bandwidth allocation for the wire group. The unmetered bandwidth is divided equally across each wire in the group, but dynamic throttling reallocates unused unmetered bandwidth from unused or underused wires to other wires in the group. Check the BandwidthAllocation enum for the list of possible values.
84534 84535 84536 84537 84538 84539 84540 84541 84542 84543 84544 84545 84546 84547 84548 84549 84550 84551 84552 84553 84554 84555 84556 84557 84558 84559 84560 84561 84562 84563 84564 84565 84566 84567 84568 84569 84570 84571 84572 84573 84574 84575 84576 84577 84578 84579 84580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84534 class WireProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of the bandwidth allocation, one of the following: # # - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation # (and associated charges) for each wire in the group. # - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures # one unmetered bandwidth allocation for the wire group. The unmetered # bandwidth is divided equally across each wire in the group, but dynamic # throttling reallocates unused unmetered bandwidth from unused or underused # wires to other wires in the group. module BandwidthAllocation # A value indicating that the enum field is not set. UNDEFINED_BANDWIDTH_ALLOCATION = 0 # Configures a separate unmetered bandwidth allocation (and associated # charges) for each wire in the group. ALLOCATE_PER_WIRE = 358_730_057 # This is the default behavior. Configures one unmetered bandwidth # allocation for the wire group. The unmetered bandwidth is divided equally # across each wire in the group, but dynamic throttling reallocates unused # unmetered bandwidth from unused or underused wires to other wires in the # group. SHARED_WITH_WIRE_GROUP = 286_454_628 end # Response when a fault is detected in a pseudowire: # # - NONE: default. # - DISABLE_PORT: set the port line protocol down when inline probes # detect a fault. This setting is only permitted on port mode # pseudowires. module FaultResponse # A value indicating that the enum field is not set. UNDEFINED_FAULT_RESPONSE = 0 # Set the port line protocol down when inline probes detect a fault. This # setting is only permitted on port mode pseudowires. DISABLE_PORT = 287_086_488 # Default. NONE = 2_402_104 end end |
#bandwidth_unmetered ⇒ ::Integer
Returns The unmetered bandwidth in Gigabits per second, using decimal units. 10
is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0.
84534 84535 84536 84537 84538 84539 84540 84541 84542 84543 84544 84545 84546 84547 84548 84549 84550 84551 84552 84553 84554 84555 84556 84557 84558 84559 84560 84561 84562 84563 84564 84565 84566 84567 84568 84569 84570 84571 84572 84573 84574 84575 84576 84577 84578 84579 84580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84534 class WireProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of the bandwidth allocation, one of the following: # # - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation # (and associated charges) for each wire in the group. # - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures # one unmetered bandwidth allocation for the wire group. The unmetered # bandwidth is divided equally across each wire in the group, but dynamic # throttling reallocates unused unmetered bandwidth from unused or underused # wires to other wires in the group. module BandwidthAllocation # A value indicating that the enum field is not set. UNDEFINED_BANDWIDTH_ALLOCATION = 0 # Configures a separate unmetered bandwidth allocation (and associated # charges) for each wire in the group. ALLOCATE_PER_WIRE = 358_730_057 # This is the default behavior. Configures one unmetered bandwidth # allocation for the wire group. The unmetered bandwidth is divided equally # across each wire in the group, but dynamic throttling reallocates unused # unmetered bandwidth from unused or underused wires to other wires in the # group. SHARED_WITH_WIRE_GROUP = 286_454_628 end # Response when a fault is detected in a pseudowire: # # - NONE: default. # - DISABLE_PORT: set the port line protocol down when inline probes # detect a fault. This setting is only permitted on port mode # pseudowires. module FaultResponse # A value indicating that the enum field is not set. UNDEFINED_FAULT_RESPONSE = 0 # Set the port line protocol down when inline probes detect a fault. This # setting is only permitted on port mode pseudowires. DISABLE_PORT = 287_086_488 # Default. NONE = 2_402_104 end end |
#fault_response ⇒ ::String
Returns Response when a fault is detected in a pseudowire:
- NONE: default.
- DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires. Check the FaultResponse enum for the list of possible values.
84534 84535 84536 84537 84538 84539 84540 84541 84542 84543 84544 84545 84546 84547 84548 84549 84550 84551 84552 84553 84554 84555 84556 84557 84558 84559 84560 84561 84562 84563 84564 84565 84566 84567 84568 84569 84570 84571 84572 84573 84574 84575 84576 84577 84578 84579 84580 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 84534 class WireProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of the bandwidth allocation, one of the following: # # - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation # (and associated charges) for each wire in the group. # - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures # one unmetered bandwidth allocation for the wire group. The unmetered # bandwidth is divided equally across each wire in the group, but dynamic # throttling reallocates unused unmetered bandwidth from unused or underused # wires to other wires in the group. module BandwidthAllocation # A value indicating that the enum field is not set. UNDEFINED_BANDWIDTH_ALLOCATION = 0 # Configures a separate unmetered bandwidth allocation (and associated # charges) for each wire in the group. ALLOCATE_PER_WIRE = 358_730_057 # This is the default behavior. Configures one unmetered bandwidth # allocation for the wire group. The unmetered bandwidth is divided equally # across each wire in the group, but dynamic throttling reallocates unused # unmetered bandwidth from unused or underused wires to other wires in the # group. SHARED_WITH_WIRE_GROUP = 286_454_628 end # Response when a fault is detected in a pseudowire: # # - NONE: default. # - DISABLE_PORT: set the port line protocol down when inline probes # detect a fault. This setting is only permitted on port mode # pseudowires. module FaultResponse # A value indicating that the enum field is not set. UNDEFINED_FAULT_RESPONSE = 0 # Set the port line protocol down when inline probes detect a fault. This # setting is only permitted on port mode pseudowires. DISABLE_PORT = 287_086_488 # Default. NONE = 2_402_104 end end |