Class: Google::Cloud::Compute::V1::WireProperties
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::WireProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
The properties of a wire.
Defined Under Namespace
Modules: BandwidthAllocation, FaultResponse
Instance Attribute Summary collapse
-
#bandwidth_allocation ⇒ ::String
The configuration of the bandwidth allocation, one of the following:.
-
#bandwidth_unmetered ⇒ ::Integer
The unmetered bandwidth in Gigabits per second, using decimal units.
-
#fault_response ⇒ ::String
Response when a fault is detected in a pseudowire:.
Instance Attribute Details
#bandwidth_allocation ⇒ ::String
Returns The configuration of the bandwidth allocation, one of the following:
- ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
- SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures one unmetered bandwidth allocation for the wire group. The unmetered bandwidth is divided equally across each wire in the group, but dynamic throttling reallocates unused unmetered bandwidth from unused or underused wires to other wires in the group. Check the BandwidthAllocation enum for the list of possible values.
82750 82751 82752 82753 82754 82755 82756 82757 82758 82759 82760 82761 82762 82763 82764 82765 82766 82767 82768 82769 82770 82771 82772 82773 82774 82775 82776 82777 82778 82779 82780 82781 82782 82783 82784 82785 82786 82787 82788 82789 82790 82791 82792 82793 82794 82795 82796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82750 class WireProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of the bandwidth allocation, one of the following: # # - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation # (and associated charges) for each wire in the group. # - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures # one unmetered bandwidth allocation for the wire group. The unmetered # bandwidth is divided equally across each wire in the group, but dynamic # throttling reallocates unused unmetered bandwidth from unused or underused # wires to other wires in the group. module BandwidthAllocation # A value indicating that the enum field is not set. UNDEFINED_BANDWIDTH_ALLOCATION = 0 # Configures a separate unmetered bandwidth allocation (and associated # charges) for each wire in the group. ALLOCATE_PER_WIRE = 358_730_057 # This is the default behavior. Configures one unmetered bandwidth # allocation for the wire group. The unmetered bandwidth is divided equally # across each wire in the group, but dynamic throttling reallocates unused # unmetered bandwidth from unused or underused wires to other wires in the # group. SHARED_WITH_WIRE_GROUP = 286_454_628 end # Response when a fault is detected in a pseudowire: # # - NONE: default. # - DISABLE_PORT: set the port line protocol down when inline probes # detect a fault. This setting is only permitted on port mode # pseudowires. module FaultResponse # A value indicating that the enum field is not set. UNDEFINED_FAULT_RESPONSE = 0 # Set the port line protocol down when inline probes detect a fault. This # setting is only permitted on port mode pseudowires. DISABLE_PORT = 287_086_488 # Default. NONE = 2_402_104 end end |
#bandwidth_unmetered ⇒ ::Integer
Returns The unmetered bandwidth in Gigabits per second, using decimal units. 10
is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0.
82750 82751 82752 82753 82754 82755 82756 82757 82758 82759 82760 82761 82762 82763 82764 82765 82766 82767 82768 82769 82770 82771 82772 82773 82774 82775 82776 82777 82778 82779 82780 82781 82782 82783 82784 82785 82786 82787 82788 82789 82790 82791 82792 82793 82794 82795 82796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82750 class WireProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of the bandwidth allocation, one of the following: # # - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation # (and associated charges) for each wire in the group. # - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures # one unmetered bandwidth allocation for the wire group. The unmetered # bandwidth is divided equally across each wire in the group, but dynamic # throttling reallocates unused unmetered bandwidth from unused or underused # wires to other wires in the group. module BandwidthAllocation # A value indicating that the enum field is not set. UNDEFINED_BANDWIDTH_ALLOCATION = 0 # Configures a separate unmetered bandwidth allocation (and associated # charges) for each wire in the group. ALLOCATE_PER_WIRE = 358_730_057 # This is the default behavior. Configures one unmetered bandwidth # allocation for the wire group. The unmetered bandwidth is divided equally # across each wire in the group, but dynamic throttling reallocates unused # unmetered bandwidth from unused or underused wires to other wires in the # group. SHARED_WITH_WIRE_GROUP = 286_454_628 end # Response when a fault is detected in a pseudowire: # # - NONE: default. # - DISABLE_PORT: set the port line protocol down when inline probes # detect a fault. This setting is only permitted on port mode # pseudowires. module FaultResponse # A value indicating that the enum field is not set. UNDEFINED_FAULT_RESPONSE = 0 # Set the port line protocol down when inline probes detect a fault. This # setting is only permitted on port mode pseudowires. DISABLE_PORT = 287_086_488 # Default. NONE = 2_402_104 end end |
#fault_response ⇒ ::String
Returns Response when a fault is detected in a pseudowire:
- NONE: default.
- DISABLE_PORT: set the port line protocol down when inline probes detect a fault. This setting is only permitted on port mode pseudowires. Check the FaultResponse enum for the list of possible values.
82750 82751 82752 82753 82754 82755 82756 82757 82758 82759 82760 82761 82762 82763 82764 82765 82766 82767 82768 82769 82770 82771 82772 82773 82774 82775 82776 82777 82778 82779 82780 82781 82782 82783 82784 82785 82786 82787 82788 82789 82790 82791 82792 82793 82794 82795 82796 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82750 class WireProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration of the bandwidth allocation, one of the following: # # - ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation # (and associated charges) for each wire in the group. # - SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures # one unmetered bandwidth allocation for the wire group. The unmetered # bandwidth is divided equally across each wire in the group, but dynamic # throttling reallocates unused unmetered bandwidth from unused or underused # wires to other wires in the group. module BandwidthAllocation # A value indicating that the enum field is not set. UNDEFINED_BANDWIDTH_ALLOCATION = 0 # Configures a separate unmetered bandwidth allocation (and associated # charges) for each wire in the group. ALLOCATE_PER_WIRE = 358_730_057 # This is the default behavior. Configures one unmetered bandwidth # allocation for the wire group. The unmetered bandwidth is divided equally # across each wire in the group, but dynamic throttling reallocates unused # unmetered bandwidth from unused or underused wires to other wires in the # group. SHARED_WITH_WIRE_GROUP = 286_454_628 end # Response when a fault is detected in a pseudowire: # # - NONE: default. # - DISABLE_PORT: set the port line protocol down when inline probes # detect a fault. This setting is only permitted on port mode # pseudowires. module FaultResponse # A value indicating that the enum field is not set. UNDEFINED_FAULT_RESPONSE = 0 # Set the port line protocol down when inline probes detect a fault. This # setting is only permitted on port mode pseudowires. DISABLE_PORT = 287_086_488 # Default. NONE = 2_402_104 end end |