Class: Google::Cloud::Compute::V1::XpnResourceId
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::XpnResourceId
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Service resource (a.k.a service project) ID.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#id ⇒ ::String
The ID of the service resource.
-
#type ⇒ ::String
The type of the service resource.
Instance Attribute Details
#id ⇒ ::String
Returns The ID of the service resource. In the case of projects, this field supports project id (e.g., my-project-123) and project number (e.g. 12345678).
82903 82904 82905 82906 82907 82908 82909 82910 82911 82912 82913 82914 82915 82916 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82903 class XpnResourceId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the service resource. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PROJECT = 408_671_993 XPN_RESOURCE_TYPE_UNSPECIFIED = 151_607_034 end end |
#type ⇒ ::String
Returns The type of the service resource. Check the Type enum for the list of possible values.
82903 82904 82905 82906 82907 82908 82909 82910 82911 82912 82913 82914 82915 82916 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 82903 class XpnResourceId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the service resource. module Type # A value indicating that the enum field is not set. UNDEFINED_TYPE = 0 PROJECT = 408_671_993 XPN_RESOURCE_TYPE_UNSPECIFIED = 151_607_034 end end |