Class: Google::Cloud::Compute::V1::Zone

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/compute/v1/compute.rb

Overview

Represents a Zone resource.

A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-b is located in theus-east1 region. For more information, readRegions and Zones.

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Attribute Details

#available_cpu_platforms::Array<::String>

Returns [Output Only] Available cpu/platform selections for the zone.

Returns:

  • (::Array<::String>)

    [Output Only] Available cpu/platform selections for the zone.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#creation_timestamp::String

Returns [Output Only] Creation timestamp inRFC3339 text format.

Returns:

  • (::String)

    [Output Only] Creation timestamp inRFC3339 text format.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#deprecated::Google::Cloud::Compute::V1::DeprecationStatus

Returns [Output Only] The deprecation status associated with this zone.

Returns:



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#description::String

Returns [Output Only] Textual description of the resource.

Returns:

  • (::String)

    [Output Only] Textual description of the resource.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#id::Integer

Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.

Returns:

  • (::Integer)

    [Output Only] The unique identifier for the resource. This identifier is defined by the server.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#kind::String

Returns Output only. [Output Only] Type of the resource. Always compute#zone for zones.

Returns:

  • (::String)

    Output only. [Output Only] Type of the resource. Always compute#zone for zones.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#name::String

Returns [Output Only] Name of the resource.

Returns:

  • (::String)

    [Output Only] Name of the resource.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#region::String

Returns [Output Only] Full URL reference to the region which hosts the zone.

Returns:

  • (::String)

    [Output Only] Full URL reference to the region which hosts the zone.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#resource_status::Google::Cloud::Compute::V1::ZoneResourceStatus



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

Returns [Output Only] Server-defined URL for the resource.

Returns:

  • (::String)

    [Output Only] Server-defined URL for the resource.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#status::String

Returns [Output Only] Status of the zone, either UP orDOWN. Check the Status enum for the list of possible values.

Returns:

  • (::String)

    [Output Only] Status of the zone, either UP orDOWN. Check the Status enum for the list of possible values.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end

#supports_pzs::Boolean

Returns Output only. [Output Only] Reserved for future use.

Returns:

  • (::Boolean)

    Output only. [Output Only] Reserved for future use.



85684
85685
85686
85687
85688
85689
85690
85691
85692
85693
85694
85695
85696
85697
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85684

class Zone
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # [Output Only] Status of the zone, either UP orDOWN.
  module Status
    # A value indicating that the enum field is not set.
    UNDEFINED_STATUS = 0

    DOWN = 2_104_482

    UP = 2715
  end
end