Class: Google::Cloud::Compute::V1::Zone
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::Zone
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Overview
Represents a Zone resource.
A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-b is located in theus-east1 region. For more information, readRegions and Zones.
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#available_cpu_platforms ⇒ ::Array<::String>
[Output Only] Available cpu/platform selections for the zone.
-
#creation_timestamp ⇒ ::String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ ::Google::Cloud::Compute::V1::DeprecationStatus
[Output Only] The deprecation status associated with this zone.
-
#description ⇒ ::String
[Output Only] Textual description of the resource.
-
#id ⇒ ::Integer
[Output Only] The unique identifier for the resource.
-
#kind ⇒ ::String
Output only.
-
#name ⇒ ::String
[Output Only] Name of the resource.
-
#region ⇒ ::String
[Output Only] Full URL reference to the region which hosts the zone.
- #resource_status ⇒ ::Google::Cloud::Compute::V1::ZoneResourceStatus
-
#self_link ⇒ ::String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ ::String
[Output Only] Status of the zone, either UP orDOWN.
-
#supports_pzs ⇒ ::Boolean
Output only.
Instance Attribute Details
#available_cpu_platforms ⇒ ::Array<::String>
Returns [Output Only] Available cpu/platform selections for the zone.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#creation_timestamp ⇒ ::String
Returns [Output Only] Creation timestamp inRFC3339 text format.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#deprecated ⇒ ::Google::Cloud::Compute::V1::DeprecationStatus
Returns [Output Only] The deprecation status associated with this zone.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#description ⇒ ::String
Returns [Output Only] Textual description of the resource.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#id ⇒ ::Integer
Returns [Output Only] The unique identifier for the resource. This identifier is defined by the server.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#kind ⇒ ::String
Returns Output only. [Output Only] Type of the resource. Always compute#zone for zones.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#name ⇒ ::String
Returns [Output Only] Name of the resource.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#region ⇒ ::String
Returns [Output Only] Full URL reference to the region which hosts the zone.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#resource_status ⇒ ::Google::Cloud::Compute::V1::ZoneResourceStatus
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#self_link ⇒ ::String
Returns [Output Only] Server-defined URL for the resource.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#status ⇒ ::String
Returns [Output Only] Status of the zone, either UP orDOWN. Check the Status enum for the list of possible values.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |
#supports_pzs ⇒ ::Boolean
Returns Output only. [Output Only] Reserved for future use.
87473 87474 87475 87476 87477 87478 87479 87480 87481 87482 87483 87484 87485 87486 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 87473 class Zone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [Output Only] Status of the zone, either UP orDOWN. module Status # A value indicating that the enum field is not set. UNDEFINED_STATUS = 0 DOWN = 2_104_482 UP = 2715 end end |