Class: Google::Cloud::Compute::V1::ZoneSetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Compute::V1::ZoneSetLabelsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/compute/v1/compute.rb
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#label_fingerprint ⇒ ::String
The fingerprint of the previous set of labels for this resource, used to detect conflicts.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
The labels to set for this resource.
Instance Attribute Details
#label_fingerprint ⇒ ::String
Returns The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint.
85746 85747 85748 85749 85750 85751 85752 85753 85754 85755 85756 85757 85758 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85746 class ZoneSetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The labels to set for this resource.
85746 85747 85748 85749 85750 85751 85752 85753 85754 85755 85756 85757 85758 |
# File 'proto_docs/google/cloud/compute/v1/compute.rb', line 85746 class ZoneSetLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |